(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2528660,      63002]*)
(*NotebookOutlinePosition[   2529341,      63025]*)
(*  CellTagsIndexPosition[   2529297,      63021]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Demonstrating the performance of transparent acceleration of \
matrix multiply with ", "Title",
    FontSize->18],
  StyleBox["Mathematica", "Title",
    FontSize->18,
    FontSlant->"Italic"],
  StyleBox[".  \n", "Title",
    FontSize->18],
  StyleBox["\nFirst, a simple function to compute the GFLOPS, or performance, \
of a matrix multiply of a square matrix of rank ", "Text",
    FontSize->18],
  StyleBox["n:", "Text",
    FontSize->18,
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[StyleBox["gflops[n_]:=\nFirst[{a=Table[1.,{n},{n}];\n\
t=First[AbsoluteTiming[a.a;]]/. Second->1;\n(2*(n^3)/1000000000)/t}]",
  FontSize->18]], "Input"],

Cell[TextData[StyleBox["gflops[5700]",
  FontSize->18]], "Input"],

Cell[BoxData[
    StyleBox["38.0",
      FontSize->18]], "Input"],

Cell[TextData[StyleBox["Using this function to generate a graph of \
performance:",
  FontSize->18]], "Text"],

Cell[CellGroupData[{

Cell["\<\
score=Table[0.,{64}];
Do[{score[[i]]=gflops[i*64.]; 
\tListPlot[score,PlotJoined\[Rule]True, PlotRange\[Rule]{0,30.0}, 
 \t AxesLabel\[Rule]{\"Matrix Size\", \"GFLOPS\"}, 
 \t ImageSize->72 6,
  \tGridLines\[Rule]{None, Automatic}, 
  \tTicks-> {{{1,\"64\"},{12,\"768\"},{24,\"1536\"},{36,\"2304\"}, {48,\"3072\
\"}, {60, \"3840\"}},Automatic}]    },{i, 64.}]\
\>", "Input",
  FontSize->18],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 0 L
.06845 0 L
.08333 0 L
.09821 0 L
.1131 0 L
.12798 0 L
.14286 0 L
.15774 0 L
.17262 0 L
.1875 0 L
.20238 0 L
.21726 0 L
.23214 0 L
.24702 0 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
0000000b0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903oool01@000000oooo
0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`0000050?ooo`00
503oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000<P3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D000000?ooo`000000oooo000000050?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`070000003oool0
oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`00503oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0?l0ooooC@3oool2000000030?ooo`000000000000<0oooo
0P0000030?ooo`@000000P3oool00`000000oooo0000000200000080oooo0P0000020?ooo`800000
00<0oooo000000000000203oool00`000000oooo0?ooo`040?ooo`8000000`3oool4000000<0oooo
0P0000050?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooCP3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool06`3oool3000001H0oooo
000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooomM0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooU03oool001@0oooo0P0000030?oo
o`030000003oool0oooo0?l0ooooU@3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0
ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
3@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000/0oooo0P00
07l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo000:0?ooo`<000001`3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0
ooooVP3oool000X0oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3o0?oooiX0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P0007l00`000000
001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3000000L0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool00`000000oooo0?oo
o`020?ooo`80001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001P3oool0
10000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool3
000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?oo
o`040000003oool0oooo0?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00103oool4000000<0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3o
ool000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0oooo0?l0ooooVP3oool000D0oooo00<000000?ooo`3oool00P3oool010000000001o0000O`00
00060000O`<00000o`0007m;0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3o
ool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo0?l0ooooVP3oool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`80001o00<000000000O`0007l0100007l30000
0?l0001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000030?ooo`@000001P3oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?oo
o`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?oo
o`3oool000000P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00050?oo
o`8000000`3oool010000000oooo0?ooo`00003o0?oooj<0oooo00070?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`00103oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000?l0ooooX`3oool000D0oooo0P0000040?ooo`800000o`3ooonT
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00103oool200000080oooo0`0000030?ooo`D00000
0`3oool200000080oooo0`0000040?ooo`<00000o`3ooon=0?ooo`000`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000o`3ooon<
0?ooo`000`3oool010000000oooo0000000000020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`<000001P3oool00`000000oooo0?oo
o`3o0?ooohX0oooo00030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000
o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0o`3ooon=0?ooo`00103oool200000080oooo1@000000103o
ool000000000000000050?ooo`8000000P3oool4000000@0oooo0`00003o0?oooh`0oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 0 L
.08333 0 L
.09821 0 L
.1131 0 L
.12798 0 L
.14286 0 L
.15774 0 L
.17262 0 L
.1875 0 L
.20238 0 L
.21726 0 L
.23214 0 L
.24702 0 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooA`3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0?l0ooooA`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0o`3ooomE0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0
ooooS@3oool001@0oooo0P0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
o`3ooon=0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3ooon=0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000?l0ooooT@3oool001@0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00003o0?oooi40oooo000D0?ooo`800000
1`3oool00`000000oooo0000003o0?oooi40oooo000D0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`000000o`3ooonA0?ooo`00503oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0?l0ooooT03oool001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oo
oi00oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`002P3oool3000000L0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0?l0ooooVP3oool000/0oooo0P0007l00`000000001o0000O`040000O`<00000o`00
07m;0000Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo000:0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`002P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooVP3oool000X0oooo100000060?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000`3oool2000000L0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0?l0ooooVP3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool3000000<0oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000
003oool0oooo0080oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<000000000O`0007l01000
07l300000?l0001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool3000000<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`040000003oool0oooo0?ooo`@000001P3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool4000000<0oooo0P00
00070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo00<00000
0?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000o`0007m;0000Odl0oooo0006
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P00
00040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0
ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`030?oo
o`80001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001P3oool010000000
oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooVP3oool000D0
oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P0007l00`000000001o0000O`04
0000O`<00000o`0007m;0000Odl0oooo00050?ooo`8000000`3oool010000000oooo0?ooo`00003o
0?oooj<0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooonQ
0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0ooooX`3o
ool000D0oooo0P0000040?ooo`800000o`3ooonT0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
103oool200000080oooo0`0000030?ooo`D000000`3oool200000080oooo0`0000040?ooo`<00000
o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`000`3oool010000000oooo000000000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooohX0oooo00030?ooo`030000003oool0
oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000030?ooo`800000o`3ooon=0?ooo`000`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooon=
0?ooo`00103oool200000080oooo1@000000103oool000000000000000050?ooo`8000000P3oool4
000000@0oooo0`00003o0?oooh`0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 0 L
.09821 0 L
.1131 0 L
.12798 0 L
.14286 0 L
.15774 0 L
.17262 0 L
.1875 0 L
.20238 0 L
.21726 0 L
.23214 0 L
.24702 0 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo@@3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0?l0oooo@P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0o`3ooom@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0
ooooQ`3oool001@0oooo0P0000030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
o`3ooon70?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0o`3ooon70?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0o`3ooon70?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooon80?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooon80?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
o`3ooon80?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0o`3ooon80?ooo`00503oool2000000L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`3o0?ooohP0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3o0?ooohP0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooohP0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooohT0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3o0?ooohT0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`3o0?ooohT0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`3o0?ooohT0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooR@3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooR@3oool001@0oooo00<0
00000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000?l0ooooS03oool001@0oooo00<0
00000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000?l0ooooS03oool001@0oooo00<0
00000?ooo`3oool02P3oool010000000oooo0?ooo`00003o0?oooh`0oooo000D0?ooo`030000003o
ool0oooo00X0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`00503oool00`000000oooo0?oo
o`0:0?ooo`040000003oool0oooo00000?l0ooooS03oool001@0oooo0P00000<0?ooo`030000003o
ool000000?l0ooooS03oool001@0oooo00<000000?ooo`3oool02`3oool200000?l0ooooS@3oool0
01@0oooo00<000000?ooo`3oool02`3oool200000?l0ooooS@3oool001@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`3o0?oooh/0oooo000D0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0o`3ooon;0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool0
00/0oooo0P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo000:0?ooo`<0
00001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo000:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0?l0ooooVP3oool000X0oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P00
07l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3o
ool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000003oool0oooo0080oooo0P000007
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3o
ool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool00`00
0000oooo0?ooo`020?ooo`80001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?oo
o`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00103oool3000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooiX0
oooo00060?ooo`040000003oool0oooo0?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool20000
0?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00103oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
0?l0ooooVP3oool000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo0?l0ooooVP3oool000D0oooo00<000000?ooo`3oool00P3oool010000000
001o0000O`0000060000O`<00000o`0007m;0000Odl0oooo00060?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000L0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000040?ooo`8000001`3oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`80001o00<000000000O`0007l0
100007l300000?l0001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000030?ooo`@000001P3o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo
0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo
00@000000?ooo`3oool000000P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0
oooo00050?ooo`8000000`3oool010000000oooo0?ooo`00003o0?oooj<0oooo00070?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`00103oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000?l0ooooX`3oool000D0oooo0P0000040?ooo`80
0000o`3ooonT0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00103oool200000080oooo0`000003
0?ooo`D000000`3oool200000080oooo0`0000040?ooo`<00000o`3ooon=0?ooo`000`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
0000o`3ooon<0?ooo`000`3oool010000000oooo0000000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`<000001P3oool00`00
0000oooo0?ooo`3o0?ooohX0oooo00030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000003
0?ooo`800000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooon=0?ooo`00103oool200000080oooo
1@000000103oool000000000000000050?ooo`8000000P3oool4000000@0oooo0`00003o0?oooh`0
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 0 L
.1131 0 L
.12798 0 L
.14286 0 L
.15774 0 L
.17262 0 L
.1875 0 L
.20238 0 L
.21726 0 L
.23214 0 L
.24702 0 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo?03oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0?l0oooo?@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0o`3ooom;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0
ooooPP3oool001@0oooo0P0000030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
o`3ooon20?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0o`3ooon20?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0o`3ooon20?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooon20?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooon20?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
o`3ooon30?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0o`3ooon30?ooo`00503oool2000000L0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`3o0?oooh<0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`3o0?oooh<0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oooh<0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oooh<0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`3o0?oooh<0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`3o0?oooh<0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`3o0?oooh@0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooQ03oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooQ03oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooQ03o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0?l0ooooQ03oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0?l0ooooQ03oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooQ03oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooQ@3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooon50?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooon5
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0o`3ooon50?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0o`3ooon50?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooon50?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooQ@3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`050000003oool0
oooo0?ooo`000000o`3ooon70?ooo`002`3oool20000O`030000000007l0001o00@0001o0`00000?
0000O`030000000007l000000?l0001o>@0007m?0?ooo`002P3oool3000000L0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0000003o0?ooohP0oooo000:0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0403oool200000?l0ooooR03oool000X0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooQP3oool000X0oooo1000
00060?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oo
oi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@00000
0`3oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo
00060?ooo`050000003oool0oooo0?ooo`0000000P0007l00`000000001o0000O`040000O`<00000
o`0007m;0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103o
ool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00060?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000
o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<00000
0000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3
000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool0
000000T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool3000000<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`040000003oool0oooo0?oo
o`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000
o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool4
000000<0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool0
00D0oooo00<000000?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000o`0007m;
0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3o
ool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3
000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000
oooo0?ooo`030?ooo`80001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`00
1P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
1`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0
ooooVP3oool000D0oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0
ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo0?l0
ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P0007l00`00
0000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00050?ooo`8000000`3oool010000000
oooo0?ooo`00003o0?oooj<0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0o`3ooonQ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000?l0ooooX`3oool000D0oooo0P0000040?ooo`800000o`3ooonT0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00103oool200000080oooo0`0000030?ooo`D000000`3oool200000080oooo0`00
00040?ooo`<00000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`000`3oool010000000
oooo0000000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooohX0oooo00030?oo
o`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000o`3ooon=0?ooo`000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0o`3ooon=0?ooo`00103oool200000080oooo1@000000103oool000000000000000050?oo
o`8000000P3oool4000000@0oooo0`00003o0?oooh`0oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 0 L
.12798 0 L
.14286 0 L
.15774 0 L
.17262 0 L
.1875 0 L
.20238 0 L
.21726 0 L
.23214 0 L
.24702 0 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo=`3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0?l0oooo>03oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0o`3ooom60?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0
ooooO@3oool001@0oooo0P0000030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
o`3ooomm0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0o`3ooomm0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
o`3ooomn0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0o`3ooomn0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`3o0?ooogh0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`3o0?ooogh0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooogh0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooogh0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`3o0?ooogh0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`3o0?ooogl0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`3o0?ooogl0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooO`3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooO`3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooO`3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0?l0ooooO`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0?l0ooooO`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooP03oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooP03oool001@0oooo0P00
000<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooon00?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooon0
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0o`3ooon00?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0o`3ooon00?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooon00?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooP03o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0o`3ooon10?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o00@0001o00<000000000O`0007l0o`0007lb0000
Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0o`3ooon10?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0100oooo00@000000?ooo`3oool0oooo0`00003o0?oooh<0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool300000?l0ooooQP3oool000X0oooo1000
00060?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oo
oi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@00000
0`3oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo
00060?ooo`050000003oool0oooo0?ooo`0000000P0007l00`000000001o0000O`040000O`<00000
o`0007m;0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103o
ool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00060?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000
o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<00000
0000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3
000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool0
000000T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool3000000<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`040000003oool0oooo0?oo
o`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000
o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool4
000000<0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool0
00D0oooo00<000000?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000o`0007m;
0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3o
ool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3
000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000
oooo0?ooo`030?ooo`80001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`00
1P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
1`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0
ooooVP3oool000D0oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0
ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo0?l0
ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P0007l00`00
0000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00050?ooo`8000000`3oool010000000
oooo0?ooo`00003o0?oooj<0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0o`3ooonQ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000?l0ooooX`3oool000D0oooo0P0000040?ooo`800000o`3ooonT0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00103oool200000080oooo0`0000030?ooo`D000000`3oool200000080oooo0`00
00040?ooo`<00000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`000`3oool010000000
oooo0000000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooohX0oooo00030?oo
o`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000o`3ooon=0?ooo`000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0o`3ooon=0?ooo`00103oool200000080oooo1@000000103oool000000000000000050?oo
o`8000000P3oool4000000@0oooo0`00003o0?oooh`0oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 0 L
.14286 0 L
.15774 0 L
.17262 0 L
.1875 0 L
.20238 0 L
.21726 0 L
.23214 0 L
.24702 0 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0oooo<P3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo0?l0oooo<P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0o`3ooom10?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0
ooooN03oool001@0oooo0P0000030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
o`3ooomh0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0o`3ooomh0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0o`3ooomh0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooomh0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooomh0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
o`3ooomh0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0o`3ooomi0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`3o0?ooogT0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`3o0?ooogT0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooogT0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooogT0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`3o0?ooogT0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`3o0?ooogT0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`3o0?ooogT0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooNP3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooNP3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooNP3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0?l0ooooNP3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0?l0ooooNP3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooNP3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooNP3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooomk
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0o`3ooomk0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0o`3ooomk0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooomk0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooN`3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0o`3ooomk0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o00X0001o00<000000000O`0007l0o`0007l/0000
Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0o`3ooomk0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0100oooo00@000000?ooo`3oool0oooo0`0000040?ooo`030000003oool0oooo0?l0
ooooO03oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<00000
0`3oool200000080oooo00<000000?ooo`3oool0o`3oooml0?ooo`002P3oool4000000H0oooo00<0
00000?ooo`3oool06@3oool300000?l0ooooOP3oool001@0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`3o0?ooog`0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0?l0ooooVP3oool000H0oooo00D000000?ooo`3oool0oooo000000020000O`030000
000007l0001o00@0001o0`00003o0000Od/0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`3o0?oooiX0oooo00040?ooo`<000000`3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo0?l0ooooVP3oool000H0oooo00<000000?ooo`3oool00P3oool2000000L0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo100000020?ooo`<00000
1`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000003oool0
oooo0080oooo0P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?oo
o`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?oo
o`<000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooVP3oool000H0
oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000000007l0001o
000000H0001o0`00003o0000Od/0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oo
oiX0oooo00050?ooo`030000003oool0oooo00<0oooo0P0007l00`000000001o0000O`040000O`<0
0000o`0007m;0000Odl0oooo00060?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000
oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000<0oooo100000060?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`800000103oool2000000L0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000
oooo0?ooo`0000020000O`030000000007l0001o00@0001o0`00003o0000Od/0001oC`3oool000D0
oooo0P0000030?ooo`040000003oool0oooo00000?l0ooooX`3oool000L0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`3o0?oooj40oooo00040?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001@3oool2000000@0oooo0P00003o0?oo
oj@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo00040?ooo`8000000P3oool3000000<0oooo1@00
00030?ooo`8000000P3oool3000000@0oooo0`00003o0?ooohd0oooo00030?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00003o0?oo
oh`0oooo00030?ooo`040000003oool0000000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0`0000060?ooo`030000003oool0
oooo0?l0ooooRP3oool000<0oooo00<000000?ooo`3oool00`3oool3000000<0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P00
003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`3o0?ooohd0oooo00040?ooo`8000000P3oool500000004
0?ooo`0000000000000000D0oooo0P0000020?ooo`@00000103oool300000?l0ooooS03oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 0 L
.15774 0 L
.17262 0 L
.1875 0 L
.20238 0 L
.21726 0 L
.23214 0 L
.24702 0 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0oooo;@3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo0?l0oooo;@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0o`3oooll0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0
ooooL`3oool001@0oooo0P0000030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
o`3ooomc0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0o`3ooomc0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
o`3ooomc0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0o`3ooomc0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`3o0?ooog@0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`3o0?ooog@0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?ooog@0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?ooog@0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`3o0?ooog@0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`3o0?ooog@0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`3o0?ooog@0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0ooooM03oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooM03oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooM@3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo0?l0ooooM@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0?l0ooooM@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooM@3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooM@3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooome0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooome
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0o`3ooome0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0o`3ooomf0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0o`3ooomf0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooMP3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0o`3ooomf0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o00l0001o00<000000000O`0007l0o`0007lW0000
Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0o`3ooomf0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0100oooo00@000000?ooo`3oool0oooo0`00000:0?ooo`030000003oool0oooo0?l0
ooooMP3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<00000
0`3oool2000000P0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`002P3oool4000000H0oooo00<0
00000?ooo`3oool06@3oool2000000H0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`00503oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooomg
0?ooo`00503oool00`000000oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`000000o`3ooomi
0?ooo`00503oool2000001h0oooo0P0000000`3oool000000?ooo`3o0?ooogP0oooo000D0?ooo`03
0000003oool0oooo01l0oooo0P00003o0?ooogT0oooo000D0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0o`3ooomg0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0?l0ooooVP3oool000H0oooo00D000000?ooo`3oool0oooo000000020000O`03
0000000007l0001o00@0001o0`00003o0000Od/0001oC`3oool000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3o0?oooiX0oooo00040?ooo`<000000`3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo0?l0ooooVP3oool000H0oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo100000020?ooo`<0
00001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000003o
ool0oooo0080oooo0P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo0006
0?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo0006
0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`3o0?oooiX0oooo0004
0?ooo`<000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooVP3oool0
00H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000000007l0
001o000000H0001o0`00003o0000Od/0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo0004
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o
0?oooiX0oooo00050?ooo`030000003oool0oooo00<0oooo0P0007l00`000000001o0000O`040000
O`<00000o`0007m;0000Odl0oooo00060?ooo`040000003oool0oooo0?ooo`<000001`3oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000<0oooo100000060?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`800000103oool20000
00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool01000
0000oooo0?ooo`0000020000O`030000000007l0001o00@0001o0`00003o0000Od/0001oC`3oool0
00D0oooo0P0000030?ooo`040000003oool0oooo00000?l0ooooX`3oool000L0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`3o0?oooj40oooo00040?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001@3oool2000000@0oooo0P00003o
0?oooj@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo00040?ooo`8000000P3oool3000000<0oooo
1@0000030?ooo`8000000P3oool3000000@0oooo0`00003o0?ooohd0oooo00030?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00003o
0?oooh`0oooo00030?ooo`040000003oool0000000000080oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0`0000060?ooo`030000003o
ool0oooo0?l0ooooRP3oool000<0oooo00<000000?ooo`3oool00`3oool3000000<0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
0P00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`3o0?ooohd0oooo00040?ooo`8000000P3oool50000
00040?ooo`0000000000000000D0oooo0P0000020?ooo`@00000103oool300000?l0ooooS03oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 0 L
.17262 0 L
.1875 0 L
.20238 0 L
.21726 0 L
.23214 0 L
.24702 0 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo:03oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0?l0oooo:@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0o`3ooolg0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0
ooooKP3oool001@0oooo0P0000030?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
o`3ooom^0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0o`3ooom^0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooom^0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooom_0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
o`3ooom_0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0o`3ooom_0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`3o0?ooofl0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`3o0?ooofl0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooofl0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooofl0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`3o0?ooog00oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`3o0?ooog00oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`3o0?ooog00oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0ooooL03oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0ooooL03oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0ooooL03o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo0?l0ooooL03oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0?l0ooooL@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooL@3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooL@3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3oooma0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3oooma
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0o`3oooma0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0o`3oooma0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooLP3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l0o`0007lS0000
Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0o`3ooomc0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0100oooo00@000000?ooo`3oool0oooo0`00000=0?ooo`030000003oool0oooo0?l0
ooooL`3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<00000
0`3oool2000000X0oooo00<000000?ooo`3oool0o`3ooomd0?ooo`002P3oool4000000H0oooo00<0
00000?ooo`3oool06@3oool2000000P0oooo00<000000?ooo`3oool0o`3ooomd0?ooo`00503oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooome
0?ooo`00503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0o`3ooome0?ooo`00503oool2000001h0oooo0P0000020?ooo`030000003oool0oooo0?l0
ooooMP3oool001@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0000003o0?ooogP0oooo
000D0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooomg0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo100000030?ooo`800000
1`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000H0oooo00D0
00000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`00003o0000Od/0001o
C`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`<000000`3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000H0oooo00<0
00000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3o0?oooiX0oooo00060?ooo`030000003oool0oooo0080oooo0P0007l00`000000001o0000O`04
0000O`<00000o`0007m;0000Odl0oooo00060?ooo`040000003oool0oooo0?ooo`<000001`3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`<000000`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0?l0ooooVP3oool000H0oooo00@000000?ooo`3oool0oooo100000060?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000`3oool2
000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`00
0000oooo0?ooo`020?ooo`040000000007l0001o000000H0001o0`00003o0000Od/0001oC`3oool0
00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2
000000@0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000
o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo100000020?ooo`<000001`3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`030000003oool0oooo00<0
oooo0P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?ooo`040000
003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
1@3oool2000000<0oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000020000O`030000000007l0001o
00@0001o0`00003o0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003oool0oooo0000
0?l0ooooX`3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oo
oj40oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooonS
0?ooo`001@3oool2000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
00040?ooo`8000000P3oool3000000<0oooo1@0000030?ooo`8000000P3oool3000000@0oooo0`00
003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003oool000000000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000080oooo0`0000060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo00<000000?oo
o`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oo
ohd0oooo00040?ooo`8000000P3oool5000000040?ooo`0000000000000000D0oooo0P0000020?oo
o`@00000103oool300000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 0 L
.1875 0 L
.20238 0 L
.21726 0 L
.23214 0 L
.24702 0 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0oooo8`3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo0?l0oooo8`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0o`3ooolb0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0
ooooJ@3oool001@0oooo0P0000030?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
o`3ooomY0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0o`3ooomY0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0o`3ooomY0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3ooomY0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3ooomY0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
o`3ooomY0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0o`3ooomZ0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`3o0?ooofX0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`3o0?ooofX0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3o0?ooofX0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3o0?ooofX0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`3o0?ooofX0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`3o0?ooofX0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`3o0?ooofX0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0ooooJP3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooJ`3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooJ`3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo0?l0ooooJ`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0?l0ooooJ`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooJ`3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooJ`3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooom[0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooom[
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0o`3ooom[0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0o`3ooom/0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0ooooK03o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l00`0007l00`00
0000001o0000O`3o0000Oad0001oC`3oool000X0oooo0`0000070?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04P3oool00`000000oooo000000040?ooo`030000003oool0oooo0?l0
ooooK03oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`040000
003oool0oooo0?ooo`<000003@3oool00`000000oooo000000040?ooo`030000003oool0oooo0?l0
ooooK03oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<00000
0`3oool2000000X0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0?l0
ooooK03oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`000000o`3ooom_0?ooo`00503oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
003o0?ooofl0oooo000D0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`800000o`3ooom_0?ooo`00503oool2000001h0oooo0P0000020?oo
o`030000003oool0oooo00D0oooo0P00003o0?ooofl0oooo000D0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`3o0?ooofd0oooo000D0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooomg0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000
o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool000@0oooo100000030?ooo`8000001`3oool00`000000
oooo0?ooo`3o0?oooiX0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000H0oooo00D000000?ooo`3oool0
oooo000000020000O`030000000007l0001o00@0001o0`00003o0000Od/0001oC`3oool000H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`<000000`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000H0oooo00<000000?ooo`3oool0
0P3oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oo
oi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0
oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo
00060?ooo`030000003oool0oooo0080oooo0P0007l00`000000001o0000O`040000O`<00000o`00
07m;0000Odl0oooo00060?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00040?ooo`<000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0?l0ooooVP3oool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000`3oool2000000L0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`02
0?ooo`040000000007l0001o000000H0001o0`00003o0000Od/0001oC`3oool000H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P00
00070?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00
003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`030000003oool0oooo00<0oooo0P0007l00`00
0000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?ooo`040000003oool0oooo0?oo
o`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000<0
oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00
003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?oo
o`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`001`3oool010000000oooo0?ooo`0000020000O`030000000007l0001o00@0001o0`00003o
0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003oool0oooo00000?l0ooooX`3oool0
00L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oooj40oooo00040?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001@3oool2
000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo00040?ooo`800000
0P3oool3000000<0oooo1@0000030?ooo`8000000P3oool3000000@0oooo0`00003o0?ooohd0oooo
00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003oool0000000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0`00
00060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo00<000000?ooo`3oool00`3oool3
000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?ooohd0oooo00040?oo
o`8000000P3oool5000000040?ooo`0000000000000000D0oooo0P0000020?ooo`@00000103oool3
00000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 0 L
.20238 0 L
.21726 0 L
.23214 0 L
.24702 0 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0oooo7P3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0?l0oooo7P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool0o`3oool]0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0
ooooI03oool001@0oooo0P0000030?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
o`3ooomT0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0o`3ooomT0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
o`3ooomT0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0o`3ooomT0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`3o0?ooofD0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`3o0?ooofD0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?ooofD0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?ooofD0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`3o0?ooofD0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`3o0?ooofD0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`3o0?ooofD0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0ooooI@3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0ooooI@3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0ooooI@3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo0?l0ooooIP3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0?l0ooooIP3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0ooooIP3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0ooooIP3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooomV
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0o`3ooomV0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0o`3ooomV0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooomV0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooI`3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l0200007l00`00
0000001o0000O`3o0000OaP0001oC`3oool000X0oooo0`0000070?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04P3oool00`000000oooo000000090?ooo`030000003oool0oooo0?l0
ooooI`3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`040000
003oool0oooo0?ooo`<000003@3oool00`000000oooo000000090?ooo`030000003oool0oooo0?l0
ooooI`3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<00000
0`3oool2000000X0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0?l0
ooooI`3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooofL0oooo
000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`00503oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooI`3oool001@0oooo0P00000N0?oo
o`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0o`3ooomX0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooofP0oooo000D0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0203oool200000080oooo00<000000?ooo`3oool0
o`3ooomX0?ooo`00503oool00`000000oooo0?ooo`0]0?ooo`<00000o`3ooomZ0?ooo`00503oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0ooooJ03oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000
o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool000@0oooo100000030?ooo`8000001`3oool00`000000
oooo0?ooo`3o0?oooiX0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000H0oooo00D000000?ooo`3oool0
oooo000000020000O`030000000007l0001o00@0001o0`00003o0000Od/0001oC`3oool000H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`<000000`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000H0oooo00<000000?ooo`3oool0
0P3oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oo
oi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0
oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo
00060?ooo`030000003oool0oooo0080oooo0P0007l00`000000001o0000O`040000O`<00000o`00
07m;0000Odl0oooo00060?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00040?ooo`<000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0?l0ooooVP3oool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000`3oool2000000L0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`02
0?ooo`040000000007l0001o000000H0001o0`00003o0000Od/0001oC`3oool000H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P00
00070?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00
003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`030000003oool0oooo00<0oooo0P0007l00`00
0000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?ooo`040000003oool0oooo0?oo
o`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000<0
oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00
003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?oo
o`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`001`3oool010000000oooo0?ooo`0000020000O`030000000007l0001o00@0001o0`00003o
0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003oool0oooo00000?l0ooooX`3oool0
00L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oooj40oooo00040?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001@3oool2
000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo00040?ooo`800000
0P3oool3000000<0oooo1@0000030?ooo`8000000P3oool3000000@0oooo0`00003o0?ooohd0oooo
00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003oool0000000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0`00
00060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo00<000000?ooo`3oool00`3oool3
000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?ooohd0oooo00040?oo
o`8000000P3oool5000000040?ooo`0000000000000000D0oooo0P0000020?ooo`@00000103oool3
00000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 0 L
.21726 0 L
.23214 0 L
.24702 0 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D000000?ooo`000000oooo
000000030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<000001@3oool001@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0903oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0
000000X0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo000D0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0o`3ooolI0?ooo`80000000<0oooo0000000000000`3oool2000000<0oooo10000002
0?ooo`030000003oool00000008000000P3oool200000080oooo0P0000000`3oool0000000000008
0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`@000000`3oool2000000D0oooo000D0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`050000003oool0oooo
0?ooo`0000002@3oool00`000000oooo0?ooo`0K0?ooo`<000005P3oool001@0oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo000D0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0o`3ooomO0?ooo`00503oool2000000<0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`3o0?oooel0oooo000D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?oooel0oooo000D0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?oooel0oooo000D0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o0?oo
oel0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`3o0?oooel0oooo000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`3o0?oooel0oooo000D0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?oooel0oooo000D0?ooo`8000001`3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0ooooG`3oool001@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooH03oool001@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0
ooooH03oool001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo0?l0ooooH03oool001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo0?l0ooooH03oool001@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0ooooH03oool001@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0ooooH03oool001@0
oooo0P0000090?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`00
503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
o`3ooomP0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0o`3ooomP0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`00503oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`00503oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`00
503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
o`3ooomQ0?ooo`00503oool2000000`0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`3o0?ooof40oooo000D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`3o0?ooof40oooo000D0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`3o0?ooof40oooo000D0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?ooof40oooo000D0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?ooof40oooo
000:0?ooo`<000001`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0o`3ooomQ0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?ooof80oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`0=0000O`030000000007l0001o0?l0001o4`0007m?0?ooo`002P3oool3000000L0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0000000h0
oooo00<000000?ooo`3oool0o`3ooomR0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0100oooo00@000000?ooo`3oool0oooo0`00000=0?ooo`030000003oool0000000h0
oooo00<000000?ooo`3oool0o`3ooomR0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0140oooo0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool0000000d0
oooo00<000000?ooo`3oool0o`3ooomR0?ooo`002P3oool4000000H0oooo00<000000?ooo`3oool0
6@3oool2000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0?l0ooooHP3oool001@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`3o0?ooof80oooo000D0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooomR
0?ooo`00503oool2000001h0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`3o0?ooof80oooo000D0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0
ooooHP3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`080?ooo`800000
1`3oool00`000000oooo0?ooo`3o0?ooof<0oooo000D0?ooo`030000003oool0oooo02d0oooo0P00
00050?ooo`030000003oool0oooo0?l0ooooH`3oool001@0oooo00<000000?ooo`3oool0;`3oool2
000000<0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`80000000<0oooo0000003oool0o`3ooomT0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000o`3ooomU0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o
0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@0
00000`3oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P0007l00`000000001o0000O`040000O`<0
0000o`0007m;0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0
oooo00060?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0oooo
V`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`80
0000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<0
00000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3o
ool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool3000000<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`040000003oool0oooo
0?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0oooo
V`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`80
0000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103o
ool4000000<0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3o
ool000D0oooo00<000000?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000o`00
07m;0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0oooo
VP3oool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3o
ool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`00
0000oooo0?ooo`030?ooo`80001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?oo
o`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooVP3oool000@0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0?l0ooooVP3oool000D0oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool20000
0?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo
0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P0007l0
0`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00050?ooo`8000000`3oool01000
0000oooo0?ooo`00003o0?oooj<0oooo00070?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0o`3ooonQ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000?l0ooooX`3oool000D0oooo0P0000040?ooo`800000o`3ooonT0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00103oool200000080oooo0`0000030?ooo`D000000`3oool200000080oooo
0`0000040?ooo`<00000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`000`3oool01000
0000oooo0000000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooohX0oooo0003
0?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000o`3ooon=0?ooo`000`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0o`3ooon=0?ooo`00103oool200000080oooo1@000000103oool00000000000000005
0?ooo`8000000P3oool4000000@0oooo0`00003o0?oooh`0oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 0 L
.23214 0 L
.24702 0 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0oooo503oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo0?l0oooo503oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool0o`3ooolR0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0?l0
ooooFP3oool001@0oooo0P0000030?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
o`3ooomJ0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0o`3ooomJ0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
o`3ooomJ0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0o`3ooomJ0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`3o0?oooeX0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`3o0?oooeX0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3o0?oooeX0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?oooe/0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`3o0?oooe/0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`3o0?oooe/0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`3o0?oooe/0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0ooooF`3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0ooooF`3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0ooooF`3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo0?l0ooooF`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo0?l0ooooF`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0ooooF`3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0ooooF`3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0o`3ooomL
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0o`3ooomL0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooG03o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`3o0000O`d0001oC`3oool000X0oooo0`0000070?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0000000D0?ooo`030000003oool0oooo0?l0
ooooG03oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`040000
003oool0oooo0?ooo`<000003@3oool00`000000oooo0000000D0?ooo`030000003oool0oooo0?l0
ooooG03oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<00000
0`3oool2000000X0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool0oooo0?l0
ooooG03oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oooed0oooo
000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooomM0?ooo`00503oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0ooooG@3oool001@0oooo0P00000N0?oo
o`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0o`3ooomM0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oooed0oooo000D0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0203oool2000000d0oooo00<000000?ooo`3oool0
o`3ooomM0?ooo`00503oool00`000000oooo0?ooo`0]0?ooo`8000002`3oool00`000000oooo0?oo
o`3o0?oooed0oooo000D0?ooo`030000003oool0oooo02l0oooo0P0000090?ooo`030000003oool0
oooo0?l0ooooG@3oool001@0oooo00<000000?ooo`3oool0<@3oool2000000L0oooo00<000000?oo
o`3oool0o`3ooomM0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`8000001@3oool00`000000
oooo0?ooo`3o0?oooed0oooo000D0?ooo`800000=P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0?l0ooooG@3oool001@0oooo00<000000?ooo`3oool0=@3oool01@000000oooo0?oo
o`3oool000000?l0ooooH03oool001@0oooo00<000000?ooo`3oool0=P3oool010000000oooo0?oo
o`00003o0?ooof00oooo000D0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000o`3o
oomP0?ooo`00503oool00`000000oooo0?ooo`0h0?ooo`800000o`3ooomP0?ooo`00503oool00`00
0000oooo0?ooo`0h0?ooo`800000o`3ooomP0?ooo`00503oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo0?l0ooooGP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000`3oool2000000L0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`050000003oool0oooo
0?ooo`0000000P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0?l0ooooVP3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool3000000<0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000003oool0oooo
0080oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo0004
0?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<000000000O`0007l0100007l300000?l0
001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00103oool3000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`3o0?oooiX0oooo00060?ooo`040000003oool0oooo0?ooo`@000001P3oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo0?l0ooooVP3oool000@0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo00<000000?ooo`3oool0
0P3oool010000000001o0000O`0000060000O`<00000o`0007m;0000Odl0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0
ooooVP3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000040?ooo`80
00001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0oooo
V`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`80
0000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`80001o00<0
00000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3o
ool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P000003
0?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0oooo
V`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`80
0000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3o
ool2000000@0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0oooo
VP3oool000L0oooo00@000000?ooo`3oool000000P0007l00`000000001o0000O`040000O`<00000
o`0007m;0000Odl0oooo00050?ooo`8000000`3oool010000000oooo0?ooo`00003o0?oooj<0oooo
00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`00103o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0ooooX`3oool000D0oooo
0P0000040?ooo`800000o`3ooonT0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00103oool20000
0080oooo0`0000030?ooo`D000000`3oool200000080oooo0`0000040?ooo`<00000o`3ooon=0?oo
o`000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000o`3ooon<0?ooo`000`3oool010000000oooo0000000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`<0
00001P3oool00`000000oooo0?ooo`3o0?ooohX0oooo00030?ooo`030000003oool0oooo00<0oooo
0`0000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000030?ooo`800000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooon=0?ooo`00103o
ool200000080oooo1@000000103oool000000000000000050?ooo`8000000P3oool4000000@0oooo
0`00003o0?oooh`0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 0 L
.24702 0 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo3`3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo0?l0oooo3`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0o`3ooolM0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0
ooooE03oool001@0oooo0P0000030?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
o`3ooomE0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0o`3ooomE0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
o`3ooomE0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0o`3ooomE0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`3o0?oooeD0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`3o0?oooeD0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?oooeD0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?oooeD0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`3o0?oooeD0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`3o0?oooeH0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`3o0?oooeH0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0?l0ooooEP3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0?l0ooooEP3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0?l0ooooEP3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo0?l0ooooEP3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0?l0ooooEP3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0ooooEP3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0ooooEP3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0o`3ooomF0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0o`3ooomF
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool0o`3ooomF0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0o`3ooomF0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool0o`3ooomG0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0ooooE`3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l0600007l00`00
0000001o0000O`3o0000O`P0001oC`3oool000X0oooo0`0000070?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0000000I0?ooo`030000003oool0oooo0?l0
ooooE`3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`040000
003oool0oooo0?ooo`<000003@3oool00`000000oooo0000000I0?ooo`030000003oool0oooo0?l0
ooooE`3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<00000
0`3oool2000000X0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000003oool0oooo0?l0
ooooE`3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?oooeL0oooo
000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`00503oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0ooooE`3oool001@0oooo0P00000N0?oo
o`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0o`3ooomG0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?oooeL0oooo000D0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0203oool2000001<0oooo00<000000?ooo`3oool0
o`3ooomG0?ooo`00503oool00`000000oooo0?ooo`0]0?ooo`800000403oool00`000000oooo0?oo
o`3o0?oooeP0oooo000D0?ooo`030000003oool0oooo02l0oooo0P00000>0?ooo`030000003oool0
oooo0?l0ooooF03oool001@0oooo00<000000?ooo`3oool0<@3oool2000000`0oooo00<000000?oo
o`3oool0o`3ooomH0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`8000002P3oool00`000000
oooo0?ooo`3o0?oooeP0oooo000D0?ooo`800000=P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0?l0ooooF03oool001@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0?l0ooooF03oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooF03oool001@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooF03oool001@0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0
ooooF03oool001@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0?l0ooooF03oool001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?l0ooooF03oool001@0oooo0P00000k0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0o`3ooomH0?ooo`00503oool00`000000oooo0?ooo`0j0?oo
o`050000003oool0oooo0?ooo`000000o`3ooomK0?ooo`00503oool00`000000oooo0?ooo`0k0?oo
o`040000003oool0oooo00000?l0ooooF`3oool001@0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0000003o0?oooe/0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`00
0000o`3ooomK0?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`800000o`3ooomK0?ooo`00503o
ool00`000000oooo0?ooo`0m0?ooo`800000o`3ooomK0?ooo`00503oool2000003l0oooo00<00000
0?ooo`3oool0o`3ooomI0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000`3oool2000000L0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`050000003oool0oooo
0?ooo`0000000P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0?l0ooooVP3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool3000000<0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000003oool0oooo
0080oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo0004
0?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<000000000O`0007l0100007l300000?l0
001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00103oool3000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`3o0?oooiX0oooo00060?ooo`040000003oool0oooo0?ooo`@000001P3oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo0?l0ooooVP3oool000@0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo00<000000?ooo`3oool0
0P3oool010000000001o0000O`0000060000O`<00000o`0007m;0000Odl0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0
ooooVP3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000040?ooo`80
00001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0oooo
V`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`80
0000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`80001o00<0
00000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3o
ool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P000003
0?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0oooo
V`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`80
0000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3o
ool2000000@0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0oooo
VP3oool000L0oooo00@000000?ooo`3oool000000P0007l00`000000001o0000O`040000O`<00000
o`0007m;0000Odl0oooo00050?ooo`8000000`3oool010000000oooo0?ooo`00003o0?oooj<0oooo
00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`00103o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0ooooX`3oool000D0oooo
0P0000040?ooo`800000o`3ooonT0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00103oool20000
0080oooo0`0000030?ooo`D000000`3oool200000080oooo0`0000040?ooo`<00000o`3ooon=0?oo
o`000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000o`3ooon<0?ooo`000`3oool010000000oooo0000000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`<0
00001P3oool00`000000oooo0?ooo`3o0?ooohX0oooo00030?ooo`030000003oool0oooo00<0oooo
0`0000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000030?ooo`800000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooon=0?ooo`00103o
ool200000080oooo1@000000103oool000000000000000050?ooo`8000000P3oool4000000@0oooo
0`00003o0?oooh`0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 0 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo2@3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo0?l0oooo2@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool0o`3ooolG0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0
ooooC`3oool001@0oooo0P0000030?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
o`3ooom?0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0o`3ooom?0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0o`3ooom?0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0o`3ooom?0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0o`3ooom?0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
o`3ooom?0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0o`3ooom?0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`3o0?ooodl0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`3o0?ooodl0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?ooodl0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?oooe00oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`3o0?oooe00oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`3o0?oooe00oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`3o0?oooe00oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo0?l0ooooD03oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooD03oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooD03o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo0?l0ooooD03oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo0?l0ooooD03oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0ooooD03oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0ooooD03oool001@0oooo0P00
000<0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooomA
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0o`3ooomA0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0?l0ooooD@3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l07P0007l00`00
0000001o0000O`3o0000O`80001oC`3oool000X0oooo0`0000070?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0000000O0?ooo`030000003oool0oooo0?l0
ooooD@3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`040000
003oool0oooo0?ooo`<000003@3oool00`000000oooo0000000O0?ooo`030000003oool0oooo0?l0
ooooD@3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<00000
0`3oool2000000X0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo0?l0
ooooDP3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?oooe80oooo
000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`00503oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooDP3oool001@0oooo0P00000N0?oo
o`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0o`3ooomB0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?oooe80oooo000D0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0203oool2000001P0oooo00<000000?ooo`3oool0
o`3ooomB0?ooo`00503oool00`000000oooo0?ooo`0]0?ooo`8000005P3oool00`000000oooo0?oo
o`3o0?oooe80oooo000D0?ooo`030000003oool0oooo02l0oooo0P00000D0?ooo`030000003oool0
oooo0?l0ooooDP3oool001@0oooo00<000000?ooo`3oool0<@3oool200000180oooo00<000000?oo
o`3oool0o`3ooomB0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`800000403oool00`000000
oooo0?ooo`3o0?oooe80oooo000D0?ooo`800000=P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0?l0ooooD`3oool001@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0?l0ooooD`3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooD`3oool001@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooD`3oool001@0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0
ooooD`3oool001@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0?l0ooooD`3oool001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0?l0ooooD`3oool001@0oooo0P00000k0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`00503oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`00503oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`00
503oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
o`3ooomC0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3ooomD0?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`00503oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`00503oool2000003l0
oooo0P0000030?ooo`030000003oool0oooo0?l0ooooE03oool001@0oooo00<000000?ooo`3oool0
@03oool2000000030?ooo`000000oooo0?l0ooooE@3oool001@0oooo00<000000?ooo`3oool0@P3o
ool200000?l0ooooEP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0
ooooVP3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000003oool0oooo0080oooo
0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o
0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@0
00000P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3o
ool00`000000oooo0?ooo`020?ooo`80001o00<000000000O`0007l0100007l300000?l0001oB`00
07m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00103oool3000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o
0?oooiX0oooo00060?ooo`040000003oool0oooo0?ooo`@000001P3oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o
0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool4000000<0oooo0P0000070?ooo`030000003o
ool0oooo0?l0ooooVP3oool000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo00<000000?ooo`3oool00P3oool0
10000000001o0000O`0000060000O`<00000o`0007m;0000Odl0oooo00060?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3o
ool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000040?ooo`8000001`3o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`80001o00<000000000
O`0007l0100007l300000?l0001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool30000
00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000030?ooo`@0
00001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool20000
00@0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool0
00L0oooo00@000000?ooo`3oool000000P0007l00`000000001o0000O`040000O`<00000o`0007m;
0000Odl0oooo00050?ooo`8000000`3oool010000000oooo0?ooo`00003o0?oooj<0oooo00070?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`00103oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0ooooX`3oool000D0oooo0P000004
0?ooo`800000o`3ooonT0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00103oool200000080oooo
0`0000030?ooo`D000000`3oool200000080oooo0`0000040?ooo`<00000o`3ooon=0?ooo`000`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool00000o`3ooon<0?ooo`000`3oool010000000oooo0000000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`<000001P3o
ool00`000000oooo0?ooo`3o0?ooohX0oooo00030?ooo`030000003oool0oooo00<0oooo0`000003
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000030?ooo`800000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooon=0?ooo`00103oool20000
0080oooo1@000000103oool000000000000000050?ooo`8000000P3oool4000000@0oooo0`00003o
0?oooh`0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 0 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0?l0oooo103oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo0?l0oooo103oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0o`3ooolB0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0?l0
ooooB@3oool001@0oooo0P0000030?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
o`3ooom90?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool0o`3ooom:0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
o`3ooom:0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0o`3ooom:0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`3o0?ooodX0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`3o0?ooodX0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?ooodX0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?ooodX0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`3o0?ooodX0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`3o0?ooodX0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`3o0?ooodX0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo0?l0ooooBP3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0ooooB`3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0ooooB`3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo0?l0ooooB`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo0?l0ooooB`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0ooooB`3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0ooooB`3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3ooom;
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool0o`3ooom;0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0o`3ooom;0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0?l0ooooB`3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l0900007l00`00
0000001o0000O`3k0000Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`000000903oool00`000000oooo0?ooo`3o0?oood`0
oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0403oool010000000oooo
0?ooo`3oool3000000d0oooo00<000000?ooo`000000903oool00`000000oooo0?ooo`3o0?oood`0
oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3000000<0oooo
0P00000:0?ooo`050000003oool0oooo0?ooo`0000008`3oool00`000000oooo0?ooo`3o0?oood`0
oooo000:0?ooo`@000001P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooC03oool001@0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?oood`0oooo000D0?ooo`8000007P3oool20000
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0?l0ooooC03oool001@0oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00503oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00P0oooo0P00000N0?ooo`030000003oool0oooo0?l0oooo
C03oool001@0oooo00<000000?ooo`3oool0;@3oool2000001`0oooo00<000000?ooo`3oool0o`3o
oom<0?ooo`00503oool00`000000oooo0?ooo`0_0?ooo`8000006P3oool00`000000oooo0?ooo`3o
0?oood`0oooo000D0?ooo`030000003oool0oooo0340oooo0P00000H0?ooo`030000003oool0oooo
0?l0ooooC03oool001@0oooo00<000000?ooo`3oool0<`3oool2000001H0oooo00<000000?ooo`3o
ool0o`3ooom<0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`3o0?oood`0oooo000D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`3o0?ooodd0oooo000D0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooodd0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooodd0oooo000D0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooodd0
oooo000D0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`3o0?ooodd0oooo000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`3o0?ooodd0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0?l0ooooC@3oool001@0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooC@3oool001@0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooC@3oool001@0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo
C@3oool001@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0?l0ooooC@3oool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0?l0ooooC@3oool001@0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooC@3oool001@0oooo0P00000o0?ooo`80
00002P3oool00`000000oooo0?ooo`3o0?ooodd0oooo000D0?ooo`030000003oool0oooo0400oooo
0P0000070?ooo`030000003oool0oooo0?l0ooooCP3oool001@0oooo00<000000?ooo`3oool0@P3o
ool2000000D0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`00503oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooom>0?ooo`00503oool00`00
0000oooo0?ooo`150?ooo`8000000P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00040?ooo`@0
00000`3oool2000000L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0000003o0?oooe00
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04P0oooo0P00003o0?oooe00oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P0007l00`000000001o0000O`040000O`<00000B@0007l00`000000001o0000O`3n0000Odl0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0?l0ooooVP3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool3000000<0oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000
003oool0oooo0080oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<000000000O`0007l01000
07l300000?l0001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool3000000<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`040000003oool0oooo0?ooo`@000001P3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool4000000<0oooo0P00
00070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo00<00000
0?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000o`0007m;0000Odl0oooo0006
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P00
00040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0
ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`030?oo
o`80001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001P3oool010000000
oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooVP3oool000D0
oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P0007l00`000000001o0000O`04
0000O`<00000o`0007m;0000Odl0oooo00050?ooo`8000000`3oool010000000oooo0?ooo`00003o
0?oooj<0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooonQ
0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0ooooX`3o
ool000D0oooo0P0000040?ooo`800000o`3ooonT0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
103oool200000080oooo0`0000030?ooo`D000000`3oool200000080oooo0`0000040?ooo`<00000
o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`000`3oool010000000oooo000000000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooohX0oooo00030?ooo`030000003oool0
oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000030?ooo`800000o`3ooon=0?ooo`000`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooon=
0?ooo`00103oool200000080oooo1@000000103oool000000000000000050?ooo`8000000P3oool4
000000@0oooo0`00003o0?oooh`0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 0 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0?h0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`3n0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3o0?oo
o`d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00l0oooo000D0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0o`3ooom40?ooo`00
503oool2000000<0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`3o0?oood@0oooo
000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`3o0?ooodD0oooo000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`3o0?ooodD0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`3o0?ooodD0oooo000D0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooodD0oooo000D0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`3o0?ooodD0oooo
000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`3o0?ooodD0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo0?l0ooooA@3oool001@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo0?l0ooooA@3oool001@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0?l0ooooA@3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0ooooA@3oool001@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0ooooA@3o
ool001@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo0?l0ooooA@3oool001@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo0?l0ooooA@3oool001@0oooo0P0000090?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0o`3ooom50?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool0o`3ooom60?ooo`00503oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0o`3ooom60?ooo`00503oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0o`3ooom6
0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0o`3ooom60?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0o`3ooom60?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0o`3ooom60?ooo`00503oool2000000`0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?ooodH0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?ooodH0oooo000D0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?oo
odH0oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`3o0?ooodH0oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`3o0?ooodH0oooo000:0?ooo`<000001`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0o`3ooom60?ooo`003@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`3o0?ooodH0oooo000;0?ooo`80001o00<000000000O`0007l0100007l30000
00l0001o00<000000000O`0007l04`0007l00`000000001o0000O`0Y0000O`030000000007l0001o
0?H0001oC`3oool000X0oooo0`0000070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo0?l0ooooAP3oool000X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0?ooo`<0
00003@3oool00`000000oooo0000000Y0?ooo`030000003oool0oooo0?l0ooooA`3oool000X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<000000`3oool2000000X0oooo
00D000000?ooo`3oool0oooo0000000X0?ooo`030000003oool0oooo0?l0ooooA`3oool000X0oooo
100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?ooodL0oooo000D0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0o`3ooom70?ooo`00503oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0?l0ooooA`3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooom70?oo
o`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`3o0?ooodL0oooo000D0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0203oool2000002<0oooo00<000000?ooo`3oool0o`3ooom70?ooo`00503o
ool00`000000oooo0?ooo`0]0?ooo`8000008@3oool00`000000oooo0?ooo`3o0?ooodL0oooo000D
0?ooo`030000003oool0oooo02l0oooo0P00000O0?ooo`030000003oool0oooo0?l0ooooA`3oool0
01@0oooo00<000000?ooo`3oool0<@3oool2000001d0oooo00<000000?ooo`3oool0o`3ooom70?oo
o`00503oool00`000000oooo0?ooo`0c0?ooo`8000006`3oool00`000000oooo0?ooo`3o0?ooodL0
oooo000D0?ooo`800000=P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0oooo
A`3oool001@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0?l0ooooA`3oool001@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0?l0ooooA`3oool001@0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooB03oool001@0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0ooooB03oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo
B03oool001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0?l0ooooB03oool001@0oooo0P00000k0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0o`3ooom80?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0o`3ooom80?ooo`00503oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooom80?ooo`00503oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooom80?ooo`00503o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3o
oom80?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0o`3ooom80?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0o`3ooom80?ooo`00503oool2000003l0oooo0P00000?0?ooo`03
0000003oool0oooo0?l0ooooB03oool001@0oooo00<000000?ooo`3oool0@03oool2000000d0oooo
00<000000?ooo`3oool0o`3ooom80?ooo`00503oool00`000000oooo0?ooo`120?ooo`8000002`3o
ool00`000000oooo0?ooo`3o0?ooodP0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooodT0oooo000D0?ooo`030000003oool0oooo
04D0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooB@3oool000@0oooo100000030?ooo`80
00001`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0o`3ooom90?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0o`3ooom90?ooo`001P3oool01@000000oooo0?ooo`3oool000000080001o00<000000000O`00
07l0100007l3000004T0001o00<000000000O`0007l00P0007l00`000000001o0000O`3i0000Odl0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo0P0000020?ooo`030000003oool0oooo0?l0ooooB@3oool000H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0C03oool300000?l0ooooB`3oool000@0oooo0`0000030?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00060?ooo`030000
003oool0oooo0080oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<000000000O`0007l01000
07l300000?l0001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool3000000<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`040000003oool0oooo0?ooo`@000001P3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool4000000<0oooo0P00
00070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo00<00000
0?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000o`0007m;0000Odl0oooo0006
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P00
00040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0
ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`030?oo
o`80001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001P3oool010000000
oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooVP3oool000D0
oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P0007l00`000000001o0000O`04
0000O`<00000o`0007m;0000Odl0oooo00050?ooo`8000000`3oool010000000oooo0?ooo`00003o
0?oooj<0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooonQ
0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0ooooX`3o
ool000D0oooo0P0000040?ooo`800000o`3ooonT0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
103oool200000080oooo0`0000030?ooo`D000000`3oool200000080oooo0`0000040?ooo`<00000
o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`000`3oool010000000oooo000000000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooohX0oooo00030?ooo`030000003oool0
oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000030?ooo`800000o`3ooon=0?ooo`000`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooon=
0?ooo`00103oool200000080oooo1@000000103oool000000000000000050?ooo`8000000P3oool4
000000@0oooo0`00003o0?oooh`0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 0 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?T0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`3i0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?oo
o`P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00l0oooo000D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`00
503oool2000000<0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3o0?ooocl0oooo
000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`3o0?ooocl0oooo000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`3o0?oood00oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`3o0?oood00oooo000D0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`3o0?oood00oooo000D0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3o0?oood00oooo
000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`3o0?oood00oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo0?l0oooo@03oool001@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo0?l0oooo@03oool001@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0oooo@03oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0oooo@03oool001@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0oooo@03o
ool001@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0?l0oooo@03oool001@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0?l0oooo@03oool001@0oooo0P0000090?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool0o`3ooom00?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooom00?ooo`00503oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooom00?ooo`00503oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooom0
0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool0o`3ooom10?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0o`3ooom10?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool0o`3ooom10?ooo`00503oool2000000`0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`3o0?oood40oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`3o0?oood40oooo000D0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`3o0?oo
od40oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`3o0?oood40oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`3o0?oood40oooo000:0?ooo`<000001`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0o`3ooom10?ooo`003@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`3o0?oood40oooo000;0?ooo`80001o00<000000000O`0007l0100007l30000
00l0001o00<000000000O`0007l04`0007l00`000000001o0000O`0^0000O`030000000007l0001o
0?40001oC`3oool000X0oooo0`0000070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0000000_0?ooo`030000003oool0oooo0?l0oooo@@3oool000X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0?ooo`<0
00003@3oool00`000000oooo0000000_0?ooo`030000003oool0oooo0?l0oooo@@3oool000X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<000000`3oool2000000X0oooo
00D000000?ooo`3oool0oooo0000000^0?ooo`030000003oool0oooo0?l0oooo@@3oool000X0oooo
100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?oood40oooo000D0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0o`3ooom10?ooo`00503oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0?l0oooo@P3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooom20?oo
o`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`3o0?oood80oooo000D0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0203oool2000002P0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00503o
ool00`000000oooo0?ooo`0]0?ooo`8000009P3oool00`000000oooo0?ooo`3o0?oood80oooo000D
0?ooo`030000003oool0oooo02l0oooo0P00000T0?ooo`030000003oool0oooo0?l0oooo@P3oool0
01@0oooo00<000000?ooo`3oool0<@3oool200000280oooo00<000000?ooo`3oool0o`3ooom20?oo
o`00503oool00`000000oooo0?ooo`0c0?ooo`800000803oool00`000000oooo0?ooo`3o0?oood80
oooo000D0?ooo`800000=P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0oooo
@P3oool001@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo0?l0oooo@P3oool001@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0?l0oooo@P3oool001@0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo@P3oool001@0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0oooo@P3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0oooo
@P3oool001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo0?l0oooo@P3oool001@0oooo0P00000k0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0o`3ooom20?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0o`3ooom30?ooo`00503oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooom30?ooo`00503oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooom30?ooo`00503o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3o
oom30?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0o`3ooom30?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0o`3ooom30?ooo`00503oool2000003l0oooo0P00000D0?ooo`03
0000003oool0oooo0?l0oooo@`3oool001@0oooo00<000000?ooo`3oool0@03oool200000180oooo
00<000000?ooo`3oool0o`3ooom30?ooo`00503oool00`000000oooo0?ooo`120?ooo`800000403o
ool00`000000oooo0?ooo`3o0?oood<0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oood<0oooo000D0?ooo`030000003oool0oooo
04D0oooo0P00000=0?ooo`030000003oool0oooo0?l0oooo@`3oool000@0oooo100000030?ooo`80
00001`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0o`3ooom30?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0o`3ooom30?ooo`001P3oool01@000000oooo0?ooo`3oool000000080001o00<000000000O`00
07l0100007l3000004T0001o00<000000000O`0007l0200007l00`000000001o0000O`3c0000Odl0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo0P0000080?ooo`030000003oool0oooo0?l0oooo@`3oool000H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0C03oool2000000H0oooo00<000000?ooo`3oool0o`3ooom30?ooo`00103oool3000000<0oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0o`3ooom40?ooo`001P3oool00`000000oooo0?ooo`020?ooo`800000
1`3oool00`000000oooo0?ooo`1?0?ooo`050000003oool0oooo0?ooo`000000o`3ooom60?ooo`00
503oool00`000000oooo0?ooo`1?0?ooo`050000003oool0oooo0?ooo`000000o`3ooom60?ooo`00
503oool00`000000oooo0?ooo`1@0?ooo`040000003oool0oooo00000?l0ooooAP3oool001@0oooo
0P00001B0?ooo`030000003oool000000?l0ooooAP3oool001@0oooo00<000000?ooo`3oool0DP3o
ool200000?l0ooooAP3oool001@0oooo00<000000?ooo`3oool0DP3oool200000?l0ooooAP3oool0
01@0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3o0?oood@0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo0006
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o
0?oooiX0oooo00060?ooo`030000003oool0oooo0080oooo0P0007l00`000000001o0000O`040000
O`<00000o`0007m;0000Odl0oooo00060?ooo`040000003oool0oooo0?ooo`<000001`3oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00040?ooo`<000000`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?l0ooooVP3oool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000`3oool20000
00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000
oooo0?ooo`020?ooo`040000000007l0001o000000H0001o0`00003o0000Od/0001oC`3oool000H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool20000
00@0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`80
0000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo100000020?ooo`<000001`3oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`030000003oool0oooo00<0oooo
0P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?ooo`040000003o
ool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3o
ool2000000<0oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`80
0000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000020000O`030000000007l0001o00@0
001o0`00003o0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003oool0oooo00000?l0
ooooX`3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oooj40
oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooonS0?oo
o`001@3oool2000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0004
0?ooo`8000000P3oool3000000<0oooo1@0000030?ooo`8000000P3oool3000000@0oooo0`00003o
0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003oool0000000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo0`0000060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo00<000000?ooo`3o
ool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?ooohd0
oooo00040?ooo`8000000P3oool5000000040?ooo`0000000000000000D0oooo0P0000020?ooo`@0
0000103oool300000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 0 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?@0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`3d0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00l0oooo000D0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`00
503oool2000000<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooocX0oooo
000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`3o0?ooocX0oooo000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`3o0?oooc/0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`3o0?oooc/0oooo000D0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`3o0?oooc/0oooo000D0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3o0?oooc/0oooo
000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`3o0?oooc/0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo0?l0oooo>`3oool001@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0?l0oooo>`3oool001@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>`3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>`3oool001@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>`3o
ool001@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo0?l0oooo>`3oool001@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1A0?oo
o`030000003oool0oooo0?l0oooo>`3oool001@0oooo0P0000090?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00503oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00503oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0o`3ooolk
0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0o`3oooll0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0o`3oooll0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool0o`3oooll0?ooo`00503oool2000000`0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?oooc`0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?oooc`0oooo000D0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?oo
oc`0oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`3o0?oooc`0oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`3o0?oooc`0oooo000:0?ooo`<000001`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3oooll0?ooo`003@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`3o0?oooc`0oooo000;0?ooo`80001o00<000000000O`0007l0100007l30000
00l0001o00<000000000O`0007l04`0007l00`000000001o0000O`0c0000O`030000000007l0001o
0>`0001oC`3oool000X0oooo0`0000070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0?l0oooo?03oool000X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0?ooo`<0
00003@3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0?l0oooo?03oool000X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<000000`3oool2000000X0oooo
00D000000?ooo`3oool0oooo0000000c0?ooo`030000003oool0oooo0?l0oooo?03oool000X0oooo
100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?oooc`0oooo000D0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool0o`3oooll0?ooo`00503oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0?l0oooo?@3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooolm0?oo
o`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`3o0?ooocd0oooo000D0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0203oool2000002d0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00503o
ool00`000000oooo0?ooo`0]0?ooo`800000:`3oool00`000000oooo0?ooo`3o0?ooocd0oooo000D
0?ooo`030000003oool0oooo02l0oooo0P00000Y0?ooo`030000003oool0oooo0?l0oooo?@3oool0
01@0oooo00<000000?ooo`3oool0<@3oool2000002L0oooo00<000000?ooo`3oool0o`3ooolm0?oo
o`00503oool00`000000oooo0?ooo`0c0?ooo`8000009@3oool00`000000oooo0?ooo`3o0?ooocd0
oooo000D0?ooo`800000=P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo
?@3oool001@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0?l0oooo?@3oool001@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0?l0oooo?@3oool001@0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0oooo?@3oool001@0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo?@3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo
?@3oool001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0?l0oooo?@3oool001@0oooo0P00000k0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0o`3ooolm0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0o`3oooln0?ooo`00503oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0o`3oooln0?ooo`00503oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0o`3oooln0?ooo`00503o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0o`3o
ooln0?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0o`3oooln0?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0o`3oooln0?ooo`00503oool2000003l0oooo0P00000I0?ooo`03
0000003oool0oooo0?l0oooo?P3oool001@0oooo00<000000?ooo`3oool0@03oool2000001L0oooo
00<000000?ooo`3oool0o`3oooln0?ooo`00503oool00`000000oooo0?ooo`120?ooo`8000005@3o
ool00`000000oooo0?ooo`3o0?oooch0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?oooch0oooo000D0?ooo`030000003oool0oooo
04D0oooo0P00000B0?ooo`030000003oool0oooo0?l0oooo?P3oool000@0oooo100000030?ooo`80
00001`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0o`3oooln0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0o`3oooln0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080001o00<000000000O`00
07l0100007l3000004T0001o00<000000000O`0007l03@0007l00`000000001o0000O`3^0000Odl0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo0P00000=0?ooo`030000003oool0oooo0?l0oooo?P3oool000H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0C03oool2000000/0oooo00<000000?ooo`3oool0o`3oooln0?ooo`00103oool3000000<0oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3ooolo0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`800000
1`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
o`3ooolo0?ooo`00503oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0o`3ooolo0?ooo`00503oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`00503oool200000580oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3o0?ooocl0oooo000D0?ooo`030000003oool0oooo0580
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooocl0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooocl0oooo
000D0?ooo`030000003oool0oooo05<0oooo1P00003o0?oood40oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0
oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo
00060?ooo`030000003oool0oooo0080oooo0P0007l00`000000001o0000O`040000O`<00000o`00
07m;0000Odl0oooo00060?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00040?ooo`<000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0?l0ooooVP3oool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000`3oool2000000L0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`02
0?ooo`040000000007l0001o000000H0001o0`00003o0000Od/0001oC`3oool000H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P00
00070?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00
003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`030000003oool0oooo00<0oooo0P0007l00`00
0000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?ooo`040000003oool0oooo0?oo
o`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000<0
oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00
003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?oo
o`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`001`3oool010000000oooo0?ooo`0000020000O`030000000007l0001o00@0001o0`00003o
0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003oool0oooo00000?l0ooooX`3oool0
00L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oooj40oooo00040?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001@3oool2
000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo00040?ooo`800000
0P3oool3000000<0oooo1@0000030?ooo`8000000P3oool3000000@0oooo0`00003o0?ooohd0oooo
00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003oool0000000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0`00
00060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo00<000000?ooo`3oool00`3oool3
000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?ooohd0oooo00040?oo
o`8000000P3oool5000000040?ooo`0000000000000000D0oooo0P0000020?ooo`@00000103oool3
00000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 0 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0>l0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`3_0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`3m0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0?l0oooo=@3oool001@0oooo
0P0000030?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3ooole0?ooo`00503o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0o`3o
oole0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05`0oooo00<00000
0?ooo`3oool0o`3ooole0?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`00503oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`00503oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`00503o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3o
oolf0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o
0?ooocH0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`3o0?ooocH0oooo000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`3o0?ooocH0oooo000D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3o0?ooocH0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3o0?ooocH0oooo000D
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`3o
0?ooocH0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`3o0?ooocH0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0?l0oooo=P3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0?l0oooo=P3oool001@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0oooo=P3oool001@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0oooo=P3oool0
01@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
0?l0oooo=P3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0?l0oooo=P3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0?l0oooo=P3oool001@0oooo0P00000<0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0o`3ooolg0?ooo`00503oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3ooolg0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3ooolg0?oo
o`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool0o`3ooolg0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool0o`3ooolg0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0?l0oooo=`3oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool0o`3ooolg0?ooo`002`3oool20000O`030000000007l0001o00@0001o0`00000?0000
O`030000000007l0001o01<0001o00<000000000O`0007l0>00007l00`000000001o0000O`3W0000
Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`000000>@3oool00`000000oooo0?ooo`3o0?ooocL0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`3oool3000000d0
oooo00<000000?ooo`000000>@3oool00`000000oooo0?ooo`3o0?ooocL0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3000000<0oooo0P00000:0?ooo`050000
003oool0oooo0?ooo`000000>03oool00`000000oooo0?ooo`3o0?ooocL0oooo000:0?ooo`@00000
1P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`00503oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo0?l0oooo=`3oool001@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`3o0?ooocL0oooo000D0?ooo`8000007P3oool200000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0oooo=`3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0o`3ooolg0?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00P0oooo0P00000c0?ooo`030000003oool0oooo0?l0oooo=`3oool001@0oooo00<0
00000?ooo`3oool0;@3oool200000340oooo00<000000?ooo`3oool0o`3ooolg0?ooo`00503oool0
0`000000oooo0?ooo`0_0?ooo`800000;P3oool00`000000oooo0?ooo`3o0?ooocP0oooo000D0?oo
o`030000003oool0oooo0340oooo0P00000/0?ooo`030000003oool0oooo0?l0oooo>03oool001@0
oooo00<000000?ooo`3oool0<`3oool2000002X0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`00
503oool2000003H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?ooocP0oooo
000D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`3o0?ooocP0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`3o0?ooocP0oooo000D0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`3o0?ooocP0oooo000D0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?ooocP0oooo000D0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?ooocP0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`3o0?ooocP0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0?l0oooo>03oool001@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0?l0oooo>03oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo>03oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0oooo>03oool001@0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0oooo>03o
ool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0?l0oooo>03oool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0?l0oooo>03oool001@0oooo0P00000o0?ooo`8000007`3oool00`000000
oooo0?ooo`3o0?ooocP0oooo000D0?ooo`030000003oool0oooo0400oooo0P00000L0?ooo`030000
003oool0oooo0?l0oooo>@3oool001@0oooo00<000000?ooo`3oool0@P3oool2000001X0oooo00<0
00000?ooo`3oool0o`3oooli0?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0o`3oooli0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`8000005`3oool00`000000oooo0?ooo`3o0?ooocT0oooo00040?ooo`@000000`3oool2000000L0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0
oooo>@3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0
oooo>@3oool000H0oooo00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0
001o0`0000190000O`030000000007l0001o0180001o00<000000000O`0007l0j@0007m?0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1:0?ooo`8000004P3oool00`000000oooo0?ooo`3o0?ooocT0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0
oooo0P00000@0?ooo`030000003oool0oooo0?l0oooo>@3oool000@0oooo0`0000030?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0?l0oooo>@3oool000H0oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo
>@3oool001@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0?l0oooo>@3oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0?l0oooo>@3oool001@0oooo0P00001B0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0o`3oooli0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3oooli0?ooo`00503oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3oooli0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H000001@3oool00`000000oooo0?ooo`3o0?ooocT0oooo000D
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o
0?ooocT0oooo000D0?ooo`030000003oool0oooo05T0oooo00D000000?ooo`3oool0oooo0000003o
0?oooc`0oooo000D0?ooo`030000003oool0oooo05T0oooo00D000000?ooo`3oool0oooo0000003o
0?oooc`0oooo000D0?ooo`800000F`3oool010000000oooo0?ooo`00003o0?oooc`0oooo000D0?oo
o`030000003oool0oooo05X0oooo00@000000?ooo`3oool00000o`3oooll0?ooo`00503oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool000000?l0oooo?03oool001@0oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0000003o0?oooc`0oooo000D0?ooo`030000003oool0oooo05`0oooo
0P00003o0?oooc`0oooo000D0?ooo`030000003oool0oooo05`0oooo0P00003o0?oooc`0oooo000D
0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`00503oool20000
05h0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0oooo
V`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo0?l0oooo
VP3oool000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0?l0ooooVP3oool000H0oooo00<000000?ooo`3oool00P3oool20000O`030000000007l0
001o00@0001o0`00003o0000Od/0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`000007
0?ooo`030000003oool0oooo0?l0ooooVP3oool000H0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo0`0000030?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool010000000oooo0?ooo`3oool40000
00H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0oooo
V`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo10000003
0?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?oo
o`030000003oool0oooo0080oooo00@000000000O`0007l000001P0007l300000?l0001oB`0007m?
0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo0005
0?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool400000080oooo0`000007
0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo00<000000?ooo`3o
ool00`3oool20000O`030000000007l0001o00@0001o0`00003o0000Od/0001oC`3oool000H0oooo
00@000000?ooo`3oool0oooo0`0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooiX0
oooo00050?ooo`8000000`3oool4000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0
oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo00000080001o00<000000000
O`0007l0100007l300000?l0001oB`0007m?0?ooo`001@3oool2000000<0oooo00@000000?ooo`3o
ool00000o`3ooonS0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0?l0ooooX@3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00003o
0?oooj<0oooo00050?ooo`800000103oool200000?l0ooooY03oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool000@0oooo0P0000020?ooo`<000000`3oool5000000<0oooo0P0000020?ooo`<00000103o
ool300000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000?l0ooooS03oool000<0oooo00@000000?ooo`00
000000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool3000000H0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`000`3oool00`00
0000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000`3oool200000?l0ooooS@3oool000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0?l0ooooS@3oool000@0oooo0P0000020?ooo`D0000000@0oooo00000000000000001@3oool20000
0080oooo100000040?ooo`<00000o`3ooon<0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 0 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0>X0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`3Z0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`3h0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0?l0oooo<03oool001@0oooo
0P0000030?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0o`3oool`0?ooo`00503o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0o`3o
ool`0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool0o`3oool`0?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
05l0oooo00<000000?ooo`3oool0o`3ooola0?ooo`00503oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3ooola0?ooo`00503oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0o`3ooola0?ooo`00503o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0o`3o
oola0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o
0?oooc40oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`3o0?oooc40oooo000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0G03oool00`000000oooo0?ooo`3o0?oooc40oooo000D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3o0?oooc40oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3o0?oooc40oooo000D
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`3o
0?oooc40oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`3o0?oooc40oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo0?l0oooo<@3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo0?l0oooo<@3oool001@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0oooo<@3oool001@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0oooo<@3oool0
01@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
0?l0oooo<@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo0?l0oooo<@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo0?l0oooo<@3oool001@0oooo0P00000<0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00503oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0o`3ooolb0?oo
o`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool0o`3ooolb0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool0o`3ooolb0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0oooo<P3oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool0o`3ooolb0?ooo`002`3oool20000O`030000000007l0001o00@0001o0`00000?0000
O`030000000007l0001o01<0001o00<000000000O`0007l0?@0007l00`000000001o0000O`3R0000
Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`000000?P3oool00`000000oooo0?ooo`3o0?oooc80oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`3oool3000000d0
oooo00<000000?ooo`000000?P3oool00`000000oooo0?ooo`3o0?oooc80oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3000000<0oooo0P00000:0?ooo`050000
003oool0oooo0?ooo`000000?@3oool00`000000oooo0?ooo`3o0?oooc80oooo000:0?ooo`@00000
1P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00503oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo0?l0oooo<P3oool001@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`3o0?oooc80oooo000D0?ooo`8000007P3oool200000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0?l0oooo<P3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00P0oooo0P00000h0?ooo`030000003oool0oooo0?l0oooo<P3oool001@0oooo00<0
00000?ooo`3oool0;@3oool2000003H0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00503oool0
0`000000oooo0?ooo`0_0?ooo`800000=03oool00`000000oooo0?ooo`3o0?oooc80oooo000D0?oo
o`030000003oool0oooo0340oooo0P00000a0?ooo`030000003oool0oooo0?l0oooo<`3oool001@0
oooo00<000000?ooo`3oool0<`3oool2000002l0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`00
503oool2000003H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?oooc<0oooo
000D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`3o0?oooc<0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`3o0?oooc<0oooo000D0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`3o0?oooc<0oooo000D0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oooc<0oooo000D0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oooc<0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`3o0?oooc<0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0?l0oooo<`3oool001@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0?l0oooo<`3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo<`3oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0oooo<`3oool001@0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0oooo<`3o
ool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo0?l0oooo<`3oool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0?l0oooo<`3oool001@0oooo0P00000o0?ooo`800000903oool00`000000
oooo0?ooo`3o0?oooc<0oooo000D0?ooo`030000003oool0oooo0400oooo0P00000R0?ooo`030000
003oool0oooo0?l0oooo<`3oool001@0oooo00<000000?ooo`3oool0@P3oool200000200oooo00<0
00000?ooo`3oool0o`3ooolc0?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0o`3ooold0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000703oool00`000000oooo0?ooo`3o0?oooc@0oooo00040?ooo`@000000`3oool2000000L0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0
oooo=03oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0
oooo=03oool000H0oooo00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0
001o0`0000190000O`030000000007l0001o01L0001o00<000000000O`0007l0i00007m?0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1:0?ooo`8000005`3oool00`000000oooo0?ooo`3o0?oooc@0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0
oooo0P00000E0?ooo`030000003oool0oooo0?l0oooo=03oool000@0oooo0`0000030?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0?l0oooo=03oool000H0oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo
=03oool001@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0?l0oooo=03oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0?l0oooo=03oool001@0oooo0P00001B0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0o`3ooold0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooold0?ooo`00503oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooold0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H000002P3oool00`000000oooo0?ooo`3o0?oooc@0oooo000D
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o
0?oooc@0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3o0?oooc@0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`3o0?oooc@0oooo000D0?ooo`800000F`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0?l0oooo=@3oool001@0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo=@3oool001@0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo=@3oool0
01@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0?l0oooo=@3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0?l0oooo=@3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0?l0oooo=@3oool001@0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo=@3oool001@0oooo0P00001N
0?ooo`8000000`3oool00`000000oooo0?ooo`3o0?ooocD0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P0000000`3oool000000?ooo`3o0?ooocH0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00003o0?ooocL0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0
oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo
00060?ooo`030000003oool0oooo0080oooo0P0007l00`000000001o0000O`040000O`<00000o`00
07m;0000Odl0oooo00060?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00040?ooo`<000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0?l0ooooVP3oool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000`3oool2000000L0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`02
0?ooo`040000000007l0001o000000H0001o0`00003o0000Od/0001oC`3oool000H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P00
00070?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00
003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`030000003oool0oooo00<0oooo0P0007l00`00
0000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?ooo`040000003oool0oooo0?oo
o`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000<0
oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00
003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?oo
o`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`001`3oool010000000oooo0?ooo`0000020000O`030000000007l0001o00@0001o0`00003o
0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003oool0oooo00000?l0ooooX`3oool0
00L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oooj40oooo00040?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001@3oool2
000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo00040?ooo`800000
0P3oool3000000<0oooo1@0000030?ooo`8000000P3oool3000000@0oooo0`00003o0?ooohd0oooo
00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003oool0000000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0`00
00060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo00<000000?ooo`3oool00`3oool3
000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?ooohd0oooo00040?oo
o`8000000P3oool5000000040?ooo`0000000000000000D0oooo0P0000020?ooo`@00000103oool3
00000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 0 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0>D0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`3U0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`3c0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0?l0oooo:`3oool001@0oooo
0P0000030?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0o`3oool[0?ooo`00503o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0o`3o
ool[0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06H0oooo00<00000
0?ooo`3oool0o`3oool[0?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool0o`3oool/0?ooo`00503oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool0o`3oool/0?ooo`00503oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0o`3oool/0?ooo`00503o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0o`3o
ool/0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`3o
0?ooob`0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`3o0?ooob`0oooo000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`3o0?ooob`0oooo000D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`3o0?ooob`0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`3o0?ooob`0oooo000D
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o
0?ooob`0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`3o0?ooob`0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo0?l0oooo;03oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo0?l0oooo;03oool001@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0oooo;03oool001@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0oooo;03oool0
01@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
0?l0oooo;03oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo0?l0oooo;03oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo0?l0oooo;03oool001@0oooo0P00000<0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0o`3oool/0?ooo`00503oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool/0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0o`3oool]0?oo
o`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool0o`3oool]0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool0o`3oool]0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0oooo;@3oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool0o`3oool]0?ooo`002`3oool20000O`030000000007l0001o00@0001o0`00000?0000
O`030000000007l0001o01<0001o00<000000000O`0007l0@P0007l00`000000001o0000O`3M0000
Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`000000@`3oool00`000000oooo0?ooo`3o0?ooobd0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`3oool3000000d0
oooo00<000000?ooo`000000@`3oool00`000000oooo0?ooo`3o0?ooobd0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3000000<0oooo0P00000:0?ooo`050000
003oool0oooo0?ooo`000000@P3oool00`000000oooo0?ooo`3o0?ooobd0oooo000:0?ooo`@00000
1P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00503oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo0?l0oooo;@3oool001@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`3o0?ooobd0oooo000D0?ooo`8000007P3oool200000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0oooo;@3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0o`3oool]0?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00P0oooo0P00000m0?ooo`030000003oool0oooo0?l0oooo;@3oool001@0oooo00<0
00000?ooo`3oool0;@3oool2000003/0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00503oool0
0`000000oooo0?ooo`0_0?ooo`800000>@3oool00`000000oooo0?ooo`3o0?ooobd0oooo000D0?oo
o`030000003oool0oooo0340oooo0P00000g0?ooo`030000003oool0oooo0?l0oooo;@3oool001@0
oooo00<000000?ooo`3oool0<`3oool2000003D0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00
503oool2000003H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o0?ooobh0oooo
000D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`3o0?ooobh0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`3o0?ooobh0oooo000D0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`3o0?ooobh0oooo000D0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?ooobh0oooo000D0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?ooobh0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`3o0?ooobh0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo0?l0oooo;P3oool001@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo0?l0oooo;P3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo;P3oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo;P3oool001@0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo;P3o
ool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0?l0oooo;P3oool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0?l0oooo;P3oool001@0oooo0P00000o0?ooo`800000:@3oool00`000000
oooo0?ooo`3o0?ooobh0oooo000D0?ooo`030000003oool0oooo0400oooo0P00000W0?ooo`030000
003oool0oooo0?l0oooo;P3oool001@0oooo00<000000?ooo`3oool0@P3oool2000002D0oooo00<0
00000?ooo`3oool0o`3oool^0?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0o`3oool^0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`8000008P3oool00`000000oooo0?ooo`3o0?ooobh0oooo00040?ooo`@000000`3oool2000000L0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0
oooo;`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0
oooo;`3oool000H0oooo00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0
001o0`0000190000O`030000000007l0001o01`0001o00<000000000O`0007l0g`0007m?0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1:0?ooo`800000703oool00`000000oooo0?ooo`3o0?ooobl0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0
oooo0P00000J0?ooo`030000003oool0oooo0?l0oooo;`3oool000@0oooo0`0000030?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo0?l0oooo;`3oool000H0oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo
;`3oool001@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0?l0oooo;`3oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0?l0oooo;`3oool001@0oooo0P00001B0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0o`3oool_0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3oool_0?ooo`00503oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3oool_0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H000003`3oool00`000000oooo0?ooo`3o0?ooobl0oooo000D
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o
0?ooobl0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`3o0?ooobl0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`3o0?ooobl0oooo000D0?ooo`800000F`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo;`3oool001@0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo;`3oool001@0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo;`3oool0
01@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0?l0oooo;`3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0?l0oooo<03oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0?l0oooo<03oool001@0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo<03oool001@0oooo0P00001N
0?ooo`800000203oool00`000000oooo0?ooo`3o0?oooc00oooo000D0?ooo`030000003oool0oooo
05l0oooo0P0000060?ooo`030000003oool0oooo0?l0oooo<03oool001@0oooo00<000000?ooo`3o
ool0H@3oool2000000@0oooo00<000000?ooo`3oool0o`3oool`0?ooo`00503oool00`000000oooo
0?ooo`1S0?ooo`050000003oool0oooo0?ooo`000000o`3ooolb0?ooo`00503oool00`000000oooo
0?ooo`1T0?ooo`80000000<0oooo0000003oool0o`3ooola0?ooo`00503oool00`000000oooo0?oo
o`1V0?ooo`800000o`3ooolb0?ooo`00503oool00`000000oooo0?ooo`1W0?ooo`030000003oool0
oooo0?l0oooo<03oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo100000020?oo
o`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00060?ooo`030000
003oool0oooo0080oooo0P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo
00060?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00040?ooo`<000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooVP3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000
o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`0400000000
07l0001o000000H0001o0`00003o0000Od/0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3o0?oooiX0oooo00050?ooo`030000003oool0oooo00<0oooo0P0007l00`000000001o0000O`04
0000O`<00000o`0007m;0000Odl0oooo00060?ooo`040000003oool0oooo0?ooo`<000001`3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000<0oooo100000060?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`800000103oool2
000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool0
10000000oooo0?ooo`0000020000O`030000000007l0001o00@0001o0`00003o0000Od/0001oC`3o
ool000D0oooo0P0000030?ooo`040000003oool0oooo00000?l0ooooX`3oool000L0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oooj40oooo00040?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001@3oool2000000@0oooo0P00
003o0?oooj@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo00040?ooo`8000000P3oool3000000<0
oooo1@0000030?ooo`8000000P3oool3000000@0oooo0`00003o0?ooohd0oooo00030?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
003o0?oooh`0oooo00030?ooo`040000003oool0000000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0`0000060?ooo`030000
003oool0oooo0?l0ooooRP3oool000<0oooo00<000000?ooo`3oool00`3oool3000000<0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo0P00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?ooohd0oooo00040?ooo`8000000P3oool5
000000040?ooo`0000000000000000D0oooo0P0000020?ooo`@00000103oool300000?l0ooooS03o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 0 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0>00oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0L@3oool00`00
0000oooo0?ooo`3P0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`3^0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo9P3oool001@0oooo
0P0000030?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`00503o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0o`3o
oolV0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06/0oooo00<00000
0?ooo`3oool0o`3ooolV0?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
06X0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`00503oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo06T0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`00503oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`00503o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0o`3o
oolW0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`3o
0?ooobL0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`3o0?ooobL0oooo000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`3o0?ooobL0oooo000D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`3o0?ooobL0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`3o0?ooobL0oooo000D
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3o
0?ooobL0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`3o0?ooobL0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo0?l0oooo9`3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo0?l0oooo9`3oool001@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0?l0oooo9`3oool001@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0?l0oooo9`3oool0
01@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
0?l0oooo9`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo0?l0oooo9`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo0?l0oooo9`3oool001@0oooo0P00000<0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool0o`3ooolW0?ooo`00503oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0o`3ooolW0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0o`3ooolW0?oo
o`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3o
ool0o`3ooolW0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool0o`3ooolX0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0oooo:03oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05h0oooo00<00000
0?ooo`3oool0o`3ooolX0?ooo`002`3oool20000O`030000000007l0001o00@0001o0`00000?0000
O`030000000007l0001o01<0001o00<000000000O`0007l0A`0007l00`000000001o0000O`3H0000
Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`000000B03oool00`000000oooo0?ooo`3o0?ooobP0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`3oool3000000d0
oooo00<000000?ooo`000000B03oool00`000000oooo0?ooo`3o0?ooobP0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3000000<0oooo0P00000:0?ooo`050000
003oool0oooo0?ooo`000000A`3oool00`000000oooo0?ooo`3o0?ooobP0oooo000:0?ooo`@00000
1P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00503oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo0?l0oooo:03oool001@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`3o0?ooobP0oooo000D0?ooo`8000007P3oool200000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo:03oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00P0oooo0P0000120?ooo`030000003oool0oooo0?l0oooo:03oool001@0oooo00<0
00000?ooo`3oool0;@3oool200000400oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00503oool0
0`000000oooo0?ooo`0_0?ooo`800000?P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000D0?oo
o`030000003oool0oooo0340oooo0P00000l0?ooo`030000003oool0oooo0?l0oooo:03oool001@0
oooo00<000000?ooo`3oool0<`3oool2000003X0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00
503oool2000003H0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`3o0?ooobP0oooo
000D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`3o0?ooobP0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`3o0?ooobP0oooo000D0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`3o0?ooobP0oooo000D0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3o0?ooobT0oooo000D0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3o0?ooobT0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`3o0?ooobT0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo0?l0oooo:@3oool001@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo0?l0oooo:@3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0oooo:@3oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0oooo:@3oool001@0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0oooo:@3o
ool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo0?l0oooo:@3oool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0?l0oooo:@3oool001@0oooo0P00000o0?ooo`800000;P3oool00`000000
oooo0?ooo`3o0?ooobT0oooo000D0?ooo`030000003oool0oooo0400oooo0P00000/0?ooo`030000
003oool0oooo0?l0oooo:@3oool001@0oooo00<000000?ooo`3oool0@P3oool2000002X0oooo00<0
00000?ooo`3oool0o`3ooolY0?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`8000009`3oool00`000000oooo0?ooo`3o0?ooobT0oooo00040?ooo`@000000`3oool2000000L0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0
oooo:@3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0
oooo:@3oool000H0oooo00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0
001o0`0000190000O`030000000007l0001o0280001o00<000000000O`0007l0f@0007m?0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1:0?ooo`8000008P3oool00`000000oooo0?ooo`3o0?ooobT0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0
oooo0P00000P0?ooo`030000003oool0oooo0?l0oooo:@3oool000@0oooo0`0000030?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0?l0oooo:@3oool000H0oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo
:P3oool001@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0?l0oooo:P3oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0?l0oooo:P3oool001@0oooo0P00001B0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`00503oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000503oool00`000000oooo0?ooo`3o0?ooobX0oooo000D
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3o
0?ooobX0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`3o0?ooobX0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`3o0?ooobX0oooo000D0?ooo`800000F`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0?l0oooo:P3oool001@0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0oooo:P3oool001@0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo:P3oool0
01@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0?l0oooo:P3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0?l0oooo:P3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo:P3oool001@0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo:P3oool001@0oooo0P00001N
0?ooo`8000003P3oool00`000000oooo0?ooo`3o0?ooobX0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00000<0?ooo`030000003oool0oooo0?l0oooo:P3oool001@0oooo00<000000?ooo`3o
ool0H@3oool2000000X0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`00503oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`00503o
ool00`000000oooo0?ooo`1T0?ooo`8000001P3oool00`000000oooo0?ooo`3o0?ooob/0oooo000D
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o
0?ooob/0oooo000D0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`3o0?ooob/0oooo000D0?ooo`800000J@3oool01@000000oooo0?ooo`3oool00000
0?l0oooo;@3oool001@0oooo00<000000?ooo`3oool0J03oool01@000000oooo0?ooo`3oool00000
0?l0oooo;@3oool001@0oooo00<000000?ooo`3oool0J@3oool010000000oooo0?ooo`00003o0?oo
obd0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`000000o`3oool]0?ooo`00
503oool00`000000oooo0?ooo`1Z0?ooo`030000003oool000000?l0oooo;@3oool000@0oooo1000
00020?ooo`<000001`3oool00`000000oooo0?ooo`1[0?ooo`800000o`3oool]0?ooo`001P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool2
00000?l0oooo;@3oool000H0oooo00<000000?ooo`3oool00P3oool20000O`030000000007l0001o
00@0001o0`00001/0000O`030000000007l0001o0=/0001oC`3oool000H0oooo00@000000?ooo`3o
ool0oooo0`0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000H0oooo00D000000?ooo`3o
ool0oooo000000090?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo0`0000030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001P3oool010000000oooo
0?ooo`3oool4000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o
0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
00@0oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oo
oiX0oooo00050?ooo`030000003oool0oooo0080oooo00@000000000O`0007l000001P0007l30000
0?l0001oB`0007m?0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o
0?oooiX0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool40000
0080oooo0`0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo
00<000000?ooo`3oool00`3oool20000O`030000000007l0001o00@0001o0`00003o0000Od/0001o
C`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003oool0oooo0?l0oooo
VP3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`3o0?oooiX0oooo00050?ooo`8000000`3oool4000000H0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo
0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo00000080
001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001@3oool2000000<0oooo
00@000000?ooo`3oool00000o`3ooonS0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0?l0ooooX@3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00003o0?oooj<0oooo00050?ooo`800000103oool200000?l0ooooY03oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool000@0oooo0P0000020?ooo`<000000`3oool5000000<0oooo0P000002
0?ooo`<00000103oool300000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000?l0ooooS03oool000<0oooo
00@000000?ooo`00000000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool3000000H0oooo00<000000?ooo`3oool0o`3ooon:0?oo
o`000`3oool00`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool200000?l0ooooS@3oool0
00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0?l0ooooS@3oool000@0oooo0P0000020?ooo`D0000000@0oooo000000000000
00001@3oool200000080oooo100000040?ooo`<00000o`3ooon<0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 0 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D000000?ooo`000000oooo
000000030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<000001@3oool001@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0903oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0
000000X0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo000D0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool0f`3oool2000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool0
0`000000oooo0000000200000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool0
0`000000oooo0?ooo`040?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo0=/0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`030000003oool0oooo01/0oooo0`00000F0?ooo`00503oool00`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo0>T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00l0oooo000D0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool0o`3ooolQ0?ooo`00503oool2000000<0oooo00<000000?ooo`3oool0L@3oool00`000000oooo
0?ooo`3o0?ooob40oooo000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`3o0?ooob40oooo000D0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`3o0?ooob40oooo000D0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`3o0?ooob40oooo000D0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`3o0?ooob80
oooo000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo
0?ooo`3o0?ooob80oooo000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`3o0?ooob80oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`1/
0?ooo`030000003oool0oooo0?l0oooo8P3oool001@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo0?l0oooo8P3oool001@0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0?l0oooo8P3oool001@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0?l0oooo
8P3oool001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1[0?ooo`030000003o
ool0oooo0?l0oooo8P3oool001@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo0?l0oooo8P3oool001@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo0?l0oooo8P3oool001@0oooo0P0000090?ooo`03
0000003oool0oooo06X0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`00503oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`00503o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0o`3o
oolR0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0o`3ooolR0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
06P0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`00503oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`00503o
ool2000000`0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`3o0?ooob80oooo000D
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`3o
0?ooob80oooo000D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`3o0?ooob80oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`3o0?ooob80oooo000D0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`3o0?ooob80oooo000:0?ooo`<000001`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0o`3o
oolS0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`3o0?ooob<0oooo000;0?ooo`80001o00<000000000
O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`000000001o0000O`1<0000
O`030000000007l0001o0=<0001oC`3oool000X0oooo0`0000070?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0000001=0?ooo`030000003oool0oooo0?l0
oooo8`3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`040000
003oool0oooo0?ooo`<000003@3oool00`000000oooo0000001=0?ooo`030000003oool0oooo0?l0
oooo8`3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<00000
0`3oool2000000X0oooo00D000000?ooo`3oool0oooo0000001<0?ooo`030000003oool0oooo0?l0
oooo8`3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3o0?ooob<0oooo
000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00503oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0oooo8`3oool001@0oooo0P00000N0?oo
o`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0o`3ooolS0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?ooob<0oooo000D0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0203oool2000004L0oooo00<000000?ooo`3oool0
o`3ooolS0?ooo`00503oool00`000000oooo0?ooo`0]0?ooo`800000A@3oool00`000000oooo0?oo
o`3o0?ooob<0oooo000D0?ooo`030000003oool0oooo02l0oooo0P0000130?ooo`030000003oool0
oooo0?l0oooo8`3oool001@0oooo00<000000?ooo`3oool0<@3oool200000440oooo00<000000?oo
o`3oool0o`3ooolS0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`800000?`3oool00`000000
oooo0?ooo`3o0?ooob<0oooo000D0?ooo`800000=P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo0?l0oooo8`3oool001@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo0?l0oooo8`3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo8`3oool001@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0oooo8`3oool001@0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0?l0
oooo8`3oool001@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0?l0oooo8`3oool001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo0?l0oooo903oool001@0oooo0P00000k0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`00503oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`00503oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`00
503oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
o`3ooolT0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0o`3ooolT0?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`00503oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`00503oool2000003l0
oooo0P00000c0?ooo`030000003oool0oooo0?l0oooo903oool001@0oooo00<000000?ooo`3oool0
@03oool200000340oooo00<000000?ooo`3oool0o`3ooolT0?ooo`00503oool00`000000oooo0?oo
o`120?ooo`800000;`3oool00`000000oooo0?ooo`3o0?ooob@0oooo000D0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?ooob@0oooo000D0?oo
o`030000003oool0oooo04D0oooo0P00000/0?ooo`030000003oool0oooo0?l0oooo903oool000@0
oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0o`3ooolT0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0o`3ooolT0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
001o00<000000000O`0007l0100007l3000004T0001o00<000000000O`0007l09`0007l00`000000
001o0000O`3D0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04X0oooo0P00000W0?ooo`030000003oool0oooo0?l0
oooo903oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0C03oool2000002D0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`00
103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooolT0?ooo`001P3oool00`000000oooo
0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0o`3ooolT0?ooo`00503oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0o`3ooolT0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooolT0?ooo`00503oool20000
0580oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooobD0oooo000D0?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooobD0
oooo000D0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`3o0?ooobD0oooo000D0?ooo`030000003oool0oooo05<0oooo1P00000I0?ooo`030000003o
ool0oooo0?l0oooo9@3oool001@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0?l0oooo9@3oool001@0oooo00<000000?ooo`3oool0F@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo9@3oool001@0oooo00<000000?ooo`3o
ool0F@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo9@3oool001@0oooo
0P00001K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`00503o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3o
oolU0?ooo`00503oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0o`3ooolU0?ooo`00503oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`00503oool00`000000oooo
0?ooo`1L0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`00503o
ool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3o
oolU0?ooo`00503oool2000005h0oooo0P00000C0?ooo`030000003oool0oooo0?l0oooo9@3oool0
01@0oooo00<000000?ooo`3oool0G`3oool200000140oooo00<000000?ooo`3oool0o`3ooolU0?oo
o`00503oool00`000000oooo0?ooo`1Q0?ooo`8000003`3oool00`000000oooo0?ooo`3o0?ooobD0
oooo000D0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`3o0?ooobD0oooo000D0?ooo`030000003oool0oooo06@0oooo0P00000<0?ooo`030000003o
ool0oooo0?l0oooo9@3oool001@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0?l0oooo9@3oool001@0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo9@3oool001@0oooo0P00001Y0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`00503oool00`000000oooo
0?ooo`1X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3o
oolV0?ooo`00503oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0o`3ooolV0?ooo`00503oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`00103oool400000080oooo0`0000070?ooo`03
0000003oool0oooo06/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooobH0
oooo00060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1[0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`001P3o
ool00`000000oooo0?ooo`020?ooo`80001o00<000000000O`0007l0100007l3000006`0001o00<0
00000000O`0007l00P0007l00`000000001o0000O`3F0000Odl0oooo00060?ooo`040000003oool0
oooo0?ooo`<000001`3oool00`000000oooo0?ooo`1]0?ooo`050000003oool0oooo0?ooo`000000
o`3ooolX0?ooo`001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0
KP3oool2000000030?ooo`000000oooo0?l0oooo9`3oool000@0oooo0`0000030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0L03oool200000?l0oooo:03oool000H0oooo00@00000
0?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0o`3o
oolV0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo
0?ooo`3o0?oooiX0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`030000003oool0oooo0080oooo00@0
00000000O`0007l000001P0007l300000?l0001oB`0007m?0?ooo`001P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo
00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`800000103oool2000000L0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0oooo
V`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo0?l0oooo
VP3oool000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0?l0ooooVP3oool000D0oooo00<000000?ooo`3oool00`3oool20000O`030000000007l0
001o00@0001o0`00003o0000Od/0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`000007
0?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`8000000`3oool40000
00H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0oooo
V`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P000004
0?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo0007
0?ooo`040000003oool0oooo00000080001o00<000000000O`0007l0100007l300000?l0001oB`00
07m?0?ooo`001@3oool2000000<0oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooX@3oool000@0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00003o0?oooj<0oooo00050?ooo`800000103o
ool200000?l0ooooY03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool000@0oooo0P0000020?ooo`<0
00000`3oool5000000<0oooo0P0000020?ooo`<00000103oool300000?l0ooooS@3oool000<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo00000?l0ooooS03oool000<0oooo00@000000?ooo`00000000000P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool3000000H0oooo
00<000000?ooo`3oool0o`3ooon:0?ooo`000`3oool00`000000oooo0?ooo`030?ooo`<000000`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000`3oool200000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooS@3oool000@0oooo0P000002
0?ooo`D0000000@0oooo00000000000000001@3oool200000080oooo100000040?ooo`<00000o`3o
oon<0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 0 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0=H0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`3T0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0?l0oooo703oool001@0oooo
0P0000030?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`00503o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0o`3o
oolL0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07D0oooo00<00000
0?ooo`3oool0o`3ooolL0?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`00503oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`00503oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0o`3ooolM0?ooo`00503o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0o`3o
oolM0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`3o
0?oooad0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L@3oool00`00
0000oooo0?ooo`3o0?oooad0oooo000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`3o0?oooad0oooo000D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`3o0?oooad0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`3o0?oooad0oooo000D
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`3o
0?oooad0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`3o0?oooad0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo0?l0oooo7@3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo0?l0oooo7@3oool001@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0?l0oooo7@3oool001@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0?l0oooo7@3oool0
01@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
0?l0oooo7@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1]0?ooo`03
0000003oool0oooo0?l0oooo7@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo0?l0oooo7@3oool001@0oooo0P00000<0?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`00503oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0o`3ooolM0?oo
o`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3o
ool0o`3ooolM0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06X0oooo
00<000000?ooo`3oool0o`3ooolN0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0?l0oooo7P3oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo06P0oooo00<00000
0?ooo`3oool0o`3ooolN0?ooo`002`3oool20000O`030000000007l0001o00@0001o0`00000?0000
O`030000000007l0001o01<0001o00<000000000O`0007l0D@0007l00`000000001o0000O`3>0000
Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`000000DP3oool00`000000oooo0?ooo`3o0?oooah0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`3oool3000000d0
oooo00<000000?ooo`000000DP3oool00`000000oooo0?ooo`3o0?oooah0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3000000<0oooo0P00000:0?ooo`050000
003oool0oooo0?ooo`000000D@3oool00`000000oooo0?ooo`3o0?oooah0oooo000:0?ooo`@00000
1P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`00503oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo0?l0oooo7P3oool001@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`3o0?oooah0oooo000D0?ooo`8000007P3oool200000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0oooo7P3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool0o`3ooolN0?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00P0oooo0P00001<0?ooo`030000003oool0oooo0?l0oooo7P3oool001@0oooo00<0
00000?ooo`3oool0;@3oool2000004X0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`00503oool0
0`000000oooo0?ooo`0_0?ooo`800000B03oool00`000000oooo0?ooo`3o0?oooah0oooo000D0?oo
o`030000003oool0oooo0340oooo0P0000160?ooo`030000003oool0oooo0?l0oooo7P3oool001@0
oooo00<000000?ooo`3oool0<`3oool2000004@0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`00
503oool2000003H0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oooah0oooo
000D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`3o0?oooah0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`3o0?oooah0oooo000D0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`3o0?oooah0oooo000D0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?oooah0oooo000D0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?oooal0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`3o0?oooal0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo0?l0oooo7`3oool001@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo0?l0oooo7`3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0oooo7`3oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0?l0oooo7`3oool001@0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0?l0oooo7`3o
ool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo0?l0oooo7`3oool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo0?l0oooo7`3oool001@0oooo0P00000o0?ooo`800000>03oool00`000000
oooo0?ooo`3o0?oooal0oooo000D0?ooo`030000003oool0oooo0400oooo0P00000f0?ooo`030000
003oool0oooo0?l0oooo7`3oool001@0oooo00<000000?ooo`3oool0@P3oool2000003@0oooo00<0
00000?ooo`3oool0o`3ooolO0?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0o`3ooolO0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000<@3oool00`000000oooo0?ooo`3o0?oooal0oooo00040?ooo`@000000`3oool2000000L0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0
oooo7`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0
oooo7`3oool000H0oooo00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0
001o0`0000190000O`030000000007l0001o02`0001o00<000000000O`0007l0c`0007m?0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1:0?ooo`800000;03oool00`000000oooo0?ooo`3o0?oooal0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0
oooo0P00000Z0?ooo`030000003oool0oooo0?l0oooo7`3oool000@0oooo0`0000030?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0?l0oooo7`3oool000H0oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo
7`3oool001@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0?l0oooo803oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0?l0oooo803oool001@0oooo0P00001B0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooolP0?ooo`00503oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooolP0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H000007P3oool00`000000oooo0?ooo`3o0?ooob00oooo000D
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o
0?ooob00oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`3o0?ooob00oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`3o0?ooob00oooo000D0?ooo`800000F`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo0?l0oooo803oool001@0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0oooo803oool001@0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0oooo803oool0
01@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0?l0oooo803oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0?l0oooo803oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo0?l0oooo803oool001@0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0oooo803oool001@0oooo0P00001N
0?ooo`800000603oool00`000000oooo0?ooo`3o0?ooob00oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00000F0?ooo`030000003oool0oooo0?l0oooo803oool001@0oooo00<000000?ooo`3o
ool0H@3oool2000001@0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`00503oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooolP0?ooo`00503o
ool00`000000oooo0?ooo`1T0?ooo`8000004@3oool00`000000oooo0?ooo`3o0?ooob00oooo000D
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o
0?ooob40oooo000D0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`3o0?ooob40oooo000D0?ooo`800000J@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0?l0oooo8@3oool001@0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo8@3oool001@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo8@3oool001@0oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo8@3oool0
01@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0?l0oooo8@3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0?l0oooo8@3oool000H0oooo00<000000?ooo`3oool00P3o
ool20000O`030000000007l0001o00@0001o0`00001/0000O`030000000007l0001o00L0001o00<0
00000000O`0007l0d@0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo8@3o
ool000H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo06h0oooo0P00
00040?ooo`800000o`3ooolT0?ooo`00103oool3000000<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1`0?ooo`040000003oool0000000000?l0oooo9P3oool000H0oooo00@00000
0?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0o`3o
oolV0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo
0?ooo`3o0?oooiX0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`030000003oool0oooo0080oooo00@0
00000000O`0007l000001P0007l300000?l0001oB`0007m?0?ooo`001P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo
00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`800000103oool2000000L0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0oooo
V`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo0?l0oooo
VP3oool000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0?l0ooooVP3oool000D0oooo00<000000?ooo`3oool00`3oool20000O`030000000007l0
001o00@0001o0`00003o0000Od/0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`000007
0?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`8000000`3oool40000
00H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0oooo
V`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P000004
0?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo0007
0?ooo`040000003oool0oooo00000080001o00<000000000O`0007l0100007l300000?l0001oB`00
07m?0?ooo`001@3oool2000000<0oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooX@3oool000@0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00003o0?oooj<0oooo00050?ooo`800000103o
ool200000?l0ooooY03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool000@0oooo0P0000020?ooo`<0
00000`3oool5000000<0oooo0P0000020?ooo`<00000103oool300000?l0ooooS@3oool000<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo00000?l0ooooS03oool000<0oooo00@000000?ooo`00000000000P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool3000000H0oooo
00<000000?ooo`3oool0o`3ooon:0?ooo`000`3oool00`000000oooo0?ooo`030?ooo`<000000`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000`3oool200000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooS@3oool000@0oooo0P000002
0?ooo`D0000000@0oooo00000000000000001@3oool200000080oooo100000040?ooo`<00000o`3o
oon<0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 0 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0=40oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0P03oool00`00
0000oooo0?ooo`3A0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`3O0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0?l0oooo5`3oool001@0oooo
0P0000030?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`00503o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0o`3o
oolG0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07X0oooo00<00000
0?ooo`3oool0o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`00503oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`00503oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00503o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0o`3o
oolH0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`3o
0?oooaP0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`3o0?oooaP0oooo000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0M@3oool00`000000oooo0?ooo`3o0?oooaP0oooo000D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`3o0?oooaP0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`3o0?oooaP0oooo000D
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`3o
0?oooaP0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`3o0?oooaP0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0?l0oooo603oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo0?l0oooo603oool001@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0?l0oooo603oool001@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0?l0oooo603oool0
01@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo
0?l0oooo603oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1b0?ooo`03
0000003oool0oooo0?l0oooo603oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1b0?ooo`030000003oool0oooo0?l0oooo603oool001@0oooo0P00000<0?ooo`030000003o
ool0oooo0740oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00503oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0o`3ooolH0?oo
o`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool0o`3ooolH0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0700oooo
00<000000?ooo`3oool0o`3ooolH0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0?l0oooo603oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo06h0oooo00<00000
0?ooo`3oool0o`3ooolH0?ooo`002`3oool20000O`030000000007l0001o00@0001o0`00000?0000
O`030000000007l0001o01<0001o00<000000000O`0007l0EP0007l00`000000001o0000O`390000
Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`000000E`3oool00`000000oooo0?ooo`3o0?oooaT0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`3oool3000000d0
oooo00<000000?ooo`000000E`3oool00`000000oooo0?ooo`3o0?oooaT0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3000000<0oooo0P00000:0?ooo`050000
003oool0oooo0?ooo`000000EP3oool00`000000oooo0?ooo`3o0?oooaT0oooo000:0?ooo`@00000
1P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`00503oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo0?l0oooo6@3oool001@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`3o0?oooaT0oooo000D0?ooo`8000007P3oool200000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo6@3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0o`3ooolI0?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00P0oooo0P00001A0?ooo`030000003oool0oooo0?l0oooo6@3oool001@0oooo00<0
00000?ooo`3oool0;@3oool2000004l0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`00503oool0
0`000000oooo0?ooo`0_0?ooo`800000C@3oool00`000000oooo0?ooo`3o0?oooaT0oooo000D0?oo
o`030000003oool0oooo0340oooo0P00001;0?ooo`030000003oool0oooo0?l0oooo6@3oool001@0
oooo00<000000?ooo`3oool0<`3oool2000004T0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`00
503oool2000003H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`3o0?oooaT0oooo
000D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`3o0?oooaT0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`3o0?oooaT0oooo000D0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`3o0?oooaT0oooo000D0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?oooaT0oooo000D0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?oooaT0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`3o0?oooaT0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0?l0oooo6@3oool001@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0?l0oooo6@3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0oooo6P3oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0oooo6P3oool001@0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0oooo6P3o
ool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo0?l0oooo6P3oool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo0?l0oooo6P3oool001@0oooo0P00000o0?ooo`800000?@3oool00`000000
oooo0?ooo`3o0?oooaX0oooo000D0?ooo`030000003oool0oooo0400oooo0P00000k0?ooo`030000
003oool0oooo0?l0oooo6P3oool001@0oooo00<000000?ooo`3oool0@P3oool2000003T0oooo00<0
00000?ooo`3oool0o`3ooolJ0?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000=P3oool00`000000oooo0?ooo`3o0?oooaX0oooo00040?ooo`@000000`3oool2000000L0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0
oooo6P3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0?l0
oooo6P3oool000H0oooo00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0
001o0`0000190000O`030000000007l0001o0340001o00<000000000O`0007l0bP0007m?0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1:0?ooo`800000<@3oool00`000000oooo0?ooo`3o0?oooaX0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0
oooo0P00000_0?ooo`030000003oool0oooo0?l0oooo6P3oool000@0oooo0`0000030?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo0?l0oooo6P3oool000H0oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo
6P3oool001@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0?l0oooo6P3oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0?l0oooo6P3oool001@0oooo0P00001B0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`00503oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000903oool00`000000oooo0?ooo`3o0?oooaX0oooo000D
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o
0?oooa/0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`3o0?oooa/0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`3o0?oooa/0oooo000D0?ooo`800000F`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo6`3oool001@0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo6`3oool001@0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0oooo6`3oool0
01@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
0?l0oooo6`3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0?l0oooo6`3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo0?l0oooo6`3oool001@0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo6`3oool001@0oooo0P00001N
0?ooo`8000007@3oool00`000000oooo0?ooo`3o0?oooa/0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00000K0?ooo`030000003oool0oooo0?l0oooo6`3oool001@0oooo00<000000?ooo`3o
ool0H@3oool2000001T0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00503oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00503o
ool00`000000oooo0?ooo`1T0?ooo`8000005P3oool00`000000oooo0?ooo`3o0?oooa/0oooo000D
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o
0?oooa/0oooo000D0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`3o0?oooa/0oooo000D0?ooo`800000J@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0?l0oooo6`3oool001@0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo6`3oool001@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0oooo6`3oool001@0oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo6`3oool0
01@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0?l0oooo6`3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo703oool000H0oooo00<000000?ooo`3oool00P3o
ool20000O`030000000007l0001o00@0001o0`00001/0000O`030000000007l0001o00`0001o00<0
00000000O`0007l0c00007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3ooolL0?ooo`001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool0KP3oool2000000@0oooo0P0000000`3oool000000?ooo`020?ooo`030000003o
ool0oooo0?l0oooo703oool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0L03oool010000000oooo0000000000030?ooo`050000003oool0oooo0?ooo`000000
o`3ooolN0?ooo`001P3oool010000000oooo0?ooo`3oool4000000H0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000?l0oooo7P3oool001@0oooo
00<000000?ooo`3oool0N03oool010000000oooo0?ooo`00003o0?oooah0oooo000D0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`000000o`3ooolN0?ooo`00503oool2000007X0oooo00<0
00000?ooo`000000o`3ooolN0?ooo`00503oool00`000000oooo0?ooo`1j0?ooo`800000o`3ooolN
0?ooo`00503oool00`000000oooo0?ooo`1j0?ooo`800000o`3ooolN0?ooo`00503oool00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo0?l0oooo703oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000
o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool4
000000<0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool0
00D0oooo00<000000?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000o`0007m;
0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3o
ool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3
000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000
oooo0?ooo`030?ooo`80001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`00
1P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
1`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0
ooooVP3oool000D0oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0
ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo0?l0
ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P0007l00`00
0000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00050?ooo`8000000`3oool010000000
oooo0?ooo`00003o0?oooj<0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0o`3ooonQ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000?l0ooooX`3oool000D0oooo0P0000040?ooo`800000o`3ooonT0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00103oool200000080oooo0`0000030?ooo`D000000`3oool200000080oooo0`00
00040?ooo`<00000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`000`3oool010000000
oooo0000000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooohX0oooo00030?oo
o`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000o`3ooon=0?ooo`000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0o`3ooon=0?ooo`00103oool200000080oooo1@000000103oool000000000000000050?oo
o`8000000P3oool4000000@0oooo0`00003o0?oooh`0oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 0 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0<`0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`3<0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`3J0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0?l0oooo4P3oool001@0oooo
0P0000030?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0o`3ooolB0?ooo`00503o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0o`3o
oolB0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07l0oooo00<00000
0?ooo`3oool0o`3ooolB0?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`00503oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`00503oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`00503o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0o`3o
oolC0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`3o
0?oooa<0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`3o0?oooa<0oooo000D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`3o0?oooa<0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`3o0?oooa<0oooo000D
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`3o
0?oooa<0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo0?l0oooo4`3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo0?l0oooo4`3oool001@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0?l0oooo4`3oool001@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0?l0oooo4`3oool0
01@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0?l0oooo4`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo0?l0oooo4`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo0?l0oooo4`3oool001@0oooo0P00000<0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00503oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07D0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0?l0oooo4`3oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`002`3oool20000O`030000000007l0001o00@0001o0`00000?0000
O`030000000007l0001o01<0001o00<000000000O`0007l0G00007l00`000000001o0000O`330000
Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`000000G@3oool00`000000oooo0?ooo`3o0?oooa<0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`3oool3000000d0
oooo00<000000?ooo`000000G03oool00`000000oooo0?ooo`3o0?oooa@0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3000000<0oooo0P00000:0?ooo`050000
003oool0oooo0?ooo`000000F`3oool00`000000oooo0?ooo`3o0?oooa@0oooo000:0?ooo`@00000
1P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`00503oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo0?l0oooo503oool001@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`3o0?oooa@0oooo000D0?ooo`8000007P3oool200000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0?l0oooo503oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool0o`3ooolD0?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00P0oooo0P00001F0?ooo`030000003oool0oooo0?l0oooo503oool001@0oooo00<0
00000?ooo`3oool0;@3oool2000005@0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`00503oool0
0`000000oooo0?ooo`0_0?ooo`800000DP3oool00`000000oooo0?ooo`3o0?oooa@0oooo000D0?oo
o`030000003oool0oooo0340oooo0P00001@0?ooo`030000003oool0oooo0?l0oooo503oool001@0
oooo00<000000?ooo`3oool0<`3oool2000004h0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`00
503oool2000003H0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?oooa@0oooo
000D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`3o0?oooa@0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`3o0?oooa@0oooo000D0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`3o0?oooa@0oooo000D0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`3o0?oooa@0oooo000D0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`3o0?oooa@0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`3o0?oooa@0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo0?l0oooo503oool001@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo0?l0oooo503oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo0?l0oooo503oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo503oool001@0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo503o
ool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo0?l0oooo503oool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo0?l0oooo5@3oool001@0oooo0P00000o0?ooo`800000@P3oool00`000000
oooo0?ooo`3o0?oooaD0oooo000D0?ooo`030000003oool0oooo0400oooo0P0000100?ooo`030000
003oool0oooo0?l0oooo5@3oool001@0oooo00<000000?ooo`3oool0@P3oool2000003h0oooo00<0
00000?ooo`3oool0o`3ooolE0?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000>`3oool00`000000oooo0?ooo`3o0?oooaD0oooo00040?ooo`@000000`3oool2000000L0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0?l0
oooo5@3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0?l0
oooo5@3oool000H0oooo00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0
001o0`0000190000O`030000000007l0001o03H0001o00<000000000O`0007l0a@0007m?0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1:0?ooo`800000=P3oool00`000000oooo0?ooo`3o0?oooaD0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0
oooo0P00000d0?ooo`030000003oool0oooo0?l0oooo5@3oool000@0oooo0`0000030?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo0?l0oooo5@3oool000H0oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0oooo
5@3oool001@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo0?l0oooo5@3oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo0?l0oooo5@3oool001@0oooo0P00001B0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`00503oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000:@3oool00`000000oooo0?ooo`3o0?oooaD0oooo000D
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o
0?oooaD0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`3o0?oooaD0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`3o0?oooaD0oooo000D0?ooo`800000F`3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo0?l0oooo5@3oool001@0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0oooo5@3oool001@0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0oooo5@3oool0
01@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0?l0oooo5P3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0?l0oooo5P3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo5P3oool001@0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo5P3oool001@0oooo0P00001N
0?ooo`8000008P3oool00`000000oooo0?ooo`3o0?oooaH0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00000P0?ooo`030000003oool0oooo0?l0oooo5P3oool001@0oooo00<000000?ooo`3o
ool0H@3oool2000001h0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00503oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00503o
ool00`000000oooo0?ooo`1T0?ooo`8000006`3oool00`000000oooo0?ooo`3o0?oooaH0oooo000D
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o
0?oooaH0oooo000D0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`3o0?oooaH0oooo000D0?ooo`800000J@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0?l0oooo5P3oool001@0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo5P3oool001@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0oooo5P3oool001@0oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo5P3oool0
01@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0?l0oooo5P3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo5P3oool000H0oooo00<000000?ooo`3oool00P3o
ool20000O`030000000007l0001o00@0001o0`00001/0000O`030000000007l0001o0180001o00<0
00000000O`0007l0aP0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0o`3ooolF0?ooo`001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool0KP3oool2000000@0oooo0P0000000`3oool000000?ooo`080?ooo`030000003o
ool0oooo0?l0oooo5P3oool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0L03oool010000000oooo0000000000030?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0o`3ooolF0?ooo`001P3oool010000000oooo0?ooo`3oool4000000H0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0o`3ooolF0?ooo`00503oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00503oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`00503oool2000007X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooaL0oooo000D0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooaL0oooo
000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?oooaL0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3o0?oooaL0oooo000D0?ooo`030000003oool0oooo07`0oooo00D000000?oo
o`3oool0oooo0000003o0?oooaT0oooo000D0?ooo`030000003oool0oooo07`0oooo00D000000?oo
o`3oool0oooo0000003o0?oooaT0oooo000D0?ooo`030000003oool0oooo07d0oooo00@000000?oo
o`3oool00000o`3ooolI0?ooo`00503oool2000007l0oooo00<000000?ooo`000000o`3ooolI0?oo
o`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool000000?l0oooo6@3oool001@0oooo
00<000000?ooo`3oool0O`3oool200000?l0oooo6@3oool001@0oooo00<000000?ooo`3oool0O`3o
ool200000?l0oooo6@3oool001@0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`3o
0?oooaL0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o
0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`3o
0?oooiX0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`030000003oool0oooo0080oooo00@000000000
O`0007l000001P0007l300000?l0001oB`0007m?0?ooo`001P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o
0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`800000103oool2000000L0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo0?l0ooooVP3oool0
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0?l0ooooVP3oool000D0oooo00<000000?ooo`3oool00`3oool20000O`030000000007l0001o00@0
001o0`00003o0000Od/0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`03
0000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`8000000`3oool4000000H0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000040?ooo`80
00001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`04
0000003oool0oooo00000080001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?oo
o`001@3oool2000000<0oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooX@3oool000@0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00003o0?oooj<0oooo00050?ooo`800000103oool20000
0?l0ooooY03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool000@0oooo0P0000020?ooo`<000000`3o
ool5000000<0oooo0P0000020?ooo`<00000103oool300000?l0ooooS@3oool000<0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0?l0ooooS03oool000<0oooo00@000000?ooo`00000000000P3oool00`000000oooo000000030?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool3000000H0oooo00<00000
0?ooo`3oool0o`3ooon:0?ooo`000`3oool00`000000oooo0?ooo`030?ooo`<000000`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3o
ool200000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooS@3oool000@0oooo0P0000020?ooo`D0
000000@0oooo00000000000000001@3oool200000080oooo100000040?ooo`<00000o`3ooon<0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 0 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0<L0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`370?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3E0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0oooo3@3oool001@0oooo
0P0000030?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o`3oool=0?ooo`00503o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0o`3o
ool=0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08@0oooo00<00000
0?ooo`3oool0o`3oool=0?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0o`3oool=0?ooo`00503oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08<0oooo00<000000?ooo`3oool0o`3oool=0?ooo`00503oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0o`3oool=0?ooo`00503o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0o`3o
ool>0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`3o
0?ooo`h0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0P03oool00`00
0000oooo0?ooo`3o0?ooo`h0oooo000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0O`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo000D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo000D
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o
0?ooo`h0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`3o0?ooo`h0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo0?l0oooo3P3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo3P3oool001@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo3P3oool001@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo3P3oool0
01@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo
0?l0oooo3P3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo0?l0oooo3P3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo0?l0oooo3P3oool001@0oooo0P00000<0?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool0o`3oool>0?ooo`00503oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0o`3oool>0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0o`3oool>0?oo
o`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3o
ool0o`3oool>0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool0o`3oool>0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0?l0oooo3P3oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool0o`3oool>0?ooo`002`3oool20000O`030000000007l0001o00@0001o0`00000?0000
O`030000000007l0001o01<0001o00<000000000O`0007l0H@0007l00`000000001o0000O`2n0000
Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`000000HP3oool00`000000oooo0?ooo`3o0?ooo`h0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`3oool3000000d0
oooo00<000000?ooo`000000HP3oool00`000000oooo0?ooo`3o0?ooo`h0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3000000<0oooo0P00000:0?ooo`050000
003oool0oooo0?ooo`000000H03oool00`000000oooo0?ooo`3o0?ooo`l0oooo000:0?ooo`@00000
1P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool?0?ooo`00503oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1M0?ooo`030000003oool0oooo0?l0oooo3`3oool001@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`3o0?ooo`l0oooo000D0?ooo`8000007P3oool200000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0oooo3`3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo05/0
oooo00<000000?ooo`3oool0o`3oool?0?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00P0oooo0P00001K0?ooo`030000003oool0oooo0?l0oooo3`3oool001@0oooo00<0
00000?ooo`3oool0;@3oool2000005T0oooo00<000000?ooo`3oool0o`3oool?0?ooo`00503oool0
0`000000oooo0?ooo`0_0?ooo`800000E`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000D0?oo
o`030000003oool0oooo0340oooo0P00001E0?ooo`030000003oool0oooo0?l0oooo3`3oool001@0
oooo00<000000?ooo`3oool0<`3oool2000005<0oooo00<000000?ooo`3oool0o`3oool?0?ooo`00
503oool2000003H0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`3o0?ooo`l0oooo
000D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`3o0?ooo`l0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`3o0?ooo`l0oooo000D0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000D0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000D0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`3o0?ooo`l0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo0?l0oooo3`3oool001@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo0?l0oooo3`3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo3`3oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo3`3oool001@0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo3`3o
ool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo0?l0oooo3`3oool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo0?l0oooo3`3oool001@0oooo0P00000o0?ooo`800000B03oool00`000000
oooo0?ooo`3o0?ooo`l0oooo000D0?ooo`030000003oool0oooo0400oooo0P0000150?ooo`030000
003oool0oooo0?l0oooo403oool001@0oooo00<000000?ooo`3oool0@P3oool2000004<0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0o`3oool@0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000@03oool00`000000oooo0?ooo`3o0?oooa00oooo00040?ooo`@000000`3oool2000000L0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0?l0
oooo403oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0?l0
oooo403oool000H0oooo00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0
001o0`0000190000O`030000000007l0001o03/0001o00<000000000O`0007l0`00007m?0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1:0?ooo`800000>`3oool00`000000oooo0?ooo`3o0?oooa00oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0
oooo0P00000i0?ooo`030000003oool0oooo0?l0oooo403oool000@0oooo0`0000030?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo0?l0oooo403oool000H0oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0?l0oooo
403oool001@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0?l0oooo403oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0?l0oooo403oool001@0oooo0P00001B0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool0o`3oool@0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0o`3oool@0?ooo`00503oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0o`3oool@0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000;P3oool00`000000oooo0?ooo`3o0?oooa00oooo000D
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o
0?oooa00oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`3o0?oooa00oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`3o0?oooa00oooo000D0?ooo`800000F`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo403oool001@0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo403oool001@0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo403oool0
01@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0?l0oooo403oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0?l0oooo403oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0?l0oooo4@3oool001@0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo4@3oool001@0oooo0P00001N
0?ooo`8000009`3oool00`000000oooo0?ooo`3o0?oooa40oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00000U0?ooo`030000003oool0oooo0?l0oooo4@3oool001@0oooo00<000000?ooo`3o
ool0H@3oool2000002<0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`00503oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooolA0?ooo`00503o
ool00`000000oooo0?ooo`1T0?ooo`800000803oool00`000000oooo0?ooo`3o0?oooa40oooo000D
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o
0?oooa40oooo000D0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`3o0?oooa40oooo000D0?ooo`800000J@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0?l0oooo4@3oool001@0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo4@3oool001@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0oooo4@3oool001@0oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0oooo4@3oool0
01@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0?l0oooo4@3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo0?l0oooo4@3oool000H0oooo00<000000?ooo`3oool00P3o
ool20000O`030000000007l0001o00@0001o0`00001/0000O`030000000007l0001o01L0001o00<0
00000000O`0007l0`@0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0o`3ooolA0?ooo`001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool0KP3oool2000000@0oooo0P0000000`3oool000000?ooo`0=0?ooo`030000003o
ool0oooo0?l0oooo4@3oool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0L03oool010000000oooo0000000000030?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0o`3ooolA0?ooo`001P3oool010000000oooo0?ooo`3oool4000000H0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0o`3ooolA0?ooo`00503oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`00503oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`00503oool2000007X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oooa40oooo000D0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooa40oooo
000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`3o0?oooa80oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3o0?oooa80oooo000D0?ooo`030000003oool0oooo07`0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3o0?oooa80oooo000D0?ooo`030000003oool0oooo07`0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oooa80oooo000D0?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oooa80oooo
000D0?ooo`800000O`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo4P3o
ool001@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0?l0oooo4P3oool001@0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0?l0oooo4P3oool001@0oooo00<000000?ooo`3oool0O`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo4P3oool001@0oooo00<000000?ooo`3oool0
P03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo4P3oool001@0oooo00<0
00000?ooo`3oool0P@3oool200000080oooo00<000000?ooo`3oool0o`3ooolB0?ooo`00503oool0
0`000000oooo0?ooo`230?ooo`<00000o`3ooolD0?ooo`00503oool2000008H0oooo00<000000?oo
o`3oool0o`3ooolB0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
103oool4000000<0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0oooo
VP3oool000D0oooo00<000000?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000
o`0007m;0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0
ooooVP3oool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oo
oi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@00000
0P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool0
0`000000oooo0?ooo`030?ooo`80001o00<000000000O`0007l0100007l300000?l0001oB`0007m?
0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooVP3oool0
00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0?l0ooooVP3oool000D0oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oo
oi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003oool0
oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P00
07l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00050?ooo`8000000`3oool0
10000000oooo0?ooo`00003o0?oooj<0oooo00070?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0o`3ooonQ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000?l0ooooX`3oool000D0oooo0P0000040?ooo`800000o`3ooonT0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00103oool200000080oooo0`0000030?ooo`D000000`3oool200000080
oooo0`0000040?ooo`<00000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`000`3oool0
10000000oooo0000000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooohX0oooo
00030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000o`3ooon=0?ooo`00
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0o`3ooon=0?ooo`00103oool200000080oooo1@000000103oool0000000000000
00050?ooo`8000000P3oool4000000@0oooo0`00003o0?oooh`0oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 0 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0<80oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`320?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`3@0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0?l0oooo203oool001@0oooo
0P0000030?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0o`3oool80?ooo`00503o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0o`3o
ool80?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool0o`3oool80?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
08P0oooo00<000000?ooo`3oool0o`3oool80?ooo`00503oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool0o`3oool90?ooo`00503oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0o`3oool90?ooo`00503o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0Q03oool00`000000oooo0?ooo`3o0?ooo`T0oooo000D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`3o0?ooo`T0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`3o0?ooo`T0oooo000D
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0P`3oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`230?ooo`03
0000003oool0oooo0?l0oooo2@3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`220?ooo`030000003oool0oooo0?l0oooo2@3oool001@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0?l0oooo2@3oool001@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0?l0oooo2@3oool0
01@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0?l0oooo2@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo0?l0oooo2@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo0?l0oooo2@3oool001@0oooo0P00000<0?ooo`030000003o
ool0oooo0800oooo00<000000?ooo`3oool0o`3oool90?ooo`00503oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0o`3oool90?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0o`3oool90?oo
o`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3o
ool0o`3oool90?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07l0oooo
00<000000?ooo`3oool0o`3oool90?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo2P3oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07`0oooo00<00000
0?ooo`3oool0o`3oool:0?ooo`002`3oool20000O`030000000007l0001o00@0001o0`00000?0000
O`030000000007l0001o01<0001o00<000000000O`0007l0I@0007l00`000000001o0000O`2j0000
Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`000000IP3oool00`000000oooo0?ooo`3o0?ooo`X0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`3oool3000000d0
oooo00<000000?ooo`000000IP3oool00`000000oooo0?ooo`3o0?ooo`X0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3000000<0oooo0P00000:0?ooo`050000
003oool0oooo0?ooo`000000I@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo000:0?ooo`@00000
1P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`8000007P3oool200000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00P0oooo0P00001P0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0oooo00<0
00000?ooo`3oool0;@3oool2000005h0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool0
0`000000oooo0?ooo`0_0?ooo`800000G03oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D0?oo
o`030000003oool0oooo0340oooo0P00001J0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0
oooo00<000000?ooo`3oool0<`3oool2000005P0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00
503oool2000003H0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo
000D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`3o0?ooo`X0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooo`X0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`3o0?ooo`/0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0?l0oooo2`3oool001@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo0?l0oooo2`3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo0?l0oooo2`3oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0oooo2`3oool001@0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0oooo2`3o
ool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0?l0oooo2`3oool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0?l0oooo2`3oool001@0oooo0P00000o0?ooo`800000C03oool00`000000
oooo0?ooo`3o0?ooo`/0oooo000D0?ooo`030000003oool0oooo0400oooo0P00001:0?ooo`030000
003oool0oooo0?l0oooo2`3oool001@0oooo00<000000?ooo`3oool0@P3oool2000004P0oooo00<0
00000?ooo`3oool0o`3oool;0?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0o`3oool;0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000A@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00040?ooo`@000000`3oool2000000L0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0
oooo2`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0
oooo2`3oool000H0oooo00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0
001o0`0000190000O`030000000007l0001o0400001o00<000000000O`0007l0^`0007m?0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1:0?ooo`800000@03oool00`000000oooo0?ooo`3o0?ooo`/0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0
oooo0P00000n0?ooo`030000003oool0oooo0?l0oooo2`3oool000@0oooo0`0000030?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo0?l0oooo2`3oool000H0oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0oooo
2`3oool001@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo0?l0oooo2`3oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo0?l0oooo2`3oool001@0oooo0P00001B0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0o`3oool<0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0o`3oool<0?ooo`00503oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0o`3oool<0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000<P3oool00`000000oooo0?ooo`3o0?ooo``0oooo000D
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3o
0?ooo``0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`3o0?ooo``0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`3o0?ooo``0oooo000D0?ooo`800000F`3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0?l0oooo303oool001@0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0oooo303oool001@0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo303oool0
01@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
0?l0oooo303oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo0?l0oooo303oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo0?l0oooo303oool001@0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo303oool001@0oooo0P00001N
0?ooo`800000;03oool00`000000oooo0?ooo`3o0?ooo``0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00000Z0?ooo`030000003oool0oooo0?l0oooo303oool001@0oooo00<000000?ooo`3o
ool0H@3oool2000002P0oooo00<000000?ooo`3oool0o`3oool<0?ooo`00503oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3oool<0?ooo`00503o
ool00`000000oooo0?ooo`1T0?ooo`8000009@3oool00`000000oooo0?ooo`3o0?ooo``0oooo000D
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o
0?ooo``0oooo000D0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`3o0?ooo``0oooo000D0?ooo`800000J@3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo0?l0oooo303oool001@0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo3@3oool001@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0oooo3@3oool001@0oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0oooo3@3oool0
01@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0?l0oooo3@3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3oool=0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo3@3oool000H0oooo00<000000?ooo`3oool00P3o
ool20000O`030000000007l0001o00@0001o0`00001/0000O`030000000007l0001o01/0001o00<0
00000000O`0007l0_@0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0o`3oool=0?ooo`001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool0KP3oool2000000@0oooo0P0000000`3oool000000?ooo`0A0?ooo`030000003o
ool0oooo0?l0oooo3@3oool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0L03oool010000000oooo0000000000030?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0o`3oool=0?ooo`001P3oool010000000oooo0?ooo`3oool4000000H0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0o`3oool=0?ooo`00503oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0o`3oool=0?ooo`00503oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3oool>0?ooo`00503oool2000007X0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooo`h0oooo000D0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooo`h0oooo
000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`3o0?ooo`h0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`3o0?ooo`l0oooo000D0?ooo`030000003oool0oooo07`0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000D0?ooo`030000003oool0oooo07`0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000D0?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooa00oooo
000D0?ooo`800000O`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo403o
ool001@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0?l0oooo403oool001@0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo4@3oool001@0oooo00<000000?ooo`3oool0O`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo4@3oool001@0oooo00<000000?ooo`3oool0
P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo4@3oool001@0oooo00<0
00000?ooo`3oool0P@3oool2000000<0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`00503oool0
0`000000oooo0?ooo`230?ooo`<00000o`3ooolD0?ooo`00503oool2000008H0oooo00<000000?oo
o`3oool0o`3ooolB0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
103oool4000000<0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0oooo
VP3oool000D0oooo00<000000?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000
o`0007m;0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0
ooooVP3oool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oo
oi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@00000
0P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool0
0`000000oooo0?ooo`030?ooo`80001o00<000000000O`0007l0100007l300000?l0001oB`0007m?
0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooVP3oool0
00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0?l0ooooVP3oool000D0oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oo
oi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003oool0
oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P00
07l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00050?ooo`8000000`3oool0
10000000oooo0?ooo`00003o0?oooj<0oooo00070?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0o`3ooonQ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000?l0ooooX`3oool000D0oooo0P0000040?ooo`800000o`3ooonT0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00103oool200000080oooo0`0000030?ooo`D000000`3oool200000080
oooo0`0000040?ooo`<00000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`000`3oool0
10000000oooo0000000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooohX0oooo
00030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000o`3ooon=0?ooo`00
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0o`3ooon=0?ooo`00103oool200000080oooo1@000000103oool0000000000000
00050?ooo`8000000P3oool4000000@0oooo0`00003o0?oooh`0oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 0 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0;`0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0U@3oool00`00
0000oooo0?ooo`2l0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`3:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0?l0oooo0P3oool001@0oooo
0P0000030?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0o`3oool20?ooo`00503o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0o`3o
ool20?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool0o`3oool20?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0o`3oool20?ooo`00503oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oool30?ooo`00503oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0o`3oool30?ooo`00503o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0R`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000D
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0R@3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`03
0000003oool0oooo0?l0oooo0`3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo0?l0oooo0`3oool001@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0?l0oooo0`3oool001@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0?l0oooo0`3oool0
01@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo
0?l0oooo0`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo0?l0oooo0`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`270?ooo`030000003oool0oooo0?l0oooo0`3oool001@0oooo0P00000<0?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0o`3oool30?ooo`00503oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0o`3oool30?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0o`3oool30?oo
o`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08D0oooo
00<000000?ooo`3oool0o`3oool30?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0?l0oooo103oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0880oooo00<00000
0?ooo`3oool0o`3oool40?ooo`002`3oool20000O`030000000007l0001o00@0001o0`00000?0000
O`030000000007l0001o01<0001o00<000000000O`0007l0J`0007l00`000000001o0000O`2d0000
Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`000000K03oool00`000000oooo0?ooo`3o0?ooo`@0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`3oool3000000d0
oooo00<000000?ooo`000000K03oool00`000000oooo0?ooo`3o0?ooo`@0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3000000<0oooo0P00000:0?ooo`050000
003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000:0?ooo`@00000
1P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0o`3oool40?ooo`00503oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1X0?ooo`030000003oool0oooo0?l0oooo103oool001@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`3o0?ooo`@0oooo000D0?ooo`8000007P3oool200000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0?l0oooo103oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo06H0
oooo00<000000?ooo`3oool0o`3oool40?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00P0oooo0P00001V0?ooo`030000003oool0oooo0?l0oooo103oool001@0oooo00<0
00000?ooo`3oool0;@3oool2000006@0oooo00<000000?ooo`3oool0o`3oool40?ooo`00503oool0
0`000000oooo0?ooo`0_0?ooo`800000HP3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000D0?oo
o`030000003oool0oooo0340oooo0P00001P0?ooo`030000003oool0oooo0?l0oooo103oool001@0
oooo00<000000?ooo`3oool0<`3oool2000005h0oooo00<000000?ooo`3oool0o`3oool40?ooo`00
503oool2000003H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`3o0?ooo`@0oooo
000D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`3o0?ooo`@0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`3o0?ooo`@0oooo000D0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000D0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooo`@0oooo000D0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooo`@0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`3o0?ooo`D0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo0?l0oooo1@3oool001@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0?l0oooo1@3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0?l0oooo1@3oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0?l0oooo1@3oool001@0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0?l0oooo1@3o
ool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo0?l0oooo1@3oool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo0?l0oooo1@3oool001@0oooo0P00000o0?ooo`800000DP3oool00`000000
oooo0?ooo`3o0?ooo`D0oooo000D0?ooo`030000003oool0oooo0400oooo0P00001@0?ooo`030000
003oool0oooo0?l0oooo1@3oool001@0oooo00<000000?ooo`3oool0@P3oool2000004h0oooo00<0
00000?ooo`3oool0o`3oool50?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0o`3oool50?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000B`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo00040?ooo`@000000`3oool2000000L0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0
oooo1@3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0
oooo1@3oool000H0oooo00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0
001o0`0000190000O`030000000007l0001o04H0001o00<000000000O`0007l0]@0007m?0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1:0?ooo`800000AP3oool00`000000oooo0?ooo`3o0?ooo`D0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0
oooo0P0000140?ooo`030000003oool0oooo0?l0oooo1@3oool000@0oooo0`0000030?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0?l0oooo1@3oool000H0oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0oooo
1@3oool001@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo0?l0oooo1@3oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo0?l0oooo1@3oool001@0oooo0P00001B0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0o`3oool60?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool0o`3oool60?ooo`00503oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0o`3oool60?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000>03oool00`000000oooo0?ooo`3o0?ooo`H0oooo000D
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o
0?ooo`H0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`3o0?ooo`H0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`3o0?ooo`H0oooo000D0?ooo`800000F`3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0?l0oooo1P3oool001@0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0oooo1P3oool001@0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0oooo1P3oool0
01@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
0?l0oooo1P3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo0?l0oooo1P3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0?l0oooo1P3oool001@0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0oooo1P3oool001@0oooo0P00001N
0?ooo`800000<P3oool00`000000oooo0?ooo`3o0?ooo`H0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00000`0?ooo`030000003oool0oooo0?l0oooo1P3oool001@0oooo00<000000?ooo`3o
ool0H@3oool2000002h0oooo00<000000?ooo`3oool0o`3oool60?ooo`00503oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3oool60?ooo`00503o
ool00`000000oooo0?ooo`1T0?ooo`800000:`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo000D
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o
0?ooo`H0oooo000D0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`3o0?ooo`H0oooo000D0?ooo`800000J@3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0?l0oooo1P3oool001@0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo0?l0oooo1`3oool001@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0oooo1`3oool001@0oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0oooo1`3oool0
01@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0?l0oooo1`3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0o`3oool70?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo1`3oool000H0oooo00<000000?ooo`3oool00P3o
ool20000O`030000000007l0001o00@0001o0`00001/0000O`030000000007l0001o0240001o00<0
00000000O`0007l0]`0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0o`3oool70?ooo`001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool0KP3oool2000000@0oooo0P0000000`3oool000000?ooo`0G0?ooo`030000003o
ool0oooo0?l0oooo1`3oool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0L03oool010000000oooo0000000000030?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0o`3oool70?ooo`001P3oool010000000oooo0?ooo`3oool4000000H0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo000D0?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo1`3oool001@0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0=0?oo
o`8000001@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo000D0?ooo`800000NP3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0o`3oool70?ooo`00
503oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`3o0?ooo`L0oooo000D0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool0303oool00`000000oooo000000040?ooo`030000003oool0oooo0?l0oooo1`3o
ool001@0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0o`3oool70?ooo`00503oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo0?l0oooo1`3oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo000D
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000o`3oool90?ooo`00503oool2000007l0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000o`3o
ool90?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`00003o0?ooo`T0oooo000D0?ooo`030000003oool0
oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
00000?l0oooo2P3oool001@0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`000000o`3oool:0?ooo`00503oool00`000000
oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0000003o0?ooo`X0oooo000D0?ooo`030000003oool0oooo0840oooo0P0000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`000000o`3oool:0?ooo`00503oool00`000000oooo0?oo
o`230?ooo`<00000203oool200000?l0oooo2P3oool001@0oooo0P0000260?ooo`030000003oool0
oooo00H0oooo0P00003o0?ooo`X0oooo000D0?ooo`030000003oool0oooo08h0oooo0P00003o0?oo
o`X0oooo000D0?ooo`030000003oool0oooo08h0oooo0P00003o0?ooo`X0oooo000D0?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool0o`3oool80?ooo`00503oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo0?l0oooo203oool001@0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`3o0?ooo`P0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool000@0oooo100000030?ooo`8000001`3oool00`000000
oooo0?ooo`3o0?oooiX0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`030000003oool0oooo0080oooo
00@000000000O`0007l000001P0007l300000?l0001oB`0007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0
oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`800000103oool2000000L0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0
ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo0?l0
ooooVP3oool000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0?l0ooooVP3oool000D0oooo00<000000?ooo`3oool00`3oool20000O`0300000000
07l0001o00@0001o0`00003o0000Od/0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`00
00070?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`8000000`3oool4
000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0
ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P00
00040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00070?ooo`040000003oool0oooo00000080001o00<000000000O`0007l0100007l300000?l0001o
B`0007m?0?ooo`001@3oool2000000<0oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooX@3oool000@0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00003o0?oooj<0oooo00050?ooo`800000
103oool200000?l0ooooY03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool000@0oooo0P0000020?oo
o`<000000`3oool5000000<0oooo0P0000020?ooo`<00000103oool300000?l0ooooS@3oool000<0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo00000?l0ooooS03oool000<0oooo00@000000?ooo`00000000000P3oool00`000000oooo
000000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool3000000H0
oooo00<000000?ooo`3oool0o`3ooon:0?ooo`000`3oool00`000000oooo0?ooo`030?ooo`<00000
0`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000`3oool200000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooS@3oool000@0oooo0P00
00020?ooo`D0000000@0oooo00000000000000001@3oool200000080oooo100000040?ooo`<00000
o`3ooon<0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 0 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0;L0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0VP3oool00`00
0000oooo0?ooo`2g0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0?`0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0?`0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`3l0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0o03oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
0?`0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0T`3oool00`000000
oooo0?ooo`3l0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0980oooo
00<000000?ooo`3oool0o03oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo0?`0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo0?d0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`3m0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool0o@3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0?d0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`3m0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0o@3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
0?d0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?d0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`3m0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0o@3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo0?d0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`3m0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0o@3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0?d0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo0?d0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`3m0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0o@3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?d0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`3m0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`290?ooo`030000003oool0oooo0?d0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0?d0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`1a0000O`030000000007l0001o0:h0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000001b0?ooo`03
0000003oool0oooo0?d0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000LP3oool00`000000
oooo0?ooo`3m0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool000000740oooo00<000000?ooo`3o
ool0o@3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`3m0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0?d0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo06d0oooo00<000000?ooo`3oool0o@3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0oP3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0oP3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000J`3oool00`000000oooo0?ooo`3n0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000J@3oool00`000000oooo0?ooo`3n0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000I`3oool00`000000oooo0?ooo`3n0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000I@3oool00`000000oooo0?ooo`3n0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000H`3oool00`000000oooo0?ooo`3n0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
H03oool00`000000oooo0?ooo`3n0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool0oP3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?h0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3n0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0oP3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?h0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?oo
o`3n0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`3n
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0oP3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo0?h0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`3n0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool0oP3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?h0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3n0?ooo`00503oool2000003l0
oooo0P00001H0?ooo`030000003oool0oooo0?h0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00001F0?ooo`030000003oool0oooo0?h0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
001D0?ooo`030000003oool0oooo0?h0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`3n0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000D@3oool00`000000oooo0?ooo`3n0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`3n0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0oP3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o04/0001o00<000000000O`0007l0/00007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000B`3oool00`000000oooo0?ooo`3o0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000B@3oool00`000000
oooo0?ooo`3o0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0o`3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo0?l0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`3o0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0o`3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000?P3oool00`000000oooo0?ooo`3o0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0o`3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
0?l0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`3o0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`3o0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0o`3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo0?l0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`3o0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0?l0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`3o0?ooo`00503oool2
000005h0oooo0P00000h0?ooo`030000003oool0oooo0?l0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00000f0?ooo`030000003oool0oooo0?l0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00000d0?ooo`030000003oool0oooo0?l0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000<@3oool00`000000oooo0?ooo`3o0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0oooo0@3oool001@0
oooo0P00001Y0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3oool10?ooo`00
503oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
o`3oool10?ooo`00503oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0o`3oool10?ooo`00503oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0o`3oool10?ooo`00503oool00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool10?ooo`00103oool400000080
oooo0`0000070?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`3o0?ooo`40oooo00060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
o`3oool10?ooo`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<000000000O`0007l01000
07l3000006`0001o00<000000000O`0007l09`0007l00`000000001o0000O`2a0000Odl0oooo0006
0?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooo`40oooo0006
0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1^0?ooo`800000103o
ool2000000030?ooo`000000oooo01d0oooo00<000000?ooo`3oool0o`3oool10?ooo`00103oool3
000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1`0?ooo`040000003oool0
0000000000<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooo`40oooo0006
0?ooo`040000003oool0oooo0?ooo`@000001P3oool00`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0?l0oooo0@3oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3oool10?ooo`00503oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo00d0oooo0P00000;0?ooo`030000003oool0oooo
0?l0oooo0@3oool001@0oooo0P00001j0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`00
00002P3oool00`000000oooo0?ooo`3o0?ooo`40oooo000D0?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool0303oool00`000000oooo0000000:0?ooo`030000003oool0oooo0?l0oooo
0@3oool001@0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000000X0oooo00<000000?ooo`3oool0o`3oool10?ooo`00503oool00`000000oooo0?ooo`1k
0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`3o0?ooo`40oooo000D0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool02@3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0o`3oool10?ooo`00503oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo0?l0oooo0@3oool001@0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3o0?ooo`40oooo000D0?ooo`800000O`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oo
o`40oooo000D0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3oool10?ooo`00
503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo0@3oool001@0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooo`40oooo000D0?ooo`030000003oool0
oooo0800oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0o`3oool10?ooo`00503oool00`000000oooo0?ooo`210?oo
o`8000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3oool10?ooo`00503oool00`000000oooo0?ooo`230?ooo`<00000203oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo0P3oool001@0oooo0P0000260?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`80oooo
000D0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3o0?ooo`80oooo000D0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?ooo`80oooo000D0?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`80oooo000D0?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`80oooo000D0?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`80oooo
000D0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3o0?ooo`80oooo000D0?ooo`800000TP3oool01@000000oooo0?ooo`3oool000000?l0oooo103o
ool001@0oooo00<000000?ooo`3oool0TP3oool010000000oooo0?ooo`00003o0?ooo`@0oooo000D
0?ooo`030000003oool0oooo0980oooo00@000000?ooo`3oool00000o`3oool40?ooo`00503oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool000000?l0oooo103oool001@0oooo00<000000?oo
o`3oool0U03oool200000?l0oooo103oool000@0oooo100000030?ooo`8000001`3oool00`000000
oooo0?ooo`2E0?ooo`030000003oool0oooo0?l0oooo0P3oool000@0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo
00<000000?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000o`0007m;0000Odl0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000D0
oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3000000L0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?oo
o`030?ooo`80001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001P3oool0
10000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooVP3o
ool000D0oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3o
ool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P0007l00`000000001o
0000O`040000O`<00000o`0007m;0000Odl0oooo00050?ooo`8000000`3oool010000000oooo0?oo
o`00003o0?oooj<0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
o`3ooonQ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0
ooooX`3oool000D0oooo0P0000040?ooo`800000o`3ooonT0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00103oool200000080oooo0`0000030?ooo`D000000`3oool200000080oooo0`0000040?oo
o`<00000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`000`3oool010000000oooo0000
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooohX0oooo00030?ooo`030000
003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000030?ooo`800000o`3ooon=0?ooo`000`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
o`3ooon=0?ooo`00103oool200000080oooo1@000000103oool000000000000000050?ooo`800000
0P3oool4000000@0oooo0`00003o0?oooh`0oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 0 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0;80oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`2b0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`300?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0?L0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0?L0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`3g0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0m`3oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo
0?L0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0V03oool00`000000
oooo0?ooo`3g0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo09L0oooo
00<000000?ooo`3oool0m`3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2F0?ooo`030000003oool0oooo0?P0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo0?P0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0U@3oool00`000000oooo0?ooo`3h0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo09@0oooo00<000000?ooo`3oool0n03oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0?P0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`3h0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0n03oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
0?P0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0?P0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`3h0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0n03oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo0?P0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`3h0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0940oooo00<000000?ooo`3oool0n03oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0?P0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0?P0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`3h0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0n03oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0?P0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`3h0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo0?P0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0?P0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`1f0000O`030000000007l0001o0:T0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000001g0?ooo`03
0000003oool0oooo0?P0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000MP3oool00`000000
oooo0?ooo`3i0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool0000007D0oooo00<000000?ooo`3o
ool0n@3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`3i0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0?T0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0740oooo00<000000?ooo`3oool0n@3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0n@3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0n@3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000L03oool00`000000oooo0?ooo`3i0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000KP3oool00`000000oooo0?ooo`3i0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000K03oool00`000000oooo0?ooo`3i0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000JP3oool00`000000oooo0?ooo`3i0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000J03oool00`000000oooo0?ooo`3i0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
I@3oool00`000000oooo0?ooo`3i0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool0n@3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0?T0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`3i0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0n@3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0?T0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?oo
o`3i0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3i
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool0n@3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo0?T0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`3i0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool0n@3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0?X0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3j0?ooo`00503oool2000003l0
oooo0P00001L0?ooo`030000003oool0oooo0?X0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00001J0?ooo`030000003oool0oooo0?X0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
001H0?ooo`030000003oool0oooo0?X0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`3j0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000E@3oool00`000000oooo0?ooo`3j0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3j0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0nP3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o0500001o00<000000000O`0007l0Z`0007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000D03oool00`000000oooo0?ooo`3j0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000CP3oool00`000000
oooo0?ooo`3j0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0nP3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo0?X0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`3j0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0nP3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool0nP3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?X0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3j0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000@`3oool00`000000oooo0?ooo`3j0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0nP3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
0?X0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`3j0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`3j0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0n`3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo0?/0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`3k0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool0n`3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0?/0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3k0?ooo`00503oool2
000005h0oooo0P00000l0?ooo`030000003oool0oooo0?/0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00000j0?ooo`030000003oool0oooo0?/0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00000h0?ooo`030000003oool0oooo0?/0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3k0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000=@3oool00`000000oooo0?ooo`3k0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0n`3oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0?/0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?/0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3k0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0n`3o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo0?/0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`3k0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`3k0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo0?/0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`0/0000O`0300000000
07l0001o0:`0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0?/0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo0280oooo00<000000?ooo`3oool0n`3o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0n`3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0o03oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o03oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`8000003`3oool00`000000oooo0?ooo`3l0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000>0?ooo`03
0000003oool0oooo0?`0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000000>0?ooo`030000003oool0oooo0?`0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000>0?ooo`030000003o
ool0oooo0?`0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0?`0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0
00000?ooo`3oool0o03oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`3l0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?`0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`3l0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?`0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o03oool001@0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`3l0?ooo`00503oool00`000000oooo0?ooo`20
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0?d0oooo000D0?ooo`030000003oool0oooo0840oooo0P0000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3m0?oo
o`00503oool00`000000oooo0?ooo`230?ooo`<00000203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0?d0oooo000D0?ooo`800000QP3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0o@3oool001@0oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?h0oooo000D0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3n0?ooo`00503oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0oP3oool001@0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0
oooo000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`3o0?ooo`00503oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3oool001@0oooo0P00002B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0o`3oool10?ooo`00503oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo
0?ooo`000000o`3oool30?ooo`00503oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo
0?ooo`000000o`3oool30?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000003oool0oooo
00000?l0oooo0`3oool001@0oooo00<000000?ooo`3oool0U03oool200000?l0oooo103oool000@0
oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0?l0
oooo0P3oool000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo0?l0ooooVP3oool000D0oooo00<000000?ooo`3oool00P3oool010000000001o
0000O`0000060000O`<00000o`0007m;0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0
ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000040?ooo`8000001`3oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`80001o00<000000000O`0007l01000
07l300000?l0001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003o
ool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000030?ooo`@000001P3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P00
00070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@0
00000?ooo`3oool000000P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo
00050?ooo`8000000`3oool010000000oooo0?ooo`00003o0?oooj<0oooo00070?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`00103oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000?l0ooooX`3oool000D0oooo0P0000040?ooo`800000
o`3ooonT0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00103oool200000080oooo0`0000030?oo
o`D000000`3oool200000080oooo0`0000040?ooo`<00000o`3ooon=0?ooo`000`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
o`3ooon<0?ooo`000`3oool010000000oooo0000000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`<000001P3oool00`000000
oooo0?ooo`3o0?ooohX0oooo00030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`800000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0o`3ooon=0?ooo`00103oool200000080oooo1@00
0000103oool000000000000000050?ooo`8000000P3oool4000000@0oooo0`00003o0?oooh`0oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 0 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo0:d0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0Y03oool00`00
0000oooo0?ooo`2]0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`2k0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo0?80oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0?80oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`3b0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0lP3oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo
0?80oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0W@3oool00`000000
oooo0?ooo`3b0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo09`0oooo
00<000000?ooo`3oool0lP3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2L0?ooo`030000003oool0oooo0?80oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo0?<0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0VP3oool00`000000oooo0?ooo`3c0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool0l`3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0?<0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`3c0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0l`3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo
0?<0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0?<0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0U`3oool00`000000oooo
0?ooo`3c0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo09L0oooo00<0
00000?ooo`3oool0l`3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2G
0?ooo`030000003oool0oooo0?<0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0UP3oool00`000000oooo0?ooo`3c0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0l`3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo0?<0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0?<0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`3c0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0l`3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0?<0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`3c0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2C0?ooo`030000003oool0oooo0?<0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?<0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`1k0000O`030000000007l0001o0:@0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000001l0?ooo`03
0000003oool0oooo0?<0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000O03oool00`000000
oooo0?ooo`3c0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool0000007/0oooo00<000000?ooo`3o
ool0l`3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`3c0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0?@0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0m03oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0m03oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool0m03oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000M@3oool00`000000oooo0?ooo`3d0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000L`3oool00`000000oooo0?ooo`3d0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000L@3oool00`000000oooo0?ooo`3d0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000K`3oool00`000000oooo0?ooo`3d0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000K@3oool00`000000oooo0?ooo`3d0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
JP3oool00`000000oooo0?ooo`3d0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo06X0oooo00<000000?ooo`3oool0m03oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0?@0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`3d0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0m03oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0?@0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`3d0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3d
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool0m03oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo0?@0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`3d0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool0m03oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0?@0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`3d0?ooo`00503oool2000003l0
oooo0P00001R0?ooo`030000003oool0oooo0?@0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00001P0?ooo`030000003oool0oooo0?@0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
001N0?ooo`030000003oool0oooo0?@0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`3e0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000FP3oool00`000000oooo0?ooo`3e0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3e0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0m@3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o05D0001o00<000000000O`0007l0YP0007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000E@3oool00`000000oooo0?ooo`3e0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000D`3oool00`000000
oooo0?ooo`3e0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0m@3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo0?D0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`3e0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0m@3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0m@3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?D0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3e0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000B03oool00`000000oooo0?ooo`3e0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0m@3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
0?D0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`3e0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`3e0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0m@3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo0?D0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`3e0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0m@3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?D0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3e0?ooo`00503oool2
000005h0oooo0P0000120?ooo`030000003oool0oooo0?D0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00000o0?ooo`030000003oool0oooo0?H0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00000m0?ooo`030000003oool0oooo0?H0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3f0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000>P3oool00`000000oooo0?ooo`3f0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0mP3oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0?H0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0?H0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3f0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0mP3o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo0?H0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`3f0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3f0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0?H0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`0a0000O`0300000000
07l0001o0:L0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo0?H0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo02L0oooo00<000000?ooo`3oool0mP3o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0mP3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0mP3oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0mP3oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`8000005@3oool00`000000oooo0?ooo`3f0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000D0?ooo`03
0000003oool0oooo0?H0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000000D0?ooo`030000003oool0oooo0?H0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000D0?ooo`030000003o
ool0oooo0?H0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00000D0?ooo`030000003oool0oooo0?H0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000001<0oooo00<0
00000?ooo`3oool0mP3oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`0000004`3oool00`000000oooo0?ooo`3f0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?L0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`3g0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?L0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`3g0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`8000000`3oool00`000000oooo0?oo
o`3g0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0m`3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0m`3oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?L0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00L000000?oo
o`3oool0oooo0000003oool000000?T0oooo000D0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool000000?T0oooo000D0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`800000n@3oool001@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo0P00003i0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3g0?ooo`00503o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3o
ool001@0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0?l0oooo000D0?ooo`800000TP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0?l0oooo0@3oool001@0oooo00<000000?ooo`3oool0TP3oool01@000000oooo0?ooo`3oool00000
0?l0oooo0`3oool001@0oooo00<000000?ooo`3oool0TP3oool01@000000oooo0?ooo`3oool00000
0?l0oooo0`3oool001@0oooo00<000000?ooo`3oool0T`3oool010000000oooo0?ooo`00003o0?oo
o`<0oooo000D0?ooo`030000003oool0oooo09@0oooo0P00003o0?ooo`@0oooo00040?ooo`@00000
0`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`3o0?ooo`80oooo
00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`3o0?oooiX0oooo00050?ooo`030000003oool0oooo0080oooo00@000000000O`0007l00000
1P0007l300000?l0001oB`0007m?0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo
00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`3o0?oooiX0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
103oool400000080oooo0`0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3o
ool000D0oooo00<000000?ooo`3oool00`3oool20000O`030000000007l0001o00@0001o0`00003o
0000Od/0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003oool0
oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`3o
0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`8000000`3oool4000000H0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000040?ooo`8000001`3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0
oooo00000080001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001@3oool2
000000<0oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0?l0ooooX@3oool000@0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00003o0?oooj<0oooo00050?ooo`800000103oool200000?l0ooooY03o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool000@0oooo0P0000020?ooo`<000000`3oool5000000<0
oooo0P0000020?ooo`<00000103oool300000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000?l0ooooS03o
ool000<0oooo00@000000?ooo`00000000000P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool3000000H0oooo00<000000?ooo`3oool0
o`3ooon:0?ooo`000`3oool00`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool200000?l0
ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0?l0ooooS@3oool000@0oooo0P0000020?ooo`D0000000@0oooo
00000000000000001@3oool200000080oooo100000040?ooo`<00000o`3ooon<0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 0 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0:P0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0Z@3oool00`00
0000oooo0?ooo`2X0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`2f0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0>d0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo0>d0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`3]0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0k@3oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo
0>d0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0XP3oool00`000000
oooo0?ooo`3]0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0:40oooo
00<000000?ooo`3oool0k@3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2Q0?ooo`030000003oool0oooo0>d0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`2P
0?ooo`030000003oool0oooo0>d0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`3^0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo09h0oooo00<000000?ooo`3oool0kP3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo0>h0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`3^0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0kP3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo
0>h0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0>h0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0W03oool00`000000oooo
0?ooo`3^0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo09`0oooo00<0
00000?ooo`3oool0kP3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2L
0?ooo`030000003oool0oooo0>h0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`3^0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo09/0oooo00<000000?ooo`3oool0kP3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0>h0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0>h0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`3^0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0kP3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0>h0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0V@3oool00`000000oooo
0?ooo`3^0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2H0?ooo`030000003oool0oooo0>h0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo0>h0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`200000O`030000000007l0001o09l0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo000000210?ooo`03
0000003oool0oooo0>h0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000P@3oool00`000000
oooo0?ooo`3^0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool000000800oooo00<000000?ooo`3o
ool0kP3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`3^0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0>h0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool0kP3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0kP3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool0kP3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000N`3oool00`000000oooo0?ooo`3^0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000N03oool00`000000oooo0?ooo`3_0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000MP3oool00`000000oooo0?ooo`3_0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000M03oool00`000000oooo0?ooo`3_0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000LP3oool00`000000oooo0?ooo`3_0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
K`3oool00`000000oooo0?ooo`3_0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool0k`3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0>l0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`3_0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0k`3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0>l0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?oo
o`3_0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`3_
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool0k`3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1Y0?ooo`03
0000003oool0oooo0>l0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
J03oool00`000000oooo0?ooo`3_0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3oool0k`3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0>l0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`3_0?ooo`00503oool2000003l0
oooo0P00001W0?ooo`030000003oool0oooo0>l0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00001U0?ooo`030000003oool0oooo0>l0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
001S0?ooo`030000003oool0oooo0>l0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`3_0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000H03oool00`000000oooo0?ooo`3_0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3_0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0k`3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o05/0001o00<000000000O`0007l0X00007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000F`3oool00`000000oooo0?ooo`3_0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000F@3oool00`000000
oooo0?ooo`3_0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0k`3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0?00oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`3`0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0l03oool001@0oooo0P00001B0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool0l03oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0?00oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3`0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000C@3oool00`000000oooo0?ooo`3`0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0l03oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
0?00oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`3`0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`3`0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool0l03oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo0?00oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`3`0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0l03oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?00oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`3`0?ooo`00503oool2
000005h0oooo0P0000170?ooo`030000003oool0oooo0?00oooo000D0?ooo`030000003oool0oooo
05l0oooo0P0000150?ooo`030000003oool0oooo0?00oooo000D0?ooo`030000003oool0oooo0640
oooo0P0000130?ooo`030000003oool0oooo0?00oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`3`0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000@03oool00`000000oooo0?ooo`3`0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0l03oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0?00oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?00oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3`0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0l03o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0?00oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`3`0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`3a0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo0?40oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`0f0000O`0300000000
07l0001o0:80001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo0?40oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo02`0oooo00<000000?ooo`3oool0l@3o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0l@3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0l@3oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0l@3oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`8000006P3oool00`000000oooo0?ooo`3a0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000I0?ooo`03
0000003oool0oooo0?40oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000000I0?ooo`030000003oool0oooo0?40oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000I0?ooo`030000003o
ool0oooo0?40oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00000I0?ooo`030000003oool0oooo0?40oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000001P0oooo00<0
00000?ooo`3oool0l@3oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000603oool00`000000oooo0?ooo`3a0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?40oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`3a0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?40
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`3a0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`8000002@3oool00`000000oooo0?oo
o`3a0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0000000T0oooo00<00000
0?ooo`3oool0l@3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool0l@3oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0?40oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo0?40oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0l@3oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3a0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?40oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0l@3oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`3a0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0?40oooo000D0?ooo`800000TP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000003d0?ooo`00503oool00`000000
oooo0?ooo`2B0?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0
00000?@0oooo000D0?ooo`030000003oool0oooo0980oooo00D000000?ooo`3oool0oooo00000009
0?ooo`050000003oool0oooo0?ooo`000000m03oool001@0oooo00<000000?ooo`3oool0T`3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo00000?@0oooo000D0?ooo`030000003o
ool0oooo09@0oooo0P00000;0?ooo`040000003oool0oooo00000?@0oooo00040?ooo`@000000`3o
ool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`090?ooo`040000003o
ool0oooo00000?@0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool000000?@0oooo00050?ooo`030000003o
ool0oooo0080oooo00@000000000O`0007l000001P0007l300000:80001o00<000000000O`000000
Y@0007m?0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2R0?ooo`030000003oool000000?@0oooo00070?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2S0?ooo`800000
m03oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo0:<0oooo0P00003d0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000
003oool0oooo0:<0oooo0P00003d0?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`800000m03o
ool001@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`3b0?ooo`00503oool20000
0:D0oooo00<000000?ooo`3oool0lP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oo
oi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@00000
0P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool0
0`000000oooo0?ooo`030?ooo`80001o00<000000000O`0007l0100007l300000?l0001oB`0007m?
0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooVP3oool0
00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0?l0ooooVP3oool000D0oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oo
oi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003oool0
oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P00
07l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00050?ooo`8000000`3oool0
10000000oooo0?ooo`00003o0?oooj<0oooo00070?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0o`3ooonQ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000?l0ooooX`3oool000D0oooo0P0000040?ooo`800000o`3ooonT0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00103oool200000080oooo0`0000030?ooo`D000000`3oool200000080
oooo0`0000040?ooo`<00000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`000`3oool0
10000000oooo0000000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooohX0oooo
00030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000o`3ooon=0?ooo`00
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0o`3ooon=0?ooo`00103oool200000080oooo1@000000103oool0000000000000
00050?ooo`8000000P3oool4000000@0oooo0`00003o0?oooh`0oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 0 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0:<0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0[P3oool00`00
0000oooo0?ooo`2S0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`2a0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0>P0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0>P0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`3X0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0j03oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo
0>P0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`3X0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0:H0oooo
00<000000?ooo`3oool0j03oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2V0?ooo`030000003oool0oooo0>P0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo0>T0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0Y03oool00`000000oooo0?ooo`3Y0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0:<0oooo00<000000?ooo`3oool0j@3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo0>T0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`3Y0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0j@3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo
0>T0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0>T0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo
0?ooo`3Y0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0:40oooo00<0
00000?ooo`3oool0j@3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2Q
0?ooo`030000003oool0oooo0>T0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0X03oool00`000000oooo0?ooo`3Y0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0:00oooo00<000000?ooo`3oool0j@3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0>T0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0>T0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`3Y0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0j@3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo0>T0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0WP3oool00`000000oooo
0?ooo`3Y0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2M0?ooo`030000003oool0oooo0>T0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0>T0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`250000O`030000000007l0001o09X0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo000000260?ooo`03
0000003oool0oooo0>T0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000QP3oool00`000000
oooo0?ooo`3Y0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool0000008D0oooo00<000000?ooo`3o
ool0j@3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`3Y0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0>X0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0800oooo00<000000?ooo`3oool0jP3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0jP3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo07l0
oooo00<000000?ooo`3oool0jP3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000O`3oool00`000000oooo0?ooo`3Z0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000O@3oool00`000000oooo0?ooo`3Z0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000N`3oool00`000000oooo0?ooo`3Z0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000N@3oool00`000000oooo0?ooo`3Z0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000M`3oool00`000000oooo0?ooo`3Z0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`3Z0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool0jP3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0>X0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`3Z0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0jP3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0>X0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?oo
o`3Z0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`3Z
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo06l0oooo00<000000?oo
o`3oool0jP3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1^0?ooo`03
0000003oool0oooo0>X0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`3Z0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool0jP3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0>X0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`3Z0?ooo`00503oool2000003l0
oooo0P00001/0?ooo`030000003oool0oooo0>X0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00001Z0?ooo`030000003oool0oooo0>X0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
001X0?ooo`030000003oool0oooo0>X0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`3Z0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000I03oool00`000000oooo0?ooo`3[0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`3[0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0j`3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o05l0001o00<000000000O`0007l0W00007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000G`3oool00`000000oooo0?ooo`3[0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000G@3oool00`000000
oooo0?ooo`3[0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0j`3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo0>/0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0F@3oool00`000000oooo0?ooo`3[0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0j`3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0j`3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0>/0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`3[0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000DP3oool00`000000oooo0?ooo`3[0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0j`3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
0>/0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`3[0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`3[0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0j`3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0>/0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`3[0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool0j`3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0>/0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3[0?ooo`00503oool2
000005h0oooo0P00001<0?ooo`030000003oool0oooo0>/0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00001:0?ooo`030000003oool0oooo0>/0oooo000D0?ooo`030000003oool0oooo0640
oooo0P0000170?ooo`030000003oool0oooo0>`0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3/0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000A03oool00`000000oooo0?ooo`3/0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0k03oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0>`0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0>`0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3/0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0k03o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo0>`0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`3/0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3/0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo0>`0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`0k0000O`0300000000
07l0001o09d0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo0>`0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo0340oooo00<000000?ooo`3oool0k03o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0k03o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0k03oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0k03oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`8000007`3oool00`000000oooo0?ooo`3/0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000N0?ooo`03
0000003oool0oooo0>`0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000000N0?ooo`030000003oool0oooo0>`0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000N0?ooo`030000003o
ool0oooo0>`0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00000N0?ooo`030000003oool0oooo0>`0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000001d0oooo00<0
00000?ooo`3oool0k03oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`0000007@3oool00`000000oooo0?ooo`3/0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0>`0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`3]0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0>d0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`3]0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`8000003@3oool00`000000oooo0?oo
o`3]0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0000000d0oooo00<00000
0?ooo`3oool0k@3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000`0oooo00<00000
0?ooo`3oool0k@3oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo0>d0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`030000003oool0oooo0>d0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0k@3oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`3]0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0>d0oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0k@3oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3]0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0>d0oooo000D0?ooo`800000TP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3]0?ooo`00
503oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0>h0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0kP3oool001@0oooo00<000000?ooo`3oool0T`3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0kP3oool001@0oooo00<000000?ooo`3oool0
U03oool2000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3_0?ooo`00103o
ool4000000<0oooo0P0000070?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0>l0oooo00040?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2R0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0k`3oool000D0oooo00<000000?ooo`3oool00P3oool0
10000000001o0000O`0000060000O`<00000XP0007l01@000000001o0000O`0007l000000:<0001o
C`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0XP3oool01@000000oooo0?ooo`3oool000000?80oooo00070?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2S0?ooo`04
0000003oool0oooo00000?80oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`2S0?ooo`030000003oool000000?<0oooo00050?oo
o`800000103oool2000000L0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0000003c0?oo
o`00503oool00`000000oooo0?ooo`2S0?ooo`030000003oool000000?<0oooo000D0?ooo`030000
003oool0oooo0:@0oooo00<000000?ooo`3oool0lP3oool001@0oooo0P00002U0?ooo`030000003o
ool0oooo0?80oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool400000080oooo0`0000070?oo
o`030000003oool0oooo0?l0ooooVP3oool000@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo00<000000?ooo`3oool0
0`3oool20000O`030000000007l0001o00@0001o0`00003o0000Od/0001oC`3oool000H0oooo00@0
00000?ooo`3oool0oooo0`0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00050?ooo`8000000`3oool4000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo00000080001o00<000000000O`00
07l0100007l300000?l0001oB`0007m?0?ooo`001@3oool2000000<0oooo00@000000?ooo`3oool0
0000o`3ooonS0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0
ooooX@3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00003o0?oo
oj<0oooo00050?ooo`800000103oool200000?l0ooooY03oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool000@0oooo0P0000020?ooo`<000000`3oool5000000<0oooo0P0000020?ooo`<00000103oool3
00000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo00000?l0ooooS03oool000<0oooo00@000000?ooo`000000
00000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool3000000H0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`000`3oool00`000000
oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool200000?l0ooooS@3oool000<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0
ooooS@3oool000@0oooo0P0000020?ooo`D0000000@0oooo00000000000000001@3oool200000080
oooo100000040?ooo`<00000o`3ooon<0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 0 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D000000?ooo`000000oooo
000000030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<000001@3oool001@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0903oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0
000000X0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo000D0?ooo`030000003oool0oooo0;<0oooo00<00000
0?ooo`3oool0WP3oool2000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool0
0`000000oooo0000000200000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool0
0`000000oooo0?ooo`040?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`00
0000oooo0?ooo`2c0?ooo`030000003oool0oooo09h0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`030000003oool0oooo01/0oooo0`00000F0?ooo`00503oool00`000000oooo0?ooo`2c0?oo
o`030000003oool0oooo0:`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00l0oooo000D0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3o
ool0h`3oool001@0oooo0P0000030?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0
h`3oool001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2]0?ooo`030000003o
ool0oooo0><0oooo000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0[@3oool0
0`000000oooo0?ooo`3S0?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0:`0oooo00<000000?ooo`3oool0h`3oool001@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2/0?ooo`030000003oool0oooo0><0oooo000D0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`3S0?ooo`00503oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0h`3oool001@0oooo0P000007
0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0h`3oool001@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0>@0oooo000D0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`3T0?ooo`00
503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0
i03oool001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2X0?ooo`030000003o
ool0oooo0>@0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0Y`3oool0
0`000000oooo0?ooo`3T0?ooo`00503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0:L0oooo00<000000?ooo`3oool0i03oool001@0oooo0P0000090?ooo`030000003oool0oooo0:L0
oooo00<000000?ooo`3oool0i03oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2V0?ooo`030000003oool0oooo0>@0oooo000D0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0YP3oool00`000000oooo0?ooo`3T0?ooo`00503oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0i03oool001@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo0>@0oooo000D0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`3T0?ooo`00
503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0
i03oool001@0oooo0P00000<0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0i03o
ool001@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0
oooo0>@0oooo000D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0Y03oool00`00
0000oooo0?ooo`3T0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0:<0
oooo00<000000?ooo`3oool0i03oool001@0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`2S0?ooo`030000003oool0oooo0>@0oooo000:0?ooo`<000001`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0i03oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0:40oooo00<00000
0?ooo`3oool0i03oool000/0oooo0P0007l00`000000001o0000O`040000O`<000003`0007l00`00
0000001o0000O`0C0000O`030000000007l0001o08X0001o00<000000000O`0007l0U@0007m?0?oo
o`002P3oool3000000L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0000008/0oooo00<000000?ooo`3oool0i03oool000X0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0?ooo`<000003@3oool00`000000
oooo0000002;0?ooo`030000003oool0oooo0>@0oooo000:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool04@3oool3000000<0oooo0P00000:0?ooo`050000003oool0oooo0?ooo`00
0000RP3oool00`000000oooo0?ooo`3T0?ooo`002P3oool4000000H0oooo00<000000?ooo`3oool0
6@3oool2000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`270?ooo`030000
003oool0oooo0>@0oooo000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0i03o
ool001@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`3T0?ooo`00503oool20000
01h0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`3T0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`3T0?ooo`00503oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00P0oooo0P0000250?ooo`030000003oool0oooo0>@0oooo
000D0?ooo`030000003oool0oooo02d0oooo0P0000220?ooo`030000003oool0oooo0>D0oooo000D
0?ooo`030000003oool0oooo02l0oooo0P0000200?ooo`030000003oool0oooo0>D0oooo000D0?oo
o`030000003oool0oooo0340oooo0P00001n0?ooo`030000003oool0oooo0>D0oooo000D0?ooo`03
0000003oool0oooo03<0oooo0P00001l0?ooo`030000003oool0oooo0>D0oooo000D0?ooo`800000
=P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0>D0oooo000D0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`3U0?ooo`00503oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0i@3oool0
01@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0>D0oooo000D0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3U0?ooo`00503oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool0i@3oool001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`1e0?ooo`030000003oool0oooo0>D0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0>D0oooo000D0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`3U0?ooo`00503oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool0i@3oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0>D0oooo000D0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`3U0?ooo`00503oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0i@3oool0
01@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
0>D0oooo000D0?ooo`800000?`3oool200000740oooo00<000000?ooo`3oool0i@3oool001@0oooo
00<000000?ooo`3oool0@03oool2000006l0oooo00<000000?ooo`3oool0i@3oool001@0oooo00<0
00000?ooo`3oool0@P3oool2000006d0oooo00<000000?ooo`3oool0i@3oool001@0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0>D0oooo000D0?oo
o`030000003oool0oooo04D0oooo0P00001Z0?ooo`030000003oool0oooo0>D0oooo00040?ooo`@0
00000`3oool2000000L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo0>D0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0IP3oool00`000000
oooo0?ooo`3U0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080001o00<000000000O`00
07l0100007l3000004T0001o00<000000000O`0007l0I@0007l00`000000001o0000O`2F0000Odl0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo0P00001U0?ooo`030000003oool0oooo0>D0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0
oooo0P00001S0?ooo`030000003oool0oooo0>D0oooo00040?ooo`<000000`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`3U0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0iP3oool001@0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0>H0oooo000D
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3V
0?ooo`00503oool200000580oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3V0?oo
o`00503oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool0iP3oool001@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo0>H0oooo000D0?ooo`030000003oool0oooo05<0oooo1P00001G0?ooo`030000003o
ool0oooo0>H0oooo000D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`3V0?ooo`00503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool0iP3oool001@0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0>H0oooo000D0?ooo`800000F`3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0>H0oooo000D0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`3V0?ooo`00503oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0iP3oool001@0oooo00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0>H0oooo000D0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3V0?ooo`00
503oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
iP3oool001@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo0>H0oooo000D0?ooo`800000GP3oool200000540oooo00<000000?ooo`3oool0iP3oool0
01@0oooo00<000000?ooo`3oool0G`3oool2000004l0oooo00<000000?ooo`3oool0iP3oool001@0
oooo00<000000?ooo`3oool0H@3oool2000004d0oooo00<000000?ooo`3oool0iP3oool001@0oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0>H0oooo
000D0?ooo`030000003oool0oooo06@0oooo0P00001:0?ooo`030000003oool0oooo0>H0oooo000D
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3V
0?ooo`00503oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool0iP3oool001@0oooo0P00001Y0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool0iP3oool001@0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo0>H0oooo000D0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`3V0?ooo`00503oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0iP3oool001@0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo0>H0oooo00040?ooo`@000000P3oool3000000L0
oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0>L0
oooo00060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1[0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0i`3oool000H0oooo00<0
00000?ooo`3oool00P3oool20000O`030000000007l0001o00@0001o0`00001/0000O`0300000000
07l0001o0400001o00<000000000O`0007l0V00007m?0?ooo`001P3oool010000000oooo0?ooo`3o
ool3000000L0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0i`3oool000H0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo06h0oooo0P0000040?ooo`80000000<0oooo0000003oool0=P3o
ool00`000000oooo0?ooo`3W0?ooo`00103oool3000000<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1`0?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`3W0?ooo`001P3oool010000000oooo0?ooo`3oool4000000H0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`3W0?ooo`00503oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3W
0?ooo`00503oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00d0oooo0P00000T0?oo
o`030000003oool0oooo0>L0oooo000D0?ooo`800000NP3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0000002<0oooo00<000000?ooo`3oool0i`3oool001@0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool0
i`3oool001@0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000002<0oooo00<000000?ooo`3oool0i`3oool001@0oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000002<0oooo00<000000?ooo`3oool0i`3o
ool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`090?ooo`050000003oool0
oooo0?ooo`0000008P3oool00`000000oooo0?ooo`3W0?ooo`00503oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000R0?ooo`030000003o
ool0oooo0>L0oooo000D0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0i`3oool0
01@0oooo0P00001o0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo0>L0oooo000D0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0i`3oool001@0oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0>L0oooo000D0?ooo`030000003oool0oooo07l0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P00
000C0?ooo`030000003oool0oooo0>L0oooo000D0?ooo`030000003oool0oooo0800oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`0000004`3oool00`000000oooo0?ooo`3W0?ooo`00503oool00`000000oooo0?ooo`210?oo
o`8000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00@000000?oo
o`3oool000004P3oool00`000000oooo0?ooo`3W0?ooo`00503oool00`000000oooo0?ooo`230?oo
o`<00000203oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo00000180oooo00<00000
0?ooo`3oool0i`3oool001@0oooo0P0000260?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0203oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool0i`3oool0
01@0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3W0?ooo`00503oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0>L0oooo000D0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0i`3oool001@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`3W0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0>L0oooo000D0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3W0?oo
o`00503oool200000980oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3X0?ooo`00
503oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0j03oool001@0oooo
00<000000?ooo`3oool0TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo000000030?ooo`030000003oool0oooo0>P0oooo000D0?ooo`030000
003oool0oooo09<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool0j03oool001@0oooo00<000000?ooo`3oool0
U03oool2000000/0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0j03oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo
0?ooo`2E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0j03oool000@0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0j03oool000D0
oooo00<000000?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000XP0007l01@00
0000001o0000O`0007l0000000D0001o00<000000000O`000000V`0007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0000003Z0?ooo`001`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0X`3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool000000>X0oooo00040?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2S0?ooo`03
0000003oool0000000L0oooo0P00003Z0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000
003oool0oooo0:<0oooo00<000000?ooo`0000001`3oool200000>X0oooo000D0?ooo`030000003o
ool0oooo0:<0oooo00<000000?ooo`0000001`3oool200000>X0oooo000D0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3X0?ooo`00503oool20000
0:D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3X0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3o0?oooiX0oooo00050?ooo`030000003oool0oooo00<0oooo0P0007l00`000000001o0000O`04
0000O`<00000o`0007m;0000Odl0oooo00060?ooo`040000003oool0oooo0?ooo`<000001`3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000<0oooo100000060?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`800000103oool2
000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool0
10000000oooo0?ooo`0000020000O`030000000007l0001o00@0001o0`00003o0000Od/0001oC`3o
ool000D0oooo0P0000030?ooo`040000003oool0oooo00000?l0ooooX`3oool000L0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oooj40oooo00040?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001@3oool2000000@0oooo0P00
003o0?oooj@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo00040?ooo`8000000P3oool3000000<0
oooo1@0000030?ooo`8000000P3oool3000000@0oooo0`00003o0?ooohd0oooo00030?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
003o0?oooh`0oooo00030?ooo`040000003oool0000000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0`0000060?ooo`030000
003oool0oooo0?l0ooooRP3oool000<0oooo00<000000?ooo`3oool00`3oool3000000<0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo0P00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?ooohd0oooo00040?ooo`8000000P3oool5
000000040?ooo`0000000000000000D0oooo0P0000020?ooo`@00000103oool300000?l0ooooS03o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 0 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo09T0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`2I0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`2W0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo0=h0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo0=h0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`3N0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0gP3oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo
0=h0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0/@3oool00`000000
oooo0?ooo`3N0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;00oooo
00<000000?ooo`3oool0gP3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2`0?ooo`030000003oool0oooo0=h0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`2_
0?ooo`030000003oool0oooo0=h0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0[`3oool00`000000oooo0?ooo`3N0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0:d0oooo00<000000?ooo`3oool0g`3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0=l0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`3O0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0g`3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo
0=l0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0=l0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo
0?ooo`3O0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool0g`3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2[
0?ooo`030000003oool0oooo0=l0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`3O0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0g`3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0=l0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0=l0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`3O0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0g`3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0=l0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0Z03oool00`000000oooo
0?ooo`3O0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2W0?ooo`030000003oool0oooo0=l0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0=l0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`2?0000O`030000000007l0001o0900001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000002@0?ooo`03
0000003oool0oooo0=l0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000T03oool00`000000
oooo0?ooo`3O0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool0000008l0oooo00<000000?ooo`3o
ool0g`3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3O0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0=l0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool0g`3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0g`3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo08X0
oooo00<000000?ooo`3oool0g`3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000RP3oool00`000000oooo0?ooo`3O0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000R03oool00`000000oooo0?ooo`3O0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000QP3oool00`000000oooo0?ooo`3O0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000P`3oool00`000000oooo0?ooo`3P0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000P@3oool00`000000oooo0?ooo`3P0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
OP3oool00`000000oooo0?ooo`3P0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0h03oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0>00oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`3P0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0h03oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0>00oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?oo
o`3P0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`3P
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool0h03oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo0>00oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`3P0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0h03oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0>00oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`3P0?ooo`00503oool2000003l0
oooo0P00001f0?ooo`030000003oool0oooo0>00oooo000D0?ooo`030000003oool0oooo0400oooo
0P00001d0?ooo`030000003oool0oooo0>00oooo000D0?ooo`030000003oool0oooo0480oooo0P00
001b0?ooo`030000003oool0oooo0>00oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`3P0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000K`3oool00`000000oooo0?ooo`3P0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`3P0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0h03oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o06X0001o00<000000000O`0007l0T@0007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000JP3oool00`000000oooo0?ooo`3P0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000J03oool00`000000
oooo0?ooo`3P0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0h03oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo0>00oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0I03oool00`000000oooo0?ooo`3P0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0h03oool001@0oooo0P00001B0?oo
o`030000003oool0oooo0680oooo00<000000?ooo`3oool0h03oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0>00oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3Q0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000G03oool00`000000oooo0?ooo`3Q0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0h@3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
0>40oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`3Q0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`3Q0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0h@3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0>40oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`3Q0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool0h@3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0>40oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`3Q0?ooo`00503oool2
000005h0oooo0P00001F0?ooo`030000003oool0oooo0>40oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00001D0?ooo`030000003oool0oooo0>40oooo000D0?ooo`030000003oool0oooo0640
oooo0P00001B0?ooo`030000003oool0oooo0>40oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3Q0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000C`3oool00`000000oooo0?ooo`3Q0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0h@3oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0>40oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0>40oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`3Q0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0h@3o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo0>40oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`3Q0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3Q0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo0>40oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`160000O`0300000000
07l0001o0980001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0>40oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo03`0oooo00<000000?ooo`3oool0h@3o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0h@3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0h@3oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000:@3oool00`000000oooo0?ooo`3R0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000X0?ooo`03
0000003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000000X0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000X0?ooo`030000003o
ool0oooo0>80oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00000X0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000002L0oooo00<0
00000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`0000009`3oool00`000000oooo0?ooo`3R0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0>80oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0>80
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000603oool00`000000oooo0?oo
o`3R0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0000001P0oooo00<00000
0?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000001L0oooo00<00000
0?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo0>80oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000000F0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0>80oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0hP3oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0hP3oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo000000090?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
00002@3oool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo000000090?ooo`03
0000003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0>80
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000080?ooo`03
0000003oool0oooo0>80oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000080?ooo`030000003oool0oooo0>80oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o00D0001o00<000000000O`0007l0T`0007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0><0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`3S0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0h`3oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`3S0?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3S0?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3S0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0><0oooo000D0?ooo`030000003oool0oooo0:l0
oooo00D000000?ooo`3oool0oooo0000003U0?ooo`00503oool00`000000oooo0?ooo`2_0?ooo`05
0000003oool0oooo0?ooo`000000i@3oool001@0oooo00<000000?ooo`3oool0/03oool010000000
oooo0?ooo`00003U0?ooo`00503oool00`000000oooo0?ooo`2`0?ooo`040000003oool0oooo0000
0>D0oooo000D0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`000000i@3oool001@0oooo
00<000000?ooo`3oool0/@3oool00`000000oooo0000003U0?ooo`00503oool00`000000oooo0?oo
o`2b0?ooo`800000i@3oool001@0oooo0P00002c0?ooo`800000i@3oool001@0oooo00<000000?oo
o`3oool0/`3oool00`000000oooo0?ooo`3S0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`80001o00<000000000
O`0007l0100007l300000?l0001oB`0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool30000
00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000030?ooo`@0
00001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool20000
00@0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool0
00L0oooo00@000000?ooo`3oool000000P0007l00`000000001o0000O`040000O`<00000o`0007m;
0000Odl0oooo00050?ooo`8000000`3oool010000000oooo0?ooo`00003o0?oooj<0oooo00070?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`00103oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0ooooX`3oool000D0oooo0P000004
0?ooo`800000o`3ooonT0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00103oool200000080oooo
0`0000030?ooo`D000000`3oool200000080oooo0`0000040?ooo`<00000o`3ooon=0?ooo`000`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool00000o`3ooon<0?ooo`000`3oool010000000oooo0000000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`<000001P3o
ool00`000000oooo0?ooo`3o0?ooohX0oooo00030?ooo`030000003oool0oooo00<0oooo0`000003
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000030?ooo`800000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooon=0?ooo`00103oool20000
0080oooo1@000000103oool000000000000000050?ooo`8000000P3oool4000000@0oooo0`00003o
0?oooh`0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 0 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo09@0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0_@3oool00`00
0000oooo0?ooo`2D0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`2R0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0=T0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo0=T0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`3I0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0f@3oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo
0=T0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0]P3oool00`000000
oooo0?ooo`3I0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;D0oooo
00<000000?ooo`3oool0f@3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2e0?ooo`030000003oool0oooo0=T0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`2d
0?ooo`030000003oool0oooo0=T0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0/`3oool00`000000oooo0?ooo`3J0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0;80oooo00<000000?ooo`3oool0fP3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0=X0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`3J0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0fP3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo
0=X0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0=X0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0/03oool00`000000oooo
0?ooo`3J0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0fP3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo0=X0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0[`3oool00`000000oooo0?ooo`3J0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0:l0oooo00<000000?ooo`3oool0fP3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0=X0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0=X0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`3J0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0fP3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0=X0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0[@3oool00`000000oooo
0?ooo`3J0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2/0?ooo`030000003oool0oooo0=X0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0=X0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`2D0000O`030000000007l0001o08/0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000002E0?ooo`03
0000003oool0oooo0=X0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000U@3oool00`000000
oooo0?ooo`3J0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool0000009@0oooo00<000000?ooo`3o
ool0fP3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`3J0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0=X0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0fP3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0fP3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool0fP3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000S`3oool00`000000oooo0?ooo`3J0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000S03oool00`000000oooo0?ooo`3K0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000RP3oool00`000000oooo0?ooo`3K0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000R03oool00`000000oooo0?ooo`3K0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000QP3oool00`000000oooo0?ooo`3K0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
P`3oool00`000000oooo0?ooo`3K0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo08<0oooo00<000000?ooo`3oool0f`3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`220?ooo`030000003oool0oooo0=/0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`3K0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0f`3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0=/0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?oo
o`3K0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3K
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool0f`3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0=/0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
O03oool00`000000oooo0?ooo`3K0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool0f`3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0=/0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`3K0?ooo`00503oool2000003l0
oooo0P00001k0?ooo`030000003oool0oooo0=/0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00001i0?ooo`030000003oool0oooo0=/0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
001g0?ooo`030000003oool0oooo0=/0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`3K0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000M03oool00`000000oooo0?ooo`3K0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`3K0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0f`3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o06l0001o00<000000000O`0007l0S00007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000K`3oool00`000000oooo0?ooo`3K0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000K@3oool00`000000
oooo0?ooo`3K0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0f`3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo0=/0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0J03oool00`000000oooo0?ooo`3L0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0g03oool001@0oooo0P00001B0?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool0g03oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0=`0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3L0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000H@3oool00`000000oooo0?ooo`3L0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0g03oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
0=`0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0GP3oool00`000000
oooo0?ooo`3L0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`3L0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool0g03oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1L
0?ooo`030000003oool0oooo0=`0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0G03oool00`000000oooo0?ooo`3L0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool0g03oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0=`0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`3L0?ooo`00503oool2
000005h0oooo0P00001K0?ooo`030000003oool0oooo0=`0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00001I0?ooo`030000003oool0oooo0=`0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00001G0?ooo`030000003oool0oooo0=`0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3L0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000E03oool00`000000oooo0?ooo`3L0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0g03oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0=`0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0=`0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3L0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0g03o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo0=`0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`3L0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3L0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo0=d0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`1:0000O`0300000000
07l0001o08h0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo0=d0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo0400oooo00<000000?ooo`3oool0g@3o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0g@3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0g@3oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0g@3oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000;P3oool00`000000oooo0?ooo`3M0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000]0?ooo`03
0000003oool0oooo0=d0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000000]0?ooo`030000003oool0oooo0=d0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000]0?ooo`030000003o
ool0oooo0=d0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00000]0?ooo`030000003oool0oooo0=d0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000002`0oooo00<0
00000?ooo`3oool0g@3oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000;03oool00`000000oooo0?ooo`3M0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0=d0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`3M0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0=d0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`3M0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`8000007@3oool00`000000oooo0?oo
o`3M0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0000001d0oooo00<00000
0?ooo`3oool0g@3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000001`0oooo00<00000
0?ooo`3oool0g@3oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo0=d0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000000K0?ooo`030000003oool0oooo0=d0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0g@3oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`3M0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0=d0oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0g@3oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`3M0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0g@3oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0g@3oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000000=0?ooo`030000003oool0oooo0=h0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
00003@3oool00`000000oooo0?ooo`3N0?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000=0?ooo`03
0000003oool0oooo0=h0oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo0=h0
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`03
0000003oool0oooo0=h0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000<0?ooo`030000003oool0oooo0=h0oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o00T0001o00<000000000O`0007l0S`0007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0=h0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3N0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0gP3oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`3N0?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3N0?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3N0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0=h0oooo000D0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3N0?ooo`00503oool00`000000oooo
0?ooo`2_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0g`3oool001@0oooo00<0
00000?ooo`3oool0/03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0=l0oooo000D
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3P
0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0h03oool001@0oooo00<000000?ooo`3oool0/@3oool01@000000oooo0?ooo`3oool00000
0><0oooo000D0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`000000i03oool001@0oooo
0P00002c0?ooo`030000003oool000000>@0oooo000D0?ooo`030000003oool0oooo0;<0oooo00<0
00000?ooo`3oool0h`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo
VP3oool000D0oooo00<000000?ooo`3oool00`3oool20000O`030000000007l0001o00@0001o0`00
003o0000Od/0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`8000000`3oool4000000H0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000040?ooo`8000001`3o
ool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003o
ool0oooo00000080001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001@3o
ool2000000<0oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0?l0ooooX@3oool000@0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00003o0?oooj<0oooo00050?ooo`800000103oool200000?l0oooo
Y03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool000@0oooo0P0000020?ooo`<000000`3oool50000
00<0oooo0P0000020?ooo`<00000103oool300000?l0ooooS@3oool000<0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000?l0oooo
S03oool000<0oooo00@000000?ooo`00000000000P3oool00`000000oooo000000030?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool3000000H0oooo00<000000?ooo`3o
ool0o`3ooon:0?ooo`000`3oool00`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool20000
0?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0?l0ooooS@3oool000@0oooo0P0000020?ooo`D0000000@0
oooo00000000000000001@3oool200000080oooo100000040?ooo`<00000o`3ooon<0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 0 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo08l0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0`P3oool00`00
0000oooo0?ooo`2?0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`2M0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0=@0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0=@0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`3D0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0e03oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo
0=@0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0^`3oool00`000000
oooo0?ooo`3D0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0e03oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2j0?ooo`030000003oool0oooo0=@0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`2i
0?ooo`030000003oool0oooo0=@0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0^@3oool00`000000oooo0?ooo`3D0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0;L0oooo00<000000?ooo`3oool0e@3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo0=D0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`3E0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0e@3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo
0=D0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo0=D0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo
0?ooo`3E0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0;D0oooo00<0
00000?ooo`3oool0e@3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2e
0?ooo`030000003oool0oooo0=D0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0]03oool00`000000oooo0?ooo`3E0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0;@0oooo00<000000?ooo`3oool0e@3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo0=D0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo0=D0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`3E0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0e@3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0=D0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0/P3oool00`000000oooo
0?ooo`3E0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2a0?ooo`030000003oool0oooo0=D0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo0=D0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`2I0000O`030000000007l0001o08H0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000002J0?ooo`03
0000003oool0oooo0=D0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000VP3oool00`000000
oooo0?ooo`3E0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool0000009T0oooo00<000000?ooo`3o
ool0e@3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`3E0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo0=D0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo09D0oooo00<000000?ooo`3oool0e@3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0e@3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo09@0
oooo00<000000?ooo`3oool0e@3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000U03oool00`000000oooo0?ooo`3E0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000TP3oool00`000000oooo0?ooo`3E0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000T03oool00`000000oooo0?ooo`3E0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000S@3oool00`000000oooo0?ooo`3F0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000R`3oool00`000000oooo0?ooo`3F0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`3F0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo08P0oooo00<000000?ooo`3oool0eP3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`270?ooo`030000003oool0oooo0=H0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`3F0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0eP3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0=H0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`3F0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`3F
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo08<0oooo00<000000?oo
o`3oool0eP3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo0=H0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`3F0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0840oooo00<000000?ooo`3oool0eP3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`200?ooo`030000003oool0oooo0=H0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`3F0?ooo`00503oool2000003l0
oooo0P0000200?ooo`030000003oool0oooo0=H0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00001n0?ooo`030000003oool0oooo0=H0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
001l0?ooo`030000003oool0oooo0=H0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`3F0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000N@3oool00`000000oooo0?ooo`3F0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`3F0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0eP3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o07@0001o00<000000000O`0007l0Q`0007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000M03oool00`000000oooo0?ooo`3F0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000LP3oool00`000000
oooo0?ooo`3F0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0eP3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo0=H0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0KP3oool00`000000oooo0?ooo`3F0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0eP3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo06`0oooo00<000000?ooo`3oool0eP3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0=H0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`3G0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000IP3oool00`000000oooo0?ooo`3G0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0e`3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
0=L0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`3G0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`3G0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0e`3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1Q
0?ooo`030000003oool0oooo0=L0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0H@3oool00`000000oooo0?ooo`3G0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo0600oooo00<000000?ooo`3oool0e`3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0=L0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3G0?ooo`00503oool2
000005h0oooo0P00001P0?ooo`030000003oool0oooo0=L0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00001N0?ooo`030000003oool0oooo0=L0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00001L0?ooo`030000003oool0oooo0=L0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3G0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000F@3oool00`000000oooo0?ooo`3G0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0e`3oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0=L0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=L0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3G0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0e`3o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo0=L0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`3G0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3G0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo0=L0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`1@0000O`0300000000
07l0001o08P0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo0=L0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo04H0oooo00<000000?ooo`3oool0e`3o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0e`3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool0e`3oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0f03oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000<`3oool00`000000oooo0?ooo`3H0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000b0?ooo`03
0000003oool0oooo0=P0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000000b0?ooo`030000003oool0oooo0=P0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000b0?ooo`030000003o
ool0oooo0=P0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00000b0?ooo`030000003oool0oooo0=P0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000340oooo00<0
00000?ooo`3oool0f03oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000<@3oool00`000000oooo0?ooo`3H0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0=P0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`3H0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0=P0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`3H0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`8000008P3oool00`000000oooo0?oo
o`3H0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool000000280oooo00<00000
0?ooo`3oool0f03oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000240oooo00<00000
0?ooo`3oool0f03oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00000Q0?ooo`030000003oool0oooo0=P0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000000P0?ooo`030000003oool0oooo0=P0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0f03oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`3H0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0=P0oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0f03oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`3H0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0f03oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0f03oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000000C0?ooo`030000003oool0oooo0=P0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
00004`3oool00`000000oooo0?ooo`3H0?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000C0?ooo`03
0000003oool0oooo0=P0oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0=P0
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`03
0000003oool0oooo0=P0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000B0?ooo`030000003oool0oooo0=P0oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o00l0001o00<000000000O`0007l0R@0007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0=T0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`3I0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0f@3oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3I0?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3I0?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`3I0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0=T0oooo000D0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0=T0
oooo000D0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
000000030?ooo`030000003oool0oooo0=T0oooo000D0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0103oool00`000000oooo000000030?ooo`030000003oool0oooo0=T0oooo000D
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0f@3oool001@0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000f`3oool0
01@0oooo00<000000?ooo`3oool0/@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`000000f`3oool001@0oooo00<000000?ooo`3oool0/P3oool00`000000oooo000000070?oo
o`800000f`3oool001@0oooo0P00002c0?ooo`030000003oool0000000L0oooo0P00003K0?ooo`00
503oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
f@3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool40000
0080oooo0`0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo
00<000000?ooo`3oool00`3oool20000O`030000000007l0001o00@0001o0`00003o0000Od/0001o
C`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003oool0oooo0?l0oooo
VP3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`3o0?oooiX0oooo00050?ooo`8000000`3oool4000000H0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo
0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo00000080
001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001@3oool2000000<0oooo
00@000000?ooo`3oool00000o`3ooonS0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0?l0ooooX@3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00003o0?oooj<0oooo00050?ooo`800000103oool200000?l0ooooY03oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool000@0oooo0P0000020?ooo`<000000`3oool5000000<0oooo0P000002
0?ooo`<00000103oool300000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000?l0ooooS03oool000<0oooo
00@000000?ooo`00000000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool3000000H0oooo00<000000?ooo`3oool0o`3ooon:0?oo
o`000`3oool00`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool200000?l0ooooS@3oool0
00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0?l0ooooS@3oool000@0oooo0P0000020?ooo`D0000000@0oooo000000000000
00001@3oool200000080oooo100000040?ooo`<00000o`3ooon<0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 0 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo08X0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`2:0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`2H0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo0<l0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0<l0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`3?0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0c`3oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo
0<l0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0`03oool00`000000
oooo0?ooo`3?0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0c`3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2o0?ooo`030000003oool0oooo0<l0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`2n
0?ooo`030000003oool0oooo0<l0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`3?0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0;d0oooo00<000000?ooo`3oool0c`3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo0=00oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`3@0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0d03oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo
0=00oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo0=00
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`3@0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0;X0oooo00<0
00000?ooo`3oool0d03oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo0=00oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0^@3oool00`000000oooo0?ooo`3@0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0;T0oooo00<000000?ooo`3oool0d03oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo0=00oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo0=00oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`3@0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0d03oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo0=00
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0]`3oool00`000000oooo
0?ooo`3@0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2f0?ooo`030000003oool0oooo0=00oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo0=00oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`2N0000O`030000000007l0001o0840001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000002O0?ooo`03
0000003oool0oooo0=00oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000W`3oool00`000000
oooo0?ooo`3@0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool0000009h0oooo00<000000?ooo`3o
ool0d03oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`3@0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0=00oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo09X0oooo00<000000?ooo`3oool0d03oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0d03oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo09T0
oooo00<000000?ooo`3oool0d03oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000V@3oool00`000000oooo0?ooo`3@0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000U`3oool00`000000oooo0?ooo`3@0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000U@3oool00`000000oooo0?ooo`3@0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000T`3oool00`000000oooo0?ooo`3@0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000T@3oool00`000000oooo0?ooo`3@0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`3A0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0d@3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0=40oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`3A0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0d@3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0=40oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`3A0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`3A
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0d@3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo0=40oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`3A0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0d@3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo0=40oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`3A0?ooo`00503oool2000003l0
oooo0P0000250?ooo`030000003oool0oooo0=40oooo000D0?ooo`030000003oool0oooo0400oooo
0P0000230?ooo`030000003oool0oooo0=40oooo000D0?ooo`030000003oool0oooo0480oooo0P00
00210?ooo`030000003oool0oooo0=40oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`3A0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000OP3oool00`000000oooo0?ooo`3A0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`3A0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0d@3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o07T0001o00<000000000O`0007l0PP0007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000N@3oool00`000000oooo0?ooo`3A0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000M`3oool00`000000
oooo0?ooo`3A0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0d@3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo0=40oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`3A0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0d@3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo0740oooo00<000000?ooo`3oool0d@3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0=40oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`3A0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000K03oool00`000000oooo0?ooo`3A0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0d@3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo
0=80oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0J03oool00`000000
oooo0?ooo`3B0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0I`3oool00`000000oooo
0?ooo`3B0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool0dP3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo0=80oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0IP3oool00`000000oooo0?ooo`3B0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool0dP3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0=80oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`3B0?ooo`00503oool2
000005h0oooo0P00001U0?ooo`030000003oool0oooo0=80oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00001S0?ooo`030000003oool0oooo0=80oooo000D0?ooo`030000003oool0oooo0640
oooo0P00001Q0?ooo`030000003oool0oooo0=80oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3B0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000GP3oool00`000000oooo0?ooo`3B0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0dP3oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0=80oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0=80oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3B0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0dP3o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo0=80oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`3B0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`3B0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0=80oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`1E0000O`0300000000
07l0001o08<0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0=80oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo04/0oooo00<000000?ooo`3oool0dP3o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0dP3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0dP3oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0dP3oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000>@3oool00`000000oooo0?ooo`3B0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000h0?ooo`03
0000003oool0oooo0=80oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000000h0?ooo`030000003oool0oooo0=80oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000g0?ooo`030000003o
ool0oooo0=<0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00000g0?ooo`030000003oool0oooo0=<0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000003H0oooo00<0
00000?ooo`3oool0d`3oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000=P3oool00`000000oooo0?ooo`3C0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0=<0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`3C0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0=<0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`3C0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`8000009`3oool00`000000oooo0?oo
o`3C0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0000002L0oooo00<00000
0?ooo`3oool0d`3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000002H0oooo00<00000
0?ooo`3oool0d`3oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo0=<0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000000U0?ooo`030000003oool0oooo0=<0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0d`3oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`3C0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0=<0oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0d`3oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`3C0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0d`3oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0d`3oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000000H0?ooo`030000003oool0oooo0=<0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
0000603oool00`000000oooo0?ooo`3C0?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000H0?ooo`03
0000003oool0oooo0=<0oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000G0?ooo`030000003oool0oooo0=<0
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000G0?ooo`03
0000003oool0oooo0=<0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000G0?ooo`030000003oool0oooo0=<0oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o01@0001o00<000000000O`0007l0Q00007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0=<0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`3C0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0d`3oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`3C0?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3C0?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`3D0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0=@0oooo000D0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=@0
oooo000D0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
000000080?ooo`030000003oool0oooo0=@0oooo000D0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0103oool00`000000oooo000000080?ooo`030000003oool0oooo0=@0oooo000D
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000000L0oooo00<000000?ooo`3oool0e03oool001@0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3D0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0=@0oooo000D0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0=@0oooo000D0?ooo`800000/`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0e03oool001@0oooo00<000000?ooo`3oool0
/`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
e03oool001@0oooo00<000000?ooo`3oool0_P3oool01@000000oooo0?ooo`3oool000000=H0oooo
000D0?ooo`030000003oool0oooo0;l0oooo00@000000?ooo`3oool00000eP3oool001@0oooo00<0
00000?ooo`3oool0`03oool00`000000oooo0000003F0?ooo`00503oool00`000000oooo0?ooo`30
0?ooo`030000003oool000000=H0oooo000D0?ooo`030000003oool0oooo0<40oooo0P00003F0?oo
o`00503oool200000<<0oooo00<000000?ooo`3oool0e03oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00
003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`030000003oool0oooo00<0oooo0P0007l00`00
0000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?ooo`040000003oool0oooo0?oo
o`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000<0
oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00
003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?oo
o`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`001`3oool010000000oooo0?ooo`0000020000O`030000000007l0001o00@0001o0`00003o
0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003oool0oooo00000?l0ooooX`3oool0
00L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oooj40oooo00040?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001@3oool2
000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo00040?ooo`800000
0P3oool3000000<0oooo1@0000030?ooo`8000000P3oool3000000@0oooo0`00003o0?ooohd0oooo
00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003oool0000000000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0`00
00060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo00<000000?ooo`3oool00`3oool3
000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?ooohd0oooo00040?oo
o`8000000P3oool5000000040?ooo`0000000000000000D0oooo0P0000020?ooo`@00000103oool3
00000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 0 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo08D0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0c03oool00`00
0000oooo0?ooo`250?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo0<X0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo0<X0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`3:0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0bP3oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo
0<X0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0a@3oool00`000000
oooo0?ooo`3:0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0<@0oooo
00<000000?ooo`3oool0bP3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`340?ooo`030000003oool0oooo0<X0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`33
0?ooo`030000003oool0oooo0<X0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`3:0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0<40oooo00<000000?ooo`3oool0b`3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0</0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`3;0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0b`3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo
0</0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo0</0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0_`3oool00`000000oooo
0?ooo`3;0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0;l0oooo00<0
00000?ooo`3oool0b`3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2o
0?ooo`030000003oool0oooo0</0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`3;0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0;h0oooo00<000000?ooo`3oool0b`3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo0</0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0</0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`3;0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0b`3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo0</0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0_03oool00`000000oooo
0?ooo`3;0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2k0?ooo`030000003oool0oooo0</0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo0</0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`2S0000O`030000000007l0001o07`0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000002T0?ooo`03
0000003oool0oooo0</0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000Y03oool00`000000
oooo0?ooo`3;0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool000000:<0oooo00<000000?ooo`3o
ool0b`3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`3;0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0</0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo09l0oooo00<000000?ooo`3oool0b`3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0b`3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo09h0
oooo00<000000?ooo`3oool0b`3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000WP3oool00`000000oooo0?ooo`3;0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000W03oool00`000000oooo0?ooo`3;0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000VP3oool00`000000oooo0?ooo`3;0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000U`3oool00`000000oooo0?ooo`3<0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000U@3oool00`000000oooo0?ooo`3<0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
TP3oool00`000000oooo0?ooo`3<0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0980oooo00<000000?ooo`3oool0c03oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0<`0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`3<0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0c03oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0<`0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`3<0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3<
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0c03oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo0<`0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`3<0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool0c03oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0<`0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3<0?ooo`00503oool2000003l0
oooo0P00002:0?ooo`030000003oool0oooo0<`0oooo000D0?ooo`030000003oool0oooo0400oooo
0P0000280?ooo`030000003oool0oooo0<`0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
00260?ooo`030000003oool0oooo0<`0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0P`3oool00`000000oooo0?ooo`3<0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000P`3oool00`000000oooo0?ooo`3<0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`3<0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0c03oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o07h0001o00<000000000O`0007l0O@0007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000OP3oool00`000000oooo0?ooo`3<0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000O03oool00`000000
oooo0?ooo`3<0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0c03oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo0<`0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`3<0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0c03oool001@0oooo0P00001B0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0c03oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0<d0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`3=0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000L03oool00`000000oooo0?ooo`3=0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0c@3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
0<d0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`3=0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0K03oool00`000000oooo
0?ooo`3=0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo06`0oooo00<0
00000?ooo`3oool0c@3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo0<d0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`3=0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo06X0oooo00<000000?ooo`3oool0c@3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0<d0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`3=0?ooo`00503oool2
000005h0oooo0P00001Z0?ooo`030000003oool0oooo0<d0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00001X0?ooo`030000003oool0oooo0<d0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00001V0?ooo`030000003oool0oooo0<d0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`3=0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000H`3oool00`000000oooo0?ooo`3=0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0c@3oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0<d0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<d0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3=0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0c@3o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo0<d0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`3=0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`3=0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo0<d0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`1J0000O`0300000000
07l0001o07h0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo0<d0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo0500oooo00<000000?ooo`3oool0c@3o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0c@3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0cP3oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0cP3oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000?@3oool00`000000oooo0?ooo`3>0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000l0?ooo`03
0000003oool0oooo0<h0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000000l0?ooo`030000003oool0oooo0<h0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000l0?ooo`030000003o
ool0oooo0<h0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00000l0?ooo`030000003oool0oooo0<h0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000003/0oooo00<0
00000?ooo`3oool0cP3oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000>`3oool00`000000oooo0?ooo`3>0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0<h0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`3>0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0<h0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`3>0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000;03oool00`000000oooo0?oo
o`3>0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0000002`0oooo00<00000
0?ooo`3oool0cP3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000002/0oooo00<00000
0?ooo`3oool0cP3oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00000[0?ooo`030000003oool0oooo0<h0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000000Z0?ooo`030000003oool0oooo0<h0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0cP3oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`3>0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0<h0oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0cP3oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`3>0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0cP3oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0cP3oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000000M0?ooo`030000003oool0oooo0<h0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
00007@3oool00`000000oooo0?ooo`3>0?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000M0?ooo`03
0000003oool0oooo0<h0oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000003oool0oooo0<h0
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`03
0000003oool0oooo0<h0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000L0?ooo`030000003oool0oooo0<h0oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o01P0001o00<000000000O`0007l0P00007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0<l0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`3?0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0c`3oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`3?0?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3?0?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`3?0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0<l0oooo000D0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0<l0
oooo000D0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0000000=0?ooo`030000003oool0oooo0<l0oooo000D0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0103oool00`000000oooo0000000=0?ooo`030000003oool0oooo0<l0oooo000D
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000000`0oooo00<000000?ooo`3oool0c`3oool001@0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`3?0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0<l0oooo000D0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0<l0oooo000D0?ooo`800000/`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0c`3oool001@0oooo00<000000?ooo`3oool0
/`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
d03oool001@0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0=00oooo000D0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`3A0?ooo`00503oool00`000000oooo0?ooo`300?ooo`050000003oool0oooo
0?ooo`000000e03oool001@0oooo00<000000?ooo`3oool0`03oool010000000oooo0?ooo`00003E
0?ooo`00503oool00`000000oooo0?ooo`310?ooo`030000003oool000000=D0oooo000D0?ooo`80
0000``3oool00`000000oooo0?ooo`3D0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo0?l0ooooVP3o
ool000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0?l0ooooVP3oool000D0oooo00<000000?ooo`3oool00`3oool20000O`030000000007l0001o
00@0001o0`00003o0000Od/0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?oo
o`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`8000000`3oool4000000H0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000040?oo
o`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?oo
o`040000003oool0oooo00000080001o00<000000000O`0007l0100007l300000?l0001oB`0007m?
0?ooo`001@3oool2000000<0oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooX@3oool000@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00003o0?oooj<0oooo00050?ooo`800000103oool2
00000?l0ooooY03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool000@0oooo0P0000020?ooo`<00000
0`3oool5000000<0oooo0P0000020?ooo`<00000103oool300000?l0ooooS@3oool000<0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000?l0ooooS03oool000<0oooo00@000000?ooo`00000000000P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool3000000H0oooo00<0
00000?ooo`3oool0o`3ooon:0?ooo`000`3oool00`000000oooo0?ooo`030?ooo`<000000`3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0`3oool200000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooS@3oool000@0oooo0P0000020?oo
o`D0000000@0oooo00000000000000001@3oool200000080oooo100000040?ooo`<00000o`3ooon<
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 0 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo0800oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0d@3oool00`00
0000oooo0?ooo`200?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo0<D0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo0<D0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`350?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool0a@3oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
0<D0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0bP3oool00`000000
oooo0?ooo`350?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0<T0oooo
00<000000?ooo`3oool0a@3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`390?ooo`030000003oool0oooo0<D0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`38
0?ooo`030000003oool0oooo0<D0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0b03oool00`000000oooo0?ooo`350?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool0a@3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo0<H0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`360?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool0aP3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo
0<H0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo0<H0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0a03oool00`000000oooo
0?ooo`360?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0<@0oooo00<0
00000?ooo`3oool0aP3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`34
0?ooo`030000003oool0oooo0<H0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`360?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0<<0oooo00<000000?ooo`3oool0aP3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0<H0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0<H0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`360?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0aP3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0<H0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0`@3oool00`000000oooo
0?ooo`360?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`300?ooo`030000003oool0oooo0<H0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo0<H0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`2X0000O`030000000007l0001o07L0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000002Y0?ooo`03
0000003oool0oooo0<H0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000Z@3oool00`000000
oooo0?ooo`360?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool000000:P0oooo00<000000?ooo`3o
ool0aP3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`360?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo0<H0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0aP3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0aP3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo0:<0
oooo00<000000?ooo`3oool0aP3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000X`3oool00`000000oooo0?ooo`360?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000X@3oool00`000000oooo0?ooo`360?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000W`3oool00`000000oooo0?ooo`360?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000W@3oool00`000000oooo0?ooo`360?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000V`3oool00`000000oooo0?ooo`360?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
U`3oool00`000000oooo0?ooo`370?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo09L0oooo00<000000?ooo`3oool0a`3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`2F0?ooo`030000003oool0oooo0<L0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`370?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0a`3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0<L0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?oo
o`370?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`37
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0980oooo00<000000?oo
o`3oool0a`3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0<L0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`370?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0a`3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0<L0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`370?ooo`00503oool2000003l0
oooo0P00002?0?ooo`030000003oool0oooo0<L0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00002=0?ooo`030000003oool0oooo0<L0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
002;0?ooo`030000003oool0oooo0<L0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0R03oool00`000000oooo0?ooo`370?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000R03oool00`000000oooo0?ooo`370?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`370?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0a`3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o08<0001o00<000000000O`0007l0N00007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000P`3oool00`000000oooo0?ooo`370?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000P@3oool00`000000
oooo0?ooo`370?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0a`3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1m0?ooo`030000003oool0oooo0<L0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`370?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0a`3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo07/0oooo00<000000?ooo`3oool0a`3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0<L0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`370?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000MP3oool00`000000oooo0?ooo`370?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0a`3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo
0<P0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0LP3oool00`000000
oooo0?ooo`380?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0L@3oool00`000000oooo
0?ooo`380?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0b03oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0oooo0<P0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0L03oool00`000000oooo0?ooo`380?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool0b03oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0<P0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`380?ooo`00503oool2
000005h0oooo0P00001_0?ooo`030000003oool0oooo0<P0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00001]0?ooo`030000003oool0oooo0<P0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00001[0?ooo`030000003oool0oooo0<P0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`380?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000J03oool00`000000oooo0?ooo`380?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0b03oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0<P0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0<P0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`380?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0b03o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo0<P0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0H@3oool00`00
0000oooo0?ooo`380?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`380?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo0<P0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`1O0000O`0300000000
07l0001o07T0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo0<P0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo05D0oooo00<000000?ooo`3oool0b03o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0b03o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0b03oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0b03oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000@`3oool00`000000oooo0?ooo`380?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo000000120?ooo`03
0000003oool0oooo0<P0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo000000120?ooo`030000003oool0oooo0<P0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo000000110?ooo`030000003o
ool0oooo0<T0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`0000110?ooo`030000003oool0oooo0<T0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000400oooo00<0
00000?ooo`3oool0b@3oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000@03oool00`000000oooo0?ooo`390?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0<T0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`390?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0<T0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`390?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000<@3oool00`000000oooo0?oo
o`390?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool000000340oooo00<00000
0?ooo`3oool0b@3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000300oooo00<00000
0?ooo`3oool0b@3oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00000`0?ooo`030000003oool0oooo0<T0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000000_0?ooo`030000003oool0oooo0<T0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0b@3oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`390?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0<T0oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0b@3oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`390?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0b@3oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0b@3oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000000R0?ooo`030000003oool0oooo0<T0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
00008P3oool00`000000oooo0?ooo`390?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000R0?ooo`03
0000003oool0oooo0<T0oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003oool0oooo0<T0
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`03
0000003oool0oooo0<T0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000Q0?ooo`030000003oool0oooo0<T0oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o01h0001o00<000000000O`0007l0NP0007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0<T0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`390?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0b@3oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`390?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`390?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`3:0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0<X0oooo000D0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0<X0
oooo000D0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0000000B0?ooo`030000003oool0oooo0<X0oooo000D0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0103oool00`000000oooo0000000B0?ooo`030000003oool0oooo0<X0oooo000D
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool000000140oooo00<000000?ooo`3oool0bP3oool001@0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`3:0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0<X0oooo000D0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0<X0oooo000D0?ooo`800000/`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3:0?ooo`00
503oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo000000030?ooo`030000003oool0oooo0<X0oooo000D0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000030?ooo`030000003o
ool0oooo0<X0oooo000D0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0bP3oool001@0oooo00<00000
0?ooo`3oool0`03oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`000000c03o
ool001@0oooo00<000000?ooo`3oool0`03oool010000000oooo0?ooo`0000070?ooo`800000c03o
ool001@0oooo00<000000?ooo`3oool0`@3oool00`000000oooo000000070?ooo`800000c03oool0
01@0oooo0P0000330?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0bP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo100000020?ooo`<00000
1`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`030000003oool0
oooo00<0oooo0P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?oo
o`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`001@3oool2000000<0oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000020000O`0300000000
07l0001o00@0001o0`00003o0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003oool0
oooo00000?l0ooooX`3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`3o0?oooj40oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
o`3ooonS0?ooo`001@3oool2000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo00040?ooo`8000000P3oool3000000<0oooo1@0000030?ooo`8000000P3oool3000000@0
oooo0`00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003oool0
000000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo00000080oooo0`0000060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo00<0
00000?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`3o0?ooohd0oooo00040?ooo`8000000P3oool5000000040?ooo`0000000000000000D0oooo0P00
00020?ooo`@00000103oool300000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 0 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo07/0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0eP3oool00`00
0000oooo0?ooo`1k0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`290?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0<00oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo0<00oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`300?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool0`03oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo
0<00oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0c`3oool00`000000
oooo0?ooo`300?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0<h0oooo
00<000000?ooo`3oool0`03oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo0<00oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`3=
0?ooo`030000003oool0oooo0<00oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0c@3oool00`000000oooo0?ooo`300?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0<`0oooo00<000000?ooo`3oool0`03oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo0<00oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`310?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0`@3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
0<40oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0<40
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0b@3oool00`000000oooo
0?ooo`310?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0<T0oooo00<0
00000?ooo`3oool0`@3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`39
0?ooo`030000003oool0oooo0<40oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0b03oool00`000000oooo0?ooo`310?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0<P0oooo00<000000?ooo`3oool0`@3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo0<40oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`370?ooo`030000003oool0oooo0<40oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`310?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0`@3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo0<40
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0aP3oool00`000000oooo
0?ooo`310?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`350?ooo`030000003oool0oooo0<40oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo0<40oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`2]0000O`030000000007l0001o0780001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000002^0?ooo`03
0000003oool0oooo0<40oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000[P3oool00`000000
oooo0?ooo`310?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool000000:d0oooo00<000000?ooo`3o
ool0`@3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`310?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0<40oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`3oool0`@3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0`@3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo0:P0
oooo00<000000?ooo`3oool0`@3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000Z03oool00`000000oooo0?ooo`310?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000YP3oool00`000000oooo0?ooo`310?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000Y03oool00`000000oooo0?ooo`310?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000XP3oool00`000000oooo0?ooo`310?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000X03oool00`000000oooo0?ooo`310?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
W@3oool00`000000oooo0?ooo`310?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool0`@3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0<40oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`320?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0`P3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0<80oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?oo
o`320?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`32
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo09L0oooo00<000000?oo
o`3oool0`P3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2F0?ooo`03
0000003oool0oooo0<80oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
U@3oool00`000000oooo0?ooo`320?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo09D0oooo00<000000?ooo`3oool0`P3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0<80oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`320?ooo`00503oool2000003l0
oooo0P00002D0?ooo`030000003oool0oooo0<80oooo000D0?ooo`030000003oool0oooo0400oooo
0P00002B0?ooo`030000003oool0oooo0<80oooo000D0?ooo`030000003oool0oooo0480oooo0P00
002@0?ooo`030000003oool0oooo0<80oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`320?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000S@3oool00`000000oooo0?ooo`320?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`320?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0`P3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o08P0001o00<000000000O`0007l0L`0007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000R03oool00`000000oooo0?ooo`320?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000QP3oool00`000000
oooo0?ooo`320?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0`P3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`220?ooo`030000003oool0oooo0<80oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0PP3oool00`000000oooo0?ooo`320?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0`P3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo0800oooo00<000000?ooo`3oool0`P3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0<80oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`320?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000N`3oool00`000000oooo0?ooo`320?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0`P3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
0<80oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`320?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`320?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo07L0oooo00<0
00000?ooo`3oool0`P3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1e
0?ooo`030000003oool0oooo0<<0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0M@3oool00`000000oooo0?ooo`330?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool0``3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0<<0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`330?ooo`00503oool2
000005h0oooo0P00001d0?ooo`030000003oool0oooo0<<0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00001b0?ooo`030000003oool0oooo0<<0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00001`0?ooo`030000003oool0oooo0<<0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`330?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000K@3oool00`000000oooo0?ooo`330?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0``3oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0<<0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0<<0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`330?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0``3o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo0<<0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0IP3oool00`00
0000oooo0?ooo`330?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`330?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo0<<0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`1T0000O`0300000000
07l0001o07@0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo0<<0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo05X0oooo00<000000?ooo`3oool0``3o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0``3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool0``3oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0``3oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000B03oool00`000000oooo0?ooo`330?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo000000170?ooo`03
0000003oool0oooo0<<0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo000000170?ooo`030000003oool0oooo0<<0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo000000170?ooo`030000003o
ool0oooo0<<0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`0000170?ooo`030000003oool0oooo0<<0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000004H0oooo00<0
00000?ooo`3oool0``3oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000AP3oool00`000000oooo0?ooo`330?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo0<<0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`330?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0<@0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`340?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000=P3oool00`000000oooo0?oo
o`340?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0000003H0oooo00<00000
0?ooo`3oool0a03oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000003D0oooo00<00000
0?ooo`3oool0a03oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00000e0?ooo`030000003oool0oooo0<@0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000000d0?ooo`030000003oool0oooo0<@0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0a03oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`340?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0<@0oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0a03oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`340?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0a03oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0a03oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000000W0?ooo`030000003oool0oooo0<@0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
00009`3oool00`000000oooo0?ooo`340?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000W0?ooo`03
0000003oool0oooo0<@0oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000V0?ooo`030000003oool0oooo0<@0
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000V0?ooo`03
0000003oool0oooo0<@0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000V0?ooo`030000003oool0oooo0<@0oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o02<0001o00<000000000O`0007l0M@0007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo0<@0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`340?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0a03oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`340?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`340?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`340?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0<@0oooo000D0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0<@0
oooo000D0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0000000H0?ooo`030000003oool0oooo0<@0oooo000D0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0103oool00`000000oooo0000000H0?ooo`030000003oool0oooo0<@0oooo000D
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000001L0oooo00<000000?ooo`3oool0a03oool001@0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`340?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0<@0oooo000D0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0<D0oooo000D0?ooo`800000/`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`350?ooo`00
503oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo000000080?ooo`030000003oool0oooo0<D0oooo000D0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000080?ooo`030000003o
ool0oooo0<D0oooo000D0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0a@3oool001@0oooo00<00000
0?ooo`3oool0`03oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`350?ooo`00503oool00`000000oooo0?ooo`300?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`350?ooo`00503oool0
0`000000oooo0?ooo`310?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`350?ooo`00503oool200000<<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0<D0oooo000D0?ooo`030000003oool0oooo0<d0
oooo00D000000?ooo`3oool0oooo000000370?ooo`00503oool00`000000oooo0?ooo`3=0?ooo`05
0000003oool0oooo0?ooo`000000a`3oool001@0oooo00<000000?ooo`3oool0cP3oool010000000
oooo0?ooo`0000370?ooo`00503oool00`000000oooo0?ooo`3>0?ooo`040000003oool0oooo0000
0<L0oooo000D0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`000000a`3oool001@0oooo
00<000000?ooo`3oool0c`3oool00`000000oooo000000370?ooo`00503oool200000=40oooo0P00
00370?ooo`00503oool00`000000oooo0?ooo`3@0?ooo`800000a`3oool001@0oooo00<000000?oo
o`3oool0d@3oool00`000000oooo0?ooo`350?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo100000020?ooo`<000001`3o
ool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`030000003oool0oooo
00<0oooo0P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00060?ooo`04
0000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`001@3oool2000000<0oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000020000O`030000000007l0
001o00@0001o0`00003o0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003oool0oooo
00000?l0ooooX`3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o
0?oooj40oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3o
oonS0?ooo`001@3oool2000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo00040?ooo`8000000P3oool3000000<0oooo1@0000030?ooo`8000000P3oool3000000@0oooo
0`00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003oool00000
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo00000080oooo0`0000060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo00<00000
0?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o
0?ooohd0oooo00040?ooo`8000000P3oool5000000040?ooo`0000000000000000D0oooo0P000002
0?ooo`@00000103oool300000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 0 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo07D0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0g03oool00`00
0000oooo0?ooo`1e0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`230?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo0;X0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo0;X0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`2j0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0^P3oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo
0;X0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0e@3oool00`000000
oooo0?ooo`2j0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=@0oooo
00<000000?ooo`3oool0^P3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3D0?ooo`030000003oool0oooo0;X0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`3C
0?ooo`030000003oool0oooo0;X0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0dP3oool00`000000oooo0?ooo`2k0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0=40oooo00<000000?ooo`3oool0^`3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo0;/0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`2k0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool0^`3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo
0;/0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo0;/0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0c`3oool00`000000oooo
0?ooo`2k0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0<l0oooo00<0
00000?ooo`3oool0^`3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3?
0?ooo`030000003oool0oooo0;/0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0cP3oool00`000000oooo0?ooo`2k0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0<h0oooo00<000000?ooo`3oool0^`3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0;/0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo0;/0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`2k0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0^`3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo0;/0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0c03oool00`000000oooo
0?ooo`2k0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`3;0?ooo`030000003oool0oooo0;/0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0;/0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`2c0000O`030000000007l0001o06`0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000002d0?ooo`03
0000003oool0oooo0;/0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000]03oool00`000000
oooo0?ooo`2k0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool000000;<0oooo00<000000?ooo`3o
ool0^`3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`2k0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo0;/0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0:l0oooo00<000000?ooo`3oool0^`3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0^`3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo0:d0
oooo00<000000?ooo`3oool0_03oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000[@3oool00`000000oooo0?ooo`2l0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000Z`3oool00`000000oooo0?ooo`2l0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000Z@3oool00`000000oooo0?ooo`2l0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000Y`3oool00`000000oooo0?ooo`2l0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000Y@3oool00`000000oooo0?ooo`2l0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
XP3oool00`000000oooo0?ooo`2l0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0:80oooo00<000000?ooo`3oool0_03oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo0;`0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`2l0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0_03oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0;`0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?oo
o`2l0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`2l
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo09d0oooo00<000000?oo
o`3oool0_03oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2L0?ooo`03
0000003oool0oooo0;`0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`2l0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo09/0oooo00<000000?ooo`3oool0_03oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0;`0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`2l0?ooo`00503oool2000003l0
oooo0P00002J0?ooo`030000003oool0oooo0;`0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00002H0?ooo`030000003oool0oooo0;`0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
002F0?ooo`030000003oool0oooo0;`0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0T`3oool00`000000oooo0?ooo`2l0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000T`3oool00`000000oooo0?ooo`2l0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`2l0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0_03oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o08h0001o00<000000000O`0007l0K@0007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000S@3oool00`000000oooo0?ooo`2m0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000R`3oool00`000000
oooo0?ooo`2m0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0_@3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`270?ooo`030000003oool0oooo0;d0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0Q`3oool00`000000oooo0?ooo`2m0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0_@3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo08D0oooo00<000000?ooo`3oool0_@3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0;d0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`2m0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000P03oool00`000000oooo0?ooo`2m0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0_@3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo
0;d0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0O@3oool00`000000
oooo0?ooo`2m0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0O03oool00`000000oooo
0?ooo`2m0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo07`0oooo00<0
00000?ooo`3oool0_@3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1k
0?ooo`030000003oool0oooo0;d0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0N`3oool00`000000oooo0?ooo`2m0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0_@3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;d0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`2m0?ooo`00503oool2
000005h0oooo0P00001j0?ooo`030000003oool0oooo0;d0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00001h0?ooo`030000003oool0oooo0;d0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00001f0?ooo`030000003oool0oooo0;d0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`2m0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000L`3oool00`000000oooo0?ooo`2m0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0_@3oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0;d0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0;d0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`2m0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0_P3o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0
oooo0;h0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`2n0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`2n0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`1Z0?ooo`030000003oool0oooo0;h0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`1Y0000O`0300000000
07l0001o06l0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo0;h0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo05l0oooo00<000000?ooo`3oool0_P3o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0_P3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0_P3oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0_P3oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000C@3oool00`000000oooo0?ooo`2n0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000001<0?ooo`03
0000003oool0oooo0;h0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000001<0?ooo`030000003oool0oooo0;h0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000001<0?ooo`030000003o
ool0oooo0;h0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00001<0?ooo`030000003oool0oooo0;h0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000004/0oooo00<0
00000?ooo`3oool0_P3oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000B`3oool00`000000oooo0?ooo`2n0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo0;h0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`2n0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0;h0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`2n0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000?03oool00`000000oooo0?oo
o`2n0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0000003`0oooo00<00000
0?ooo`3oool0_P3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000003/0oooo00<00000
0?ooo`3oool0_P3oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00000k0?ooo`030000003oool0oooo0;h0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000000j0?ooo`030000003oool0oooo0;h0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool0_P3oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`2o0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0;l0oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0_`3oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`2o0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0_`3oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0_`3oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000000/0?ooo`030000003oool0oooo0;l0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
0000;03oool00`000000oooo0?ooo`2o0?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000/0?ooo`03
0000003oool0oooo0;l0oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000[0?ooo`030000003oool0oooo0;l0
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000[0?ooo`03
0000003oool0oooo0;l0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000[0?ooo`030000003oool0oooo0;l0oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o02P0001o00<000000000O`0007l0L00007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo0;l0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`2o0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0_`3oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`2o0?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`2o0?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`2o0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0;l0oooo000D0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0;l0
oooo000D0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0000000M0?ooo`030000003oool0oooo0;l0oooo000D0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0103oool00`000000oooo0000000M0?ooo`030000003oool0oooo0;l0oooo000D
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000001`0oooo00<000000?ooo`3oool0_`3oool001@0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`2o0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0;l0oooo000D0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0;l0oooo000D0?ooo`800000/`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2o0?ooo`00
503oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0000000=0?ooo`030000003oool0oooo0<00oooo000D0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000=0?ooo`030000003o
ool0oooo0<00oooo000D0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0`03oool001@0oooo00<00000
0?ooo`3oool0`03oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`300?ooo`00503oool00`000000oooo0?ooo`300?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`300?ooo`00503oool0
0`000000oooo0?ooo`310?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`300?ooo`00503oool200000<<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0<00oooo000D0?ooo`030000003oool0oooo0<d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`300?ooo`00503oool00`000000oooo
0?ooo`3=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0`03oool001@0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0<00oooo000D
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`30
0?ooo`00503oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0`03oool001@0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0<00oooo000D0?ooo`800000d@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0<00oooo000D0?ooo`030000003oool0oooo0=00oooo00@000000?ooo`3oool0oooo
0`0000320?ooo`00503oool00`000000oooo0?ooo`3A0?ooo`<00000a@3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@0
00000P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3o
ool00`000000oooo0?ooo`030?ooo`80001o00<000000000O`0007l0100007l300000?l0001oB`00
07m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooVP3o
ool000@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0?l0ooooVP3oool000D0oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o
0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003o
ool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool00000
0P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00050?ooo`8000000`3o
ool010000000oooo0?ooo`00003o0?oooj<0oooo00070?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0o`3ooonQ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000?l0ooooX`3oool000D0oooo0P0000040?ooo`800000o`3ooonT0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00103oool200000080oooo0`0000030?ooo`D000000`3oool20000
0080oooo0`0000040?ooo`<00000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`000`3o
ool010000000oooo0000000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooohX0
oooo00030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000o`3ooon=0?oo
o`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0o`3ooon=0?ooo`00103oool200000080oooo1@000000103oool000000000
000000050?ooo`8000000P3oool4000000@0oooo0`00003o0?oooh`0oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 0 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo0700oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0h@3oool00`00
0000oooo0?ooo`1`0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo0;D0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo0;D0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`2e0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool0]@3oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo
0;D0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0fP3oool00`000000
oooo0?ooo`2e0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=T0oooo
00<000000?ooo`3oool0]@3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3I0?ooo`030000003oool0oooo0;D0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`3H
0?ooo`030000003oool0oooo0;D0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0f03oool00`000000oooo0?ooo`2e0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0=L0oooo00<000000?ooo`3oool0]@3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo0;D0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`2f0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0]P3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo
0;H0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0;H0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0e03oool00`000000oooo
0?ooo`2f0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0=@0oooo00<0
00000?ooo`3oool0]P3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3D
0?ooo`030000003oool0oooo0;H0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0d`3oool00`000000oooo0?ooo`2f0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0=<0oooo00<000000?ooo`3oool0]P3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo0;H0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo0;H0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`2f0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0]P3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo0;H0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0d@3oool00`000000oooo
0?ooo`2f0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`3@0?ooo`030000003oool0oooo0;H0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo0;H0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`2h0000O`030000000007l0001o06L0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000002i0?ooo`03
0000003oool0oooo0;H0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000^@3oool00`000000
oooo0?ooo`2f0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool000000;P0oooo00<000000?ooo`3o
ool0]P3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`2f0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo0;H0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0;@0oooo00<000000?ooo`3oool0]P3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0]P3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo0;<0
oooo00<000000?ooo`3oool0]P3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000/`3oool00`000000oooo0?ooo`2f0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000/@3oool00`000000oooo0?ooo`2f0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000[`3oool00`000000oooo0?ooo`2f0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000[@3oool00`000000oooo0?ooo`2f0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000Z`3oool00`000000oooo0?ooo`2f0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
Z03oool00`000000oooo0?ooo`2f0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool0]P3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0;H0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`2g0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0]`3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo0;L0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?oo
o`2g0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`2g
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0:80oooo00<000000?oo
o`3oool0]`3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2Q0?ooo`03
0000003oool0oooo0;L0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
X03oool00`000000oooo0?ooo`2g0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0:00oooo00<000000?ooo`3oool0]`3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0;L0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`2g0?ooo`00503oool2000003l0
oooo0P00002O0?ooo`030000003oool0oooo0;L0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00002M0?ooo`030000003oool0oooo0;L0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
002K0?ooo`030000003oool0oooo0;L0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0V03oool00`000000oooo0?ooo`2g0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000V03oool00`000000oooo0?ooo`2g0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`2g0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0]`3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o09<0001o00<000000000O`0007l0J00007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000T`3oool00`000000oooo0?ooo`2g0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000T@3oool00`000000
oooo0?ooo`2g0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0]`3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo0;L0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`2g0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0]`3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool0]`3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0;L0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`2g0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000QP3oool00`000000oooo0?ooo`2g0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0]`3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo
0;L0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0P`3oool00`000000
oooo0?ooo`2g0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0PP3oool00`000000oooo
0?ooo`2g0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0880oooo00<0
00000?ooo`3oool0]`3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`20
0?ooo`030000003oool0oooo0;P0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0P03oool00`000000oooo0?ooo`2h0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo07l0oooo00<000000?ooo`3oool0^03oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0;P0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`2h0?ooo`00503oool2
000005h0oooo0P00001o0?ooo`030000003oool0oooo0;P0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00001m0?ooo`030000003oool0oooo0;P0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00001k0?ooo`030000003oool0oooo0;P0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`2h0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000N03oool00`000000oooo0?ooo`2h0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0^03oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0;P0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0;P0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`2h0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0^03o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0
oooo0;P0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0L@3oool00`00
0000oooo0?ooo`2h0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`2h0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo0;P0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`1_0000O`0300000000
07l0001o06T0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo0;P0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo06D0oooo00<000000?ooo`3oool0^03o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0^03o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool0^03oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0^03oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000D`3oool00`000000oooo0?ooo`2h0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000001B0?ooo`03
0000003oool0oooo0;P0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000001B0?ooo`030000003oool0oooo0;P0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000001B0?ooo`030000003o
ool0oooo0;P0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0;P0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000540oooo00<0
00000?ooo`3oool0^03oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000D@3oool00`000000oooo0?ooo`2h0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0;P0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`2h0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0;T0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`2i0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000@@3oool00`000000oooo0?oo
o`2i0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool000000440oooo00<00000
0?ooo`3oool0^@3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000400oooo00<00000
0?ooo`3oool0^@3oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`0000100?ooo`030000003oool0oooo0;T0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000000o0?ooo`030000003oool0oooo0;T0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0^@3oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`2i0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0;T0oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0^@3oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`2i0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool0^@3oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0^@3oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000000b0?ooo`030000003oool0oooo0;T0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
0000<P3oool00`000000oooo0?ooo`2i0?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000b0?ooo`03
0000003oool0oooo0;T0oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000a0?ooo`030000003oool0oooo0;T0
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000a0?ooo`03
0000003oool0oooo0;T0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000a0?ooo`030000003oool0oooo0;T0oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o02h0001o00<000000000O`0007l0JP0007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0;T0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`2i0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0^@3oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`2i0?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2i0?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`2i0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo0;T0oooo000D0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;T0
oooo000D0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0000000S0?ooo`030000003oool0oooo0;T0oooo000D0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0103oool00`000000oooo0000000S0?ooo`030000003oool0oooo0;T0oooo000D
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool000000280oooo00<000000?ooo`3oool0^@3oool001@0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`2i0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0;T0oooo000D0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0;X0oooo000D0?ooo`800000/`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2j0?ooo`00
503oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0000000C0?ooo`030000003oool0oooo0;X0oooo000D0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000C0?ooo`030000003o
ool0oooo0;X0oooo000D0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0^P3oool001@0oooo00<00000
0?ooo`3oool0`03oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`2j0?ooo`00503oool00`000000oooo0?ooo`300?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2j0?ooo`00503oool0
0`000000oooo0?ooo`310?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`2j0?ooo`00503oool200000<<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0;X0oooo000D0?ooo`030000003oool0oooo0<d0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2j0?ooo`00503oool00`000000oooo
0?ooo`3=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0^P3oool001@0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;X0oooo000D
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2j
0?ooo`00503oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0^P3oool001@0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0;X0oooo000D0?ooo`800000d@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0;X0oooo000D0?ooo`030000003oool0oooo0=00oooo00@000000?ooo`3oool0oooo
2@00002l0?ooo`00503oool00`000000oooo0?ooo`3A0?ooo`<00000a@3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`@0
00000P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3o
ool00`000000oooo0?ooo`030?ooo`80001o00<000000000O`0007l0100007l300000?l0001oB`00
07m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooVP3o
ool000@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0?l0ooooVP3oool000D0oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o
0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003o
ool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool00000
0P0007l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00050?ooo`8000000`3o
ool010000000oooo0?ooo`00003o0?oooj<0oooo00070?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0o`3ooonQ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000?l0ooooX`3oool000D0oooo0P0000040?ooo`800000o`3ooonT0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00103oool200000080oooo0`0000030?ooo`D000000`3oool20000
0080oooo0`0000040?ooo`<00000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`000`3o
ool010000000oooo0000000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooohX0
oooo00030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000o`3ooon=0?oo
o`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0o`3ooon=0?ooo`00103oool200000080oooo1@000000103oool000000000
000000050?ooo`8000000P3oool4000000@0oooo0`00003o0?oooh`0oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 0 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo06/0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0iP3oool00`00
0000oooo0?ooo`1[0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo0;00oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo0;00oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`2`0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0/03oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo
0;00oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0g`3oool00`000000
oooo0?ooo`2`0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=h0oooo
00<000000?ooo`3oool0/03oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3N0?ooo`030000003oool0oooo0;00oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`3M
0?ooo`030000003oool0oooo0;00oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0g@3oool00`000000oooo0?ooo`2`0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0=`0oooo00<000000?ooo`3oool0/03oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo0;00oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`2a0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool0/@3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo
0;40oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo0;40
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0f@3oool00`000000oooo
0?ooo`2a0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0=T0oooo00<0
00000?ooo`3oool0/@3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3I
0?ooo`030000003oool0oooo0;40oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0f03oool00`000000oooo0?ooo`2a0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0=P0oooo00<000000?ooo`3oool0/@3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo0;40oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo0;40oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`2a0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0/@3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0;40
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0eP3oool00`000000oooo
0?ooo`2a0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo0;40oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo0;40oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`2m0000O`030000000007l0001o0680001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000002n0?ooo`03
0000003oool0oooo0;40oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000_P3oool00`000000
oooo0?ooo`2a0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool000000;d0oooo00<000000?ooo`3o
ool0/@3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`2a0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo0;40oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0;T0oooo00<000000?ooo`3oool0/@3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0/@3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo0;P0
oooo00<000000?ooo`3oool0/@3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000^03oool00`000000oooo0?ooo`2a0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000]P3oool00`000000oooo0?ooo`2a0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000]03oool00`000000oooo0?ooo`2a0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000/P3oool00`000000oooo0?ooo`2a0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000/03oool00`000000oooo0?ooo`2a0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`2a0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0:d0oooo00<000000?ooo`3oool0/@3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0;40oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`2a0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0/P3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0;80oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?oo
o`2b0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2b
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0:L0oooo00<000000?oo
o`3oool0/P3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2V0?ooo`03
0000003oool0oooo0;80oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
Y@3oool00`000000oooo0?ooo`2b0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0:D0oooo00<000000?ooo`3oool0/P3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo0;80oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`2b0?ooo`00503oool2000003l0
oooo0P00002T0?ooo`030000003oool0oooo0;80oooo000D0?ooo`030000003oool0oooo0400oooo
0P00002R0?ooo`030000003oool0oooo0;80oooo000D0?ooo`030000003oool0oooo0480oooo0P00
002P0?ooo`030000003oool0oooo0;80oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0W@3oool00`000000oooo0?ooo`2b0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000W@3oool00`000000oooo0?ooo`2b0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`2b0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0/P3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o09P0001o00<000000000O`0007l0H`0007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000V03oool00`000000oooo0?ooo`2b0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000UP3oool00`000000
oooo0?ooo`2b0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0/P3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo0;80oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0TP3oool00`000000oooo0?ooo`2b0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0/P3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0/P3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0;80oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`2b0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000R`3oool00`000000oooo0?ooo`2b0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0/P3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo
0;80oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`2b0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo
0?ooo`2b0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo08L0oooo00<0
00000?ooo`3oool0/P3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo0;80oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`2b0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool0/P3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0;<0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`2c0?ooo`00503oool2
000005h0oooo0P0000240?ooo`030000003oool0oooo0;<0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P0000220?ooo`030000003oool0oooo0;<0oooo000D0?ooo`030000003oool0oooo0640
oooo0P0000200?ooo`030000003oool0oooo0;<0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2c0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000O@3oool00`000000oooo0?ooo`2c0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0/`3oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0;<0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0;<0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`2c0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0/`3o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo0;<0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`2c0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`2c0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`1e0?ooo`030000003oool0oooo0;<0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`1d0000O`0300000000
07l0001o06@0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo0;<0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo06X0oooo00<000000?ooo`3oool0/`3o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0/`3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool0/`3oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0/`3oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000F03oool00`000000oooo0?ooo`2c0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000001G0?ooo`03
0000003oool0oooo0;<0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000001G0?ooo`030000003oool0oooo0;<0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000001G0?ooo`030000003o
ool0oooo0;<0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00001G0?ooo`030000003oool0oooo0;<0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000005H0oooo00<0
00000?ooo`3oool0/`3oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000EP3oool00`000000oooo0?ooo`2c0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0;<0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`2c0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0;<0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`2c0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000A`3oool00`000000oooo0?oo
o`2c0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0000004L0oooo00<00000
0?ooo`3oool0/`3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000004D0oooo00<00000
0?ooo`3oool0]03oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`0000150?ooo`030000003oool0oooo0;@0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo000000140?ooo`030000003oool0oooo0;@0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0]03oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`2d0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0;@0oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0]03oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`2d0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0]03oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0]03oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000000g0?ooo`030000003oool0oooo0;@0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
0000=`3oool00`000000oooo0?ooo`2d0?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000g0?ooo`03
0000003oool0oooo0;@0oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000f0?ooo`030000003oool0oooo0;@0
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000f0?ooo`03
0000003oool0oooo0;@0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000f0?ooo`030000003oool0oooo0;@0oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o03<0001o00<000000000O`0007l0I@0007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo0;@0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`2d0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0]03oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`2d0?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`2d0?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`2d0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo0;@0oooo000D0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0;@0
oooo000D0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0000000X0?ooo`030000003oool0oooo0;@0oooo000D0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0103oool00`000000oooo0000000X0?ooo`030000003oool0oooo0;@0oooo000D
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000002L0oooo00<000000?ooo`3oool0]03oool001@0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`2d0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0;@0oooo000D0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;@0oooo000D0?ooo`800000/`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2d0?ooo`00
503oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0000000I0?ooo`030000003oool0oooo0;@0oooo000D0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000I0?ooo`030000003o
ool0oooo0;@0oooo000D0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000001P0oooo00<000000?ooo`3oool0]03oool001@0oooo00<00000
0?ooo`3oool0`03oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`2e0?ooo`00503oool00`000000oooo0?ooo`300?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2e0?ooo`00503oool0
0`000000oooo0?ooo`310?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`2e0?ooo`00503oool200000<<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0;D0oooo000D0?ooo`030000003oool0oooo0<d0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2e0?ooo`00503oool00`000000oooo
0?ooo`3=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0]@3oool001@0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0;D0oooo000D
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`2e
0?ooo`00503oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0]@3oool001@0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0;D0oooo000D0?ooo`800000d@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0;D0oooo000D0?ooo`030000003oool0oooo0=00oooo00@000000?ooo`3oool0oooo
2@0000040?ooo`030000003oool0oooo0;D0oooo000D0?ooo`030000003oool0oooo0=40oooo0`00
00090?ooo`050000003oool0oooo0?ooo`000000]`3oool001@0oooo00<000000?ooo`3oool0gP3o
ool010000000oooo0?ooo`00002g0?ooo`00503oool00`000000oooo0?ooo`3O0?ooo`030000003o
ool000000;L0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0g`3oool0
0`000000oooo0000002g0?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0h03oool200000;L0oooo00050?ooo`030000003oool0oooo00<0
oooo0P0007l00`000000001o0000O`040000O`<00000h@0007l00`000000001o0000O`1V0000Odl0
oooo00060?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiX0
oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`001@3oool2000000<0oooo100000060?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0oooo
V`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`80
0000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000020000
O`030000000007l0001o00@0001o0`00003o0000Od/0001oC`3oool000D0oooo0P0000030?ooo`04
0000003oool0oooo00000?l0ooooX`3oool000L0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`3o0?oooj40oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000o`3ooonS0?ooo`001@3oool2000000@0oooo0P00003o0?oooj@0oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo00040?ooo`8000000P3oool3000000<0oooo1@0000030?ooo`8000000P3o
ool3000000@0oooo0`00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`04
0000003oool0000000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo0`0000060?ooo`030000003oool0oooo0?l0ooooRP3oool0
00<0oooo00<000000?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P00003o0?ooohd0oooo0003
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`3o0?ooohd0oooo00040?ooo`8000000P3oool5000000040?ooo`00000000000000
00D0oooo0P0000020?ooo`@00000103oool300000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 0 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo06H0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0j`3oool00`00
0000oooo0?ooo`1V0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0j`3oool00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo0:/0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo0:/0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`2[0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0>D0oooo00<000000?ooo`3oool0Z`3oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo
0:/0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0i03oool00`000000
oooo0?ooo`2[0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0><0oooo
00<000000?ooo`3oool0Z`3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3S0?ooo`030000003oool0oooo0:/0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`3R
0?ooo`030000003oool0oooo0:/0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0hP3oool00`000000oooo0?ooo`2[0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0>40oooo00<000000?ooo`3oool0Z`3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo0:/0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`2/0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0[03oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo
0:`0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo0:`0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0gP3oool00`000000oooo
0?ooo`2/0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0=h0oooo00<0
00000?ooo`3oool0[03oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3N
0?ooo`030000003oool0oooo0:`0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0g@3oool00`000000oooo0?ooo`2/0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0=d0oooo00<000000?ooo`3oool0[03oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo0:`0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo0:`0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`2/0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool0[03oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3K0?ooo`030000003oool0oooo0:`0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0f`3oool00`000000oooo
0?ooo`2/0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`3J0?ooo`030000003oool0oooo0:`0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo0:`0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`320000O`030000000007l0001o05d0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo000000330?ooo`03
0000003oool0oooo0:`0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000``3oool00`000000
oooo0?ooo`2/0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool000000<80oooo00<000000?ooo`3o
ool0[03oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`2/0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo0:`0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0;h0oooo00<000000?ooo`3oool0[03oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0[03oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo0;d0
oooo00<000000?ooo`3oool0[03oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000_@3oool00`000000oooo0?ooo`2/0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000^`3oool00`000000oooo0?ooo`2/0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000^@3oool00`000000oooo0?ooo`2/0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000]`3oool00`000000oooo0?ooo`2/0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000]@3oool00`000000oooo0?ooo`2/0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`2/0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0;80oooo00<000000?ooo`3oool0[03oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0:`0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`2/0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0[03oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0:d0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`2]0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`2]
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0:`0oooo00<000000?oo
o`3oool0[@3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2[0?ooo`03
0000003oool0oooo0:d0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
ZP3oool00`000000oooo0?ooo`2]0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0:X0oooo00<000000?ooo`3oool0[@3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0:d0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`2]0?ooo`00503oool2000003l0
oooo0P00002Y0?ooo`030000003oool0oooo0:d0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00002W0?ooo`030000003oool0oooo0:d0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
002U0?ooo`030000003oool0oooo0:d0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0XP3oool00`000000oooo0?ooo`2]0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000XP3oool00`000000oooo0?ooo`2]0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`2]0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0[@3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o09d0001o00<000000000O`0007l0GP0007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000W@3oool00`000000oooo0?ooo`2]0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000V`3oool00`000000
oooo0?ooo`2]0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0[@3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`2G0?ooo`030000003oool0oooo0:d0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0U`3oool00`000000oooo0?ooo`2]0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0[@3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo09D0oooo00<000000?ooo`3oool0[@3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0:d0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`2]0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000T03oool00`000000oooo0?ooo`2]0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0[@3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
0:d0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`2]0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`2]0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool0[@3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo0:d0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`2]0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo08X0oooo00<000000?ooo`3oool0[@3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0:h0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2^0?ooo`00503oool2
000005h0oooo0P0000290?ooo`030000003oool0oooo0:h0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P0000270?ooo`030000003oool0oooo0:h0oooo000D0?ooo`030000003oool0oooo0640
oooo0P0000250?ooo`030000003oool0oooo0:h0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`2^0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000PP3oool00`000000oooo0?ooo`2^0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0[P3oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0:h0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0:h0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2^0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0[P3o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0
oooo0:h0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`2^0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2^0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`1j0?ooo`030000003oool0oooo0:h0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`1i0000O`0300000000
07l0001o05l0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo0:h0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo06l0oooo00<000000?ooo`3oool0[P3o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0[P3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool0[P3oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0[P3oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000G@3oool00`000000oooo0?ooo`2^0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000001L0?ooo`03
0000003oool0oooo0:h0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000001L0?ooo`030000003oool0oooo0:h0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000001L0?ooo`030000003o
ool0oooo0:h0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00001L0?ooo`030000003oool0oooo0:h0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000005/0oooo00<0
00000?ooo`3oool0[P3oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000F`3oool00`000000oooo0?ooo`2^0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0:h0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0F@3oool00`00
0000oooo0?ooo`2^0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0:h0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`2^0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000C03oool00`000000oooo0?oo
o`2^0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0000004`0oooo00<00000
0?ooo`3oool0[P3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000004X0oooo00<00000
0?ooo`3oool0[`3oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00001:0?ooo`030000003oool0oooo0:l0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo000000190?ooo`030000003oool0oooo0:l0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0[`3oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`2_0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0:l0oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0[`3oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`2_0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0[`3oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0[`3oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000000l0?ooo`030000003oool0oooo0:l0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
0000?03oool00`000000oooo0?ooo`2_0?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000l0?ooo`03
0000003oool0oooo0:l0oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000k0?ooo`030000003oool0oooo0:l0
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000k0?ooo`03
0000003oool0oooo0:l0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000k0?ooo`030000003oool0oooo0:l0oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o03P0001o00<000000000O`0007l0H00007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo0:l0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`2_0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0[`3oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`2_0?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2_0?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`2_0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo0:l0oooo000D0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0:l0
oooo000D0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0000000]0?ooo`030000003oool0oooo0:l0oooo000D0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0103oool00`000000oooo0000000]0?ooo`030000003oool0oooo0:l0oooo000D
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000002`0oooo00<000000?ooo`3oool0[`3oool001@0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`2_0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0:l0oooo000D0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo0:l0oooo000D0?ooo`800000/`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`2_0?ooo`00
503oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0000000N0?ooo`030000003oool0oooo0:l0oooo000D0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000N0?ooo`030000003o
ool0oooo0:l0oooo000D0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000001d0oooo00<000000?ooo`3oool0[`3oool001@0oooo00<00000
0?ooo`3oool0`03oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`2_0?ooo`00503oool00`000000oooo0?ooo`300?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2`0?ooo`00503oool0
0`000000oooo0?ooo`310?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`2`0?ooo`00503oool200000<<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0;00oooo000D0?ooo`030000003oool0oooo0<d0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`2`0?ooo`00503oool00`000000oooo
0?ooo`3=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0/03oool001@0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0;00oooo000D
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2`
0?ooo`00503oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0/03oool001@0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0;00oooo000D0?ooo`800000d@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0;00oooo000D0?ooo`030000003oool0oooo0=00oooo00@000000?ooo`3oool0oooo
2@0000090?ooo`030000003oool0oooo0;00oooo000D0?ooo`030000003oool0oooo0=40oooo0`00
00090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0/03oool001@0oooo00<00000
0?ooo`3oool0gP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;00oooo000D0?oo
o`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2`0?oo
o`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2`0?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0;00oooo00050?ooo`030000003oool0oooo00<0oooo0P0007l00`000000001o0000
O`040000O`<00000h@0007l300000080001o00<000000000O`0007l0H@0007m?0?ooo`001P3oool0
10000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0i03oool300000;80oooo0007
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`001@3oool2000000<0oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000020000O`030000
000007l0001o00@0001o0`00003o0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003o
ool0oooo00000?l0ooooX`3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`3o0?oooj40oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000o`3ooonS0?ooo`001@3oool2000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo00040?ooo`8000000P3oool3000000<0oooo1@0000030?ooo`8000000P3oool30000
00@0oooo0`00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003o
ool0000000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo00000080oooo0`0000060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo
00<000000?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`3o0?ooohd0oooo00040?ooo`8000000P3oool5000000040?ooo`0000000000000000D0oooo
0P0000020?ooo`@00000103oool300000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 0 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D000000?ooo`000000oooo
000000030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<000001@3oool001@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0903oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0
000000X0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo000D0?ooo`030000003oool0oooo0?00oooo00<00000
0?ooo`3oool0H@3oool2000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool0
0`000000oooo0000000200000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool0
0`000000oooo0?ooo`040?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`00
0000oooo0?ooo`3`0?ooo`030000003oool0oooo0640oooo00D000000?ooo`3oool0oooo00000009
0?ooo`030000003oool0oooo01/0oooo0`00000F0?ooo`00503oool00`000000oooo0?ooo`3`0?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00l0oooo000D0?ooo`030000003oool0oooo0?00oooo00<000000?ooo`3o
ool0YP3oool001@0oooo0P0000030?ooo`030000003oool0oooo0>/0oooo00<000000?ooo`3oool0
YP3oool001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3Z0?ooo`030000003o
ool0oooo0:H0oooo000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0jP3oool0
0`000000oooo0?ooo`2V0?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0>T0oooo00<000000?ooo`3oool0YP3oool001@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3Y0?ooo`030000003oool0oooo0:H0oooo000D0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0j03oool00`000000oooo0?ooo`2V0?ooo`00503oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0>P0oooo00<000000?ooo`3oool0YP3oool001@0oooo0P000007
0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool0YP3oool001@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3W0?ooo`030000003oool0oooo0:H0oooo000D0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`2V0?ooo`00
503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0>H0oooo00<000000?ooo`3oool0
YP3oool001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3U0?ooo`030000003o
ool0oooo0:L0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0i03oool0
0`000000oooo0?ooo`2W0?ooo`00503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0>@0oooo00<000000?ooo`3oool0Y`3oool001@0oooo0P0000090?ooo`030000003oool0oooo0>@0
oooo00<000000?ooo`3oool0Y`3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`3S0?ooo`030000003oool0oooo0:L0oooo000D0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0h`3oool00`000000oooo0?ooo`2W0?ooo`00503oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0><0oooo00<000000?ooo`3oool0Y`3oool001@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo0:L0oooo000D0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0hP3oool00`000000oooo0?ooo`2W0?ooo`00
503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool0
Y`3oool001@0oooo0P00000<0?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool0Y`3o
ool001@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0
oooo0:L0oooo000D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0h@3oool00`00
0000oooo0?ooo`2W0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0>00
oooo00<000000?ooo`3oool0Y`3oool001@0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`3P0?ooo`030000003oool0oooo0:L0oooo000:0?ooo`<000001`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0Y`3oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0=h0oooo00<00000
0?ooo`3oool0Y`3oool000/0oooo0P0007l00`000000001o0000O`040000O`<000003`0007l00`00
0000001o0000O`0C0000O`030000000007l0001o0<L0001o00<000000000O`0007l0F00007m?0?oo
o`002P3oool3000000L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool000000<P0oooo00<000000?ooo`3oool0Y`3oool000X0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0?ooo`<000003@3oool00`000000
oooo000000380?ooo`030000003oool0oooo0:L0oooo000:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool04@3oool3000000<0oooo0P00000:0?ooo`050000003oool0oooo0?ooo`00
0000a`3oool00`000000oooo0?ooo`2W0?ooo`002P3oool4000000H0oooo00<000000?ooo`3oool0
6@3oool2000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`340?ooo`030000
003oool0oooo0:L0oooo000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0Y`3o
ool001@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`2W0?ooo`00503oool20000
01h0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0``3oool00`00
0000oooo0?ooo`2W0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`2W0?ooo`00503oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00P0oooo0P0000320?ooo`030000003oool0oooo0:L0oooo
000D0?ooo`030000003oool0oooo02d0oooo0P0000300?ooo`030000003oool0oooo0:L0oooo000D
0?ooo`030000003oool0oooo02l0oooo0P00002n0?ooo`030000003oool0oooo0:L0oooo000D0?oo
o`030000003oool0oooo0340oooo0P00002l0?ooo`030000003oool0oooo0:L0oooo000D0?ooo`03
0000003oool0oooo03<0oooo0P00002j0?ooo`030000003oool0oooo0:L0oooo000D0?ooo`800000
=P3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo0:L0oooo000D0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`2W0?ooo`00503oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0Y`3oool0
01@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
0:L0oooo000D0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0/`3oool00`000000
oooo0?ooo`2X0?ooo`00503oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0;<0oooo
00<000000?ooo`3oool0Z03oool001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`2b0?ooo`030000003oool0oooo0:P0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`2a
0?ooo`030000003oool0oooo0:P0oooo000D0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0/@3oool00`000000oooo0?ooo`2X0?ooo`00503oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo0;00oooo00<000000?ooo`3oool0Z03oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0:P0oooo000D0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`2X0?ooo`00503oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0Z03oool0
01@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo
0:P0oooo000D0?ooo`800000?`3oool200000:h0oooo00<000000?ooo`3oool0Z03oool001@0oooo
00<000000?ooo`3oool0@03oool200000:`0oooo00<000000?ooo`3oool0Z03oool001@0oooo00<0
00000?ooo`3oool0@P3oool200000:X0oooo00<000000?ooo`3oool0Z03oool001@0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0:P0oooo000D0?oo
o`030000003oool0oooo04D0oooo0P00002W0?ooo`030000003oool0oooo0:P0oooo00040?ooo`@0
00000`3oool2000000L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2T0?ooo`03
0000003oool0oooo0:P0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0X`3oool00`000000
oooo0?ooo`2X0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080001o00<000000000O`00
07l0100007l3000004T0001o00<000000000O`0007l0XP0007l00`000000001o0000O`1I0000Odl0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo0P00002R0?ooo`030000003oool0oooo0:P0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0
oooo0P00002P0?ooo`030000003oool0oooo0:P0oooo00040?ooo`<000000`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0W@3oool00`000000
oooo0?ooo`2X0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0Z03oool001@0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0:P0oooo000D
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`2X
0?ooo`00503oool200000580oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`2X0?oo
o`00503oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0Z03oool001@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2I0?ooo`030000
003oool0oooo0:P0oooo000D0?ooo`030000003oool0oooo05<0oooo1P00002E0?ooo`030000003o
ool0oooo0:P0oooo000D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`2X0?ooo`00503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
0980oooo00<000000?ooo`3oool0Z03oool001@0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo0:P0oooo000D0?ooo`800000F`3oool00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo0:P0oooo000D0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`2X0?ooo`00503oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0Z03oool001@0oooo00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0:P0oooo000D0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`2Y0?ooo`00
503oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
Z@3oool001@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo0:T0oooo000D0?ooo`800000GP3oool2000008h0oooo00<000000?ooo`3oool0Z@3oool0
01@0oooo00<000000?ooo`3oool0G`3oool2000008`0oooo00<000000?ooo`3oool0Z@3oool001@0
oooo00<000000?ooo`3oool0H@3oool2000008X0oooo00<000000?ooo`3oool0Z@3oool001@0oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0:T0oooo
000D0?ooo`030000003oool0oooo06@0oooo0P0000270?ooo`030000003oool0oooo0:T0oooo000D
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`2Y
0?ooo`00503oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo08<0oooo00<000000?oo
o`3oool0Z@3oool001@0oooo0P00001Y0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3o
ool0Z@3oool001@0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`220?ooo`030000
003oool0oooo0:T0oooo000D0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`2Y0?ooo`00503oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo0800oooo00<000000?ooo`3oool0Z@3oool001@0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`200?ooo`030000003oool0oooo0:T0oooo00040?ooo`@000000P3oool3000000L0
oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0:T0
oooo00060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1[0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0Z@3oool000H0oooo00<0
00000?ooo`3oool00P3oool20000O`030000000007l0001o00@0001o0`00001/0000O`0300000000
07l0001o07h0001o00<000000000O`0007l0FP0007m?0?ooo`001P3oool010000000oooo0?ooo`3o
ool3000000L0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool0Z@3oool000H0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo06h0oooo0P0000040?ooo`80000000<0oooo0000003oool0M03o
ool00`000000oooo0?ooo`2Y0?ooo`00103oool3000000<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1`0?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`2Y0?ooo`001P3oool010000000oooo0?ooo`3oool4000000H0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`2Y0?ooo`00503oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`2Y
0?ooo`00503oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00d0oooo0P00001R0?oo
o`030000003oool0oooo0:T0oooo000D0?ooo`800000NP3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool000000640oooo00<000000?ooo`3oool0Z@3oool001@0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool000000640oooo00<000000?ooo`3oool0
Z@3oool001@0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool000000640oooo00<000000?ooo`3oool0Z@3oool001@0oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000640oooo00<000000?ooo`3oool0Z@3o
ool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`090?ooo`050000003oool0
oooo0?ooo`000000H03oool00`000000oooo0?ooo`2Y0?ooo`00503oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000001P0?ooo`030000003o
ool0oooo0:T0oooo000D0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0Z@3oool0
01@0oooo0P00001o0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo0:T0oooo000D0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05d0
oooo00<000000?ooo`3oool0Z@3oool001@0oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo0:T0oooo000D0?ooo`030000003oool0oooo07l0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P00
001A0?ooo`030000003oool0oooo0:T0oooo000D0?ooo`030000003oool0oooo0800oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`000000D03oool00`000000oooo0?ooo`2Z0?ooo`00503oool00`000000oooo0?ooo`210?oo
o`8000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00@000000?oo
o`3oool00000C`3oool00`000000oooo0?ooo`2Z0?ooo`00503oool00`000000oooo0?ooo`230?oo
o`<00000203oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000004l0oooo00<00000
0?ooo`3oool0ZP3oool001@0oooo0P0000260?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0203oool01@000000oooo0?ooo`3oool0000004h0oooo00<000000?ooo`3oool0ZP3oool0
01@0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`2Z0?ooo`00503oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0:X0oooo000D0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0ZP3oool001@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`2Z0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0:X0oooo000D0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2Z0?oo
o`00503oool200000980oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2Z0?ooo`00
503oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000
oooo0?ooo`050?ooo`030000003oool000000440oooo00<000000?ooo`3oool0ZP3oool001@0oooo
00<000000?ooo`3oool0TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo000000110?ooo`030000003oool0oooo0:X0oooo000D0?ooo`030000
003oool0oooo09<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool000000440oooo00<000000?ooo`3oool0ZP3oool001@0oooo00<000000?ooo`3oool0
U03oool2000000/0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000400
oooo00<000000?ooo`3oool0ZP3oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo
0?ooo`2E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool000000400oooo00<000000?ooo`3oool0ZP3oool000@0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool000000400oooo00<000000?ooo`3oool0ZP3oool000D0
oooo00<000000?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000XP0007l01@00
0000001o0000O`0007l0000000D0001o00<000000000O`0007l0?@0007l00`000000001o0000O`1K
0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0:80oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool0ZP3oool000L0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:<0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0:X0oooo00040?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2S0?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Z0?ooo`00
1@3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`000000
1`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0:X0oooo000D0?ooo`030000003o
ool0oooo0:<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0:X0oooo000D0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0:X0oooo000D0?ooo`800000Y@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0ZP3oool001@0
oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0ZP3oool001@0oooo00<000000?ooo`3oool0[`3oool00`000000oooo
0?ooo`050?ooo`030000003oool000000380oooo00<000000?ooo`3oool0ZP3oool001@0oooo00<0
00000?ooo`3oool0/03oool00`000000oooo0?ooo`040?ooo`030000003oool000000380oooo00<0
00000?ooo`3oool0ZP3oool001@0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`000000<@3oool00`000000oooo0?ooo`2Z0?ooo`00503oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0:X0oooo000D0?ooo`030000003oool0oooo
0;40oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0ZP3oool001@0oooo00<000000?ooo`3oool0/P3oool00`000000oooo000000070?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0ZP3oool001@0oooo0P00002c0?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0:X0oooo000D0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool0
ZP3oool001@0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0000002<0oooo00<000000?ooo`3oool0ZP3oool001@0oooo00<000000?ooo`3oool0_`3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000008@3oool00`000000oooo0?oo
o`2[0?ooo`00503oool00`000000oooo0?ooo`300?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0:/0oooo000D0?ooo`030000003oool0
oooo0<00oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo0:/0oooo000D0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`0000001`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0:/0oooo000D0?ooo`800000``3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0Z`3oool001@0
oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0:/0
oooo000D0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`2[0?ooo`00503oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0Z`3oool001@0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0:/0oooo000D0?ooo`030000003oool0oooo0<l0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`2[0?ooo`00503oool00`000000oooo0?ooo`3?0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0Z`3oool001@0oooo0P00003A0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0Z`3oool001@0oooo00<000000?ooo`3oool0d03o
ool010000000oooo0?ooo`3oool9000000h0oooo00<000000?ooo`3oool0Z`3oool001@0oooo00<0
00000?ooo`3oool0d@3oool3000000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`2[0?ooo`00503oool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0Z`3oool001@0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0:/0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3o
ool0g`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0:/0oooo00040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3P0?ooo`030000
003oool0oooo00L0oooo0P00002]0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`80001o00<0
00000000O`0007l0100007l300000>40001o0`0000040000O`800000H00007m?0?ooo`001P3oool0
10000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0i03oool400000;40oooo0007
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`001@3oool2000000<0oooo100000060?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3o
oonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo
0?ooo`3o0?oooiX0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000020000O`030000
000007l0001o00@0001o0`00003o0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003o
ool0oooo00000?l0ooooX`3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`3o0?oooj40oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000o`3ooonS0?ooo`001@3oool2000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo00040?ooo`8000000P3oool3000000<0oooo1@0000030?ooo`8000000P3oool30000
00@0oooo0`00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003o
ool0000000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo00000080oooo0`0000060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo
00<000000?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`3o0?ooohd0oooo00040?ooo`8000000P3oool5000000040?ooo`0000000000000000D0oooo
0P0000020?ooo`@00000103oool300000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 0 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo05`0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0m@3oool00`00
0000oooo0?ooo`1L0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0m@3oool00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo0:40oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`3`0?ooo`030000003oool0oooo0:40oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?ooo`2Q0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0>l0oooo00<000000?ooo`3oool0X@3oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3^0?ooo`030000003oool0oooo
0:40oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0kP3oool00`000000
oooo0?ooo`2Q0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0>d0oooo
00<000000?ooo`3oool0X@3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3]0?ooo`030000003oool0oooo0:40oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`3/
0?ooo`030000003oool0oooo0:40oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0k03oool00`000000oooo0?ooo`2Q0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0>/0oooo00<000000?ooo`3oool0X@3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo0:40oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0jP3oool00`000000oooo0?ooo`2R0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0>T0oooo00<000000?ooo`3oool0XP3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo
0:80oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo0:80
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0j03oool00`000000oooo
0?ooo`2R0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0>P0oooo00<0
00000?ooo`3oool0XP3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3X
0?ooo`030000003oool0oooo0:80oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0i`3oool00`000000oooo0?ooo`2R0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0>L0oooo00<000000?ooo`3oool0XP3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3W0?ooo`030000003oool0oooo0:80oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo0:80oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`2R0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0>H0oooo00<000000?ooo`3oool0XP3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3U0?ooo`030000003oool0oooo0:80
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0i@3oool00`000000oooo
0?ooo`2R0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`3T0?ooo`030000003oool0oooo0:80oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo0:80oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`3<0000O`030000000007l0001o05<0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000003=0?ooo`03
0000003oool0oooo0:80oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000c@3oool00`000000
oooo0?ooo`2R0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool000000<`0oooo00<000000?ooo`3o
ool0XP3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`2R0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`390?ooo`030000003oool0oooo0:80oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0<P0oooo00<000000?ooo`3oool0XP3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0XP3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo0<L0
oooo00<000000?ooo`3oool0XP3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000a`3oool00`000000oooo0?ooo`2R0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000a@3oool00`000000oooo0?ooo`2R0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000``3oool00`000000oooo0?ooo`2R0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000`@3oool00`000000oooo0?ooo`2R0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000_`3oool00`000000oooo0?ooo`2R0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
_03oool00`000000oooo0?ooo`2R0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0;`0oooo00<000000?ooo`3oool0XP3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`2k0?ooo`030000003oool0oooo0:80oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`2S0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0X`3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo0:<0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?oo
o`2S0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`2S
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0;H0oooo00<000000?oo
o`3oool0X`3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo0:<0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
]03oool00`000000oooo0?ooo`2S0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0;@0oooo00<000000?ooo`3oool0X`3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`2c0?ooo`030000003oool0oooo0:<0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`2S0?ooo`00503oool2000003l0
oooo0P00002c0?ooo`030000003oool0oooo0:<0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00002a0?ooo`030000003oool0oooo0:<0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
002_0?ooo`030000003oool0oooo0:<0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0[03oool00`000000oooo0?ooo`2S0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000[03oool00`000000oooo0?ooo`2S0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`2S0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0X`3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o0:L0001o00<000000000O`0007l0E00007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000Y`3oool00`000000oooo0?ooo`2S0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000Y@3oool00`000000
oooo0?ooo`2S0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0X`3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`2Q0?ooo`030000003oool0oooo0:<0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0X@3oool00`000000oooo0?ooo`2S0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0X`3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo09l0oooo00<000000?ooo`3oool0X`3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo0:<0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`2S0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000VP3oool00`000000oooo0?ooo`2S0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0X`3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo
0:<0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0U`3oool00`000000
oooo0?ooo`2S0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0UP3oool00`000000oooo
0?ooo`2S0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool0X`3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo0:<0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0U03oool00`000000oooo0?ooo`2T0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo09<0oooo00<000000?ooo`3oool0Y03oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:@0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2T0?ooo`00503oool2
000005h0oooo0P00002C0?ooo`030000003oool0oooo0:@0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00002A0?ooo`030000003oool0oooo0:@0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00002?0?ooo`030000003oool0oooo0:@0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2T0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000S03oool00`000000oooo0?ooo`2T0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0Y03oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0:@0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0:@0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`2T0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0Y03o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`250?ooo`030000003oool0
oooo0:@0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`2T0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`2T0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`240?ooo`030000003oool0oooo0:@0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`230000O`0300000000
07l0001o05D0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo0:@0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo07T0oooo00<000000?ooo`3oool0Y03o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0Y03o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool0Y03oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0Y03oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000I`3oool00`000000oooo0?ooo`2T0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000001V0?ooo`03
0000003oool0oooo0:@0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000001V0?ooo`030000003oool0oooo0:@0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000001V0?ooo`030000003o
ool0oooo0:@0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00001V0?ooo`030000003oool0oooo0:@0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000006D0oooo00<0
00000?ooo`3oool0Y03oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000I@3oool00`000000oooo0?ooo`2T0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0:@0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`2T0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0:@0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`2U0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000E@3oool00`000000oooo0?oo
o`2U0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0000005D0oooo00<00000
0?ooo`3oool0Y@3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000005@0oooo00<00000
0?ooo`3oool0Y@3oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00001D0?ooo`030000003oool0oooo0:D0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000001C0?ooo`030000003oool0oooo0:D0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool0Y@3oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`2U0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0:D0oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0Y@3oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`2U0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0Y@3oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0Y@3oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo000000160?ooo`030000003oool0oooo0:D0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
0000AP3oool00`000000oooo0?ooo`2U0?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo000000160?ooo`03
0000003oool0oooo0:D0oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000150?ooo`030000003oool0oooo0:D0
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000150?ooo`03
0000003oool0oooo0:D0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000150?ooo`030000003oool0oooo0:D0oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o0480001o00<000000000O`0007l0EP0007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo0:D0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`2U0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0Y@3oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`2U0?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2U0?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`2U0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo0:D0oooo000D0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0:D0
oooo000D0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0000000g0?ooo`030000003oool0oooo0:D0oooo000D0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0103oool00`000000oooo0000000g0?ooo`030000003oool0oooo0:D0oooo000D
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000003H0oooo00<000000?ooo`3oool0Y@3oool001@0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`2U0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0:D0oooo000D0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo0:D0oooo000D0?ooo`800000/`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2V0?ooo`00
503oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0000000W0?ooo`030000003oool0oooo0:H0oooo000D0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000W0?ooo`030000003o
ool0oooo0:H0oooo000D0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool0YP3oool001@0oooo00<00000
0?ooo`3oool0`03oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`2V0?ooo`00503oool00`000000oooo0?ooo`300?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2V0?ooo`00503oool0
0`000000oooo0?ooo`310?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`2V0?ooo`00503oool200000<<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0:H0oooo000D0?ooo`030000003oool0oooo0<d0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2V0?ooo`00503oool00`000000oooo
0?ooo`3=0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0YP3oool001@0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0:H0oooo000D
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2V
0?ooo`00503oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0YP3oool001@0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0:H0oooo000D0?ooo`800000d@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0:H0oooo000D0?ooo`030000003oool0oooo0=00oooo00@000000?ooo`3oool0oooo
2@00000C0?ooo`030000003oool0oooo0:H0oooo000D0?ooo`030000003oool0oooo0=40oooo0`00
00090?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0YP3oool001@0oooo00<00000
0?ooo`3oool0gP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0:H0oooo000D0?oo
o`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0303oool200000:T0oooo00040?ooo`@0
00000P3oool3000000L0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`0:0?ooo`80
0000Z`3oool000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0>00oooo00<000000?ooo`3oool01`3oool200000:d0oooo00050?ooo`030000003o
ool0oooo00<0oooo0P0007l00`000000001o0000O`040000O`<00000h@0007l3000000@0001o0P00
001P0000Odl0oooo00060?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?oo
o`3T0?ooo`@00000/@3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`8000000`3oool4000000H0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool000D0oooo0P0000040?ooo`8000001`3o
ool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003o
ool0oooo00000080001o00<000000000O`0007l0100007l300000?l0001oB`0007m?0?ooo`001@3o
ool2000000<0oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`001`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0?l0ooooX@3oool000@0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00003o0?oooj<0oooo00050?ooo`800000103oool200000?l0oooo
Y03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool000@0oooo0P0000020?ooo`<000000`3oool50000
00<0oooo0P0000020?ooo`<00000103oool300000?l0ooooS@3oool000<0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000?l0oooo
S03oool000<0oooo00@000000?ooo`00000000000P3oool00`000000oooo000000030?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool3000000H0oooo00<000000?ooo`3o
ool0o`3ooon:0?ooo`000`3oool00`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool20000
0?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0?l0ooooS@3oool000@0oooo0P0000020?ooo`D0000000@0
oooo00000000000000001@3oool200000080oooo100000040?ooo`<00000o`3ooon<0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 0 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo05L0oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0nP3oool00`00
0000oooo0?ooo`1G0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo09`0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo09`0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`2L0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool0W03oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo
09`0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0l`3oool00`000000
oooo0?ooo`2L0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?80oooo
00<000000?ooo`3oool0W03oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3b0?ooo`030000003oool0oooo09`0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`3a
0?ooo`030000003oool0oooo09`0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0l@3oool00`000000oooo0?ooo`2L0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?00oooo00<000000?ooo`3oool0W03oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3`0?ooo`030000003oool0oooo09`0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0l03oool00`000000oooo0?ooo`2L0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`3oool0W@3oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3^0?ooo`030000003oool0oooo
09d0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`3^0?ooo`030000003oool0oooo09d0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0k@3oool00`000000oooo
0?ooo`2M0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0>d0oooo00<0
00000?ooo`3oool0W@3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3]
0?ooo`030000003oool0oooo09d0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0k03oool00`000000oooo0?ooo`2M0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0>`0oooo00<000000?ooo`3oool0W@3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo09d0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo09d0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0j`3oool00`000000oooo0?ooo`2M0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0>/0oooo00<000000?ooo`3oool0W@3oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3Z0?ooo`030000003oool0oooo09d0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0jP3oool00`000000oooo
0?ooo`2M0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`3Y0?ooo`030000003oool0oooo09d0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`3X0?ooo`030000003oool0oooo09d0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`3A0000O`030000000007l0001o04h0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000003B0?ooo`03
0000003oool0oooo09d0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000dP3oool00`000000
oooo0?ooo`2M0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool000000=40oooo00<000000?ooo`3o
ool0W@3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`2M0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo09d0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0<d0oooo00<000000?ooo`3oool0W@3oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0W@3oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo0<`0
oooo00<000000?ooo`3oool0W@3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000c03oool00`000000oooo0?ooo`2M0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000bP3oool00`000000oooo0?ooo`2M0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000b03oool00`000000oooo0?ooo`2M0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000aP3oool00`000000oooo0?ooo`2M0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000a03oool00`000000oooo0?ooo`2M0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
`@3oool00`000000oooo0?ooo`2M0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0<40oooo00<000000?ooo`3oool0W@3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`300?ooo`030000003oool0oooo09d0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`2M0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0W@3oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo09d0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?oo
o`2M0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`2N
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0;/0oooo00<000000?oo
o`3oool0WP3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2j0?ooo`03
0000003oool0oooo09h0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
^@3oool00`000000oooo0?ooo`2N0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0;T0oooo00<000000?ooo`3oool0WP3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`2h0?ooo`030000003oool0oooo09h0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`2N0?ooo`00503oool2000003l0
oooo0P00002h0?ooo`030000003oool0oooo09h0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00002f0?ooo`030000003oool0oooo09h0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
002d0?ooo`030000003oool0oooo09h0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0/@3oool00`000000oooo0?ooo`2N0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000/@3oool00`000000oooo0?ooo`2N0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`2N0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0WP3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o0:`0001o00<000000000O`0007l0C`0007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000[03oool00`000000oooo0?ooo`2N0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000ZP3oool00`000000
oooo0?ooo`2N0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0WP3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`2V0?ooo`030000003oool0oooo09h0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0YP3oool00`000000oooo0?ooo`2N0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0WP3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0WP3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo09h0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`2N0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000W`3oool00`000000oooo0?ooo`2N0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0WP3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo
09h0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0W03oool00`000000
oooo0?ooo`2N0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`2N0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo09/0oooo00<0
00000?ooo`3oool0WP3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo09h0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0VP3oool00`000000oooo0?ooo`2N0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool0WP3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo09h0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`2N0?ooo`00503oool2
000005h0oooo0P00002I0?ooo`030000003oool0oooo09h0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00002G0?ooo`030000003oool0oooo09h0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00002D0?ooo`030000003oool0oooo09l0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`2O0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000T@3oool00`000000oooo0?ooo`2O0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0W`3oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo09l0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo09l0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2O0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0W`3o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0
oooo09l0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`2O0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2O0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`290?ooo`030000003oool0oooo09l0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`280000O`0300000000
07l0001o0500001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo09l0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo07h0oooo00<000000?ooo`3oool0W`3o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0W`3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06X0oooo00<0
00000?ooo`3oool0W`3oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0W`3oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000K03oool00`000000oooo0?ooo`2O0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000001[0?ooo`03
0000003oool0oooo09l0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000001[0?ooo`030000003oool0oooo09l0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000001[0?ooo`030000003o
ool0oooo09l0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00001[0?ooo`030000003oool0oooo09l0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000006X0oooo00<0
00000?ooo`3oool0W`3oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000JP3oool00`000000oooo0?ooo`2O0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1X0?ooo`030000003oool0oooo09l0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0J03oool00`00
0000oooo0?ooo`2O0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo09l0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`2O0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000F`3oool00`000000oooo0?oo
o`2O0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0000005/0oooo00<00000
0?ooo`3oool0W`3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000005X0oooo00<00000
0?ooo`3oool0W`3oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo09l0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000001I0?ooo`030000003oool0oooo09l0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool0W`3oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`2O0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0:00oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0X03oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`2P0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool0X03oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0X03oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000001;0?ooo`030000003oool0oooo0:00oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
0000B`3oool00`000000oooo0?ooo`2P0?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000001;0?ooo`03
0000003oool0oooo0:00oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000001:0?ooo`030000003oool0oooo0:00
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000001:0?ooo`03
0000003oool0oooo0:00oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000001:0?ooo`030000003oool0oooo0:00oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o04L0001o00<000000000O`0007l0D@0007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo0:00oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`2P0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool0X03oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`2P0?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`2P0?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`2P0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo0:00oooo000D0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0:00
oooo000D0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0000000l0?ooo`030000003oool0oooo0:00oooo000D0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0103oool00`000000oooo0000000l0?ooo`030000003oool0oooo0:00oooo000D
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000003/0oooo00<000000?ooo`3oool0X03oool001@0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`2P0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0:00oooo000D0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo0:00oooo000D0?ooo`800000/`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2P0?ooo`00
503oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo0:00oooo000D0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000]0?ooo`030000003o
ool0oooo0:00oooo000D0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000002`0oooo00<000000?ooo`3oool0X03oool001@0oooo00<00000
0?ooo`3oool0`03oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`2P0?ooo`00503oool00`000000oooo0?ooo`300?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`2P0?ooo`00503oool0
0`000000oooo0?ooo`310?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`2P0?ooo`00503oool200000<<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0:00oooo000D0?ooo`030000003oool0oooo0<d0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2P0?ooo`00503oool00`000000oooo
0?ooo`3=0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0X03oool001@0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0:00oooo000D
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2Q
0?ooo`00503oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0X@3oool001@0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0:40oooo000D0?ooo`800000d@3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo0:40oooo000D0?ooo`030000003oool0oooo0=00oooo00@000000?ooo`3oool0oooo
2@00000H0?ooo`030000003oool0oooo0:40oooo000D0?ooo`030000003oool0oooo0=40oooo0`00
00090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0X@3oool001@0oooo00<00000
0?ooo`3oool0gP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0X@3oool001@0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`0<0?oo
o`<00000103oool00`000000oooo0?ooo`2Q0?ooo`00103oool400000080oooo0`0000070?ooo`03
0000003oool0oooo0=l0oooo00<000000?ooo`3oool02P3oool2000000<0oooo00D000000?ooo`3o
ool0oooo0000002S0?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`070?ooo`8000001@3oool01@000000
oooo0?ooo`3oool000000:<0oooo00050?ooo`030000003oool0oooo00<0oooo0P0007l00`000000
001o0000O`040000O`<00000h@0007l3000000@0001o0P0000080000O`040000000007l0001o0000
05@0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003oool0oooo
0>@0oooo1000000:0?ooo`040000003oool0oooo00000:<0oooo00070?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0000002S0?ooo`00103oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0l`3oool0
0`000000oooo0000002S0?ooo`001@3oool2000000<0oooo100000060?ooo`030000003oool0oooo
0?<0oooo00<000000?ooo`000000X`3oool001@0oooo00<000000?ooo`3oool0m03oool200000:<0
oooo000D0?ooo`030000003oool0oooo0?@0oooo0P00002S0?ooo`00503oool200000?H0oooo00<0
00000?ooo`3oool0X@3oool001@0oooo00<000000?ooo`3oool0m@3oool00`000000oooo0?ooo`2Q
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oo
oi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool2
00000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003oool0
oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo0?l0ooooVP3oool000L0oooo00@000000?ooo`3oool000000P00
07l00`000000001o0000O`040000O`<00000o`0007m;0000Odl0oooo00050?ooo`8000000`3oool0
10000000oooo0?ooo`00003o0?oooj<0oooo00070?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0o`3ooonQ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000?l0ooooX`3oool000D0oooo0P0000040?ooo`800000o`3ooonT0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00103oool200000080oooo0`0000030?ooo`D000000`3oool200000080
oooo0`0000040?ooo`<00000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`000`3oool0
10000000oooo0000000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooohX0oooo
00030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000o`3ooon=0?ooo`00
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0o`3ooon=0?ooo`00103oool200000080oooo1@000000103oool0000000000000
00050?ooo`8000000P3oool4000000@0oooo0`00003o0?oooh`0oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 0 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo0580oooo0P000000
0`3oool00000000000030?ooo`8000000`3oool400000080oooo00<000000?ooo`0000000P000002
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0103oool2
000000<0oooo100000030?ooo`8000001@3oool001@0oooo00<000000?ooo`3oool0o`3oool00`00
0000oooo0?ooo`1B0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0K
0?ooo`<000005P3oool001@0oooo00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo09L0oooo000D0?ooo`800000
0`3oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo09L0oooo000D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`2G0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0?T0oooo00<000000?ooo`3oool0U`3oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3h0?ooo`030000003oool0oooo
09L0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0n03oool00`000000
oooo0?ooo`2G0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?L0oooo
00<000000?ooo`3oool0U`3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3g0?ooo`030000003oool0oooo09L0oooo000D0?ooo`8000001`3oool00`000000oooo0?ooo`3f
0?ooo`030000003oool0oooo09L0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0mP3oool00`000000oooo0?ooo`2G0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?D0oooo00<000000?ooo`3oool0U`3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo09L0oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0m@3oool00`000000oooo0?ooo`2G0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0V03oool0
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo
09P0oooo000D0?ooo`8000002@3oool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo09P0
oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0lP3oool00`000000oooo
0?ooo`2H0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?80oooo00<0
00000?ooo`3oool0V03oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3b
0?ooo`030000003oool0oooo09P0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0l@3oool00`000000oooo0?ooo`2H0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0?40oooo00<000000?ooo`3oool0V03oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo09P0oooo000D0?ooo`800000303o
ool00`000000oooo0?ooo`3`0?ooo`030000003oool0oooo09P0oooo000D0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0l03oool00`000000oooo0?ooo`2H0?ooo`00503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0?00oooo00<000000?ooo`3oool0V03oool001@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3_0?ooo`030000003oool0oooo09P0
oooo000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0k`3oool00`000000oooo
0?ooo`2H0?ooo`002P3oool3000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`3^0?ooo`030000003oool0oooo09P0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`3]0?ooo`030000003oool0oooo09P0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`3F0000O`030000000007l0001o04T0001oC`3oool000X0oooo0`0000070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000003G0?ooo`03
0000003oool0oooo09P0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`3oool3000000d0oooo00<000000?ooo`000000e`3oool00`000000
oooo0?ooo`2H0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool000000=H0oooo00<000000?ooo`3o
ool0V03oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`2H0?ooo`00503o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo09P0oooo000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0=80oooo00<000000?ooo`3oool0V03oool001@0oooo0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0V03oool001@0
oooo00<000000?ooo`3oool07`3oool00`000000oooo000000080?ooo`030000003oool0oooo0=40
oooo00<000000?ooo`3oool0V03oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`800000d@3oool00`000000oooo0?ooo`2H0?ooo`00503oool00`000000oooo0?oo
o`0]0?ooo`800000c`3oool00`000000oooo0?ooo`2H0?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`800000c@3oool00`000000oooo0?ooo`2H0?ooo`00503oool00`000000oooo0?ooo`0a0?oo
o`800000b`3oool00`000000oooo0?ooo`2H0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`80
0000b@3oool00`000000oooo0?ooo`2H0?ooo`00503oool2000003H0oooo00<000000?ooo`3oool0
aP3oool00`000000oooo0?ooo`2H0?ooo`00503oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0<H0oooo00<000000?ooo`3oool0V03oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`350?ooo`030000003oool0oooo09P0oooo000D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`2H0?ooo`00503oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0V03oool001@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo09P0oooo
000D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?oo
o`2I0?ooo`00503oool2000003/0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`2I
0?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0<00oooo00<000000?oo
o`3oool0V@3oool001@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2o0?ooo`03
0000003oool0oooo09T0oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
_P3oool00`000000oooo0?ooo`2I0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool0V@3oool001@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo09T0oooo000D0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`2I0?ooo`00503oool2000003l0
oooo0P00002m0?ooo`030000003oool0oooo09T0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00002k0?ooo`030000003oool0oooo09T0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
002i0?ooo`030000003oool0oooo09T0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0]P3oool00`000000oooo0?ooo`2I0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000]P3oool00`000000oooo0?ooo`2I0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`2I0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0V@3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o0;40001o00<000000000O`0007l0BP0007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000/@3oool00`000000oooo0?ooo`2I0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000[`3oool00`000000
oooo0?ooo`2I0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0V@3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`2[0?ooo`030000003oool0oooo09T0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`2I0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0V@3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0V@3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo09T0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`2I0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000Y03oool00`000000oooo0?ooo`2I0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0V@3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo
09T0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0X@3oool00`000000
oooo0?ooo`2I0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0X03oool00`000000oooo
0?ooo`2I0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0:00oooo00<0
00000?ooo`3oool0V@3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`2O
0?ooo`030000003oool0oooo09T0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`2I0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo09h0oooo00<000000?ooo`3oool0V@3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo09T0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`2I0?ooo`00503oool2
000005h0oooo0P00002N0?ooo`030000003oool0oooo09T0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00002K0?ooo`030000003oool0oooo09X0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00002I0?ooo`030000003oool0oooo09X0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`2J0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000UP3oool00`000000oooo0?ooo`2J0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0VP3oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo09X0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo09X0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`2J0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0VP3o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo09X0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`2J0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`2J0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo09X0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`2=0000O`0300000000
07l0001o04/0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`230?ooo`030000003o
ool0oooo09X0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo08<0oooo00<000000?ooo`3oool0VP3o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0VP3o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06l0oooo00<0
00000?ooo`3oool0VP3oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0VP3oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000L@3oool00`000000oooo0?ooo`2J0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000001`0?ooo`03
0000003oool0oooo09X0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000001`0?ooo`030000003oool0oooo09X0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000001`0?ooo`030000003o
ool0oooo09X0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00001`0?ooo`030000003oool0oooo09X0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000006l0oooo00<0
00000?ooo`3oool0VP3oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000K`3oool00`000000oooo0?ooo`2J0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo09X0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`2J0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo09X0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0G`3oool00`000000oooo
0?ooo`2J0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000H03oool00`000000oooo0?oo
o`2J0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool000000600oooo00<00000
0?ooo`3oool0VP3oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000005l0oooo00<00000
0?ooo`3oool0VP3oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00001O0?ooo`030000003oool0oooo09X0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000001N0?ooo`030000003oool0oooo09X0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
05`0oooo00<000000?ooo`3oool0VP3oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`2K0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo09/0oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0V`3oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`2K0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0V`3oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0V`3oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000001@0?ooo`030000003oool0oooo09/0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
0000D03oool00`000000oooo0?ooo`2K0?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000001@0?ooo`03
0000003oool0oooo09/0oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000001?0?ooo`030000003oool0oooo09/0
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000001?0?ooo`03
0000003oool0oooo09/0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000001?0?ooo`030000003oool0oooo09/0oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o04`0001o00<000000000O`0007l0C00007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo09/0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`2K0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0V`3oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`2K0?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`2K0?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`2K0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo09/0oooo000D0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo09/0
oooo000D0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
000000110?ooo`030000003oool0oooo09/0oooo000D0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0103oool00`000000oooo000000110?ooo`030000003oool0oooo09/0oooo000D
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool000000400oooo00<000000?ooo`3oool0V`3oool001@0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`2K0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo09/0oooo000D0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo09/0oooo000D0?ooo`800000/`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2K0?ooo`00
503oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0000000b0?ooo`030000003oool0oooo09/0oooo000D0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000b0?ooo`030000003o
ool0oooo09/0oooo000D0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool000000340oooo00<000000?ooo`3oool0V`3oool001@0oooo00<00000
0?ooo`3oool0`03oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`2K0?ooo`00503oool00`000000oooo0?ooo`300?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2K0?ooo`00503oool0
0`000000oooo0?ooo`310?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`2K0?ooo`00503oool200000<<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo09/0oooo000D0?ooo`030000003oool0oooo0<d0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2K0?ooo`00503oool00`000000oooo
0?ooo`3=0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0W03oool001@0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo09`0oooo000D
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`2L
0?ooo`00503oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0W03oool001@0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo09`0oooo000D0?ooo`800000d@3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo09`0oooo000D0?ooo`030000003oool0oooo0=00oooo00@000000?ooo`3oool0oooo
2@00000M0?ooo`030000003oool0oooo09`0oooo000D0?ooo`030000003oool0oooo0=40oooo0`00
00090?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0W03oool001@0oooo00<00000
0?ooo`3oool0gP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0W03oool001@0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`0<0?oo
o`<000002@3oool00`000000oooo0?ooo`2L0?ooo`00103oool400000080oooo0`0000070?ooo`03
0000003oool0oooo0=l0oooo00<000000?ooo`3oool02P3oool2000000<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`2L0?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`070?ooo`800000
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo09`0oooo00050?ooo`030000003o
ool0oooo00<0oooo0P0007l00`000000001o0000O`040000O`<00000h@0007l3000000@0001o0P00
00080000O`030000000007l0001o00D0001o00<000000000O`0007l0C@0007m?0?ooo`001P3oool0
10000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0i03oool4000000X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2L0?ooo`001`3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2L0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0l`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo09`0oooo0005
0?ooo`8000000`3oool4000000H0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo09`0oooo000D0?ooo`030000003oool0oooo0?@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`2L0?ooo`00503oool00`000000oooo0?ooo`3d0?ooo`03
0000003oool0oooo0080oooo0P00002N0?ooo`00503oool200000?H0oooo00@000000?ooo`000000
0000X03oool001@0oooo00<000000?ooo`3oool0m@3oool200000:80oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`03
0000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D
0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
01@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00103o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000020000O`030000000007l0001o00@0
001o0`00003o0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003oool0oooo00000?l0
ooooX`3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oooj40
oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooonS0?oo
o`001@3oool2000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0004
0?ooo`8000000P3oool3000000<0oooo1@0000030?ooo`8000000P3oool3000000@0oooo0`00003o
0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003oool0000000000080
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo0`0000060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo00<000000?ooo`3o
ool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?ooohd0
oooo00040?ooo`8000000P3oool5000000040?ooo`0000000000000000D0oooo0P0000020?ooo`@0
0000103oool300000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 .55149 L
.79762 0 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool0C@3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`3o0?oo
o`D0oooo00<000000?ooo`3oool0C@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo0?l0oooo1@3oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3o
ool0TP3oool001@0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3oool0
TP3oool001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3n0?ooo`030000003o
ool0oooo0980oooo000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0oP3oool0
0`000000oooo0?ooo`2B0?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0?d0oooo00<000000?ooo`3oool0TP3oool001@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3m0?ooo`030000003oool0oooo0980oooo000D0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0o03oool00`000000oooo0?ooo`2B0?ooo`00503oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0?`0oooo00<000000?ooo`3oool0TP3oool001@0oooo0P000007
0?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`3oool0TP3oool001@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3k0?ooo`030000003oool0oooo0980oooo000D0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`2B0?ooo`00
503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?X0oooo00<000000?ooo`3oool0
TP3oool001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3j0?ooo`030000003o
ool0oooo0980oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0n03oool0
0`000000oooo0?ooo`2C0?ooo`00503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?P0oooo00<000000?ooo`3oool0T`3oool001@0oooo0P0000090?ooo`030000003oool0oooo0?P0
oooo00<000000?ooo`3oool0T`3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`3g0?ooo`030000003oool0oooo09<0oooo000D0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0m`3oool00`000000oooo0?ooo`2C0?ooo`00503oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0?L0oooo00<000000?ooo`3oool0T`3oool001@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo09<0oooo000D0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`2C0?ooo`00
503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?H0oooo00<000000?ooo`3oool0
T`3oool001@0oooo0P00000<0?ooo`030000003oool0oooo0?D0oooo00<000000?ooo`3oool0T`3o
ool001@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3e0?ooo`030000003oool0
oooo09<0oooo000D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0m@3oool00`00
0000oooo0?ooo`2C0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?@0
oooo00<000000?ooo`3oool0T`3oool001@0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`3d0?ooo`030000003oool0oooo09<0oooo000:0?ooo`<000001`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0T`3oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?80oooo00<00000
0?ooo`3oool0T`3oool000/0oooo0P0007l00`000000001o0000O`040000O`<000003`0007l00`00
0000001o0000O`0C0000O`030000000007l0001o0=/0001o00<000000000O`0007l0A00007m?0?oo
o`002P3oool3000000L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool000000=`0oooo00<000000?ooo`3oool0T`3oool000X0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0?ooo`<000003@3oool00`000000
oooo0000003L0?ooo`030000003oool0oooo09<0oooo000:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool04@3oool3000000<0oooo0P00000:0?ooo`050000003oool0oooo0?ooo`00
0000f`3oool00`000000oooo0?ooo`2C0?ooo`002P3oool4000000H0oooo00<000000?ooo`3oool0
6@3oool2000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3H0?ooo`030000
003oool0oooo09<0oooo000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0T`3o
ool001@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`2C0?ooo`00503oool20000
01h0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0e`3oool00`00
0000oooo0?ooo`2C0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`2C0?ooo`00503oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00P0oooo0P00003F0?ooo`030000003oool0oooo09<0oooo
000D0?ooo`030000003oool0oooo02d0oooo0P00003D0?ooo`030000003oool0oooo09<0oooo000D
0?ooo`030000003oool0oooo02l0oooo0P00003B0?ooo`030000003oool0oooo09<0oooo000D0?oo
o`030000003oool0oooo0340oooo0P00003@0?ooo`030000003oool0oooo09<0oooo000D0?ooo`03
0000003oool0oooo03<0oooo0P00003>0?ooo`030000003oool0oooo09<0oooo000D0?ooo`800000
=P3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo09<0oooo000D0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`2C0?ooo`00503oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0T`3oool0
01@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo
09<0oooo000D0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0b03oool00`000000
oooo0?ooo`2C0?ooo`00503oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0<P0oooo
00<000000?ooo`3oool0T`3oool001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo09<0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`36
0?ooo`030000003oool0oooo09<0oooo000D0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0a@3oool00`000000oooo0?ooo`2D0?ooo`00503oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo0<@0oooo00<000000?ooo`3oool0U03oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo09@0oooo000D0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`2D0?ooo`00503oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0U03oool0
01@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo
09@0oooo000D0?ooo`800000?`3oool200000<80oooo00<000000?ooo`3oool0U03oool001@0oooo
00<000000?ooo`3oool0@03oool200000<00oooo00<000000?ooo`3oool0U03oool001@0oooo00<0
00000?ooo`3oool0@P3oool200000;h0oooo00<000000?ooo`3oool0U03oool001@0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo09@0oooo000D0?oo
o`030000003oool0oooo04D0oooo0P00002k0?ooo`030000003oool0oooo09@0oooo00040?ooo`@0
00000`3oool2000000L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2h0?ooo`03
0000003oool0oooo09@0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`2D0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080001o00<000000000O`00
07l0100007l3000004T0001o00<000000000O`0007l0]P0007l00`000000001o0000O`150000Odl0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo0P00002f0?ooo`030000003oool0oooo09@0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0
oooo0P00002d0?ooo`030000003oool0oooo09@0oooo00040?ooo`<000000`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0/@3oool00`000000
oooo0?ooo`2D0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0U03oool001@0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo09@0oooo000D
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`2D
0?ooo`00503oool200000580oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`2D0?oo
o`00503oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool0U03oool001@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2]0?ooo`030000
003oool0oooo09@0oooo000D0?ooo`030000003oool0oooo05<0oooo1P00002Y0?ooo`030000003o
ool0oooo09@0oooo000D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0Y`3oool0
0`000000oooo0?ooo`2D0?ooo`00503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
0:H0oooo00<000000?ooo`3oool0U03oool001@0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`2V0?ooo`030000003oool0oooo09@0oooo000D0?ooo`800000F`3oool00`000000oooo
0?ooo`2U0?ooo`030000003oool0oooo09@0oooo000D0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0Y@3oool00`000000oooo0?ooo`2D0?ooo`00503oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0U03oool001@0oooo00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo09@0oooo000D0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`2D0?ooo`00
503oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0
U03oool001@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`2R0?ooo`030000003o
ool0oooo09@0oooo000D0?ooo`800000GP3oool200000:<0oooo00<000000?ooo`3oool0U03oool0
01@0oooo00<000000?ooo`3oool0G`3oool200000:40oooo00<000000?ooo`3oool0U03oool001@0
oooo00<000000?ooo`3oool0H@3oool2000009l0oooo00<000000?ooo`3oool0U03oool001@0oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo09@0oooo
000D0?ooo`030000003oool0oooo06@0oooo0P00002K0?ooo`030000003oool0oooo09D0oooo000D
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`2E
0?ooo`00503oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo09L0oooo00<000000?oo
o`3oool0U@3oool001@0oooo0P00001Y0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3o
ool0U@3oool001@0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo09D0oooo000D0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0U@3o
ool00`000000oooo0?ooo`2E0?ooo`00503oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo09@0oooo00<000000?ooo`3oool0U@3oool001@0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo09D0oooo00040?ooo`@000000P3oool3000000L0
oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo09D0
oooo00060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1[0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0U@3oool000H0oooo00<0
00000?ooo`3oool00P3oool20000O`030000000007l0001o00@0001o0`00001/0000O`0300000000
07l0001o0980001o00<000000000O`0007l0AP0007m?0?ooo`001P3oool010000000oooo0?ooo`3o
ool3000000L0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo08P0oooo00<000000?ooo`3oool0U@3oool000H0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo06h0oooo0P0000040?ooo`80000000<0oooo0000003oool0R03o
ool00`000000oooo0?ooo`2E0?ooo`00103oool3000000<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1`0?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool0Q`3o
ool00`000000oooo0?ooo`2E0?ooo`001P3oool010000000oooo0?ooo`3oool4000000H0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`2E0?ooo`00503oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`2E
0?ooo`00503oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00d0oooo0P00001f0?oo
o`030000003oool0oooo09D0oooo000D0?ooo`800000NP3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0000007D0oooo00<000000?ooo`3oool0U@3oool001@0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000007D0oooo00<000000?ooo`3oool0
U@3oool001@0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000007D0oooo00<000000?ooo`3oool0U@3oool001@0oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000007D0oooo00<000000?ooo`3oool0U@3o
ool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`090?ooo`050000003oool0
oooo0?ooo`000000M03oool00`000000oooo0?ooo`2E0?ooo`00503oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000001d0?ooo`030000003o
ool0oooo09D0oooo000D0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0U@3oool0
01@0oooo0P00001o0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1b0?ooo`030000003oool0oooo09D0oooo000D0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0740
oooo00<000000?ooo`3oool0U@3oool001@0oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo09D0oooo000D0?ooo`030000003oool0oooo07l0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P00
001U0?ooo`030000003oool0oooo09D0oooo000D0?ooo`030000003oool0oooo0800oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`000000I@3oool00`000000oooo0?ooo`2E0?ooo`00503oool00`000000oooo0?ooo`210?oo
o`8000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00@000000?oo
o`3oool00000I03oool00`000000oooo0?ooo`2E0?ooo`00503oool00`000000oooo0?ooo`230?oo
o`<00000203oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000006@0oooo00<00000
0?ooo`3oool0U@3oool001@0oooo0P0000260?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0203oool01@000000oooo0?ooo`3oool0000006<0oooo00<000000?ooo`3oool0U@3oool0
01@0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`2E0?ooo`00503oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo09D0oooo000D0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool0U@3oool001@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?oo
o`2E0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo09D0oooo000D0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2F0?oo
o`00503oool200000980oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2F0?ooo`00
503oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0000005D0oooo00<000000?ooo`3oool0UP3oool001@0oooo
00<000000?ooo`3oool0TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0000001E0?ooo`030000003oool0oooo09H0oooo000D0?ooo`030000
003oool0oooo09<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0000005D0oooo00<000000?ooo`3oool0UP3oool001@0oooo00<000000?ooo`3oool0
U03oool2000000/0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000005@0
oooo00<000000?ooo`3oool0UP3oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo
0?ooo`2E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000005@0oooo00<000000?ooo`3oool0UP3oool000@0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000005@0oooo00<000000?ooo`3oool0UP3oool000D0
oooo00<000000?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000XP0007l01@00
0000001o0000O`0007l0000000D0001o00<000000000O`0007l0D@0007l00`000000001o0000O`17
0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0:80oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool0UP3oool000L0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:<0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo09H0oooo00040?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2S0?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`2F0?ooo`00
1@3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`000000
1`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo09H0oooo000D0?ooo`030000003o
ool0oooo0:<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo09H0oooo000D0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo09H0oooo000D0?ooo`800000Y@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0UP3oool001@0
oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0UP3oool001@0oooo00<000000?ooo`3oool0[`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0000004H0oooo00<000000?ooo`3oool0UP3oool001@0oooo00<0
00000?ooo`3oool0/03oool00`000000oooo0?ooo`040?ooo`030000003oool0000004H0oooo00<0
00000?ooo`3oool0UP3oool001@0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`000000A@3oool00`000000oooo0?ooo`2F0?ooo`00503oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo09H0oooo000D0?ooo`030000003oool0oooo
0;40oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0UP3oool001@0oooo00<000000?ooo`3oool0/P3oool00`000000oooo000000070?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0UP3oool001@0oooo0P00002c0?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo09H0oooo000D0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000003L0oooo00<000000?ooo`3oool0
UP3oool001@0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0000003L0oooo00<000000?ooo`3oool0UP3oool001@0oooo00<000000?ooo`3oool0_`3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000=P3oool00`000000oooo0?oo
o`2F0?ooo`00503oool00`000000oooo0?ooo`300?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo09H0oooo000D0?ooo`030000003oool0
oooo0<00oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo09H0oooo000D0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`0000001`3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo09H0oooo000D0?ooo`800000``3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0UP3oool001@0
oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo09H0
oooo000D0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`2F0?ooo`00503oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0UP3oool001@0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo09H0oooo000D0?ooo`030000003oool0oooo0<l0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`2F0?ooo`00503oool00`000000oooo0?ooo`3?0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0UP3oool001@0oooo0P00003A0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0UP3oool001@0oooo00<000000?ooo`3oool0d03o
ool010000000oooo0?ooo`3oool900000280oooo00<000000?ooo`3oool0U`3oool001@0oooo00<0
00000?ooo`3oool0d@3oool3000000T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`2G0?ooo`00503oool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`2G0?ooo`00503oool00`000000oooo0?ooo`3O0?oo
o`030000003oool0oooo00`0oooo0`00000>0?ooo`030000003oool0oooo09L0oooo00040?ooo`@0
00000P3oool3000000L0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`0:0?ooo`80
00000`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo09L0oooo00040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3P0?ooo`030000
003oool0oooo00L0oooo0P0000050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
U`3oool000D0oooo00<000000?ooo`3oool00`3oool20000O`030000000007l0001o00@0001o0`00
003Q0000O`<00000100007l2000000P0001o00<000000000O`0007l02P0007l00`000000001o0000
O`180000Odl0oooo00060?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?oo
o`3T0?ooo`@000002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo09L0oooo0007
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo09L0oooo00040?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0U`3oool000D0oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3c
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0U`3oool001@0oooo00<000000?oo
o`3oool0m03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09L0oooo000D0?ooo`03
0000003oool0oooo0?@0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3o
ool0U`3oool001@0oooo0P00003f0?ooo`040000003oool0000000000080oooo00D000000?ooo`3o
ool0oooo0000002I0?ooo`00503oool00`000000oooo0?ooo`3e0?ooo`8000001@3oool010000000
oooo0?ooo`00002I0?ooo`00503oool00`000000oooo0?ooo`3m0?ooo`030000003oool0000009T0
oooo000D0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`000000V@3oool001@0oooo00<0
00000?ooo`3oool0oP3oool2000009T0oooo000D0?ooo`030000003oool0oooo0?l0oooo00<00000
0?ooo`3oool0U`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool200000?l0
ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?ooo`030000003oool0
oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000
oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?oo
o`800000o`3ooonK0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000
003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00050?ooo`800000103oool2000000L0oooo00<000000?oo
o`3oool0o`3ooonJ0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000H0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`000002
0000O`030000000007l0001o00@0001o0`00003o0000Od/0001oC`3oool000D0oooo0P0000030?oo
o`040000003oool0oooo00000?l0ooooX`3oool000L0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`3o0?oooj40oooo00040?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000o`3ooonS0?ooo`001@3oool2000000@0oooo0P00003o0?oooj@0oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo00040?ooo`8000000P3oool3000000<0oooo1@0000030?ooo`800000
0P3oool3000000@0oooo0`00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00003o0?oooh`0oooo00030?oo
o`040000003oool0000000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo00000080oooo0`0000060?ooo`030000003oool0oooo0?l0ooooRP3o
ool000<0oooo00<000000?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P00003o0?ooohd0oooo
00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`3o0?ooohd0oooo00040?ooo`8000000P3oool5000000040?ooo`0000000000
000000D0oooo0P0000020?ooo`@00000103oool300000?l0ooooS03oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 .55149 L
.79762 .55947 L
.8125 0 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0B03oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`3o0?oo
o`X0oooo00<000000?ooo`3oool0B03oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo0?l0oooo2P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3o
ool0S@3oool001@0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo1@3oool00`000000oooo
0?ooo`2=0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo103o
ool00`000000oooo0?ooo`2=0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo103oool00`000000oooo0?ooo`2=0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo0`3oool00`000000oooo0?ooo`2=0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo0`3oool00`000000oooo0?ooo`2=0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000oooo
0?ooo`2=0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo0P3o
ool00`000000oooo0?ooo`2=0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0o`3oool1
0?ooo`030000003oool0oooo08d0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3oool10?ooo`030000003oool0oooo08d0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`2=0?ooo`00503oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3oool0S@3oool001@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo08d0oooo000D
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?ooo`2=
0?ooo`00503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?d0oooo00<000000?oo
o`3oool0SP3oool001@0oooo0P0000090?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3o
ool0SP3oool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3l0?ooo`030000
003oool0oooo08h0oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o03o
ool00`000000oooo0?ooo`2>0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0?`0oooo00<000000?ooo`3oool0SP3oool001@0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`3k0?ooo`030000003oool0oooo08h0oooo000D0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0n`3oool00`000000oooo0?ooo`2>0?ooo`00503oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`3oool0SP3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo0?X0oooo00<000000?ooo`3oool0SP3oool001@0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo08h0oooo000D0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`2>0?oo
o`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?T0oooo00<000000?ooo`3o
ool0SP3oool001@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3i0?ooo`030000
003oool0oooo08h0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0?P0oooo00<000000?ooo`3oool0SP3oool000d0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?L0oooo00<000000?ooo`3oool0SP3oool0
00/0oooo0P0007l00`000000001o0000O`040000O`<000003`0007l00`000000001o0000O`0C0000
O`030000000007l0001o0>00001o00<000000000O`0007l0?`0007m?0?ooo`002P3oool3000000L0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool000000>40
oooo00<000000?ooo`3oool0SP3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0@0?ooo`040000003oool0oooo0?ooo`<000003@3oool00`000000oooo0000003Q0?ooo`03
0000003oool0oooo08h0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
4@3oool3000000<0oooo0P00000:0?ooo`050000003oool0oooo0?ooo`000000h03oool00`000000
oooo0?ooo`2>0?ooo`002P3oool4000000H0oooo00<000000?ooo`3oool06@3oool2000000P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo08h0oooo
000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool0SP3oool001@0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0g03oool00`000000oooo0?ooo`2>0?ooo`00503oool2000001h0oooo0P0000020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`2>0?oo
o`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0oooo00<000000?ooo`3o
ool0f`3oool00`000000oooo0?ooo`2>0?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00P0oooo0P00003K0?ooo`030000003oool0oooo08h0oooo000D0?ooo`030000003o
ool0oooo02d0oooo0P00003I0?ooo`030000003oool0oooo08h0oooo000D0?ooo`030000003oool0
oooo02l0oooo0P00003G0?ooo`030000003oool0oooo08h0oooo000D0?ooo`030000003oool0oooo
0340oooo0P00003E0?ooo`030000003oool0oooo08h0oooo000D0?ooo`030000003oool0oooo03<0
oooo0P00003C0?ooo`030000003oool0oooo08h0oooo000D0?ooo`800000=P3oool00`000000oooo
0?ooo`3@0?ooo`030000003oool0oooo08h0oooo000D0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0d03oool00`000000oooo0?ooo`2>0?ooo`00503oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0SP3oool001@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo08h0oooo000D0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`2>0?ooo`00
503oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0
SP3oool001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo08h0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0
oooo08h0oooo000D0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0b`3oool00`00
0000oooo0?ooo`2>0?ooo`00503oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0<T0
oooo00<000000?ooo`3oool0S`3oool001@0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`380?ooo`030000003oool0oooo08l0oooo000D0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0b03oool00`000000oooo0?ooo`2?0?ooo`00503oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0S`3oool001@0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo08l0oooo000D0?ooo`80
0000?`3oool200000<L0oooo00<000000?ooo`3oool0S`3oool001@0oooo00<000000?ooo`3oool0
@03oool200000<D0oooo00<000000?ooo`3oool0S`3oool001@0oooo00<000000?ooo`3oool0@P3o
ool200000<<0oooo00<000000?ooo`3oool0S`3oool001@0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`300?ooo`030000003oool0oooo08l0oooo000D0?ooo`030000003oool0oooo
04D0oooo0P0000300?ooo`030000003oool0oooo08l0oooo00040?ooo`@000000`3oool2000000L0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo08l0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`2?0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080001o00<000000000O`0007l0100007l3000004T0
001o00<000000000O`0007l0^`0007l00`000000001o0000O`100000Odl0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04X0
oooo0P00002k0?ooo`030000003oool0oooo08l0oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0oooo0P00002i0?ooo`03
0000003oool0oooo08l0oooo00040?ooo`<000000`3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`2?0?ooo`00
1P3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0;D0oooo00<000000?ooo`3oool0S`3oool001@0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo08l0oooo000D0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`2?0?ooo`00503oool20000
0580oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`2?0?ooo`00503oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0S`3oool001@0oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo08l0oooo
000D0?ooo`030000003oool0oooo05<0oooo1P00002^0?ooo`030000003oool0oooo08l0oooo000D
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`2?
0?ooo`00503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0:/0oooo00<000000?oo
o`3oool0S`3oool001@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`2[0?ooo`03
0000003oool0oooo08l0oooo000D0?ooo`800000F`3oool00`000000oooo0?ooo`2Z0?ooo`030000
003oool0oooo08l0oooo000D0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0ZP3o
ool00`000000oooo0?ooo`2?0?ooo`00503oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`3oool0S`3oool001@0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`2Y0?ooo`030000003oool0oooo08l0oooo000D0?ooo`030000003oool0oooo05`0
oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`2?0?ooo`00503oool00`000000oooo
0?ooo`1L0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0S`3oool001@0oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo08l0oooo000D
0?ooo`800000GP3oool200000:P0oooo00<000000?ooo`3oool0S`3oool001@0oooo00<000000?oo
o`3oool0G`3oool200000:H0oooo00<000000?ooo`3oool0S`3oool001@0oooo00<000000?ooo`3o
ool0H@3oool200000:@0oooo00<000000?ooo`3oool0S`3oool001@0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo08l0oooo000D0?ooo`030000003o
ool0oooo06@0oooo0P00002Q0?ooo`030000003oool0oooo08l0oooo000D0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`2@0?ooo`00503oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0T03oool001@0
oooo0P00001Y0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0T03oool001@0oooo
00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0900oooo
000D0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?oo
o`2@0?ooo`00503oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo09T0oooo00<00000
0?ooo`3oool0T03oool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`2I0?oo
o`030000003oool0oooo0900oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0900oooo00060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1[0?ooo`030000
003oool0oooo09P0oooo00<000000?ooo`3oool0T03oool000H0oooo00<000000?ooo`3oool00P3o
ool20000O`030000000007l0001o00@0001o0`00001/0000O`030000000007l0001o09L0001o00<0
00000000O`0007l0@@0007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0T03oool000H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003o
ool0oooo06h0oooo0P0000040?ooo`80000000<0oooo0000003oool0S@3oool00`000000oooo0?oo
o`2@0?ooo`00103oool3000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1`
0?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`2@0?ooo`001P3oool010000000oooo0?ooo`3oool4000000H0oooo00<000000?ooo`3oool0L@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`2@0?ooo`00503oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`2@0?ooo`00503oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo00d0oooo0P00001k0?ooo`030000003oool0oooo
0900oooo000D0?ooo`800000NP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000007X0
oooo00<000000?ooo`3oool0T03oool001@0oooo00<000000?ooo`3oool0NP3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000007X0oooo00<000000?ooo`3oool0T03oool001@0oooo00<0
00000?ooo`3oool0NP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000007X0oooo00<0
00000?ooo`3oool0T03oool001@0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0:
0?ooo`040000003oool0oooo000007X0oooo00<000000?ooo`3oool0T03oool001@0oooo00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000N@3o
ool00`000000oooo0?ooo`2@0?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo00T0oooo00D000000?ooo`3oool0oooo0000001i0?ooo`030000003oool0oooo0900oooo000D
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0T03oool001@0oooo0P00001o0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo0900oooo000D0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool0T03oool001@0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1Y0?ooo`030000
003oool0oooo0900oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P00001Z0?ooo`030000003o
ool0oooo0900oooo000D0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000JP3oool0
0`000000oooo0?ooo`2@0?ooo`00503oool00`000000oooo0?ooo`210?ooo`8000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000J@3oool0
0`000000oooo0?ooo`2@0?ooo`00503oool00`000000oooo0?ooo`230?ooo`<00000203oool00`00
0000oooo0?ooo`080?ooo`040000003oool0oooo000006T0oooo00<000000?ooo`3oool0T03oool0
01@0oooo0P0000260?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool01@00
0000oooo0?ooo`3oool0000006P0oooo00<000000?ooo`3oool0T03oool001@0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0IP3oool00`000000oooo0?ooo`2@0?ooo`00503oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo0900oooo000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0
T03oool001@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`2@0?ooo`00503oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0900oooo000D0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`2@0?ooo`00503oool200000980
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`2@0?ooo`00503oool00`000000oooo
0?ooo`2B0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0000005X0oooo00<000000?ooo`3oool0T@3oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000001J0?ooo`030000003oool0oooo0940oooo000D0?ooo`030000003oool0oooo09<0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000005X0
oooo00<000000?ooo`3oool0T@3oool001@0oooo00<000000?ooo`3oool0U03oool2000000/0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000005T0oooo00<000000?ooo`3o
ool0T@3oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`2E0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000005T0
oooo00<000000?ooo`3oool0T@3oool000@0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000005T0oooo00<000000?ooo`3oool0T@3oool000D0oooo00<000000?ooo`3o
ool00P3oool010000000001o0000O`0000060000O`<00000XP0007l01@000000001o0000O`0007l0
000000D0001o00<000000000O`0007l0EP0007l00`000000001o0000O`120000Odl0oooo00060?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0:80oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool0T@3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0:<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0940oooo00040?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`2A0?ooo`001@3oool2000000@0oooo
0P0000070?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`0000001`3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0940oooo000D0?ooo`030000003oool0oooo0:<0oooo00<0
00000?ooo`0000001`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0940oooo000D
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0940oooo000D0?ooo`800000Y@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool0T@3oool001@0oooo00<000000?ooo`3o
ool0[`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool0T@3oool001@0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0000004/0oooo00<000000?ooo`3oool0T@3oool001@0oooo00<000000?ooo`3oool0/03o
ool00`000000oooo0?ooo`040?ooo`030000003oool0000004/0oooo00<000000?ooo`3oool0T@3o
ool001@0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`000000BP3oool00`000000oooo0?ooo`2A0?ooo`00503oool00`000000oooo0?ooo`2a
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo0940oooo000D0?ooo`030000003oool0oooo0;40oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0T@3oool0
01@0oooo00<000000?ooo`3oool0/P3oool00`000000oooo000000070?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0T@3oool001@0oooo0P00002c0?ooo`030000003oool0000000L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0940
oooo000D0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0T@3oool001@0oooo00<0
00000?ooo`3oool0_P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000003`0oooo00<0
00000?ooo`3oool0T@3oool001@0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`000000>`3oool00`000000oooo0?ooo`2A0?ooo`00503oool0
0`000000oooo0?ooo`300?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo0940oooo000D0?ooo`030000003oool0oooo0<00oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0940oooo000D
0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0940oooo000D0?ooo`800000``3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0T@3oool001@0oooo00<000000?ooo`3o
ool0c@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0940oooo000D0?ooo`030000
003oool0oooo0<d0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2A0?ooo`00503o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0T@3o
ool001@0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0940oooo000D0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`2A0?ooo`00503oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0T@3oool001@0oooo0P00003A0?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool0T@3oool001@0oooo00<000000?ooo`3oool0d03oool010000000oooo0?oo
o`3oool9000002P0oooo00<000000?ooo`3oool0T@3oool001@0oooo00<000000?ooo`3oool0d@3o
ool3000000T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`2A0?ooo`00503oool0
0`000000oooo0?ooo`3N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`2B0?ooo`00503oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo
00`0oooo0`00000C0?ooo`030000003oool0oooo0980oooo00040?ooo`@000000P3oool3000000L0
oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`0:0?ooo`8000000`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0980oooo00040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo00L0oooo
0P0000050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0TP3oool000D0oooo00<0
00000?ooo`3oool00`3oool20000O`030000000007l0001o00@0001o0`00003Q0000O`<000001000
07l2000000P0001o00<000000000O`0007l03`0007l00`000000001o0000O`130000Odl0oooo0006
0?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`3T0?ooo`@000002P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0980oooo00070?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0980oooo00040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0TP3o
ool000D0oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3c0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0TP3oool001@0oooo00<000000?ooo`3oool0m03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0980oooo000D0?ooo`030000003oool0oooo0?@0
oooo00<000000?ooo`3oool00P3oool2000000T0oooo00<000000?ooo`3oool0TP3oool001@0oooo
0P00003f0?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`2B0?ooo`00503oool00`000000oooo0?ooo`3e0?ooo`8000001@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0980oooo000D0?ooo`030000003oool0oooo0?d0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2B0?ooo`00503oool00`000000oooo0?ooo`3m
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0TP3oool001@0oooo00<000000?oo
o`3oool0oP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0980oooo000D0?ooo`03
0000003oool0oooo0?l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2B0?ooo`00
503oool00`000000oooo0?ooo`3o0?ooo`40oooo0P0000020?ooo`030000003oool0oooo0980oooo
000D0?ooo`800000o`3oool40?ooo`<00000U03oool001@0oooo00<000000?ooo`3oool0o`3oool5
0?ooo`030000003oool0oooo0980oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo00000080001o00<000000000O`00
07l0100007l300000?l0001oB`0007m?0?ooo`001@3oool2000000<0oooo00@000000?ooo`3oool0
0000o`3ooonS0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0
ooooX@3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00003o0?oo
oj<0oooo00050?ooo`800000103oool200000?l0ooooY03oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool000@0oooo0P0000020?ooo`<000000`3oool5000000<0oooo0P0000020?ooo`<00000103oool3
00000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo00000?l0ooooS03oool000<0oooo00@000000?ooo`000000
00000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool3000000H0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`000`3oool00`000000
oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool200000?l0ooooS@3oool000<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0
ooooS@3oool000@0oooo0P0000020?ooo`D0000000@0oooo00000000000000001@3oool200000080
oooo100000040?ooo`<00000o`3ooon<0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 .55149 L
.79762 .55947 L
.8125 .57258 L
.82738 0 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool0@`3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`3o0?oo
o`l0oooo00<000000?ooo`3oool0@`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo0?l0oooo3`3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3o
ool0R03oool001@0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo
0?ooo`280?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo2@3o
ool00`000000oooo0?ooo`280?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo2@3oool00`000000oooo0?ooo`280?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`280?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`280?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo1`3oool00`000000oooo
0?ooo`280?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo1`3o
ool00`000000oooo0?ooo`280?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0o`3oool6
0?ooo`030000003oool0oooo08P0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3oool60?ooo`030000003oool0oooo08P0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo08P0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo08P0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3oool50?ooo`030000003o
ool0oooo08P0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3oool4
0?ooo`030000003oool0oooo08P0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0o`3oool30?ooo`030000003oool0oooo08T0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool0R@3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool0R@3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool0R@3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<00000
0?ooo`3oool0R@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
o`40oooo00<000000?ooo`3oool0R@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3oool0R@3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3oool0R@3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3oool0R@3oool001@0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo08T0oooo000D0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`290?oo
o`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3o
ool0R@3oool001@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3n0?ooo`030000
003oool0oooo08T0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0?d0oooo00<000000?ooo`3oool0R@3oool000d0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?`0oooo00<000000?ooo`3oool0R@3oool0
00/0oooo0P0007l00`000000001o0000O`040000O`<000003`0007l00`000000001o0000O`0C0000
O`030000000007l0001o0>D0001o00<000000000O`0007l0>P0007m?0?ooo`002P3oool3000000L0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool000000>H0
oooo00<000000?ooo`3oool0R@3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0@0?ooo`040000003oool0oooo0?ooo`<000003@3oool00`000000oooo0000003V0?ooo`03
0000003oool0oooo08T0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
4@3oool3000000<0oooo0P00000:0?ooo`050000003oool0oooo0?ooo`000000i@3oool00`000000
oooo0?ooo`290?ooo`002P3oool4000000H0oooo00<000000?ooo`3oool06@3oool2000000P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo08T0oooo
000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool0R@3oool001@0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0h@3oool00`000000oooo0?ooo`290?ooo`00503oool2000001h0oooo0P0000020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`290?oo
o`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0oooo00<000000?ooo`3o
ool0h03oool00`000000oooo0?ooo`290?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00P0oooo0P00003P0?ooo`030000003oool0oooo08T0oooo000D0?ooo`030000003o
ool0oooo02d0oooo0P00003N0?ooo`030000003oool0oooo08T0oooo000D0?ooo`030000003oool0
oooo02l0oooo0P00003L0?ooo`030000003oool0oooo08T0oooo000D0?ooo`030000003oool0oooo
0340oooo0P00003J0?ooo`030000003oool0oooo08T0oooo000D0?ooo`030000003oool0oooo03<0
oooo0P00003H0?ooo`030000003oool0oooo08T0oooo000D0?ooo`800000=P3oool00`000000oooo
0?ooo`3E0?ooo`030000003oool0oooo08T0oooo000D0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0e@3oool00`000000oooo0?ooo`290?ooo`00503oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool0R@3oool001@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo08T0oooo000D0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`290?ooo`00
503oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0
R@3oool001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3A0?ooo`030000003o
ool0oooo08T0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo08T0oooo000D0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0d03oool00`00
0000oooo0?ooo`290?ooo`00503oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0<l0
oooo00<000000?ooo`3oool0R@3oool001@0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`3=0?ooo`030000003oool0oooo08X0oooo000D0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0c@3oool00`000000oooo0?ooo`2:0?ooo`00503oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0RP3oool001@0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo08X0oooo000D0?ooo`80
0000?`3oool200000<`0oooo00<000000?ooo`3oool0RP3oool001@0oooo00<000000?ooo`3oool0
@03oool200000<X0oooo00<000000?ooo`3oool0RP3oool001@0oooo00<000000?ooo`3oool0@P3o
ool200000<P0oooo00<000000?ooo`3oool0RP3oool001@0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`350?ooo`030000003oool0oooo08X0oooo000D0?ooo`030000003oool0oooo
04D0oooo0P0000350?ooo`030000003oool0oooo08X0oooo00040?ooo`@000000`3oool2000000L0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo08X0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`2:0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080001o00<000000000O`0007l0100007l3000004T0
001o00<000000000O`0007l0`00007l00`000000001o0000O`0k0000Odl0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04X0
oooo0P0000300?ooo`030000003oool0oooo08X0oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0oooo0P00002n0?ooo`03
0000003oool0oooo08X0oooo00040?ooo`<000000`3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`2:0?ooo`00
1P3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0RP3oool001@0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo08X0oooo000D0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`2:0?ooo`00503oool20000
0580oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`2:0?ooo`00503oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0RP3oool001@0oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo08X0oooo
000D0?ooo`030000003oool0oooo05<0oooo1P00002c0?ooo`030000003oool0oooo08X0oooo000D
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`2:
0?ooo`00503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0;00oooo00<000000?oo
o`3oool0RP3oool001@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`2`0?ooo`03
0000003oool0oooo08X0oooo000D0?ooo`800000F`3oool00`000000oooo0?ooo`2_0?ooo`030000
003oool0oooo08X0oooo000D0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0[`3o
ool00`000000oooo0?ooo`2:0?ooo`00503oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo0:h0oooo00<000000?ooo`3oool0RP3oool001@0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo08X0oooo000D0?ooo`030000003oool0oooo05`0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`2:0?ooo`00503oool00`000000oooo
0?ooo`1L0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0RP3oool001@0oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo08X0oooo000D
0?ooo`800000GP3oool200000:d0oooo00<000000?ooo`3oool0RP3oool001@0oooo00<000000?oo
o`3oool0G`3oool200000:/0oooo00<000000?ooo`3oool0RP3oool001@0oooo00<000000?ooo`3o
ool0H@3oool200000:T0oooo00<000000?ooo`3oool0RP3oool001@0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo08X0oooo000D0?ooo`030000003o
ool0oooo06@0oooo0P00002V0?ooo`030000003oool0oooo08X0oooo000D0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`2:0?ooo`00503oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0RP3oool001@0
oooo0P00001Y0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0R`3oool001@0oooo
00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo08/0oooo
000D0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?oo
o`2;0?ooo`00503oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo09h0oooo00<00000
0?ooo`3oool0R`3oool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`2N0?oo
o`030000003oool0oooo08/0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo08/0oooo00060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1[0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool0R`3oool000H0oooo00<000000?ooo`3oool00P3o
ool20000O`030000000007l0001o00@0001o0`00001/0000O`030000000007l0001o09`0001o00<0
00000000O`0007l0?00007m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0R`3oool000H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003o
ool0oooo06h0oooo0P0000040?ooo`80000000<0oooo0000003oool0TP3oool00`000000oooo0?oo
o`2;0?ooo`00103oool3000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1`
0?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`2;0?ooo`001P3oool010000000oooo0?ooo`3oool4000000H0oooo00<000000?ooo`3oool0L@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`2;0?ooo`00503oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`2;0?ooo`00503oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo00d0oooo0P0000200?ooo`030000003oool0oooo
08/0oooo000D0?ooo`800000NP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000007l0
oooo00<000000?ooo`3oool0R`3oool001@0oooo00<000000?ooo`3oool0NP3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000007l0oooo00<000000?ooo`3oool0R`3oool001@0oooo00<0
00000?ooo`3oool0NP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000007l0oooo00<0
00000?ooo`3oool0R`3oool001@0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0:
0?ooo`040000003oool0oooo000007l0oooo00<000000?ooo`3oool0R`3oool001@0oooo00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000OP3o
ool00`000000oooo0?ooo`2;0?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo00T0oooo00D000000?ooo`3oool0oooo0000001n0?ooo`030000003oool0oooo08/0oooo000D
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0R`3oool001@0oooo0P00001o0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo08/0oooo000D0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3o
ool0R`3oool001@0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo08/0oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P00001_0?ooo`030000003o
ool0oooo08/0oooo000D0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000K`3oool0
0`000000oooo0?ooo`2;0?ooo`00503oool00`000000oooo0?ooo`210?ooo`8000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000KP3oool0
0`000000oooo0?ooo`2;0?ooo`00503oool00`000000oooo0?ooo`230?ooo`<00000203oool00`00
0000oooo0?ooo`080?ooo`040000003oool0oooo000006h0oooo00<000000?ooo`3oool0R`3oool0
01@0oooo0P0000260?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool01@00
0000oooo0?ooo`3oool0000006d0oooo00<000000?ooo`3oool0R`3oool001@0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`2;0?ooo`00503oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo08/0oooo000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0
R`3oool001@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`2;0?ooo`00503oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo08/0oooo000D0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`2;0?ooo`00503oool200000980
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`2;0?ooo`00503oool00`000000oooo
0?ooo`2B0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool000000600oooo00<000000?ooo`3oool0R`3oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000001P0?ooo`030000003oool0oooo08/0oooo000D0?ooo`030000003oool0oooo09<0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool000000600
oooo00<000000?ooo`3oool0R`3oool001@0oooo00<000000?ooo`3oool0U03oool2000000/0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000005h0oooo00<000000?ooo`3o
ool0S03oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`2E0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000005h0
oooo00<000000?ooo`3oool0S03oool000@0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000005h0oooo00<000000?ooo`3oool0S03oool000D0oooo00<000000?ooo`3o
ool00P3oool010000000001o0000O`0000060000O`<00000XP0007l01@000000001o0000O`0007l0
000000D0001o00<000000000O`0007l0F`0007l00`000000001o0000O`0m0000Odl0oooo00060?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0:80oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool0S03oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0:<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo08`0oooo00040?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`2<0?ooo`001@3oool2000000@0oooo
0P0000070?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`0000001`3oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo08`0oooo000D0?ooo`030000003oool0oooo0:<0oooo00<0
00000?ooo`0000001`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo08`0oooo000D
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo08`0oooo000D0?ooo`800000Y@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0S03oool001@0oooo00<000000?ooo`3o
ool0[`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0S03oool001@0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`050?ooo`030000
003oool000000500oooo00<000000?ooo`3oool0S03oool001@0oooo00<000000?ooo`3oool0/03o
ool00`000000oooo0?ooo`040?ooo`030000003oool000000500oooo00<000000?ooo`3oool0S03o
ool001@0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`000000C`3oool00`000000oooo0?ooo`2<0?ooo`00503oool00`000000oooo0?ooo`2a
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo08`0oooo000D0?ooo`030000003oool0oooo0;40oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0S03oool0
01@0oooo00<000000?ooo`3oool0/P3oool00`000000oooo000000070?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0S03oool001@0oooo0P00002c0?ooo`030000003oool0000000L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo08`0
oooo000D0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool000000440oooo00<000000?ooo`3oool0S03oool001@0oooo00<0
00000?ooo`3oool0_P3oool00`000000oooo0?ooo`050?ooo`030000003oool000000440oooo00<0
00000?ooo`3oool0S03oool001@0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`000000@03oool00`000000oooo0?ooo`2<0?ooo`00503oool0
0`000000oooo0?ooo`300?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo08`0oooo000D0?ooo`030000003oool0oooo0<00oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo08`0oooo000D
0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo08`0oooo000D0?ooo`800000``3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0S03oool001@0oooo00<000000?ooo`3o
ool0c@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo08`0oooo000D0?ooo`030000
003oool0oooo0<d0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`2<0?ooo`00503o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0S03o
ool001@0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo08`0oooo000D0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`2<0?ooo`00503oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0S03oool001@0oooo0P00003A0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0S03oool001@0oooo00<000000?ooo`3oool0d03oool010000000oooo0?oo
o`3oool9000002d0oooo00<000000?ooo`3oool0S03oool001@0oooo00<000000?ooo`3oool0d@3o
ool3000000T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2<0?ooo`00503oool0
0`000000oooo0?ooo`3N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`2<0?ooo`00503oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo
00`0oooo0`00000I0?ooo`030000003oool0oooo08`0oooo00040?ooo`@000000P3oool3000000L0
oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`0:0?ooo`8000000`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo08`0oooo00040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo00L0oooo
0P0000050?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0S03oool000D0oooo00<0
00000?ooo`3oool00`3oool20000O`030000000007l0001o00@0001o0`00003Q0000O`<000001000
07l2000000P0001o00<000000000O`0007l0500007l00`000000001o0000O`0n0000Odl0oooo0006
0?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`3T0?ooo`@000002P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo08d0oooo00070?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo08d0oooo00040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0S@3o
ool000D0oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3c0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0S@3oool001@0oooo00<000000?ooo`3oool0m03oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo08d0oooo000D0?ooo`030000003oool0oooo0?@0
oooo00<000000?ooo`3oool00P3oool2000000h0oooo00<000000?ooo`3oool0S@3oool001@0oooo
0P00003f0?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`2=0?ooo`00503oool00`000000oooo0?ooo`3e0?ooo`8000001@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo08d0oooo000D0?ooo`030000003oool0oooo0?d0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`2=0?ooo`00503oool00`000000oooo0?ooo`3m
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0S@3oool001@0oooo00<000000?oo
o`3oool0oP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08d0oooo000D0?ooo`03
0000003oool0oooo0?l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2=0?ooo`00
503oool00`000000oooo0?ooo`3o0?ooo`40oooo0P0000070?ooo`030000003oool0oooo08d0oooo
000D0?ooo`800000o`3oool40?ooo`8000001@3oool00`000000oooo0?ooo`2=0?ooo`00503oool0
0`000000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2=
0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`H0oooo00D000000?ooo`3oool0oooo0000002?
0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`L0oooo0P0000000`3oool000000?ooo`2>0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooo`T0oooo0P00002?0?ooo`00503oool00`000000oooo
0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0S@3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0
oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo00000080001o00<000000000
O`0007l0100007l300000?l0001oB`0007m?0?ooo`001@3oool2000000<0oooo00@000000?ooo`3o
ool00000o`3ooonS0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0?l0ooooX@3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00003o
0?oooj<0oooo00050?ooo`800000103oool200000?l0ooooY03oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool000@0oooo0P0000020?ooo`<000000`3oool5000000<0oooo0P0000020?ooo`<00000103o
ool300000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000?l0ooooS03oool000<0oooo00@000000?ooo`00
000000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool3000000H0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`000`3oool00`00
0000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000`3oool200000?l0ooooS@3oool000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0?l0ooooS@3oool000@0oooo0P0000020?ooo`D0000000@0oooo00000000000000001@3oool20000
0080oooo100000040?ooo`<00000o`3ooon<0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 .55149 L
.79762 .55947 L
.8125 .57258 L
.82738 .57002 L
.84226 0 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3o0?oooa@0oooo00<000000?ooo`3oool0?P3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oa@0oooo00<000000?ooo`3oool0?P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo0?l0oooo503oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`3o0?oooa@0oooo00<000000?ooo`3o
ool0P`3oool001@0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000oooo
0?ooo`230?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo3P3o
ool00`000000oooo0?ooo`230?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo3P3oool00`000000oooo0?ooo`230?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo3@3oool00`000000oooo0?ooo`230?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo3@3oool00`000000oooo0?ooo`230?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo303oool00`000000oooo
0?ooo`230?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo303o
ool00`000000oooo0?ooo`230?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0o`3oool;
0?ooo`030000003oool0oooo08<0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3oool;0?ooo`030000003oool0oooo08<0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo08<0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo08<0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003o
ool0oooo08<0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`030000003oool0oooo08<0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0o`3oool80?ooo`030000003oool0oooo08@0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool0Q03oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool0Q03oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool0Q03o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<00000
0?ooo`3oool0Q03oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
o`H0oooo00<000000?ooo`3oool0Q03oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0Q03oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0Q03oool001@0oooo0P00
000<0?ooo`030000003oool0oooo0?l0oooo1@3oool00`000000oooo0?ooo`240?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo1@3oool00`000000oooo0?ooo`24
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo1@3oool00`00
0000oooo0?ooo`240?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
oooo103oool00`000000oooo0?ooo`240?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0?l0oooo103oool00`000000oooo0?ooo`240?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool0Q03o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0?l0oooo0P3oool00`000000oooo0?ooo`240?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l0jP0007l00`00
0000001o0000O`0e0000Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`000000j`3oool00`000000oooo0?ooo`240?ooo`00
2P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0
oooo0`00000=0?ooo`030000003oool000000>/0oooo00<000000?ooo`3oool0Q03oool000X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<000000`3oool2000000X0oooo
00D000000?ooo`3oool0oooo0000003Z0?ooo`030000003oool0oooo08@0oooo000:0?ooo`@00000
1P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0>L0oooo00<000000?ooo`3oool0Q03oool001@0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0i`3o
ool00`000000oooo0?ooo`240?ooo`00503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3V0?ooo`030000003oool0
oooo08@0oooo000D0?ooo`8000007P3oool200000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3V0?ooo`030000003oool0oooo08@0oooo000D0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`3U0?ooo`030000003oool0oooo08@0
oooo000D0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool200000>D0oooo
00<000000?ooo`3oool0Q03oool001@0oooo00<000000?ooo`3oool0;@3oool200000><0oooo00<0
00000?ooo`3oool0Q03oool001@0oooo00<000000?ooo`3oool0;`3oool200000>40oooo00<00000
0?ooo`3oool0Q03oool001@0oooo00<000000?ooo`3oool0<@3oool200000=l0oooo00<000000?oo
o`3oool0Q03oool001@0oooo00<000000?ooo`3oool0<`3oool200000=d0oooo00<000000?ooo`3o
ool0Q03oool001@0oooo0P00000f0?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool0
Q03oool001@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3J0?ooo`030000003o
ool0oooo08@0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0f@3oool0
0`000000oooo0?ooo`240?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0=P0oooo00<000000?ooo`3oool0Q03oool001@0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`3G0?ooo`030000003oool0oooo08@0oooo000D0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`240?ooo`00503oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0Q03oool001@0oooo0P00000k
0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0Q03oool001@0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo08@0oooo000D0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`240?ooo`00
503oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0
Q@3oool001@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3B0?ooo`030000003o
ool0oooo08D0oooo000D0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0d@3oool0
0`000000oooo0?ooo`250?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
0=40oooo00<000000?ooo`3oool0Q@3oool001@0oooo0P00000o0?ooo`800000d@3oool00`000000
oooo0?ooo`250?ooo`00503oool00`000000oooo0?ooo`100?ooo`800000c`3oool00`000000oooo
0?ooo`250?ooo`00503oool00`000000oooo0?ooo`120?ooo`800000c@3oool00`000000oooo0?oo
o`250?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0<X0oooo00<00000
0?ooo`3oool0Q@3oool001@0oooo00<000000?ooo`3oool0A@3oool200000<X0oooo00<000000?oo
o`3oool0Q@3oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool0Q@3oool000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`360?ooo`030000003oool0oooo08D0oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P0007l00`000000001o0000O`040000O`<00000B@0007l00`000000001o0000O`350000O`03
0000000007l0001o03H0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0BP3oool200000<D0oooo00<000000?ooo`3o
ool0Q@3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0C03oool200000<<0oooo00<000000?ooo`3oool0Q@3oool000@0oooo
0`0000030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`300?ooo`030000003oool0oooo08D0oooo00060?ooo`030000003oool0oooo0080oooo
0P0000070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0_`3oool00`000000oooo
0?ooo`250?ooo`00503oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0;l0oooo00<0
00000?ooo`3oool0Q@3oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`2n
0?ooo`030000003oool0oooo08D0oooo000D0?ooo`800000DP3oool00`000000oooo0?ooo`2m0?oo
o`030000003oool0oooo08D0oooo000D0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0_03oool00`000000oooo0?ooo`250?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo0;`0oooo00<000000?ooo`3oool0Q@3oool001@0oooo00<000000?ooo`3oool0D`3o
ool600000;P0oooo00<000000?ooo`3oool0Q@3oool001@0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`2f0?ooo`030000003oool0oooo08D0oooo000D0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`250?ooo`00503oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0Q@3oool001@0oooo
0P00001K0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0Q@3oool001@0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo08D0oooo000D
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`25
0?ooo`00503oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0;<0oooo00<000000?oo
o`3oool0Q@3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`2b0?ooo`03
0000003oool0oooo08D0oooo000D0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`250?ooo`00503oool00`000000oooo0?ooo`1M0?ooo`030000003o
ool0oooo0;40oooo00<000000?ooo`3oool0Q@3oool001@0oooo0P00001N0?ooo`800000/P3oool0
0`000000oooo0?ooo`250?ooo`00503oool00`000000oooo0?ooo`1O0?ooo`800000/03oool00`00
0000oooo0?ooo`250?ooo`00503oool00`000000oooo0?ooo`1Q0?ooo`800000[P3oool00`000000
oooo0?ooo`250?ooo`00503oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0:/0oooo
00<000000?ooo`3oool0Q@3oool001@0oooo00<000000?ooo`3oool0I03oool200000:/0oooo00<0
00000?ooo`3oool0Q@3oool001@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`2X
0?ooo`030000003oool0oooo08D0oooo000D0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0Y`3oool00`000000oooo0?ooo`250?ooo`00503oool2000006T0oooo00<000000?ooo`3o
ool0Y@3oool00`000000oooo0?ooo`260?ooo`00503oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo0:D0oooo00<000000?ooo`3oool0QP3oool001@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo08H0oooo000D0?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`260?ooo`00503oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0QP3oool000@0
oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0:80
oooo00<000000?ooo`3oool0QP3oool000H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0XP3oool00`000000oooo
0?ooo`260?ooo`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<000000000O`0007l01000
07l3000006`0001o00<000000000O`0007l0X@0007l00`000000001o0000O`0g0000Odl0oooo0006
0?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`260?ooo`001P3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0KP3oool2000000@0oooo0P00
00000`3oool000000?ooo`2G0?ooo`030000003oool0oooo08H0oooo00040?ooo`<000000`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0700oooo00@000000?ooo`00000000000`3o
ool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo08H0oooo00060?ooo`040000003oool0
oooo0?ooo`@000001P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo08H0oooo000D
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`23
0?ooo`030000003oool0oooo08H0oooo000D0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool03@3oool2000008D0oooo00<000000?ooo`3oool0QP3oool001@0oooo0P00001j0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`000000Q03oool00`000000oooo0?ooo`260?ooo`00
503oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
Q03oool00`000000oooo0?ooo`260?ooo`00503oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`000000Q03oool00`000000oooo0?ooo`260?ooo`00503oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000Q03o
ool00`000000oooo0?ooo`260?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo00T0oooo00D000000?ooo`3oool0oooo000000230?ooo`030000003oool0oooo08H0oooo000D
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3o
ool0000008<0oooo00<000000?ooo`3oool0QP3oool001@0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`260?ooo`00503oool2000007l0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0QP3oool001@0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`260?ooo`00503oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0QP3oool001@0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02P3oool2000007@0oooo00<000000?ooo`3oool0QP3oool001@0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0000001d0?ooo`030000003oool0oooo08H0oooo000D0?oo
o`030000003oool0oooo0840oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`00001c0?ooo`030000003oool0oooo08H0oooo000D0?oo
o`030000003oool0oooo08<0oooo0`0000080?ooo`030000003oool0oooo00P0oooo00@000000?oo
o`3oool00000L`3oool00`000000oooo0?ooo`260?ooo`00503oool2000008H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000LP3oool0
0`000000oooo0?ooo`260?ooo`00503oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo
08H0oooo000D0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0QP3oool001@0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`260?ooo`00503oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1^0?ooo`030000003oool0oooo08H0oooo000D0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06h0oooo00<00000
0?ooo`3oool0QP3oool001@0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1T0?oo
o`030000003oool0oooo08H0oooo000D0?ooo`800000TP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo08H0oooo000D0?ooo`030000003oool0oooo0980oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000I@3oool00`000000
oooo0?ooo`260?ooo`00503oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo0?ooo`00
00002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000006D0oooo00<000000?ooo`3o
ool0QP3oool001@0oooo00<000000?ooo`3oool0T`3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`000000I03oool00`000000oooo0?ooo`270?ooo`00
503oool00`000000oooo0?ooo`2D0?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`000000H`3oool00`000000oooo0?ooo`270?ooo`00103oool4000000<0oooo
0P0000070?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000H`3oool00`000000oooo0?ooo`270?ooo`00
103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0XP3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000H`3oool00`00
0000oooo0?ooo`270?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000000007l0001o0000
00H0001o0`00002R0000O`050000000007l0001o0000O`0000001@0007l00`000000001o0000O`1P
0000O`030000000007l0001o03P0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0XP3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`270?ooo`001`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0X`3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
Q`3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo0:<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo08L0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0
X`3oool00`000000oooo000000070?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0
Q`3oool001@0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`030000003o
ool0oooo05l0oooo00<000000?ooo`3oool0Q`3oool001@0oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0Q`3oool0
01@0oooo0P00002U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`270?ooo`00503oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`270?ooo`00503oool00`000000oooo
0?ooo`2_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000E@3oool00`000000oooo
0?ooo`270?ooo`00503oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`000000E@3oool00`000000oooo0?ooo`270?ooo`00503oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000001D0?ooo`030000003o
ool0oooo08L0oooo000D0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0Q`3oool0
01@0oooo00<000000?ooo`3oool0/@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`270?ooo`00503oool00`000000oooo0?ooo`2b0?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`270?oo
o`00503oool200000;<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0Q`3oool001@0oooo00<000000?ooo`3oool0
/`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
AP3oool00`000000oooo0?ooo`270?ooo`00503oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`000000AP3oool00`000000oooo0?ooo`270?ooo`00503oool0
0`000000oooo0?ooo`2o0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00150?ooo`030000003oool0oooo08L0oooo000D0?ooo`030000003oool0oooo0<00oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0Q`3o
ool001@0oooo00<000000?ooo`3oool0`03oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0Q`3oool001@0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo000000070?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0Q`3oool0
01@0oooo0P0000330?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`270?ooo`00503oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0Q`3oool001@0oooo00<000000?ooo`3oool0c@3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo08L0oooo000D0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`270?ooo`00503oool00`000000oooo0?ooo`3>
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0Q`3oool001@0oooo00<000000?oo
o`3oool0c`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo08L0oooo000D0?ooo`03
0000003oool0oooo0<l0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`270?ooo`00
503oool200000=40oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`270?ooo`00503o
ool00`000000oooo0?ooo`3@0?ooo`040000003oool0oooo0?ooo`T00000<P3oool00`000000oooo
0?ooo`270?ooo`00503oool00`000000oooo0?ooo`3A0?ooo`<000002@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo08L0oooo000D0?ooo`030000003oool0oooo0=h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo08L0oooo000D0?oo
o`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0303oool3000001h0oooo00<000000?oo
o`3oool0Q`3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3O0?ooo`03
0000003oool0oooo00X0oooo0P0000030?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0Q`3oool000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0>00oooo00<000000?ooo`3oool01`3oool2000000D0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`280?ooo`001@3oool00`000000oooo0?ooo`030?ooo`80001o00<0
00000000O`0007l0100007l300000>40001o0`0000040000O`800000200007l00`000000001o0000
O`0I0000O`030000000007l0001o03T0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`00
00070?ooo`030000003oool0oooo0>@0oooo1000000:0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0R03oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`3c0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0R03oool000@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?<0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`280?ooo`001@3oool2000000<0oooo10000006
0?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`28
0?ooo`00503oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0R03oool001@0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`020?ooo`80
00004`3oool00`000000oooo0?ooo`280?ooo`00503oool200000?H0oooo00@000000?ooo`000000
00000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo08P0oooo000D0?ooo`030000
003oool0oooo0?D0oooo0P0000050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
R03oool001@0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo08P0oooo000D0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`280?ooo`00503oool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0R03oool001@0oooo00<000000?ooo`3oool0o`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo08P0oooo000D0?ooo`030000003oool0oooo0?l0oooo
0@3oool2000000`0oooo00<000000?ooo`3oool0R03oool001@0oooo0P00003o0?ooo`@0oooo0P00
000:0?ooo`030000003oool0oooo08P0oooo000D0?ooo`030000003oool0oooo0?l0oooo1@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo000D0?ooo`030000003oool0oooo
0?l0oooo1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08P0oooo000D0?ooo`03
0000003oool0oooo0?l0oooo1`3oool2000000H0oooo00<000000?ooo`3oool0R03oool001@0oooo
00<000000?ooo`3oool0o`3oool90?ooo`040000003oool0oooo0?ooo`<00000RP3oool001@0oooo
00<000000?ooo`3oool0o`3oool:0?ooo`<00000S@3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0
oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo00000080001o00<000000000
O`0007l0100007l300000?l0001oB`0007m?0?ooo`001@3oool2000000<0oooo00@000000?ooo`3o
ool00000o`3ooonS0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0?l0ooooX@3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00003o
0?oooj<0oooo00050?ooo`800000103oool200000?l0ooooY03oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool000@0oooo0P0000020?ooo`<000000`3oool5000000<0oooo0P0000020?ooo`<00000103o
ool300000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000?l0ooooS03oool000<0oooo00@000000?ooo`00
000000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool3000000H0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`000`3oool00`00
0000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000`3oool200000?l0ooooS@3oool000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0?l0ooooS@3oool000@0oooo0P0000020?ooo`D0000000@0oooo00000000000000001@3oool20000
0080oooo100000040?ooo`<00000o`3ooon<0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 .55149 L
.79762 .55947 L
.8125 .57258 L
.82738 .57002 L
.84226 .57018 L
.85714 0 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3o0?oooaT0oooo00<000000?ooo`3oool0>@3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oaT0oooo00<000000?ooo`3oool0>@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo0?l0oooo6@3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`3o0?oooaT0oooo00<000000?ooo`3o
ool0OP3oool001@0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo503oool00`000000oooo
0?ooo`1n0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo4`3o
ool00`000000oooo0?ooo`1n0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo4`3oool00`000000oooo0?ooo`1n0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo4P3oool00`000000oooo0?ooo`1n0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo4P3oool00`000000oooo0?ooo`1n0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo4@3oool00`000000oooo
0?ooo`1n0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo4@3o
ool00`000000oooo0?ooo`1n0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo07h0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo07h0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo07h0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo07h0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003o
ool0oooo07h0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3oool>
0?ooo`030000003oool0oooo07h0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0o`3oool=0?ooo`030000003oool0oooo07l0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`3o0?ooo`d0oooo00<000000?ooo`3oool0O`3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3oool0O`3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3oool0O`3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooo``0oooo00<00000
0?ooo`3oool0O`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
o`/0oooo00<000000?ooo`3oool0O`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0O`3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0O`3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`1o0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`1o
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo2P3oool00`00
0000oooo0?ooo`1o0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
oooo2@3oool00`000000oooo0?ooo`1o0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`1o0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool0O`3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0?l0oooo1`3oool00`000000oooo0?ooo`1o0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l0k`0007l00`00
0000001o0000O`0`0000Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`000000l03oool00`000000oooo0?ooo`1o0?ooo`00
2P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0
oooo0`00000=0?ooo`030000003oool000000?00oooo00<000000?ooo`3oool0O`3oool000X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<000000`3oool2000000X0oooo
00D000000?ooo`3oool0oooo0000003_0?ooo`030000003oool0oooo07l0oooo000:0?ooo`@00000
1P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0>`0oooo00<000000?ooo`3oool0O`3oool001@0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0k03o
ool00`000000oooo0?ooo`1o0?ooo`00503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3[0?ooo`030000003oool0
oooo07l0oooo000D0?ooo`8000007P3oool200000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3[0?ooo`030000003oool0oooo07l0oooo000D0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`3Z0?ooo`030000003oool0oooo07l0
oooo000D0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool200000>X0oooo
00<000000?ooo`3oool0O`3oool001@0oooo00<000000?ooo`3oool0;@3oool200000>P0oooo00<0
00000?ooo`3oool0O`3oool001@0oooo00<000000?ooo`3oool0;`3oool200000>H0oooo00<00000
0?ooo`3oool0O`3oool001@0oooo00<000000?ooo`3oool0<@3oool200000>@0oooo00<000000?oo
o`3oool0O`3oool001@0oooo00<000000?ooo`3oool0<`3oool200000>80oooo00<000000?ooo`3o
ool0O`3oool001@0oooo0P00000f0?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0
O`3oool001@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3O0?ooo`030000003o
ool0oooo07l0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0gP3oool0
0`000000oooo0?ooo`1o0?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0=d0oooo00<000000?ooo`3oool0O`3oool001@0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`3L0?ooo`030000003oool0oooo07l0oooo000D0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`1o0?ooo`00503oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool0O`3oool001@0oooo0P00000k
0?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool0O`3oool001@0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo07l0oooo000D0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`1o0?ooo`00
503oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0
P03oool001@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3G0?ooo`030000003o
ool0oooo0800oooo000D0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0eP3oool0
0`000000oooo0?ooo`200?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
0=H0oooo00<000000?ooo`3oool0P03oool001@0oooo0P00000o0?ooo`800000eP3oool00`000000
oooo0?ooo`200?ooo`00503oool00`000000oooo0?ooo`100?ooo`800000e03oool00`000000oooo
0?ooo`200?ooo`00503oool00`000000oooo0?ooo`120?ooo`800000dP3oool00`000000oooo0?oo
o`200?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0<l0oooo00<00000
0?ooo`3oool0P03oool001@0oooo00<000000?ooo`3oool0A@3oool200000<l0oooo00<000000?oo
o`3oool0P03oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0<`0oooo00<000000?ooo`3oool0P03oool000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`3;0?ooo`030000003oool0oooo0800oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P0007l00`000000001o0000O`040000O`<00000B@0007l00`000000001o0000O`3:0000O`03
0000000007l0001o0340001oC`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0BP3oool200000<X0oooo00<000000?ooo`3o
ool0P03oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0C03oool200000<P0oooo00<000000?ooo`3oool0P03oool000@0oooo
0`0000030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`350?ooo`030000003oool0oooo0800oooo00060?ooo`030000003oool0oooo0080oooo
0P0000070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0a03oool00`000000oooo
0?ooo`200?ooo`00503oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0<@0oooo00<0
00000?ooo`3oool0P03oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`33
0?ooo`030000003oool0oooo0800oooo000D0?ooo`800000DP3oool00`000000oooo0?ooo`320?oo
o`030000003oool0oooo0800oooo000D0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0`@3oool00`000000oooo0?ooo`200?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo0<40oooo00<000000?ooo`3oool0P03oool001@0oooo00<000000?ooo`3oool0D`3o
ool600000;d0oooo00<000000?ooo`3oool0P03oool001@0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`2k0?ooo`030000003oool0oooo0800oooo000D0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`200?ooo`00503oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0P03oool001@0oooo
0P00001K0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0P03oool001@0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo0800oooo000D
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`20
0?ooo`00503oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0;P0oooo00<000000?oo
o`3oool0P03oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`2g0?ooo`03
0000003oool0oooo0800oooo000D0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
]`3oool00`000000oooo0?ooo`200?ooo`00503oool00`000000oooo0?ooo`1M0?ooo`030000003o
ool0oooo0;H0oooo00<000000?ooo`3oool0P03oool001@0oooo0P00001N0?ooo`800000]`3oool0
0`000000oooo0?ooo`200?ooo`00503oool00`000000oooo0?ooo`1O0?ooo`800000]@3oool00`00
0000oooo0?ooo`200?ooo`00503oool00`000000oooo0?ooo`1Q0?ooo`800000/`3oool00`000000
oooo0?ooo`200?ooo`00503oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0;00oooo
00<000000?ooo`3oool0P03oool001@0oooo00<000000?ooo`3oool0I03oool200000;00oooo00<0
00000?ooo`3oool0P03oool001@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`2]
0?ooo`030000003oool0oooo0800oooo000D0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0[03oool00`000000oooo0?ooo`200?ooo`00503oool2000006T0oooo00<000000?ooo`3o
ool0ZP3oool00`000000oooo0?ooo`210?ooo`00503oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo0:X0oooo00<000000?ooo`3oool0P@3oool001@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0840oooo000D0?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`210?ooo`00503oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0P@3oool000@0
oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0:L0
oooo00<000000?ooo`3oool0P@3oool000H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo
0?ooo`210?ooo`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<000000000O`0007l01000
07l3000006`0001o00<000000000O`0007l0YP0007l00`000000001o0000O`0b0000Odl0oooo0006
0?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`210?ooo`001P3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0KP3oool2000000@0oooo0P00
00000`3oool000000?ooo`2L0?ooo`030000003oool0oooo0840oooo00040?ooo`<000000`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0700oooo00@000000?ooo`00000000000`3o
ool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0840oooo00060?ooo`040000003oool0
oooo0?ooo`@000001P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0840oooo000D
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`28
0?ooo`030000003oool0oooo0840oooo000D0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool03@3oool2000008X0oooo00<000000?ooo`3oool0P@3oool001@0oooo0P00001j0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`000000R@3oool00`000000oooo0?ooo`210?ooo`00
503oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
R@3oool00`000000oooo0?ooo`210?ooo`00503oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`000000R@3oool00`000000oooo0?ooo`210?ooo`00503oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000R@3o
ool00`000000oooo0?ooo`210?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo00T0oooo00D000000?ooo`3oool0oooo000000280?ooo`030000003oool0oooo0840oooo000D
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3o
ool0000008P0oooo00<000000?ooo`3oool0P@3oool001@0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`210?ooo`00503oool2000007l0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0P@3oool001@0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`210?ooo`00503oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0P@3oool001@0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02P3oool2000007T0oooo00<000000?ooo`3oool0P@3oool001@0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0000001i0?ooo`030000003oool0oooo0840oooo000D0?oo
o`030000003oool0oooo0840oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`00001h0?ooo`030000003oool0oooo0840oooo000D0?oo
o`030000003oool0oooo08<0oooo0`0000080?ooo`030000003oool0oooo00P0oooo00@000000?oo
o`3oool00000N03oool00`000000oooo0?ooo`210?ooo`00503oool2000008H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000M`3oool0
0`000000oooo0?ooo`210?ooo`00503oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo
0840oooo000D0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0P@3oool001@0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`210?ooo`00503oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo0840oooo000D0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool0P@3oool001@0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1Y0?oo
o`030000003oool0oooo0840oooo000D0?ooo`800000TP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1Y0?ooo`03
0000003oool0oooo0840oooo000D0?ooo`030000003oool0oooo0980oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000JP3oool00`000000
oooo0?ooo`210?ooo`00503oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo0?ooo`00
00002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000006X0oooo00<000000?ooo`3o
ool0P@3oool001@0oooo00<000000?ooo`3oool0T`3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`000000J@3oool00`000000oooo0?ooo`220?ooo`00
503oool00`000000oooo0?ooo`2D0?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`000000J03oool00`000000oooo0?ooo`220?ooo`00103oool4000000<0oooo
0P0000070?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000J03oool00`000000oooo0?ooo`220?ooo`00
103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0XP3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000J03oool00`00
0000oooo0?ooo`220?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000000007l0001o0000
00H0001o0`00002R0000O`050000000007l0001o0000O`0000001@0007l00`000000001o0000O`1U
0000O`030000000007l0001o03<0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0XP3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`220?ooo`001`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0X`3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0
PP3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo0:<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo0880oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0
X`3oool00`000000oooo000000070?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
PP3oool001@0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool0PP3oool001@0oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0PP3oool0
01@0oooo0P00002U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`220?ooo`00503oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`220?ooo`00503oool00`000000oooo
0?ooo`2_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000FP3oool00`000000oooo
0?ooo`220?ooo`00503oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`000000FP3oool00`000000oooo0?ooo`220?ooo`00503oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000001I0?ooo`030000003o
ool0oooo0880oooo000D0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0PP3oool0
01@0oooo00<000000?ooo`3oool0/@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`220?ooo`00503oool00`000000oooo0?ooo`2b0?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`220?oo
o`00503oool200000;<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0PP3oool001@0oooo00<000000?ooo`3oool0
/`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
B`3oool00`000000oooo0?ooo`220?ooo`00503oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`000000B`3oool00`000000oooo0?ooo`220?ooo`00503oool0
0`000000oooo0?ooo`2o0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
001:0?ooo`030000003oool0oooo0880oooo000D0?ooo`030000003oool0oooo0<00oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0PP3o
ool001@0oooo00<000000?ooo`3oool0`03oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool0PP3oool001@0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo000000070?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0PP3oool0
01@0oooo0P0000330?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`220?ooo`00503oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0PP3oool001@0oooo00<000000?ooo`3oool0c@3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0880oooo000D0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`220?ooo`00503oool00`000000oooo0?ooo`3>
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0PP3oool001@0oooo00<000000?oo
o`3oool0c`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0880oooo000D0?ooo`03
0000003oool0oooo0<l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`220?ooo`00
503oool200000=40oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`220?ooo`00503o
ool00`000000oooo0?ooo`3@0?ooo`040000003oool0oooo0?ooo`T00000=`3oool00`000000oooo
0?ooo`220?ooo`00503oool00`000000oooo0?ooo`3A0?ooo`<000002@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0880oooo000D0?ooo`030000003oool0oooo0=h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0880oooo000D0?oo
o`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0303oool3000002<0oooo00<000000?oo
o`3oool0PP3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3O0?ooo`03
0000003oool0oooo00X0oooo0P0000030?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0PP3oool000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0>00oooo00<000000?ooo`3oool01`3oool2000000D0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`230?ooo`001@3oool00`000000oooo0?ooo`030?ooo`80001o00<0
00000000O`0007l0100007l300000>40001o0`0000040000O`800000200007l00`000000001o0000
O`0N0000O`030000000007l0001o03@0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`00
00070?ooo`030000003oool0oooo0>@0oooo1000000:0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0P`3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`3c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0P`3oool000@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?<0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`230?ooo`001@3oool2000000<0oooo10000006
0?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`23
0?ooo`00503oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0P`3oool001@0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`020?ooo`80
0000603oool00`000000oooo0?ooo`230?ooo`00503oool200000?H0oooo00@000000?ooo`000000
00000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo08<0oooo000D0?ooo`030000
003oool0oooo0?D0oooo0P0000050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
P`3oool001@0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo08<0oooo000D0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`230?ooo`00503oool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0P`3oool001@0oooo00<000000?ooo`3oool0o`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo08<0oooo000D0?ooo`030000003oool0oooo0?l0oooo
0@3oool200000140oooo00<000000?ooo`3oool0P`3oool001@0oooo0P00003o0?ooo`@0oooo0P00
000?0?ooo`030000003oool0oooo08<0oooo000D0?ooo`030000003oool0oooo0?l0oooo1@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08<0oooo000D0?ooo`030000003oool0oooo
0?l0oooo1P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo08<0oooo000D0?ooo`03
0000003oool0oooo0?l0oooo1`3oool2000000/0oooo00<000000?ooo`3oool0P`3oool001@0oooo
00<000000?ooo`3oool0o`3oool90?ooo`040000003oool0oooo0?ooo`P00000Q@3oool001@0oooo
00<000000?ooo`3oool0o`3oool:0?ooo`<00000S@3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool200000?l0ooooV`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo
0?l0ooooVP3oool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0
oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00070?ooo`040000003oool0oooo00000080001o00<000000000
O`0007l0100007l300000?l0001oB`0007m?0?ooo`001@3oool2000000<0oooo00@000000?ooo`3o
ool00000o`3ooonS0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0?l0ooooX@3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00003o
0?oooj<0oooo00050?ooo`800000103oool200000?l0ooooY03oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool000@0oooo0P0000020?ooo`<000000`3oool5000000<0oooo0P0000020?ooo`<00000103o
ool300000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000?l0ooooS03oool000<0oooo00@000000?ooo`00
000000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool3000000H0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`000`3oool00`00
0000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000`3oool200000?l0ooooS@3oool000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0?l0ooooS@3oool000@0oooo0P0000020?ooo`D0000000@0oooo00000000000000001@3oool20000
0080oooo100000040?ooo`<00000o`3ooon<0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 .55149 L
.79762 .55947 L
.8125 .57258 L
.82738 .57002 L
.84226 .57018 L
.85714 .58421 L
.87202 0 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3o0?oooah0oooo00<000000?ooo`3oool0=03oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oah0oooo00<000000?ooo`3oool0=03oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo0?l0oooo7P3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`3o0?oooah0oooo00<000000?ooo`3o
ool0N@3oool001@0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo
0?ooo`1i0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo603o
ool00`000000oooo0?ooo`1i0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo603oool00`000000oooo0?ooo`1i0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo5`3oool00`000000oooo0?ooo`1i0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo5`3oool00`000000oooo0?ooo`1i0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo5P3oool00`000000oooo
0?ooo`1i0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo5P3o
ool00`000000oooo0?ooo`1i0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0o`3ooolE
0?ooo`030000003oool0oooo07T0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3ooolE0?ooo`030000003oool0oooo07T0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3ooolD0?ooo`030000003oool0oooo07T0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`030000003oool0oooo07T0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`030000003o
ool0oooo07T0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolC
0?ooo`030000003oool0oooo07T0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0o`3ooolB0?ooo`030000003oool0oooo07X0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`3o0?oooa80oooo00<000000?ooo`3oool0NP3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3o0?oooa40oooo00<000000?ooo`3oool0NP3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooa40oooo00<000000?ooo`3oool0NP3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooa40oooo00<00000
0?ooo`3oool0NP3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool0NP3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0NP3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0NP3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000oooo0?ooo`1j0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000oooo0?ooo`1j
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo3`3oool00`00
0000oooo0?ooo`1j0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
oooo3P3oool00`000000oooo0?ooo`1j0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`1j0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooo`d0oooo00<000000?ooo`3oool0NP3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0?l0oooo303oool00`000000oooo0?ooo`1j0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l0m00007l00`00
0000001o0000O`0[0000Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`000000m@3oool00`000000oooo0?ooo`1j0?ooo`00
2P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0
oooo0`00000=0?ooo`030000003oool000000?D0oooo00<000000?ooo`3oool0NP3oool000X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<000000`3oool2000000X0oooo
00D000000?ooo`3oool0oooo0000003d0?ooo`030000003oool0oooo07X0oooo000:0?ooo`@00000
1P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0?40oooo00<000000?ooo`3oool0NP3oool001@0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0l@3o
ool00`000000oooo0?ooo`1j0?ooo`00503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3`0?ooo`030000003oool0
oooo07X0oooo000D0?ooo`8000007P3oool200000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3`0?ooo`030000003oool0oooo07X0oooo000D0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`3_0?ooo`030000003oool0oooo07X0
oooo000D0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool200000>l0oooo
00<000000?ooo`3oool0NP3oool001@0oooo00<000000?ooo`3oool0;@3oool200000>d0oooo00<0
00000?ooo`3oool0NP3oool001@0oooo00<000000?ooo`3oool0;`3oool200000>/0oooo00<00000
0?ooo`3oool0NP3oool001@0oooo00<000000?ooo`3oool0<@3oool200000>T0oooo00<000000?oo
o`3oool0NP3oool001@0oooo00<000000?ooo`3oool0<`3oool200000>L0oooo00<000000?ooo`3o
ool0NP3oool001@0oooo0P00000f0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool0
NP3oool001@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3T0?ooo`030000003o
ool0oooo07X0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0h`3oool0
0`000000oooo0?ooo`1j0?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0>80oooo00<000000?ooo`3oool0NP3oool001@0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`3Q0?ooo`030000003oool0oooo07X0oooo000D0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`1j0?ooo`00503oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0NP3oool001@0oooo0P00000k
0?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0NP3oool001@0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo07X0oooo000D0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0gP3oool00`000000oooo0?ooo`1j0?ooo`00
503oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool0
NP3oool001@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3L0?ooo`030000003o
ool0oooo07/0oooo000D0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0f`3oool0
0`000000oooo0?ooo`1k0?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
0=/0oooo00<000000?ooo`3oool0N`3oool001@0oooo0P00000o0?ooo`800000f`3oool00`000000
oooo0?ooo`1k0?ooo`00503oool00`000000oooo0?ooo`100?ooo`800000f@3oool00`000000oooo
0?ooo`1k0?ooo`00503oool00`000000oooo0?ooo`120?ooo`800000e`3oool00`000000oooo0?oo
o`1k0?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0=@0oooo00<00000
0?ooo`3oool0N`3oool001@0oooo00<000000?ooo`3oool0A@3oool200000=@0oooo00<000000?oo
o`3oool0N`3oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0=40oooo00<000000?ooo`3oool0N`3oool000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`3@0?ooo`030000003oool0oooo07/0oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P0007l00`000000001o0000O`040000O`<00000B@0007l00`000000001o0000O`3?0000O`03
0000000007l0001o02`0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0BP3oool200000<l0oooo00<000000?ooo`3o
ool0N`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0C03oool200000<d0oooo00<000000?ooo`3oool0N`3oool000@0oooo
0`0000030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`3:0?ooo`030000003oool0oooo07/0oooo00060?ooo`030000003oool0oooo0080oooo
0P0000070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0b@3oool00`000000oooo
0?ooo`1k0?ooo`00503oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0<T0oooo00<0
00000?ooo`3oool0N`3oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`38
0?ooo`030000003oool0oooo07/0oooo000D0?ooo`800000DP3oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo07/0oooo000D0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0aP3oool00`000000oooo0?ooo`1k0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo0<H0oooo00<000000?ooo`3oool0N`3oool001@0oooo00<000000?ooo`3oool0D`3o
ool600000<80oooo00<000000?ooo`3oool0N`3oool001@0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`300?ooo`030000003oool0oooo07/0oooo000D0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`1k0?ooo`00503oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0N`3oool001@0oooo
0P00001K0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0N`3oool001@0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo07/0oooo000D
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`1k
0?ooo`00503oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0;d0oooo00<000000?oo
o`3oool0N`3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`2l0?ooo`03
0000003oool0oooo07/0oooo000D0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
_03oool00`000000oooo0?ooo`1k0?ooo`00503oool00`000000oooo0?ooo`1M0?ooo`030000003o
ool0oooo0;/0oooo00<000000?ooo`3oool0N`3oool001@0oooo0P00001N0?ooo`800000_03oool0
0`000000oooo0?ooo`1k0?ooo`00503oool00`000000oooo0?ooo`1O0?ooo`800000^P3oool00`00
0000oooo0?ooo`1k0?ooo`00503oool00`000000oooo0?ooo`1Q0?ooo`800000^03oool00`000000
oooo0?ooo`1k0?ooo`00503oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0;D0oooo
00<000000?ooo`3oool0N`3oool001@0oooo00<000000?ooo`3oool0I03oool200000;D0oooo00<0
00000?ooo`3oool0N`3oool001@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`2b
0?ooo`030000003oool0oooo07/0oooo000D0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0/@3oool00`000000oooo0?ooo`1k0?ooo`00503oool2000006T0oooo00<000000?ooo`3o
ool0/03oool00`000000oooo0?ooo`1k0?ooo`00503oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo0;00oooo00<000000?ooo`3oool0N`3oool001@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo07`0oooo000D0?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`1l0?ooo`00503oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0O03oool000@0
oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0:`0
oooo00<000000?ooo`3oool0O03oool000H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1l0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<000000000O`0007l01000
07l3000006`0001o00<000000000O`0007l0Z`0007l00`000000001o0000O`0]0000Odl0oooo0006
0?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`1l0?ooo`001P3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0KP3oool2000000@0oooo0P00
00000`3oool000000?ooo`2Q0?ooo`030000003oool0oooo07`0oooo00040?ooo`<000000`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0700oooo00@000000?ooo`00000000000`3o
ool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo07`0oooo00060?ooo`040000003oool0
oooo0?ooo`@000001P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo07`0oooo000D
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo07`0oooo000D0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool03@3oool2000008l0oooo00<000000?ooo`3oool0O03oool001@0oooo0P00001j0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`000000SP3oool00`000000oooo0?ooo`1l0?ooo`00
503oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
SP3oool00`000000oooo0?ooo`1l0?ooo`00503oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`000000SP3oool00`000000oooo0?ooo`1l0?ooo`00503oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000SP3o
ool00`000000oooo0?ooo`1l0?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo00T0oooo00D000000?ooo`3oool0oooo0000002=0?ooo`030000003oool0oooo07`0oooo000D
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3o
ool0000008d0oooo00<000000?ooo`3oool0O03oool001@0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`1l0?ooo`00503oool2000007l0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0O03oool001@0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`1l0?ooo`00503oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0O03oool001@0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02P3oool2000007h0oooo00<000000?ooo`3oool0O03oool001@0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0000001n0?ooo`030000003oool0oooo07`0oooo000D0?oo
o`030000003oool0oooo0840oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`00001m0?ooo`030000003oool0oooo07`0oooo000D0?oo
o`030000003oool0oooo08<0oooo0`0000080?ooo`030000003oool0oooo00P0oooo00@000000?oo
o`3oool00000O@3oool00`000000oooo0?ooo`1l0?ooo`00503oool2000008H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000O03oool0
0`000000oooo0?ooo`1l0?ooo`00503oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
07`0oooo000D0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0O03oool001@0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1l0?ooo`00503oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo07`0oooo000D0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool0O03oool001@0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo07`0oooo000D0?ooo`800000TP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1^0?ooo`03
0000003oool0oooo07`0oooo000D0?ooo`030000003oool0oooo0980oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000K`3oool00`000000
oooo0?ooo`1l0?ooo`00503oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo0?ooo`00
00002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000006l0oooo00<000000?ooo`3o
ool0O03oool001@0oooo00<000000?ooo`3oool0T`3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`000000K`3oool00`000000oooo0?ooo`1l0?ooo`00
503oool00`000000oooo0?ooo`2D0?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`000000KP3oool00`000000oooo0?ooo`1l0?ooo`00103oool4000000<0oooo
0P0000070?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000KP3oool00`000000oooo0?ooo`1l0?ooo`00
103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0XP3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000KP3oool00`00
0000oooo0?ooo`1l0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000000007l0001o0000
00H0001o0`00002R0000O`050000000007l0001o0000O`0000001@0007l00`000000001o0000O`1Z
0000O`030000000007l0001o02h0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0XP3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1m0?ooo`001`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0X`3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0
O@3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo0:<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`1Y0?ooo`03
0000003oool0oooo07d0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0
X`3oool00`000000oooo000000070?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
O@3oool001@0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`030000003o
ool0oooo06T0oooo00<000000?ooo`3oool0O@3oool001@0oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0O@3oool0
01@0oooo0P00002U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0J03oool00`00
0000oooo0?ooo`1m0?ooo`00503oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1m0?ooo`00503oool00`000000oooo
0?ooo`2_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000G`3oool00`000000oooo
0?ooo`1m0?ooo`00503oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`000000G`3oool00`000000oooo0?ooo`1m0?ooo`00503oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000001N0?ooo`030000003o
ool0oooo07d0oooo000D0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0O@3oool0
01@0oooo00<000000?ooo`3oool0/@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`1m0?ooo`00503oool00`000000oooo0?ooo`2b0?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1m0?oo
o`00503oool200000;<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0O@3oool001@0oooo00<000000?ooo`3oool0
/`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
D03oool00`000000oooo0?ooo`1m0?ooo`00503oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`000000D03oool00`000000oooo0?ooo`1m0?ooo`00503oool0
0`000000oooo0?ooo`2o0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
001?0?ooo`030000003oool0oooo07d0oooo000D0?ooo`030000003oool0oooo0<00oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0O@3o
ool001@0oooo00<000000?ooo`3oool0`03oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0O@3oool001@0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo000000070?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0O@3oool0
01@0oooo0P0000330?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`1m0?ooo`00503oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0O@3oool001@0oooo00<000000?ooo`3oool0c@3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo07d0oooo000D0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`1m0?ooo`00503oool00`000000oooo0?ooo`3>
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0O@3oool001@0oooo00<000000?oo
o`3oool0c`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo07d0oooo000D0?ooo`03
0000003oool0oooo0<l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1m0?ooo`00
503oool200000=40oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1m0?ooo`00503o
ool00`000000oooo0?ooo`3@0?ooo`040000003oool0oooo0?ooo`T00000?03oool00`000000oooo
0?ooo`1m0?ooo`00503oool00`000000oooo0?ooo`3A0?ooo`<000002@3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo07d0oooo000D0?ooo`030000003oool0oooo0=h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo07d0oooo000D0?oo
o`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0303oool3000002P0oooo00<000000?oo
o`3oool0O@3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3O0?ooo`03
0000003oool0oooo00X0oooo0P0000030?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0O@3oool000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0>00oooo00<000000?ooo`3oool01`3oool2000000D0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`1m0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`80001o00<0
00000000O`0007l0100007l300000>40001o0`0000040000O`800000200007l00`000000001o0000
O`0T0000O`030000000007l0001o02h0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`00
00070?ooo`030000003oool0oooo0>@0oooo1000000:0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0O@3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`3c0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0O@3oool000@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?<0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`1m0?ooo`001@3oool2000000<0oooo10000006
0?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1n
0?ooo`00503oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0OP3oool001@0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`020?ooo`80
00007@3oool00`000000oooo0?ooo`1n0?ooo`00503oool200000?H0oooo00@000000?ooo`000000
00000P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo07h0oooo000D0?ooo`030000
003oool0oooo0?D0oooo0P0000050?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
OP3oool001@0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo07h0oooo000D0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`1n0?ooo`00503oool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0OP3oool001@0oooo00<000000?ooo`3oool0o`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo07h0oooo000D0?ooo`030000003oool0oooo0?l0oooo
0@3oool2000001H0oooo00<000000?ooo`3oool0OP3oool001@0oooo0P00003o0?ooo`@0oooo0P00
000D0?ooo`030000003oool0oooo07h0oooo000D0?ooo`030000003oool0oooo0?l0oooo1@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07h0oooo000D0?ooo`030000003oool0oooo
0?l0oooo1P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07h0oooo000D0?ooo`03
0000003oool0oooo0?l0oooo1`3oool200000100oooo00<000000?ooo`3oool0OP3oool001@0oooo
00<000000?ooo`3oool0o`3oool90?ooo`040000003oool0oooo0?ooo`P00000103oool00`000000
oooo0?ooo`1n0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo0`0000080?ooo`050000
003oool0oooo0?ooo`000000P03oool001@0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`040000
003oool0oooo00000800oooo000D0?ooo`800000o`3ooolH0?ooo`030000003oool000000800oooo
000D0?ooo`030000003oool0oooo0?l0oooo603oool200000800oooo000D0?ooo`030000003oool0
oooo0?l0oooo6@3oool00`000000oooo0?ooo`1n0?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0
o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK
0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?oo
o`3o0?oooiX0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ
0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000020000O`0300000000
07l0001o00@0001o0`00003o0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003oool0
oooo00000?l0ooooX`3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`3o0?oooj40oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
o`3ooonS0?ooo`001@3oool2000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo00040?ooo`8000000P3oool3000000<0oooo1@0000030?ooo`8000000P3oool3000000@0
oooo0`00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003oool0
000000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo00000080oooo0`0000060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo00<0
00000?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`3o0?ooohd0oooo00040?ooo`8000000P3oool5000000040?ooo`0000000000000000D0oooo0P00
00020?ooo`@00000103oool300000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 .55149 L
.79762 .55947 L
.8125 .57258 L
.82738 .57002 L
.84226 .57018 L
.85714 .58421 L
.87202 .58127 L
.8869 0 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3o0?ooob<0oooo00<000000?ooo`3oool0;`3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`3o0?oo
ob<0oooo00<000000?ooo`3oool0;`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo0?l0oooo8`3oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`3o0?ooob<0oooo00<000000?ooo`3o
ool0M03oool001@0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo7P3oool00`000000oooo
0?ooo`1d0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo7@3o
ool00`000000oooo0?ooo`1d0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo7@3oool00`000000oooo0?ooo`1d0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`1d0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`1d0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo
0?ooo`1d0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo6`3o
ool00`000000oooo0?ooo`1d0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0o`3ooolJ
0?ooo`030000003oool0oooo07@0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3ooolJ0?ooo`030000003oool0oooo07@0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo07@0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo07@0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003o
ool0oooo07@0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolH
0?ooo`030000003oool0oooo07@0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0o`3ooolG0?ooo`030000003oool0oooo07D0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`3o0?oooaL0oooo00<000000?ooo`3oool0M@3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3o0?oooaH0oooo00<000000?ooo`3oool0M@3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooaH0oooo00<000000?ooo`3oool0M@3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooaH0oooo00<00000
0?ooo`3oool0M@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
oaD0oooo00<000000?ooo`3oool0M@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?oooaD0oooo00<000000?ooo`3oool0M@3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3o0?oooaD0oooo00<000000?ooo`3oool0M@3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo0?l0oooo503oool00`000000oooo0?ooo`1e0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo503oool00`000000oooo0?ooo`1e
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo503oool00`00
0000oooo0?ooo`1e0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
oooo4`3oool00`000000oooo0?ooo`1e0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0?l0oooo4`3oool00`000000oooo0?ooo`1e0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oooa80oooo00<000000?ooo`3oool0M@3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0?l0oooo4@3oool00`000000oooo0?ooo`1e0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l0n@0007l00`00
0000001o0000O`0V0000Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`000000nP3oool00`000000oooo0?ooo`1e0?ooo`00
2P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0
oooo0`00000=0?ooo`030000003oool000000?X0oooo00<000000?ooo`3oool0M@3oool000X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<000000`3oool2000000X0oooo
00D000000?ooo`3oool0oooo0000003i0?ooo`030000003oool0oooo07D0oooo000:0?ooo`@00000
1P3oool00`000000oooo0?ooo`0I0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0?H0oooo00<000000?ooo`3oool0M@3oool001@0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0mP3o
ool00`000000oooo0?ooo`1e0?ooo`00503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3e0?ooo`030000003oool0
oooo07D0oooo000D0?ooo`8000007P3oool200000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3e0?ooo`030000003oool0oooo07D0oooo000D0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo07D0
oooo000D0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool200000?@0oooo
00<000000?ooo`3oool0M@3oool001@0oooo00<000000?ooo`3oool0;@3oool200000?80oooo00<0
00000?ooo`3oool0M@3oool001@0oooo00<000000?ooo`3oool0;`3oool200000?00oooo00<00000
0?ooo`3oool0M@3oool001@0oooo00<000000?ooo`3oool0<@3oool200000>h0oooo00<000000?oo
o`3oool0M@3oool001@0oooo00<000000?ooo`3oool0<`3oool200000>`0oooo00<000000?ooo`3o
ool0M@3oool001@0oooo0P00000f0?ooo`030000003oool0oooo0>T0oooo00<000000?ooo`3oool0
M@3oool001@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3Y0?ooo`030000003o
ool0oooo07D0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0j03oool0
0`000000oooo0?ooo`1e0?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0>L0oooo00<000000?ooo`3oool0M@3oool001@0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`3V0?ooo`030000003oool0oooo07D0oooo000D0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`1e0?ooo`00503oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo0>D0oooo00<000000?ooo`3oool0M@3oool001@0oooo0P00000k
0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool0M@3oool001@0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo07D0oooo000D0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0h`3oool00`000000oooo0?ooo`1e0?ooo`00
503oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool0
M@3oool001@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3Q0?ooo`030000003o
ool0oooo07H0oooo000D0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0h03oool0
0`000000oooo0?ooo`1f0?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
0>00oooo00<000000?ooo`3oool0MP3oool001@0oooo0P00000o0?ooo`800000h03oool00`000000
oooo0?ooo`1f0?ooo`00503oool00`000000oooo0?ooo`100?ooo`800000gP3oool00`000000oooo
0?ooo`1f0?ooo`00503oool00`000000oooo0?ooo`120?ooo`800000g03oool00`000000oooo0?oo
o`1f0?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0=T0oooo00<00000
0?ooo`3oool0MP3oool001@0oooo00<000000?ooo`3oool0A@3oool200000=T0oooo00<000000?oo
o`3oool0MP3oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0=H0oooo00<000000?ooo`3oool0MP3oool000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`3E0?ooo`030000003oool0oooo07H0oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P0007l00`000000001o0000O`040000O`<00000B@0007l00`000000001o0000O`3D0000O`03
0000000007l0001o02L0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0BP3oool200000=@0oooo00<000000?ooo`3o
ool0MP3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0C03oool200000=80oooo00<000000?ooo`3oool0MP3oool000@0oooo
0`0000030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`3?0?ooo`030000003oool0oooo07H0oooo00060?ooo`030000003oool0oooo0080oooo
0P0000070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0cP3oool00`000000oooo
0?ooo`1f0?ooo`00503oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool0MP3oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`3=
0?ooo`030000003oool0oooo07H0oooo000D0?ooo`800000DP3oool00`000000oooo0?ooo`3<0?oo
o`030000003oool0oooo07H0oooo000D0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0b`3oool00`000000oooo0?ooo`1f0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo0</0oooo00<000000?ooo`3oool0MP3oool001@0oooo00<000000?ooo`3oool0D`3o
ool600000<L0oooo00<000000?ooo`3oool0MP3oool001@0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`350?ooo`030000003oool0oooo07H0oooo000D0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`1f0?ooo`00503oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0MP3oool001@0oooo
0P00001K0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0MP3oool001@0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo07H0oooo000D
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`1f
0?ooo`00503oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0<80oooo00<000000?oo
o`3oool0MP3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`310?ooo`03
0000003oool0oooo07H0oooo000D0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
`@3oool00`000000oooo0?ooo`1f0?ooo`00503oool00`000000oooo0?ooo`1M0?ooo`030000003o
ool0oooo0<00oooo00<000000?ooo`3oool0MP3oool001@0oooo0P00001N0?ooo`800000`@3oool0
0`000000oooo0?ooo`1f0?ooo`00503oool00`000000oooo0?ooo`1O0?ooo`800000_`3oool00`00
0000oooo0?ooo`1f0?ooo`00503oool00`000000oooo0?ooo`1Q0?ooo`800000_@3oool00`000000
oooo0?ooo`1f0?ooo`00503oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0MP3oool001@0oooo00<000000?ooo`3oool0I03oool200000;X0oooo00<0
00000?ooo`3oool0MP3oool001@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`2g
0?ooo`030000003oool0oooo07H0oooo000D0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0]P3oool00`000000oooo0?ooo`1f0?ooo`00503oool2000006T0oooo00<000000?ooo`3o
ool0]@3oool00`000000oooo0?ooo`1f0?ooo`00503oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo0;D0oooo00<000000?ooo`3oool0MP3oool001@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo07L0oooo000D0?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`1g0?ooo`00503oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0M`3oool000@0
oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0;40
oooo00<000000?ooo`3oool0M`3oool000H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`1g0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<000000000O`0007l01000
07l3000006`0001o00<000000000O`0007l0/00007l00`000000001o0000O`0X0000Odl0oooo0006
0?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`1g0?ooo`001P3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0KP3oool2000000@0oooo0P00
00000`3oool000000?ooo`2V0?ooo`030000003oool0oooo07L0oooo00040?ooo`<000000`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0700oooo00@000000?ooo`00000000000`3o
ool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo07L0oooo00060?ooo`040000003oool0
oooo0?ooo`@000001P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo07L0oooo000D
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo07L0oooo000D0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool03@3oool2000009@0oooo00<000000?ooo`3oool0M`3oool001@0oooo0P00001j0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`000000T`3oool00`000000oooo0?ooo`1g0?ooo`00
503oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
T`3oool00`000000oooo0?ooo`1g0?ooo`00503oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`000000T`3oool00`000000oooo0?ooo`1g0?ooo`00503oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000T`3o
ool00`000000oooo0?ooo`1g0?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo00T0oooo00D000000?ooo`3oool0oooo0000002B0?ooo`030000003oool0oooo07L0oooo000D
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3o
ool000000980oooo00<000000?ooo`3oool0M`3oool001@0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`1g0?ooo`00503oool2000007l0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0M`3oool001@0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`1g0?ooo`00503oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0M`3oool001@0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02P3oool2000008<0oooo00<000000?ooo`3oool0M`3oool001@0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo000000230?ooo`030000003oool0oooo07L0oooo000D0?oo
o`030000003oool0oooo0840oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`0000220?ooo`030000003oool0oooo07L0oooo000D0?oo
o`030000003oool0oooo08<0oooo0`0000080?ooo`030000003oool0oooo00P0oooo00@000000?oo
o`3oool00000PP3oool00`000000oooo0?ooo`1g0?ooo`00503oool2000008H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000P@3oool0
0`000000oooo0?ooo`1g0?ooo`00503oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo
07L0oooo000D0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0M`3oool001@0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1g0?ooo`00503oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1m0?ooo`030000003oool0oooo07L0oooo000D0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07d0oooo00<00000
0?ooo`3oool0M`3oool001@0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo07L0oooo000D0?ooo`800000TP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1c0?ooo`03
0000003oool0oooo07L0oooo000D0?ooo`030000003oool0oooo0980oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000M03oool00`000000
oooo0?ooo`1g0?ooo`00503oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo0?ooo`00
00002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000007@0oooo00<000000?ooo`3o
ool0M`3oool001@0oooo00<000000?ooo`3oool0T`3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`1g0?ooo`00
503oool00`000000oooo0?ooo`2D0?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`000000L`3oool00`000000oooo0?ooo`1g0?ooo`00103oool4000000<0oooo
0P0000070?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000L`3oool00`000000oooo0?ooo`1g0?ooo`00
103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0XP3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000LP3oool00`00
0000oooo0?ooo`1h0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000000007l0001o0000
00H0001o0`00002R0000O`050000000007l0001o0000O`0000001@0007l00`000000001o0000O`1_
0000O`030000000007l0001o02T0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0XP3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1h0?ooo`001`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0X`3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0
N03oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo0:<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`1^0?ooo`03
0000003oool0oooo07P0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0
X`3oool00`000000oooo000000070?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0
N03oool001@0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0N03oool001@0oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0N03oool0
01@0oooo0P00002U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`1h0?ooo`00503oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1h0?ooo`00503oool00`000000oooo
0?ooo`2_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000I03oool00`000000oooo
0?ooo`1h0?ooo`00503oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`000000I03oool00`000000oooo0?ooo`1h0?ooo`00503oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000001S0?ooo`030000003o
ool0oooo07P0oooo000D0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0N03oool0
01@0oooo00<000000?ooo`3oool0/@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`1h0?ooo`00503oool00`000000oooo0?ooo`2b0?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1h0?oo
o`00503oool200000;<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0N03oool001@0oooo00<000000?ooo`3oool0
/`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
E@3oool00`000000oooo0?ooo`1h0?ooo`00503oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`000000E@3oool00`000000oooo0?ooo`1h0?ooo`00503oool0
0`000000oooo0?ooo`2o0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
001D0?ooo`030000003oool0oooo07P0oooo000D0?ooo`030000003oool0oooo0<00oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0N03o
ool001@0oooo00<000000?ooo`3oool0`03oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo0500oooo00<000000?ooo`3oool0N03oool001@0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo000000070?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0N03oool0
01@0oooo0P0000330?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`1h0?ooo`00503oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0N03oool001@0oooo00<000000?ooo`3oool0c@3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo07P0oooo000D0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`1h0?ooo`00503oool00`000000oooo0?ooo`3>
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0N03oool001@0oooo00<000000?oo
o`3oool0c`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo07P0oooo000D0?ooo`03
0000003oool0oooo0<l0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1h0?ooo`00
503oool200000=40oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1h0?ooo`00503o
ool00`000000oooo0?ooo`3@0?ooo`040000003oool0oooo0?ooo`T00000@@3oool00`000000oooo
0?ooo`1h0?ooo`00503oool00`000000oooo0?ooo`3A0?ooo`<000002@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo07P0oooo000D0?ooo`030000003oool0oooo0=h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo07P0oooo000D0?oo
o`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0303oool3000002d0oooo00<000000?oo
o`3oool0N03oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3O0?ooo`03
0000003oool0oooo00X0oooo0P0000030?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0N03oool000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0>00oooo00<000000?ooo`3oool01`3oool2000000D0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`1h0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`80001o00<0
00000000O`0007l0100007l300000>40001o0`0000040000O`800000200007l00`000000001o0000
O`0Y0000O`030000000007l0001o02T0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`00
00070?ooo`030000003oool0oooo0>@0oooo1000000:0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0N03oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`3c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0N03oool000@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?<0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`1i0?ooo`001@3oool2000000<0oooo10000006
0?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1i
0?ooo`00503oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0N@3oool001@0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`020?ooo`80
00008P3oool00`000000oooo0?ooo`1i0?ooo`00503oool200000?H0oooo00@000000?ooo`000000
00000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo07T0oooo000D0?ooo`030000
003oool0oooo0?D0oooo0P0000050?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
N@3oool001@0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo07T0oooo000D0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1i0?ooo`00503oool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0N@3oool001@0oooo00<000000?ooo`3oool0o`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo07T0oooo000D0?ooo`030000003oool0oooo0?l0oooo
0@3oool2000001/0oooo00<000000?ooo`3oool0N@3oool001@0oooo0P00003o0?ooo`@0oooo0P00
000I0?ooo`030000003oool0oooo07T0oooo000D0?ooo`030000003oool0oooo0?l0oooo1@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo07T0oooo000D0?ooo`030000003oool0oooo
0?l0oooo1P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo07T0oooo000D0?ooo`03
0000003oool0oooo0?l0oooo1`3oool2000001D0oooo00<000000?ooo`3oool0N@3oool001@0oooo
00<000000?ooo`3oool0o`3oool90?ooo`040000003oool0oooo0?ooo`P000002@3oool00`000000
oooo0?ooo`1i0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo0`0000080?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0N@3oool001@0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0N@3oool001@0oooo0P00003o
0?oooaP0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1i0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooaP0oooo00@000000?ooo`3oool0oooo0`00001k0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooaT0oooo0`00001n0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0
oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`800000o`3ooonK0?oo
o`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000020000O`030000000007l0
001o00@0001o0`00003o0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003oool0oooo
00000?l0ooooX`3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o
0?oooj40oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3o
oonS0?ooo`001@3oool2000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo00040?ooo`8000000P3oool3000000<0oooo1@0000030?ooo`8000000P3oool3000000@0oooo
0`00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003oool00000
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo00000080oooo0`0000060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo00<00000
0?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o
0?ooohd0oooo00040?ooo`8000000P3oool5000000040?ooo`0000000000000000D0oooo0P000002
0?ooo`@00000103oool300000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 .55149 L
.79762 .55947 L
.8125 .57258 L
.82738 .57002 L
.84226 .57018 L
.85714 .58421 L
.87202 .58127 L
.8869 .59136 L
.90179 0 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0903o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3o0?ooobT0oooo00<000000?ooo`3oool0:@3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`3o0?oo
obT0oooo00<000000?ooo`3oool0:@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo0?l0oooo:@3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`3o0?ooobT0oooo00<000000?ooo`3o
ool0KP3oool001@0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo
0?ooo`1^0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo8`3o
ool00`000000oooo0?ooo`1^0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo8`3oool00`000000oooo0?ooo`1^0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo8P3oool00`000000oooo0?ooo`1^0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo8P3oool00`000000oooo0?ooo`1^0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo8@3oool00`000000oooo
0?ooo`1^0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo8@3o
ool00`000000oooo0?ooo`1^0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0o`3ooolP
0?ooo`030000003oool0oooo06h0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3ooolP0?ooo`030000003oool0oooo06h0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030000003oool0oooo06h0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`030000003oool0oooo06l0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`030000003o
ool0oooo06l0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolM
0?ooo`030000003oool0oooo06l0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0o`3ooolM0?ooo`030000003oool0oooo06l0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`3o0?oooad0oooo00<000000?ooo`3oool0K`3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0K`3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0K`3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<00000
0?ooo`3oool0K`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
oa/0oooo00<000000?ooo`3oool0K`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool0K`3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool0K`3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`1_0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`1_
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo6P3oool00`00
0000oooo0?ooo`1_0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
oooo6@3oool00`000000oooo0?ooo`1_0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`1_0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oooaP0oooo00<000000?ooo`3oool0K`3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0?l0oooo5`3oool00`000000oooo0?ooo`1_0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l0o`0007l00`00
0000001o0000O`0P0000Odl0oooo000:0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`000000o`3oool10?ooo`030000003oool0oooo06l0
oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0403oool010000000oooo
0?ooo`3oool3000000d0oooo00<000000?ooo`000000o`3oool10?ooo`030000003oool0oooo06l0
oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3000000<0oooo
0P00000:0?ooo`050000003oool0oooo0?ooo`000000o`3oool00`000000oooo0?ooo`1_0?ooo`00
2P3oool4000000H0oooo00<000000?ooo`3oool06@3oool2000000P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo06l0oooo000D0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0?`0oooo00<000000?ooo`3oool0K`3oool001@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0n`3oool0
0`000000oooo0?ooo`1_0?ooo`00503oool2000001h0oooo0P0000020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0n`3oool00`000000oooo0?ooo`1_0?ooo`00503oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0nP3oool00`000000
oooo0?ooo`1_0?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00P0oooo
0P00003j0?ooo`030000003oool0oooo06l0oooo000D0?ooo`030000003oool0oooo02d0oooo0P00
003h0?ooo`030000003oool0oooo06l0oooo000D0?ooo`030000003oool0oooo02l0oooo0P00003f
0?ooo`030000003oool0oooo06l0oooo000D0?ooo`030000003oool0oooo0340oooo0P00003d0?oo
o`030000003oool0oooo06l0oooo000D0?ooo`030000003oool0oooo03<0oooo0P00003b0?ooo`03
0000003oool0oooo06l0oooo000D0?ooo`800000=P3oool00`000000oooo0?ooo`3_0?ooo`030000
003oool0oooo06l0oooo000D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0k`3o
ool00`000000oooo0?ooo`1_0?ooo`00503oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo0>d0oooo00<000000?ooo`3oool0L03oool001@0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`3/0?ooo`030000003oool0oooo0700oooo000D0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0j`3oool00`000000oooo0?ooo`1`0?ooo`00503oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo0>/0oooo00<000000?ooo`3oool0L03oool001@0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`3Z0?ooo`030000003oool0oooo0700oooo000D
0?ooo`800000>`3oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo0700oooo000D0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0j@3oool00`000000oooo0?ooo`1`0?oo
o`00503oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0>P0oooo00<000000?ooo`3o
ool0L03oool001@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3W0?ooo`030000
003oool0oooo0700oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0i`3o
ool00`000000oooo0?ooo`1`0?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo0>H0oooo00<000000?ooo`3oool0L03oool001@0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`3V0?ooo`030000003oool0oooo0700oooo000D0?ooo`800000?`3oool200000>H0
oooo00<000000?ooo`3oool0L03oool001@0oooo00<000000?ooo`3oool0@03oool200000>@0oooo
00<000000?ooo`3oool0L03oool001@0oooo00<000000?ooo`3oool0@P3oool200000>80oooo00<0
00000?ooo`3oool0L03oool001@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3O
0?ooo`030000003oool0oooo0700oooo000D0?ooo`030000003oool0oooo04D0oooo0P00003O0?oo
o`030000003oool0oooo0700oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo0700oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`1`0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080001o00<000000000O`0007l0100007l3000004T0001o00<000000000O`00
07l0fP0007l00`000000001o0000O`0Q0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04X0oooo0P00003J0?ooo`03
0000003oool0oooo0700oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04`0oooo0P00003H0?ooo`030000003oool0oooo0700
oooo00040?ooo`<000000`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`1`0?ooo`001P3oool00`000000oooo
0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0=@0oooo
00<000000?ooo`3oool0L03oool001@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`3D0?ooo`030000003oool0oooo0700oooo000D0?ooo`030000003oool0oooo0500oooo00<00000
0?ooo`3oool0d`3oool00`000000oooo0?ooo`1`0?ooo`00503oool200000580oooo00<000000?oo
o`3oool0dP3oool00`000000oooo0?ooo`1`0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0=40oooo00<000000?ooo`3oool0L03oool001@0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo0700oooo000D0?ooo`030000003o
ool0oooo05<0oooo1P00003=0?ooo`030000003oool0oooo0700oooo000D0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`1`0?ooo`00503oool00`00
0000oooo0?ooo`1I0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0L03oool001@0
oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0700
oooo000D0?ooo`800000F`3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo0700oooo
000D0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?oo
o`1a0?ooo`00503oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0<L0oooo00<00000
0?ooo`3oool0L@3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo0740oooo000D0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3o
ool0aP3oool00`000000oooo0?ooo`1a0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`030000
003oool0oooo0<H0oooo00<000000?ooo`3oool0L@3oool001@0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`350?ooo`030000003oool0oooo0740oooo000D0?ooo`800000GP3oool2
00000<H0oooo00<000000?ooo`3oool0L@3oool001@0oooo00<000000?ooo`3oool0G`3oool20000
0<@0oooo00<000000?ooo`3oool0L@3oool001@0oooo00<000000?ooo`3oool0H@3oool200000<80
oooo00<000000?ooo`3oool0L@3oool001@0oooo00<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`2o0?ooo`030000003oool0oooo0740oooo000D0?ooo`030000003oool0oooo06@0oooo0P00
002o0?ooo`030000003oool0oooo0740oooo000D0?ooo`030000003oool0oooo06H0oooo00<00000
0?ooo`3oool0_03oool00`000000oooo0?ooo`1a0?ooo`00503oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0L@3oool001@0oooo0P00001Y0?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool0L@3oool001@0oooo00<000000?ooo`3oool0
J03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo0740oooo000D0?ooo`030000003o
ool0oooo06T0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`1a0?ooo`00503oool0
0`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0L@3oool0
01@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo
0740oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0J`3oool00`000000
oooo0?ooo`2g0?ooo`030000003oool0oooo0740oooo00060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0;L0oooo
00<000000?ooo`3oool0L@3oool000H0oooo00<000000?ooo`3oool00P3oool20000O`0300000000
07l0001o00@0001o0`00001/0000O`030000000007l0001o0;H0001o00<000000000O`0007l08P00
07m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0L@3o
ool000H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo06h0oooo0P00
00040?ooo`80000000<0oooo0000003oool0[03oool00`000000oooo0?ooo`1a0?ooo`00103oool3
000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1`0?ooo`040000003oool0
0000000000<0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1a0?ooo`001P3oool0
10000000oooo0?ooo`3oool4000000H0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?oo
o`1a0?ooo`00503oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0V03oool00`000000oooo0?ooo`1a0?ooo`00503oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo00d0oooo0P00002J0?ooo`030000003oool0oooo0740oooo000D0?ooo`80
0000NP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000009T0oooo00<000000?ooo`3o
ool0L@3oool001@0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0000009T0oooo00<000000?ooo`3oool0L@3oool001@0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0000009T0oooo00<000000?ooo`3oool0L@3o
ool001@0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0
oooo000009T0oooo00<000000?ooo`3oool0L@3oool001@0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000V03oool00`000000oooo0?oo
o`1a0?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00T0oooo00D00000
0?ooo`3oool0oooo0000002H0?ooo`030000003oool0oooo0740oooo000D0?ooo`030000003oool0
oooo07d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo09D0oooo00<000000?ooo`3oool0LP3oool001@0oooo0P00001o0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo
0780oooo000D0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0LP3oool001@0oooo
00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0780oooo
000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00X0oooo0P0000280?ooo`030000003oool0oooo0780oooo000D
0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000R03oool00`000000oooo0?ooo`1b
0?ooo`00503oool00`000000oooo0?ooo`210?ooo`8000000`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000Q`3oool00`000000oooo0?ooo`1b
0?ooo`00503oool00`000000oooo0?ooo`230?ooo`<00000203oool00`000000oooo0?ooo`080?oo
o`040000003oool0oooo000008L0oooo00<000000?ooo`3oool0LP3oool001@0oooo0P0000260?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0
000008H0oooo00<000000?ooo`3oool0LP3oool001@0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0Q03oool00`00
0000oooo0?ooo`1b0?ooo`00503oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0780
oooo000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0LP3oool001@0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0PP3oool00`000000oooo0?ooo`1b0?ooo`00503oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`22
0?ooo`030000003oool0oooo0780oooo000D0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`1b0?ooo`00503oool200000980oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`1b0?ooo`00503oool00`000000oooo0?ooo`2B0?ooo`050000
003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000007T0
oooo00<000000?ooo`3oool0LP3oool001@0oooo00<000000?ooo`3oool0TP3oool01@000000oooo
0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000001i0?ooo`03
0000003oool0oooo0780oooo000D0?ooo`030000003oool0oooo09<0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000007T0oooo00<000000?ooo`3o
ool0LP3oool001@0oooo00<000000?ooo`3oool0U03oool2000000/0oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool0000007P0oooo00<000000?ooo`3oool0LP3oool000@0oooo
100000030?ooo`8000001`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000007P0oooo00<000000?ooo`3o
ool0LP3oool000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo0:80oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
07P0oooo00<000000?ooo`3oool0LP3oool000D0oooo00<000000?ooo`3oool00P3oool010000000
001o0000O`0000060000O`<00000XP0007l01@000000001o0000O`0007l0000000D0001o00<00000
0000O`0007l0M@0007l00`000000001o0000O`0S0000Odl0oooo00060?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:80oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0LP3o
ool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0:<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1e0?ooo`030000
003oool0oooo0780oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`1b0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000
003oool0oooo0:<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0780oooo000D0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0780oooo000D0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo0780oooo000D0?ooo`800000Y@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool0LP3oool001@0oooo00<000000?ooo`3oool0[`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0LP3oool001@0oooo
00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`050?ooo`030000003oool0000006X0oooo
00<000000?ooo`3oool0LP3oool001@0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?oo
o`040?ooo`030000003oool0000006X0oooo00<000000?ooo`3oool0LP3oool001@0oooo00<00000
0?ooo`3oool0/03oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000J@3o
ool00`000000oooo0?ooo`1b0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0
oooo07<0oooo000D0?ooo`030000003oool0oooo0;40oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0L`3oool001@0oooo00<000000?oo
o`3oool0/P3oool00`000000oooo000000070?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0L`3oool001@0oooo0P00002c0?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo07<0oooo000D0?ooo`030000
003oool0oooo0;<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0000005X0oooo00<000000?ooo`3oool0L`3oool001@0oooo00<000000?ooo`3oool0_P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0L`3o
ool001@0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`000000F@3oool00`000000oooo0?ooo`1c0?ooo`00503oool00`000000oooo0?ooo`30
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo07<0oooo000D0?ooo`030000003oool0oooo0<00oooo00@000000?ooo`3oool000001`3o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo07<0oooo000D0?ooo`030000003oool0
oooo0<40oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo07<0oooo000D0?ooo`800000``3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool0L`3oool001@0oooo00<000000?ooo`3oool0c@3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo07<0oooo000D0?ooo`030000003oool0oooo0<d0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1c0?ooo`00503oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0L`3oool001@0oooo00<00000
0?ooo`3oool0cP3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo07<0oooo000D0?oo
o`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1c0?oo
o`00503oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool0L`3oool001@0oooo0P00003A0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
L`3oool001@0oooo00<000000?ooo`3oool0d03oool010000000oooo0?ooo`3oool9000004H0oooo
00<000000?ooo`3oool0L`3oool001@0oooo00<000000?ooo`3oool0d@3oool3000000T0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`1c0?ooo`00503oool00`000000oooo0?ooo`3N
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1c
0?ooo`00503oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo00`0oooo0`00000b0?oo
o`030000003oool0oooo07<0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3o
ool0g`3oool00`000000oooo0?ooo`0:0?ooo`8000000`3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo07<0oooo00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo00L0oooo0P0000050?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0L`3oool000D0oooo00<000000?ooo`3oool00`3o
ool20000O`030000000007l0001o00@0001o0`00003Q0000O`<00000100007l2000000P0001o00<0
00000000O`0007l0;P0007l00`000000001o0000O`0T0000Odl0oooo00060?ooo`040000003oool0
oooo0?ooo`<000001`3oool00`000000oooo0?ooo`3T0?ooo`@000002P3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo07<0oooo00070?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool0l`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo07<0oooo0004
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`3c0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0L`3oool000D0oooo0P000003
0?ooo`@000001P3oool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0L`3oool001@0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo07<0oooo000D0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3o
ool00P3oool2000002P0oooo00<000000?ooo`3oool0L`3oool001@0oooo0P00003f0?ooo`040000
003oool0000000000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1c0?ooo`00
503oool00`000000oooo0?ooo`3e0?ooo`8000001@3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo07<0oooo000D0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1c0?ooo`00503oool00`000000oooo0?ooo`3m0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0M03oool001@0oooo00<000000?ooo`3oool0oP3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo07@0oooo000D0?ooo`030000003oool0oooo0?l0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1d0?ooo`00503oool00`000000oooo
0?ooo`3o0?ooo`40oooo0P00000P0?ooo`030000003oool0oooo07@0oooo000D0?ooo`800000o`3o
ool40?ooo`8000007P3oool00`000000oooo0?ooo`1d0?ooo`00503oool00`000000oooo0?ooo`3o
0?ooo`D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1d0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1d0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooo`L0oooo0P00000J0?ooo`030000003oool0oooo07@0
oooo000D0?ooo`030000003oool0oooo0?l0oooo2@3oool010000000oooo0?ooo`3oool8000000h0
oooo00<000000?ooo`3oool0M03oool001@0oooo00<000000?ooo`3oool0o`3oool:0?ooo`<00000
203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07@0oooo000D0?ooo`030000003o
ool0oooo0?l0oooo5P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo07@0oooo000D
0?ooo`800000o`3ooolH0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0M03oool0
01@0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`040000003oool0oooo0?ooo`<00000103oool0
0`000000oooo0?ooo`1d0?ooo`00503oool00`000000oooo0?ooo`3o0?oooaT0oooo0`0000030?oo
o`050000003oool0oooo0?ooo`000000MP3oool001@0oooo00<000000?ooo`3oool0o`3ooolP0?oo
o`80000000<0oooo0000003oool0M@3oool001@0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`80
0000MP3oool001@0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`030000003oool0oooo07@0oooo
000D0?ooo`030000003oool0oooo0?l0ooooVP3oool001@0oooo0P00003o0?oooi/0oooo000D0?oo
o`030000003oool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00
503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3o
ool000D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00070?ooo`040000003oool0oooo00000080001o00<000000000O`0007l01000
07l300000?l0001oB`0007m?0?ooo`001@3oool2000000<0oooo00@000000?ooo`3oool00000o`3o
oonS0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooX@3o
ool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00003o0?oooj<0oooo
00050?ooo`800000103oool200000?l0ooooY03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool000@0
oooo0P0000020?ooo`<000000`3oool5000000<0oooo0P0000020?ooo`<00000103oool300000?l0
ooooS@3oool000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo00000?l0ooooS03oool000<0oooo00@000000?ooo`00000000000P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0P3oool3000000H0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`000`3oool00`000000oooo0?oo
o`030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000`3oool200000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooS@3o
ool000@0oooo0P0000020?ooo`D0000000@0oooo00000000000000001@3oool200000080oooo1000
00040?ooo`<00000o`3ooon<0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 .55149 L
.79762 .55947 L
.8125 .57258 L
.82738 .57002 L
.84226 .57018 L
.85714 .58421 L
.87202 .58127 L
.8869 .59136 L
.90179 .60053 L
.91667 0 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D000000?ooo`000000oooo
000000030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<000001@3oool001@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0903oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0
000000X0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo000D0?ooo`030000003oool0oooo0?l0oooo;P3oool0
0`000000oooo0?ooo`0T0?ooo`80000000<0oooo0000000000000`3oool2000000<0oooo10000002
0?ooo`030000003oool00000008000000P3oool200000080oooo0P0000000`3oool0000000000008
0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`@000000`3oool2000000D0oooo000D0?oo
o`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0T0?ooo`050000003oool0oooo
0?ooo`0000002@3oool00`000000oooo0?ooo`0K0?ooo`<000005P3oool001@0oooo00<000000?oo
o`3oool0o`3oool^0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo000D0?ooo`030000003oool0oooo0?l0
oooo;P3oool00`000000oooo0?ooo`1Y0?ooo`00503oool2000000<0oooo00<000000?ooo`3oool0
o`3ooolY0?ooo`030000003oool0oooo06T0oooo000D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0o`3ooolX0?ooo`030000003oool0oooo06T0oooo000D0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`030000003oool0oooo06T0oooo000D0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo
06T0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`03
0000003oool0oooo06T0oooo000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
o`3ooolV0?ooo`030000003oool0oooo06T0oooo000D0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0o`3ooolV0?ooo`030000003oool0oooo06T0oooo000D0?ooo`8000001`3oool0
0`000000oooo0?ooo`3o0?ooobD0oooo00<000000?ooo`3oool0J@3oool001@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3o0?ooobD0oooo00<000000?ooo`3oool0J@3oool001@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3o
ool0J@3oool001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooob@0oooo
00<000000?ooo`3oool0J@3oool001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`3o0?ooob@0oooo00<000000?ooo`3oool0J@3oool001@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`3o0?ooob<0oooo00<000000?ooo`3oool0J@3oool001@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`3o0?ooob<0oooo00<000000?ooo`3oool0J@3oool001@0
oooo0P0000090?ooo`030000003oool0oooo0?l0oooo8P3oool00`000000oooo0?ooo`1Z0?ooo`00
503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo8@3oool00`000000oooo
0?ooo`1Z0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo8@3o
ool00`000000oooo0?ooo`1Z0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0?l0oooo8@3oool00`000000oooo0?ooo`1Z0?ooo`00503oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0?l0oooo803oool00`000000oooo0?ooo`1Z0?ooo`00503oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo803oool00`000000oooo0?ooo`1Z0?ooo`00
503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo803oool00`000000oooo
0?ooo`1Z0?ooo`00503oool2000000`0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030000003o
ool0oooo06X0oooo000D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooolO
0?ooo`030000003oool0oooo06X0oooo000D0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0o`3ooolO0?ooo`030000003oool0oooo06X0oooo000D0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0o`3ooolN0?ooo`030000003oool0oooo06X0oooo000D0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`030000003oool0oooo06X0oooo
000:0?ooo`<000001`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo7@3o
ool00`000000oooo0?ooo`1Z0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo06X0oooo000;0?oo
o`80001o00<000000000O`0007l0100007l3000000l0001o00<000000000O`0007l04`0007l00`00
0000001o0000O`3o0000O`D0001o00<000000000O`0007l06`0007m?0?ooo`002P3oool3000000L0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool000000?l0
oooo1P3oool00`000000oooo0?ooo`1Z0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0100oooo00@000000?ooo`3oool0oooo0`00000=0?ooo`030000003oool000000?l0
oooo1P3oool00`000000oooo0?ooo`1Z0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0140oooo0`0000030?ooo`8000002P3oool01@000000oooo0?ooo`3oool000000?l0
oooo1@3oool00`000000oooo0?ooo`1Z0?ooo`002P3oool4000000H0oooo00<000000?ooo`3oool0
6@3oool2000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`80oooo
00<000000?ooo`3oool0JP3oool001@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool20?ooo`030000003o
ool0oooo06X0oooo000D0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`1Z
0?ooo`00503oool2000001h0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0o`3oool10?ooo`030000003oool0oooo06X0oooo000D0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo06X0
oooo000D0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool200000?l0oooo
00<000000?ooo`3oool0JP3oool001@0oooo00<000000?ooo`3oool0;@3oool200000?d0oooo00<0
00000?ooo`3oool0JP3oool001@0oooo00<000000?ooo`3oool0;`3oool200000?/0oooo00<00000
0?ooo`3oool0JP3oool001@0oooo00<000000?ooo`3oool0<@3oool200000?T0oooo00<000000?oo
o`3oool0JP3oool001@0oooo00<000000?ooo`3oool0<`3oool200000?L0oooo00<000000?ooo`3o
ool0JP3oool001@0oooo0P00000f0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool0
JP3oool001@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3d0?ooo`030000003o
ool0oooo06X0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0l`3oool0
0`000000oooo0?ooo`1Z0?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0?80oooo00<000000?ooo`3oool0JP3oool001@0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`3a0?ooo`030000003oool0oooo06X0oooo000D0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`1Z0?ooo`00503oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo0?00oooo00<000000?ooo`3oool0JP3oool001@0oooo0P00000k
0?ooo`030000003oool0oooo0>l0oooo00<000000?ooo`3oool0JP3oool001@0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`3_0?ooo`030000003oool0oooo06X0oooo000D0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0kP3oool00`000000oooo0?ooo`1Z0?ooo`00
503oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0>d0oooo00<000000?ooo`3oool0
JP3oool001@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3]0?ooo`030000003o
ool0oooo06X0oooo000D0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0k03oool0
0`000000oooo0?ooo`1Z0?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
0>/0oooo00<000000?ooo`3oool0J`3oool001@0oooo0P00000o0?ooo`800000j`3oool00`000000
oooo0?ooo`1[0?ooo`00503oool00`000000oooo0?ooo`100?ooo`800000j@3oool00`000000oooo
0?ooo`1[0?ooo`00503oool00`000000oooo0?ooo`120?ooo`800000i`3oool00`000000oooo0?oo
o`1[0?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0>@0oooo00<00000
0?ooo`3oool0J`3oool001@0oooo00<000000?ooo`3oool0A@3oool200000>@0oooo00<000000?oo
o`3oool0J`3oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0>40oooo00<000000?ooo`3oool0J`3oool000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`3P0?ooo`030000003oool0oooo06/0oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P0007l00`000000001o0000O`040000O`<00000B@0007l00`000000001o0000O`3O0000O`03
0000000007l0001o01`0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0BP3oool200000=l0oooo00<000000?ooo`3o
ool0J`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0C03oool200000=d0oooo00<000000?ooo`3oool0J`3oool000@0oooo
0`0000030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`3J0?ooo`030000003oool0oooo06/0oooo00060?ooo`030000003oool0oooo0080oooo
0P0000070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0f@3oool00`000000oooo
0?ooo`1[0?ooo`00503oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0=T0oooo00<0
00000?ooo`3oool0J`3oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`3H
0?ooo`030000003oool0oooo06/0oooo000D0?ooo`800000DP3oool00`000000oooo0?ooo`3G0?oo
o`030000003oool0oooo06/0oooo000D0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0eP3oool00`000000oooo0?ooo`1[0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo0=H0oooo00<000000?ooo`3oool0J`3oool001@0oooo00<000000?ooo`3oool0D`3o
ool600000=80oooo00<000000?ooo`3oool0J`3oool001@0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo06/0oooo000D0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`1[0?ooo`00503oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0J`3oool001@0oooo
0P00001K0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0J`3oool001@0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo06/0oooo000D
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`1[
0?ooo`00503oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0<d0oooo00<000000?oo
o`3oool0J`3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3<0?ooo`03
0000003oool0oooo06/0oooo000D0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
c03oool00`000000oooo0?ooo`1[0?ooo`00503oool00`000000oooo0?ooo`1M0?ooo`030000003o
ool0oooo0</0oooo00<000000?ooo`3oool0J`3oool001@0oooo0P00001N0?ooo`800000c03oool0
0`000000oooo0?ooo`1[0?ooo`00503oool00`000000oooo0?ooo`1O0?ooo`800000bP3oool00`00
0000oooo0?ooo`1[0?ooo`00503oool00`000000oooo0?ooo`1Q0?ooo`800000b03oool00`000000
oooo0?ooo`1[0?ooo`00503oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0<D0oooo
00<000000?ooo`3oool0J`3oool001@0oooo00<000000?ooo`3oool0I03oool200000<D0oooo00<0
00000?ooo`3oool0J`3oool001@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`32
0?ooo`030000003oool0oooo06/0oooo000D0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`1[0?ooo`00503oool2000006T0oooo00<000000?ooo`3o
ool0`03oool00`000000oooo0?ooo`1[0?ooo`00503oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo0<00oooo00<000000?ooo`3oool0J`3oool001@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo06/0oooo000D0?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`1[0?ooo`00503oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0J`3oool000@0
oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0;`0
oooo00<000000?ooo`3oool0K03oool000H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0_03oool00`000000oooo
0?ooo`1/0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<000000000O`0007l01000
07l3000006`0001o00<000000000O`0007l0^`0007l00`000000001o0000O`0M0000Odl0oooo0006
0?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`1/0?ooo`001P3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0KP3oool2000000@0oooo0P00
00000`3oool000000?ooo`2a0?ooo`030000003oool0oooo06`0oooo00040?ooo`<000000`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0700oooo00@000000?ooo`00000000000`3o
ool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo06`0oooo00060?ooo`040000003oool0
oooo0?ooo`@000001P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo06`0oooo000D
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2M
0?ooo`030000003oool0oooo06`0oooo000D0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool03@3oool2000009l0oooo00<000000?ooo`3oool0K03oool001@0oooo0P00001j0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`000000WP3oool00`000000oooo0?ooo`1/0?ooo`00
503oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
WP3oool00`000000oooo0?ooo`1/0?ooo`00503oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`000000WP3oool00`000000oooo0?ooo`1/0?ooo`00503oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000WP3o
ool00`000000oooo0?ooo`1/0?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo00T0oooo00D000000?ooo`3oool0oooo0000002M0?ooo`030000003oool0oooo06`0oooo000D
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3o
ool0000009d0oooo00<000000?ooo`3oool0K03oool001@0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0V`3oool0
0`000000oooo0?ooo`1/0?ooo`00503oool2000007l0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0K03oool001@0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`1/0?ooo`00503oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0K03oool001@0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02P3oool2000008h0oooo00<000000?ooo`3oool0K03oool001@0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0000002>0?ooo`030000003oool0oooo06`0oooo000D0?oo
o`030000003oool0oooo0840oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`00002=0?ooo`030000003oool0oooo06`0oooo000D0?oo
o`030000003oool0oooo08<0oooo0`0000080?ooo`030000003oool0oooo00P0oooo00@000000?oo
o`3oool00000S@3oool00`000000oooo0?ooo`1/0?ooo`00503oool2000008H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000S03oool0
0`000000oooo0?ooo`1/0?ooo`00503oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo
06`0oooo000D0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0K03oool001@0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`1/0?ooo`00503oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`280?ooo`030000003oool0oooo06`0oooo000D0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool0K03oool001@0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo06`0oooo000D0?ooo`800000TP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo06`0oooo000D0?ooo`030000003oool0oooo0980oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000O`3oool00`000000
oooo0?ooo`1/0?ooo`00503oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo0?ooo`00
00002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000007l0oooo00<000000?ooo`3o
ool0K03oool001@0oooo00<000000?ooo`3oool0T`3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`000000O`3oool00`000000oooo0?ooo`1/0?ooo`00
503oool00`000000oooo0?ooo`2D0?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`000000OP3oool00`000000oooo0?ooo`1/0?ooo`00103oool4000000<0oooo
0P0000070?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000OP3oool00`000000oooo0?ooo`1/0?ooo`00
103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0XP3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000OP3oool00`00
0000oooo0?ooo`1/0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000000007l0001o0000
00H0001o0`00002R0000O`050000000007l0001o0000O`0000001@0007l00`000000001o0000O`1k
0000O`030000000007l0001o01d0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0XP3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1/0?ooo`001`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0X`3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
K03oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo0:<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`1j0?ooo`03
0000003oool0oooo06`0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0
X`3oool00`000000oooo000000070?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
K@3oool001@0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0K@3oool001@0oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0K@3oool0
01@0oooo0P00002U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`1]0?ooo`00503oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1]0?ooo`00503oool00`000000oooo
0?ooo`2_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000K`3oool00`000000oooo
0?ooo`1]0?ooo`00503oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`000000K`3oool00`000000oooo0?ooo`1]0?ooo`00503oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000001^0?ooo`030000003o
ool0oooo06d0oooo000D0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0K@3oool0
01@0oooo00<000000?ooo`3oool0/@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`3oool0J`3oool00`000000oooo0?ooo`1]0?ooo`00503oool00`000000oooo0?ooo`2b0?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1]0?oo
o`00503oool200000;<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo05l0oooo00<000000?ooo`3oool0K@3oool001@0oooo00<000000?ooo`3oool0
/`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
H03oool00`000000oooo0?ooo`1]0?ooo`00503oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`000000H03oool00`000000oooo0?ooo`1]0?ooo`00503oool0
0`000000oooo0?ooo`2o0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
001O0?ooo`030000003oool0oooo06d0oooo000D0?ooo`030000003oool0oooo0<00oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0K@3o
ool001@0oooo00<000000?ooo`3oool0`03oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0K@3oool001@0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo000000070?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0K@3oool0
01@0oooo0P0000330?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`1]0?ooo`00503oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo05T0
oooo00<000000?ooo`3oool0K@3oool001@0oooo00<000000?ooo`3oool0c@3oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo06d0oooo000D0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`1]0?ooo`00503oool00`000000oooo0?ooo`3>
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0K@3oool001@0oooo00<000000?oo
o`3oool0c`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo06d0oooo000D0?ooo`03
0000003oool0oooo0<l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1]0?ooo`00
503oool200000=40oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1]0?ooo`00503o
ool00`000000oooo0?ooo`3@0?ooo`040000003oool0oooo0?ooo`T00000C03oool00`000000oooo
0?ooo`1]0?ooo`00503oool00`000000oooo0?ooo`3A0?ooo`<000002@3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo06d0oooo000D0?ooo`030000003oool0oooo0=h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo06d0oooo000D0?oo
o`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0303oool3000003P0oooo00<000000?oo
o`3oool0K@3oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3O0?ooo`03
0000003oool0oooo00X0oooo0P0000030?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0K@3oool000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0>00oooo00<000000?ooo`3oool01`3oool2000000D0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`1]0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`80001o00<0
00000000O`0007l0100007l300000>40001o0`0000040000O`800000200007l00`000000001o0000
O`0d0000O`030000000007l0001o01h0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`00
00070?ooo`030000003oool0oooo0>@0oooo1000000:0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0K@3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`3c0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0K@3oool000@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?<0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`1]0?ooo`001@3oool2000000<0oooo10000006
0?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1]
0?ooo`00503oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0K@3oool001@0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`020?ooo`80
0000;P3oool00`000000oooo0?ooo`1]0?ooo`00503oool200000?H0oooo00@000000?ooo`000000
00000P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo06d0oooo000D0?ooo`030000
003oool0oooo0?D0oooo0P0000050?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
K@3oool001@0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo06h0oooo000D0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`1^0?ooo`00503oool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0KP3oool001@0oooo00<000000?ooo`3oool0o`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo06h0oooo000D0?ooo`030000003oool0oooo0?l0oooo
0@3oool2000002H0oooo00<000000?ooo`3oool0KP3oool001@0oooo0P00003o0?ooo`@0oooo0P00
000T0?ooo`030000003oool0oooo06h0oooo000D0?ooo`030000003oool0oooo0?l0oooo1@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06h0oooo000D0?ooo`030000003oool0oooo
0?l0oooo1P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06h0oooo000D0?ooo`03
0000003oool0oooo0?l0oooo1`3oool200000200oooo00<000000?ooo`3oool0KP3oool001@0oooo
00<000000?ooo`3oool0o`3oool90?ooo`040000003oool0oooo0?ooo`P00000503oool00`000000
oooo0?ooo`1^0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo0`0000080?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0KP3oool001@0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0KP3oool001@0oooo0P00003o
0?oooaP0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1^0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooaP0oooo00@000000?ooo`3oool0oooo0`00000:0?ooo`030000003oool0
oooo06h0oooo000D0?ooo`030000003oool0oooo0?l0oooo6@3oool3000000<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`1^0?ooo`00503oool00`000000oooo0?ooo`3o0?ooob00
oooo0P0000070?ooo`030000003oool0oooo06h0oooo000D0?ooo`030000003oool0oooo0?l0oooo
8P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06h0oooo000D0?ooo`030000003o
ool0oooo0?l0oooo8`3oool2000000@0oooo00<000000?ooo`3oool0KP3oool001@0oooo00<00000
0?ooo`3oool0o`3ooolU0?ooo`8000000P3oool00`000000oooo0?ooo`1^0?ooo`00503oool20000
0?l0oooo:03oool300000700oooo000D0?ooo`030000003oool0oooo0?l0oooo:@3oool00`000000
oooo0?ooo`1^0?ooo`00503oool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003o
ool0oooo0?l0ooooVP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`001@3oool20000
00@0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooVP3oool000@0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooVP3oool0
00L0oooo00@000000?ooo`3oool000000P0007l00`000000001o0000O`040000O`<00000o`0007m;
0000Odl0oooo00050?ooo`8000000`3oool010000000oooo0?ooo`00003o0?oooj<0oooo00070?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`00103oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0ooooX`3oool000D0oooo0P000004
0?ooo`800000o`3ooonT0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00103oool200000080oooo
0`0000030?ooo`D000000`3oool200000080oooo0`0000040?ooo`<00000o`3ooon=0?ooo`000`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool00000o`3ooon<0?ooo`000`3oool010000000oooo0000000000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`<000001P3o
ool00`000000oooo0?ooo`3o0?ooohX0oooo00030?ooo`030000003oool0oooo00<0oooo0`000003
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000030?ooo`800000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooon=0?ooo`00103oool20000
0080oooo1@000000103oool000000000000000050?ooo`8000000P3oool4000000@0oooo0`00003o
0?oooh`0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 .55149 L
.79762 .55947 L
.8125 .57258 L
.82738 .57002 L
.84226 .57018 L
.85714 .58421 L
.87202 .58127 L
.8869 .59136 L
.90179 .60053 L
.91667 .60061 L
.93155 0 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07`3o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01l0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3o0?oooc<0oooo00<000000?ooo`3oool07`3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oc<0oooo00<000000?ooo`3oool07`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo0?l0oooo<`3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`3o0?oooc<0oooo00<000000?ooo`3o
ool0I03oool001@0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo
0?ooo`1T0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo;@3o
ool00`000000oooo0?ooo`1T0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo;@3oool00`000000oooo0?ooo`1T0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo;03oool00`000000oooo0?ooo`1T0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo;03oool00`000000oooo0?ooo`1T0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo
0?ooo`1T0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo:`3o
ool00`000000oooo0?ooo`1T0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0o`3ooolZ
0?ooo`030000003oool0oooo06@0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3ooolZ0?ooo`030000003oool0oooo06@0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030000003oool0oooo06@0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030000003oool0oooo06@0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030000003o
ool0oooo06@0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolX
0?ooo`030000003oool0oooo06@0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0o`3ooolX0?ooo`030000003oool0oooo06@0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0I@3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool0I@3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool0I@3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<00000
0?ooo`3oool0I@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
obD0oooo00<000000?ooo`3oool0I@3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?ooobD0oooo00<000000?ooo`3oool0I@3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3o0?ooobD0oooo00<000000?ooo`3oool0I@3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`1U0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`1U
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo903oool00`00
0000oooo0?ooo`1U0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
oooo8`3oool00`000000oooo0?ooo`1U0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0?l0oooo8`3oool00`000000oooo0?ooo`1U0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooob80oooo00<000000?ooo`3oool0I@3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0?l0oooo8@3oool00`000000oooo0?ooo`1U0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l0o`0007l:0000
O`030000000007l0001o01H0001oC`3oool000X0oooo0`0000070?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0000003o0?ooo`/0oooo00<000000?ooo`3o
ool0I@3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`040000
003oool0oooo0?ooo`<000003@3oool00`000000oooo0000003o0?ooo`/0oooo00<000000?ooo`3o
ool0I@3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<00000
0`3oool2000000X0oooo00D000000?ooo`3oool0oooo0000003o0?ooo`X0oooo00<000000?ooo`3o
ool0I@3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool70?ooo`030000003oool0oooo06D0oooo
000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?l0oooo1`3oool00`000000oooo0?ooo`1U0?ooo`00503oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0I@3oool001@0oooo0P00000N0?oo
o`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo1P3oool00`00
0000oooo0?ooo`1U0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo06D0oooo000D0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0203oool200000?l0oooo1@3oool00`000000oooo
0?ooo`1U0?ooo`00503oool00`000000oooo0?ooo`0]0?ooo`800000o`3oool30?ooo`030000003o
ool0oooo06D0oooo000D0?ooo`030000003oool0oooo02l0oooo0P00003o0?ooo`40oooo00<00000
0?ooo`3oool0I@3oool001@0oooo00<000000?ooo`3oool0<@3oool200000?h0oooo00<000000?oo
o`3oool0I@3oool001@0oooo00<000000?ooo`3oool0<`3oool200000?`0oooo00<000000?ooo`3o
ool0I@3oool001@0oooo0P00000f0?ooo`030000003oool0oooo0?T0oooo00<000000?ooo`3oool0
I@3oool001@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3i0?ooo`030000003o
ool0oooo06D0oooo000D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0n03oool0
0`000000oooo0?ooo`1U0?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0?L0oooo00<000000?ooo`3oool0I@3oool001@0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`3f0?ooo`030000003oool0oooo06D0oooo000D0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`1U0?ooo`00503oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo0?D0oooo00<000000?ooo`3oool0I@3oool001@0oooo0P00000k
0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool0I@3oool001@0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo06D0oooo000D0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`1U0?ooo`00
503oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0
I@3oool001@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3b0?ooo`030000003o
ool0oooo06D0oooo000D0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0l@3oool0
0`000000oooo0?ooo`1U0?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
0?00oooo00<000000?ooo`3oool0IP3oool001@0oooo0P00000o0?ooo`800000l03oool00`000000
oooo0?ooo`1V0?ooo`00503oool00`000000oooo0?ooo`100?ooo`800000kP3oool00`000000oooo
0?ooo`1V0?ooo`00503oool00`000000oooo0?ooo`120?ooo`800000k03oool00`000000oooo0?oo
o`1V0?ooo`00503oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0>T0oooo00<00000
0?ooo`3oool0IP3oool001@0oooo00<000000?ooo`3oool0A@3oool200000>T0oooo00<000000?oo
o`3oool0IP3oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0>H0oooo00<000000?ooo`3oool0IP3oool000H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`3U0?ooo`030000003oool0oooo06H0oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P0007l00`000000001o0000O`040000O`<00000B@0007l00`000000001o0000O`3T0000O`03
0000000007l0001o01L0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0BP3oool200000>@0oooo00<000000?ooo`3o
ool0IP3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0C03oool200000>80oooo00<000000?ooo`3oool0IP3oool000@0oooo
0`0000030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`3O0?ooo`030000003oool0oooo06H0oooo00060?ooo`030000003oool0oooo0080oooo
0P0000070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0gP3oool00`000000oooo
0?ooo`1V0?ooo`00503oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0=h0oooo00<0
00000?ooo`3oool0IP3oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`3M
0?ooo`030000003oool0oooo06H0oooo000D0?ooo`800000DP3oool00`000000oooo0?ooo`3L0?oo
o`030000003oool0oooo06H0oooo000D0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0f`3oool00`000000oooo0?ooo`1V0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo0=/0oooo00<000000?ooo`3oool0IP3oool001@0oooo00<000000?ooo`3oool0D`3o
ool600000=L0oooo00<000000?ooo`3oool0IP3oool001@0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`3E0?ooo`030000003oool0oooo06H0oooo000D0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`1V0?ooo`00503oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool0IP3oool001@0oooo
0P00001K0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0IP3oool001@0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo06H0oooo000D
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`1V
0?ooo`00503oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0=80oooo00<000000?oo
o`3oool0IP3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3A0?ooo`03
0000003oool0oooo06H0oooo000D0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
d@3oool00`000000oooo0?ooo`1V0?ooo`00503oool00`000000oooo0?ooo`1M0?ooo`030000003o
ool0oooo0=00oooo00<000000?ooo`3oool0IP3oool001@0oooo0P00001N0?ooo`800000d@3oool0
0`000000oooo0?ooo`1V0?ooo`00503oool00`000000oooo0?ooo`1O0?ooo`800000c`3oool00`00
0000oooo0?ooo`1V0?ooo`00503oool00`000000oooo0?ooo`1Q0?ooo`800000c@3oool00`000000
oooo0?ooo`1V0?ooo`00503oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0<X0oooo
00<000000?ooo`3oool0IP3oool001@0oooo00<000000?ooo`3oool0I03oool200000<X0oooo00<0
00000?ooo`3oool0IP3oool001@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`37
0?ooo`030000003oool0oooo06H0oooo000D0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0aP3oool00`000000oooo0?ooo`1V0?ooo`00503oool2000006T0oooo00<000000?ooo`3o
ool0a@3oool00`000000oooo0?ooo`1V0?ooo`00503oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo0<D0oooo00<000000?ooo`3oool0IP3oool001@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`340?ooo`030000003oool0oooo06H0oooo000D0?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`1V0?ooo`00503oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0IP3oool000@0
oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0<40
oooo00<000000?ooo`3oool0I`3oool000H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0`@3oool00`000000oooo
0?ooo`1W0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`80001o00<000000000O`0007l01000
07l3000006`0001o00<000000000O`0007l0`00007l00`000000001o0000O`0H0000Odl0oooo0006
0?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`1W0?ooo`001P3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0KP3oool2000000@0oooo0P00
00000`3oool000000?ooo`2f0?ooo`030000003oool0oooo06L0oooo00040?ooo`<000000`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0700oooo00@000000?ooo`00000000000`3o
ool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo06L0oooo00060?ooo`040000003oool0
oooo0?ooo`@000001P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo06L0oooo000D
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2R
0?ooo`030000003oool0oooo06L0oooo000D0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool03@3oool200000:@0oooo00<000000?ooo`3oool0I`3oool001@0oooo0P00001j0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`000000X`3oool00`000000oooo0?ooo`1W0?ooo`00
503oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
X`3oool00`000000oooo0?ooo`1W0?ooo`00503oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`000000X`3oool00`000000oooo0?ooo`1W0?ooo`00503oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000X`3o
ool00`000000oooo0?ooo`1W0?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo00T0oooo00D000000?ooo`3oool0oooo0000002R0?ooo`030000003oool0oooo06L0oooo000D
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3o
ool000000:80oooo00<000000?ooo`3oool0I`3oool001@0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0X03oool0
0`000000oooo0?ooo`1W0?ooo`00503oool2000007l0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0I`3oool001@0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`1W0?ooo`00503oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0I`3oool001@0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02P3oool2000009<0oooo00<000000?ooo`3oool0I`3oool001@0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0000002C0?ooo`030000003oool0oooo06L0oooo000D0?oo
o`030000003oool0oooo0840oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`00002B0?ooo`030000003oool0oooo06L0oooo000D0?oo
o`030000003oool0oooo08<0oooo0`0000080?ooo`030000003oool0oooo00P0oooo00@000000?oo
o`3oool00000TP3oool00`000000oooo0?ooo`1W0?ooo`00503oool2000008H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000T@3oool0
0`000000oooo0?ooo`1W0?ooo`00503oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
06L0oooo000D0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0I`3oool001@0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`1W0?ooo`00503oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo06L0oooo000D0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0I`3oool001@0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`230?oo
o`030000003oool0oooo06L0oooo000D0?ooo`800000TP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`230?ooo`03
0000003oool0oooo06L0oooo000D0?ooo`030000003oool0oooo0980oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000Q03oool00`000000
oooo0?ooo`1W0?ooo`00503oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo0?ooo`00
00002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000008@0oooo00<000000?ooo`3o
ool0I`3oool001@0oooo00<000000?ooo`3oool0T`3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`000000Q03oool00`000000oooo0?ooo`1W0?ooo`00
503oool00`000000oooo0?ooo`2D0?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`000000P`3oool00`000000oooo0?ooo`1W0?ooo`00103oool4000000<0oooo
0P0000070?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000P`3oool00`000000oooo0?ooo`1W0?ooo`00
103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0XP3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000P`3oool00`00
0000oooo0?ooo`1W0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000000007l0001o0000
00H0001o0`00002R0000O`050000000007l0001o0000O`0000001@0007l00`000000001o0000O`20
0000O`030000000007l0001o01P0001oC`3oool000H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0XP3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`1W0?ooo`001`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0X`3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0
I`3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo0:<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`1o0?ooo`03
0000003oool0oooo06L0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0
X`3oool00`000000oooo000000070?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
J03oool001@0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0J03oool001@0oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0J03oool0
01@0oooo0P00002U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0O@3oool00`00
0000oooo0?ooo`1X0?ooo`00503oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1X0?ooo`00503oool00`000000oooo
0?ooo`2_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000M03oool00`000000oooo
0?ooo`1X0?ooo`00503oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`000000M03oool00`000000oooo0?ooo`1X0?ooo`00503oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000001c0?ooo`030000003o
ool0oooo06P0oooo000D0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0J03oool0
01@0oooo00<000000?ooo`3oool0/@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`1X0?ooo`00503oool00`000000oooo0?ooo`2b0?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1X0?oo
o`00503oool200000;<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool0J03oool001@0oooo00<000000?ooo`3oool0
/`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
I@3oool00`000000oooo0?ooo`1X0?ooo`00503oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`000000I@3oool00`000000oooo0?ooo`1X0?ooo`00503oool0
0`000000oooo0?ooo`2o0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
001T0?ooo`030000003oool0oooo06P0oooo000D0?ooo`030000003oool0oooo0<00oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0J03o
ool001@0oooo00<000000?ooo`3oool0`03oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool0J03oool001@0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo000000070?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0J03oool0
01@0oooo0P0000330?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0G`3oool00`00
0000oooo0?ooo`1X0?ooo`00503oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0J03oool001@0oooo00<000000?ooo`3oool0c@3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo06P0oooo000D0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`1X0?ooo`00503oool00`000000oooo0?ooo`3>
0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0J03oool001@0oooo00<000000?oo
o`3oool0c`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo06P0oooo000D0?ooo`03
0000003oool0oooo0<l0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1X0?ooo`00
503oool200000=40oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1X0?ooo`00503o
ool00`000000oooo0?ooo`3@0?ooo`040000003oool0oooo0?ooo`T00000D@3oool00`000000oooo
0?ooo`1X0?ooo`00503oool00`000000oooo0?ooo`3A0?ooo`<000002@3oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo06P0oooo000D0?ooo`030000003oool0oooo0=h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo06P0oooo000D0?oo
o`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0303oool3000003d0oooo00<000000?oo
o`3oool0J03oool000@0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`3O0?ooo`03
0000003oool0oooo00X0oooo0P0000030?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0J03oool000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0>00oooo00<000000?ooo`3oool01`3oool2000000D0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`1X0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`80001o00<0
00000000O`0007l0100007l300000>40001o0`0000040000O`800000200007l00`000000001o0000
O`0i0000O`030000000007l0001o01T0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`00
00070?ooo`030000003oool0oooo0>@0oooo1000000:0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0J03oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`3c0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0J03oool000@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?<0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`1X0?ooo`001@3oool2000000<0oooo10000006
0?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1X
0?ooo`00503oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0J03oool001@0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`020?ooo`80
0000<`3oool00`000000oooo0?ooo`1X0?ooo`00503oool200000?H0oooo00@000000?ooo`000000
00000P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo06P0oooo000D0?ooo`030000
003oool0oooo0?D0oooo0P0000050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
J03oool001@0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo06T0oooo000D0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`1Y0?ooo`00503oool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0J@3oool001@0oooo00<000000?ooo`3oool0o`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo06T0oooo000D0?ooo`030000003oool0oooo0?l0oooo
0@3oool2000002/0oooo00<000000?ooo`3oool0J@3oool001@0oooo0P00003o0?ooo`@0oooo0P00
000Y0?ooo`030000003oool0oooo06T0oooo000D0?ooo`030000003oool0oooo0?l0oooo1@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo06T0oooo000D0?ooo`030000003oool0oooo
0?l0oooo1P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo06T0oooo000D0?ooo`03
0000003oool0oooo0?l0oooo1`3oool2000002D0oooo00<000000?ooo`3oool0J@3oool001@0oooo
00<000000?ooo`3oool0o`3oool90?ooo`040000003oool0oooo0?ooo`P000006@3oool00`000000
oooo0?ooo`1Y0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo0`0000080?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0J@3oool001@0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0J@3oool001@0oooo0P00003o
0?oooaP0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Y0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooaP0oooo00@000000?ooo`3oool0oooo0`00000?0?ooo`030000003oool0
oooo06T0oooo000D0?ooo`030000003oool0oooo0?l0oooo6@3oool3000000<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`1Y0?ooo`00503oool00`000000oooo0?ooo`3o0?ooob00
oooo0P00000<0?ooo`030000003oool0oooo06T0oooo000D0?ooo`030000003oool0oooo0?l0oooo
8P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06T0oooo000D0?ooo`030000003o
ool0oooo0?l0oooo8`3oool2000000T0oooo00<000000?ooo`3oool0J@3oool001@0oooo00<00000
0?ooo`3oool0o`3ooolU0?ooo`8000001`3oool00`000000oooo0?ooo`1Y0?ooo`00503oool20000
0?l0oooo:03oool2000000D0oooo00<000000?ooo`3oool0J@3oool001@0oooo00<000000?ooo`3o
ool0o`3ooolY0?ooo`H00000J`3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooiX0oooo000D0?ooo`030000003oool0oooo0?l0ooooVP3oool0
00D0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00040?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o
0?oooiX0oooo00070?ooo`040000003oool0oooo00000080001o00<000000000O`0007l0100007l3
00000?l0001oB`0007m?0?ooo`001@3oool2000000<0oooo00@000000?ooo`3oool00000o`3ooonS
0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooX@3oool0
00@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00003o0?oooj<0oooo0005
0?ooo`800000103oool200000?l0ooooY03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool000@0oooo
0P0000020?ooo`<000000`3oool5000000<0oooo0P0000020?ooo`<00000103oool300000?l0oooo
S@3oool000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000?l0ooooS03oool000<0oooo00@000000?ooo`00000000000P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3o
ool3000000H0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`000`3oool00`000000oooo0?ooo`03
0?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000`3oool200000?l0ooooS@3oool000<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooS@3oool0
00@0oooo0P0000020?ooo`D0000000@0oooo00000000000000001@3oool200000080oooo10000004
0?ooo`<00000o`3ooon<0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 .55149 L
.79762 .55947 L
.8125 .57258 L
.82738 .57002 L
.84226 .57018 L
.85714 .58421 L
.87202 .58127 L
.8869 .59136 L
.90179 .60053 L
.91667 .60061 L
.93155 .60053 L
.94643 0 L
.96131 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool06P3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`3o0?oo
ocP0oooo00<000000?ooo`3oool06P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo0?l0oooo>03oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3o
ool0G`3oool001@0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo<`3oool00`000000oooo
0?ooo`1O0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo<P3o
ool00`000000oooo0?ooo`1O0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo<P3oool00`000000oooo0?ooo`1O0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo<@3oool00`000000oooo0?ooo`1O0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo<@3oool00`000000oooo0?ooo`1O0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo<03oool00`000000oooo
0?ooo`1O0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo<03o
ool00`000000oooo0?ooo`1O0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0o`3oool_
0?ooo`030000003oool0oooo05l0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3oool_0?ooo`030000003oool0oooo05l0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo05l0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo05l0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003o
ool0oooo05l0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3oool]
0?ooo`030000003oool0oooo05l0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0o`3oool]0?ooo`030000003oool0oooo05l0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`3o0?ooob`0oooo00<000000?ooo`3oool0H03oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0H03oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0H03o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<00000
0?ooo`3oool0H03oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
obX0oooo00<000000?ooo`3oool0H03oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?ooobX0oooo00<000000?ooo`3oool0H03oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3o0?ooobX0oooo00<000000?ooo`3oool0H03oool001@0oooo0P00
000<0?ooo`030000003oool0oooo0?l0oooo:@3oool00`000000oooo0?ooo`1P0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo:@3oool00`000000oooo0?ooo`1P
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo:@3oool00`00
0000oooo0?ooo`1P0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
oooo:03oool00`000000oooo0?ooo`1P0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`1P0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0H03o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0?l0oooo9P3oool00`000000oooo0?ooo`1P0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l0o`0007l?0000
O`030000000007l0001o0140001oC`3oool000X0oooo0`0000070?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0000003o0?oooa00oooo00<000000?ooo`3o
ool0H03oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`040000
003oool0oooo0?ooo`<000003@3oool00`000000oooo0000003o0?oooa00oooo00<000000?ooo`3o
ool0H03oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<00000
0`3oool2000000X0oooo00D000000?ooo`3oool0oooo0000003o0?ooo`l0oooo00<000000?ooo`3o
ool0H03oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000003oool0oooo0600oooo
000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?l0oooo303oool00`000000oooo0?ooo`1P0?ooo`00503oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0H03oool001@0oooo0P00000N0?oo
o`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo2`3oool00`00
0000oooo0?ooo`1P0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo0600oooo000D0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0203oool200000?l0oooo2P3oool00`000000oooo
0?ooo`1P0?ooo`00503oool00`000000oooo0?ooo`0]0?ooo`800000o`3oool80?ooo`030000003o
ool0oooo0600oooo000D0?ooo`030000003oool0oooo02l0oooo0P00003o0?ooo`H0oooo00<00000
0?ooo`3oool0H03oool001@0oooo00<000000?ooo`3oool0<@3oool200000?l0oooo103oool00`00
0000oooo0?ooo`1P0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`800000o`3oool20?ooo`03
0000003oool0oooo0600oooo000D0?ooo`800000=P3oool00`000000oooo0?ooo`3n0?ooo`030000
003oool0oooo0600oooo000D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0oP3o
ool00`000000oooo0?ooo`1P0?ooo`00503oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo0?d0oooo00<000000?ooo`3oool0H03oool001@0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`3l0?ooo`030000003oool0oooo0600oooo000D0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0n`3oool00`000000oooo0?ooo`1P0?ooo`00503oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`3oool0H03oool001@0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo0600oooo000D
0?ooo`800000>`3oool00`000000oooo0?ooo`3i0?ooo`030000003oool0oooo0600oooo000D0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`1P0?oo
o`00503oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?P0oooo00<000000?ooo`3o
ool0H03oool001@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3g0?ooo`030000
003oool0oooo0600oooo000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0m`3o
ool00`000000oooo0?ooo`1P0?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo0?H0oooo00<000000?ooo`3oool0H03oool001@0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`3e0?ooo`030000003oool0oooo0640oooo000D0?ooo`800000?`3oool200000?D0
oooo00<000000?ooo`3oool0H@3oool001@0oooo00<000000?ooo`3oool0@03oool200000?<0oooo
00<000000?ooo`3oool0H@3oool001@0oooo00<000000?ooo`3oool0@P3oool200000?40oooo00<0
00000?ooo`3oool0H@3oool001@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3^
0?ooo`030000003oool0oooo0640oooo000D0?ooo`030000003oool0oooo04D0oooo0P00003^0?oo
o`030000003oool0oooo0640oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo0640oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0jP3oool00`000000oooo0?ooo`1Q0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080001o00<000000000O`0007l0100007l3000004T0001o00<000000000O`00
07l0j@0007l00`000000001o0000O`0B0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04X0oooo0P00003Y0?ooo`03
0000003oool0oooo0640oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04`0oooo0P00003W0?ooo`030000003oool0oooo0640
oooo00040?ooo`<000000`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`1Q0?ooo`001P3oool00`000000oooo
0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0><0oooo
00<000000?ooo`3oool0H@3oool001@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`3S0?ooo`030000003oool0oooo0640oooo000D0?ooo`030000003oool0oooo0500oooo00<00000
0?ooo`3oool0hP3oool00`000000oooo0?ooo`1Q0?ooo`00503oool200000580oooo00<000000?oo
o`3oool0h@3oool00`000000oooo0?ooo`1Q0?ooo`00503oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0>00oooo00<000000?ooo`3oool0H@3oool001@0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo0640oooo000D0?ooo`030000003o
ool0oooo05<0oooo1P00003L0?ooo`030000003oool0oooo0640oooo000D0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0fP3oool00`000000oooo0?ooo`1Q0?ooo`00503oool00`00
0000oooo0?ooo`1I0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`3oool0H@3oool001@0
oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo0640
oooo000D0?ooo`800000F`3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo0640oooo
000D0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?oo
o`1Q0?ooo`00503oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0=L0oooo00<00000
0?ooo`3oool0H@3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`3G0?oo
o`030000003oool0oooo0640oooo000D0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3o
ool0eP3oool00`000000oooo0?ooo`1Q0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`030000
003oool0oooo0=H0oooo00<000000?ooo`3oool0H@3oool001@0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0640oooo000D0?ooo`800000GP3oool2
00000=H0oooo00<000000?ooo`3oool0H@3oool001@0oooo00<000000?ooo`3oool0G`3oool20000
0=@0oooo00<000000?ooo`3oool0H@3oool001@0oooo00<000000?ooo`3oool0H@3oool200000=80
oooo00<000000?ooo`3oool0H@3oool001@0oooo00<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`3?0?ooo`030000003oool0oooo0640oooo000D0?ooo`030000003oool0oooo06@0oooo0P00
003?0?ooo`030000003oool0oooo0640oooo000D0?ooo`030000003oool0oooo06H0oooo00<00000
0?ooo`3oool0c03oool00`000000oooo0?ooo`1Q0?ooo`00503oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool0H@3oool001@0oooo0P00001Y0?ooo`03
0000003oool0oooo0<X0oooo00<000000?ooo`3oool0H@3oool001@0oooo00<000000?ooo`3oool0
J03oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0640oooo000D0?ooo`030000003o
ool0oooo06T0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`1Q0?ooo`00503oool0
0`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0H@3oool0
01@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo
0640oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3oool0J`3oool00`000000
oooo0?ooo`360?ooo`030000003oool0oooo0680oooo00060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0<H0oooo
00<000000?ooo`3oool0HP3oool000H0oooo00<000000?ooo`3oool00P3oool20000O`0300000000
07l0001o00@0001o0`00001/0000O`030000000007l0001o0<D0001o00<000000000O`0007l04`00
07m?0?ooo`001P3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0HP3o
ool000H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo06h0oooo0P00
00040?ooo`80000000<0oooo0000003oool0^`3oool00`000000oooo0?ooo`1R0?ooo`00103oool3
000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1`0?ooo`040000003oool0
0000000000<0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`1R0?ooo`001P3oool0
10000000oooo0?ooo`3oool4000000H0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?oo
o`1R0?ooo`00503oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0Y`3oool00`000000oooo0?ooo`1R0?ooo`00503oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo00d0oooo0P00002Y0?ooo`030000003oool0oooo0680oooo000D0?ooo`80
0000NP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000:P0oooo00<000000?ooo`3o
ool0HP3oool001@0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool000000:P0oooo00<000000?ooo`3oool0HP3oool001@0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool000000:P0oooo00<000000?ooo`3oool0HP3o
ool001@0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0
oooo00000:P0oooo00<000000?ooo`3oool0HP3oool001@0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000Y`3oool00`000000oooo0?oo
o`1R0?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00T0oooo00D00000
0?ooo`3oool0oooo0000002W0?ooo`030000003oool0oooo0680oooo000D0?ooo`030000003oool0
oooo07d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0:D0oooo00<000000?ooo`3oool0HP3oool001@0oooo0P00001o0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo
0680oooo000D0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0HP3oool001@0oooo
00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo0680oooo
000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00X0oooo0P00002H0?ooo`030000003oool0oooo0680oooo000D
0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000V03oool00`000000oooo0?ooo`1R
0?ooo`00503oool00`000000oooo0?ooo`210?ooo`8000000`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000U`3oool00`000000oooo0?ooo`1R
0?ooo`00503oool00`000000oooo0?ooo`230?ooo`<00000203oool00`000000oooo0?ooo`080?oo
o`040000003oool0oooo000009L0oooo00<000000?ooo`3oool0HP3oool001@0oooo0P0000260?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0
000009H0oooo00<000000?ooo`3oool0HP3oool001@0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0U03oool00`00
0000oooo0?ooo`1R0?ooo`00503oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0680
oooo000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0HP3oool001@0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0TP3oool00`000000oooo0?ooo`1R0?ooo`00503oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo0680oooo000D0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`1R0?ooo`00503oool200000980oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`1R0?ooo`00503oool00`000000oooo0?ooo`2B0?ooo`050000
003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000008T0
oooo00<000000?ooo`3oool0HP3oool001@0oooo00<000000?ooo`3oool0TP3oool01@000000oooo
0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000290?ooo`03
0000003oool0oooo0680oooo000D0?ooo`030000003oool0oooo09<0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000008T0oooo00<000000?ooo`3o
ool0HP3oool001@0oooo00<000000?ooo`3oool0U03oool2000000/0oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool0000008P0oooo00<000000?ooo`3oool0HP3oool000@0oooo
100000030?ooo`8000001`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000008P0oooo00<000000?ooo`3o
ool0HP3oool000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo0:80oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
08P0oooo00<000000?ooo`3oool0HP3oool000D0oooo00<000000?ooo`3oool00P3oool010000000
001o0000O`0000060000O`<00000XP0007l01@000000001o0000O`0007l0000000D0001o00<00000
0000O`0007l0Q@0007l00`000000001o0000O`0C0000Odl0oooo00060?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:80oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0HP3o
ool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0:<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`250?ooo`030000
003oool0oooo0680oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool0Q03oool00`000000oooo0?ooo`1R0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000
003oool0oooo0:<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`230?ooo`030000
003oool0oooo06<0oooo000D0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`230?ooo`030000003oool0oooo06<0oooo000D0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`220?ooo`030000003oool0
oooo06<0oooo000D0?ooo`800000Y@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0880oooo00<000000?ooo`3oool0H`3oool001@0oooo00<000000?ooo`3oool0[`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0H`3oool001@0oooo
00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`050?ooo`030000003oool0000007T0oooo
00<000000?ooo`3oool0H`3oool001@0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?oo
o`040?ooo`030000003oool0000007T0oooo00<000000?ooo`3oool0H`3oool001@0oooo00<00000
0?ooo`3oool0/03oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000N03o
ool00`000000oooo0?ooo`1S0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0
oooo06<0oooo000D0?ooo`030000003oool0oooo0;40oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0H`3oool001@0oooo00<000000?oo
o`3oool0/P3oool00`000000oooo000000070?ooo`030000003oool0oooo07@0oooo00<000000?oo
o`3oool0H`3oool001@0oooo0P00002c0?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo06<0oooo000D0?ooo`030000
003oool0oooo0;<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0000006X0oooo00<000000?ooo`3oool0H`3oool001@0oooo00<000000?ooo`3oool0_P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0000006X0oooo00<000000?ooo`3oool0H`3o
ool001@0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`000000J@3oool00`000000oooo0?ooo`1S0?ooo`00503oool00`000000oooo0?ooo`30
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo06<0oooo000D0?ooo`030000003oool0oooo0<00oooo00@000000?ooo`3oool000001`3o
ool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo06<0oooo000D0?ooo`030000003oool0
oooo0<40oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0
oooo06<0oooo000D0?ooo`800000``3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool0H`3oool001@0oooo00<000000?ooo`3oool0c@3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo000D0?ooo`030000003oool0oooo0<d0oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1S0?ooo`00503oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0H`3oool001@0oooo00<00000
0?ooo`3oool0cP3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo06<0oooo000D0?oo
o`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1S0?oo
o`00503oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3o
ool0H`3oool001@0oooo0P00003A0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
H`3oool001@0oooo00<000000?ooo`3oool0d03oool010000000oooo0?ooo`3oool9000005H0oooo
00<000000?ooo`3oool0H`3oool001@0oooo00<000000?ooo`3oool0d@3oool3000000T0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`1S0?ooo`00503oool00`000000oooo0?ooo`3N
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1S
0?ooo`00503oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo00`0oooo0`0000120?oo
o`030000003oool0oooo06<0oooo00040?ooo`@000000P3oool3000000L0oooo00<000000?ooo`3o
ool0g`3oool00`000000oooo0?ooo`0:0?ooo`8000000`3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo06<0oooo00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo00L0oooo0P0000050?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0H`3oool000D0oooo00<000000?ooo`3oool00`3o
ool20000O`030000000007l0001o00@0001o0`00003Q0000O`<00000100007l2000000P0001o00<0
00000000O`0007l0?P0007l00`000000001o0000O`0D0000Odl0oooo00060?ooo`040000003oool0
oooo0?ooo`<000001`3oool00`000000oooo0?ooo`3T0?ooo`@000002P3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo06<0oooo00070?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool0l`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo06<0oooo0004
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`3c0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0H`3oool000D0oooo0P000003
0?ooo`@000001P3oool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0H`3oool001@0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo06<0oooo000D0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3o
ool00P3oool2000003P0oooo00<000000?ooo`3oool0H`3oool001@0oooo0P00003f0?ooo`040000
003oool0000000000080oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1S0?ooo`00
503oool00`000000oooo0?ooo`3e0?ooo`8000001@3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo06<0oooo000D0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`1T0?ooo`00503oool00`000000oooo0?ooo`3m0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0I03oool001@0oooo00<000000?ooo`3oool0oP3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo06@0oooo000D0?ooo`030000003oool0oooo0?l0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1T0?ooo`00503oool00`000000oooo
0?ooo`3o0?ooo`40oooo0P00000`0?ooo`030000003oool0oooo06@0oooo000D0?ooo`800000o`3o
ool40?ooo`800000;P3oool00`000000oooo0?ooo`1T0?ooo`00503oool00`000000oooo0?ooo`3o
0?ooo`D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1T0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1T0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooo`L0oooo0P00000Z0?ooo`030000003oool0oooo06@0
oooo000D0?ooo`030000003oool0oooo0?l0oooo2@3oool010000000oooo0?ooo`3oool8000001h0
oooo00<000000?ooo`3oool0I03oool001@0oooo00<000000?ooo`3oool0o`3oool:0?ooo`<00000
203oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06@0oooo000D0?ooo`030000003o
ool0oooo0?l0oooo5P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo06@0oooo000D
0?ooo`800000o`3ooolH0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0I03oool0
01@0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`040000003oool0oooo0?ooo`<00000503oool0
0`000000oooo0?ooo`1T0?ooo`00503oool00`000000oooo0?ooo`3o0?oooaT0oooo0`0000030?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool001@0oooo00<000000?ooo`3o
ool0o`3ooolP0?ooo`8000004@3oool00`000000oooo0?ooo`1T0?ooo`00503oool00`000000oooo
0?ooo`3o0?ooob80oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1T0?ooo`00503o
ool00`000000oooo0?ooo`3o0?ooob<0oooo0P00000>0?ooo`030000003oool0oooo06@0oooo000D
0?ooo`030000003oool0oooo0?l0oooo9@3oool2000000`0oooo00<000000?ooo`3oool0I03oool0
01@0oooo0P00003o0?ooobP0oooo0P00000:0?ooo`030000003oool0oooo06@0oooo000D0?ooo`03
0000003oool0oooo0?l0oooo:@3oool;000006H0oooo000D0?ooo`030000003oool0oooo0?l0oooo
VP3oool001@0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`00503oool00`000000oooo0?ooo`3o
0?oooiX0oooo00050?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`001`3oool010000000oooo0?ooo`0000020000O`030000000007l0
001o00@0001o0`00003o0000Od/0001oC`3oool000D0oooo0P0000030?ooo`040000003oool0oooo
00000?l0ooooX`3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o
0?oooj40oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3o
oonS0?ooo`001@3oool2000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo00040?ooo`8000000P3oool3000000<0oooo1@0000030?ooo`8000000P3oool3000000@0oooo
0`00003o0?ooohd0oooo00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003oool00000
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo00000080oooo0`0000060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo00<00000
0?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o
0?ooohd0oooo00040?ooo`8000000P3oool5000000040?ooo`0000000000000000D0oooo0P000002
0?ooo`@00000103oool300000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 .55149 L
.79762 .55947 L
.8125 .57258 L
.82738 .57002 L
.84226 .57018 L
.85714 .58421 L
.87202 .58127 L
.8869 .59136 L
.90179 .60053 L
.91667 .60061 L
.93155 .60053 L
Mfstroke
.93155 .60053 m
.94626 .61803 L
s
.94643 .61803 m
.96131 0 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05@3o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01D0oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3o0?ooocd0oooo00<000000?ooo`3oool05@3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`3o0?oo
ocd0oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo0?l0oooo?@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`3o0?ooocd0oooo00<000000?ooo`3o
ool0FP3oool001@0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo
0?ooo`1J0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo=`3o
ool00`000000oooo0?ooo`1J0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo=`3oool00`000000oooo0?ooo`1J0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo=P3oool00`000000oooo0?ooo`1J0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo=P3oool00`000000oooo0?ooo`1J0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo=@3oool00`000000oooo
0?ooo`1J0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo=@3o
ool00`000000oooo0?ooo`1J0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0o`3ooold
0?ooo`030000003oool0oooo05X0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3ooold0?ooo`030000003oool0oooo05X0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3ooolc0?ooo`030000003oool0oooo05X0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`030000003oool0oooo05X0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`030000003o
ool0oooo05X0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolb
0?ooo`030000003oool0oooo05X0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0o`3ooolb0?ooo`030000003oool0oooo05X0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`3o0?oooc80oooo00<000000?ooo`3oool0FP3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3o0?oooc00oooo00<000000?ooo`3oool0F`3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooc00oooo00<000000?ooo`3oool0F`3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooc00oooo00<00000
0?ooo`3oool0F`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
obl0oooo00<000000?ooo`3oool0F`3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?ooobl0oooo00<000000?ooo`3oool0F`3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3o0?ooobl0oooo00<000000?ooo`3oool0F`3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`1K0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`1K
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo;P3oool00`00
0000oooo0?ooo`1K0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
oooo;@3oool00`000000oooo0?ooo`1K0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`1K0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooob`0oooo00<000000?ooo`3oool0F`3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0?l0oooo:`3oool00`000000oooo0?ooo`1K0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l0o`0007lD0000
O`030000000007l0001o00`0001oC`3oool000X0oooo0`0000070?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0000003o0?oooaD0oooo00<000000?ooo`3o
ool0F`3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`040000
003oool0oooo0?ooo`<000003@3oool00`000000oooo0000003o0?oooaD0oooo00<000000?ooo`3o
ool0F`3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<00000
0`3oool2000000X0oooo00D000000?ooo`3oool0oooo0000003o0?oooa@0oooo00<000000?ooo`3o
ool0F`3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooolA0?ooo`030000003oool0oooo05/0oooo
000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?l0oooo4@3oool00`000000oooo0?ooo`1K0?ooo`00503oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0F`3oool001@0oooo0P00000N0?oo
o`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`1K0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo05/0oooo000D0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0203oool200000?l0oooo3`3oool00`000000oooo
0?ooo`1K0?ooo`00503oool00`000000oooo0?ooo`0]0?ooo`800000o`3oool=0?ooo`030000003o
ool0oooo05/0oooo000D0?ooo`030000003oool0oooo02l0oooo0P00003o0?ooo`/0oooo00<00000
0?ooo`3oool0F`3oool001@0oooo00<000000?ooo`3oool0<@3oool200000?l0oooo2@3oool00`00
0000oooo0?ooo`1K0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`800000o`3oool70?ooo`03
0000003oool0oooo05/0oooo000D0?ooo`800000=P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo
00<000000?ooo`3oool0F`3oool001@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`3o0?ooo`@0oooo00<000000?ooo`3oool0F`3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool0F`3oool001@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool0F`3oool001@0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3o
ool0F`3oool001@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?ooo`40oooo
00<000000?ooo`3oool0F`3oool001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`3o0?ooo`030000003oool0oooo05/0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`3n
0?ooo`030000003oool0oooo05/0oooo000D0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0oP3oool00`000000oooo0?ooo`1K0?ooo`00503oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo0?d0oooo00<000000?ooo`3oool0F`3oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo05/0oooo000D0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool0o03oool00`000000oooo0?ooo`1K0?ooo`00503oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`3oool0F`3oool0
01@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`3k0?ooo`030000003oool0oooo
05/0oooo000D0?ooo`800000?`3oool200000?/0oooo00<000000?ooo`3oool0F`3oool001@0oooo
00<000000?ooo`3oool0@03oool200000?P0oooo00<000000?ooo`3oool0G03oool001@0oooo00<0
00000?ooo`3oool0@P3oool200000?H0oooo00<000000?ooo`3oool0G03oool001@0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo05`0oooo000D0?oo
o`030000003oool0oooo04D0oooo0P00003c0?ooo`030000003oool0oooo05`0oooo00040?ooo`@0
00000`3oool2000000L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3`0?ooo`03
0000003oool0oooo05`0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0k`3oool00`000000
oooo0?ooo`1L0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080001o00<000000000O`00
07l0100007l3000004T0001o00<000000000O`0007l0kP0007l00`000000001o0000O`0=0000Odl0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo0P00003^0?ooo`030000003oool0oooo05`0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0
oooo0P00003/0?ooo`030000003oool0oooo05`0oooo00040?ooo`<000000`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0j@3oool00`000000
oooo0?ooo`1L0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo0>P0oooo00<000000?ooo`3oool0G03oool001@0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`3X0?ooo`030000003oool0oooo05`0oooo000D
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`1L
0?ooo`00503oool200000580oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`1L0?oo
o`00503oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0>D0oooo00<000000?ooo`3o
ool0G03oool001@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3U0?ooo`030000
003oool0oooo05`0oooo000D0?ooo`030000003oool0oooo05<0oooo1P00003Q0?ooo`030000003o
ool0oooo05`0oooo000D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0g`3oool0
0`000000oooo0?ooo`1L0?ooo`00503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
0=h0oooo00<000000?ooo`3oool0G03oool001@0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`3N0?ooo`030000003oool0oooo05`0oooo000D0?ooo`800000F`3oool00`000000oooo
0?ooo`3M0?ooo`030000003oool0oooo05`0oooo000D0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0g@3oool00`000000oooo0?ooo`1L0?ooo`00503oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool0G03oool001@0oooo00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo05`0oooo000D0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`1L0?ooo`00
503oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool0
G03oool001@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3J0?ooo`030000003o
ool0oooo05`0oooo000D0?ooo`800000GP3oool200000=/0oooo00<000000?ooo`3oool0G03oool0
01@0oooo00<000000?ooo`3oool0G`3oool200000=T0oooo00<000000?ooo`3oool0G03oool001@0
oooo00<000000?ooo`3oool0H@3oool200000=L0oooo00<000000?ooo`3oool0G03oool001@0oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo05`0oooo
000D0?ooo`030000003oool0oooo06@0oooo0P00003D0?ooo`030000003oool0oooo05`0oooo000D
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`1L
0?ooo`00503oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0=00oooo00<000000?oo
o`3oool0G03oool001@0oooo0P00001Y0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3o
ool0G03oool001@0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`3?0?ooo`030000
003oool0oooo05`0oooo000D0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`1L0?ooo`00503oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo0<d0oooo00<000000?ooo`3oool0G03oool001@0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`3=0?ooo`030000003oool0oooo05`0oooo00040?ooo`@000000P3oool3000000L0
oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo05`0
oooo00060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1[0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0G03oool000H0oooo00<0
00000?ooo`3oool00P3oool20000O`030000000007l0001o00@0001o0`00001/0000O`0300000000
07l0001o0</0001o00<000000000O`0007l03@0007m?0?ooo`001P3oool010000000oooo0?ooo`3o
ool3000000L0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0<00oooo00<000000?ooo`3oool0G@3oool000H0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo06h0oooo0P0000040?ooo`80000000<0oooo0000003oool0`03o
ool00`000000oooo0?ooo`1M0?ooo`00103oool3000000<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1`0?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool0_`3o
ool00`000000oooo0?ooo`1M0?ooo`001P3oool010000000oooo0?ooo`3oool4000000H0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0[03oool00`000000oooo0?ooo`1M0?ooo`00503oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`1M
0?ooo`00503oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00d0oooo0P00002^0?oo
o`030000003oool0oooo05d0oooo000D0?ooo`800000NP3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool000000:d0oooo00<000000?ooo`3oool0G@3oool001@0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool000000:d0oooo00<000000?ooo`3oool0
G@3oool001@0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool000000:d0oooo00<000000?ooo`3oool0G@3oool001@0oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000:d0oooo00<000000?ooo`3oool0G@3o
ool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`090?ooo`050000003oool0
oooo0?ooo`000000[03oool00`000000oooo0?ooo`1M0?ooo`00503oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000002/0?ooo`030000003o
ool0oooo05d0oooo000D0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0G@3oool0
01@0oooo0P00001o0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`2Z0?ooo`030000003oool0oooo05d0oooo000D0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0:T0
oooo00<000000?ooo`3oool0G@3oool001@0oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`2L0?ooo`030000003oool0oooo05d0oooo000D0?ooo`030000003oool0oooo07l0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P00
002M0?ooo`030000003oool0oooo05d0oooo000D0?ooo`030000003oool0oooo0800oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`000000W@3oool00`000000oooo0?ooo`1M0?ooo`00503oool00`000000oooo0?ooo`210?oo
o`8000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00@000000?oo
o`3oool00000W03oool00`000000oooo0?ooo`1M0?ooo`00503oool00`000000oooo0?ooo`230?oo
o`<00000203oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000009`0oooo00<00000
0?ooo`3oool0G@3oool001@0oooo0P0000260?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0203oool01@000000oooo0?ooo`3oool0000009/0oooo00<000000?ooo`3oool0G@3oool0
01@0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`1M0?ooo`00503oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`2H0?ooo`030000003oool0oooo05d0oooo000D0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo09P0oooo
00<000000?ooo`3oool0G@3oool001@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?oo
o`1M0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo05d0oooo000D0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1M0?oo
o`00503oool200000980oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1M0?ooo`00
503oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0000008h0oooo00<000000?ooo`3oool0G@3oool001@0oooo
00<000000?ooo`3oool0TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0000002>0?ooo`030000003oool0oooo05d0oooo000D0?ooo`030000
003oool0oooo09<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0000008h0oooo00<000000?ooo`3oool0G@3oool001@0oooo00<000000?ooo`3oool0
U03oool2000000/0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000008d0
oooo00<000000?ooo`3oool0G@3oool000@0oooo100000030?ooo`8000001`3oool00`000000oooo
0?ooo`2E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000008d0oooo00<000000?ooo`3oool0G@3oool000@0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000008d0oooo00<000000?ooo`3oool0G@3oool000D0
oooo00<000000?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000XP0007l01@00
0000001o0000O`0007l0000000D0001o00<000000000O`0007l0RP0007l00`000000001o0000O`0>
0000Odl0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0:80oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool0G@3oool000L0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:<0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo05d0oooo00040?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2S0?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`1M0?ooo`00
1@3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`000000
1`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo05d0oooo000D0?ooo`030000003o
ool0oooo0:<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`290?ooo`030000003o
ool0oooo05d0oooo000D0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo05d0oooo000D0?ooo`800000Y@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0G@3oool001@0
oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool0GP3oool001@0oooo00<000000?ooo`3oool0[`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0000007h0oooo00<000000?ooo`3oool0GP3oool001@0oooo00<0
00000?ooo`3oool0/03oool00`000000oooo0?ooo`040?ooo`030000003oool0000007h0oooo00<0
00000?ooo`3oool0GP3oool001@0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`000000O@3oool00`000000oooo0?ooo`1N0?ooo`00503oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1j0?ooo`030000003oool0oooo05h0oooo000D0?ooo`030000003oool0oooo
0;40oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo07X0oooo00<00000
0?ooo`3oool0GP3oool001@0oooo00<000000?ooo`3oool0/P3oool00`000000oooo000000070?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool0GP3oool001@0oooo0P00002c0?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`03
0000003oool0oooo05h0oooo000D0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000006l0oooo00<000000?ooo`3oool0
GP3oool001@0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0000006l0oooo00<000000?ooo`3oool0GP3oool001@0oooo00<000000?ooo`3oool0_`3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000KP3oool00`000000oooo0?oo
o`1N0?ooo`00503oool00`000000oooo0?ooo`300?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo05h0oooo000D0?ooo`030000003oool0
oooo0<00oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo05h0oooo000D0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`0000001`3oool0
0`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo05h0oooo000D0?ooo`800000``3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0GP3oool001@0
oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo05h0
oooo000D0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`1N0?ooo`00503oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool0GP3oool001@0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo05h0oooo000D0?ooo`030000003oool0oooo0<l0oooo00<000000?oo
o`3oool0IP3oool00`000000oooo0?ooo`1N0?ooo`00503oool00`000000oooo0?ooo`3?0?ooo`03
0000003oool0oooo06H0oooo00<000000?ooo`3oool0GP3oool001@0oooo0P00003A0?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool0GP3oool001@0oooo00<000000?ooo`3oool0d03o
ool010000000oooo0?ooo`3oool9000005/0oooo00<000000?ooo`3oool0GP3oool001@0oooo00<0
00000?ooo`3oool0d@3oool3000000T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`1N0?ooo`00503oool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`1N0?ooo`00503oool00`000000oooo0?ooo`3O0?oo
o`030000003oool0oooo00`0oooo0`0000170?ooo`030000003oool0oooo05h0oooo00040?ooo`@0
00000P3oool3000000L0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`0:0?ooo`80
00000`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo05h0oooo00040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3P0?ooo`030000
003oool0oooo00L0oooo0P0000050?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
GP3oool000D0oooo00<000000?ooo`3oool00`3oool20000O`030000000007l0001o00@0001o0`00
003Q0000O`<00000100007l2000000P0001o00<000000000O`0007l0@`0007l00`000000001o0000
O`0?0000Odl0oooo00060?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?oo
o`3T0?ooo`@000002P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo05h0oooo0007
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo05h0oooo00040?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0GP3oool000D0oooo0P0000030?ooo`@000001P3oool00`000000oooo0?ooo`3c
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0GP3oool001@0oooo00<000000?oo
o`3oool0m03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo05h0oooo000D0?ooo`03
0000003oool0oooo0?@0oooo00<000000?ooo`3oool00P3oool2000003d0oooo00<000000?ooo`3o
ool0GP3oool001@0oooo0P00003f0?ooo`040000003oool0000000000080oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`1N0?ooo`00503oool00`000000oooo0?ooo`3e0?ooo`800000
1@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo05h0oooo000D0?ooo`030000003o
ool0oooo0?d0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1N0?ooo`00503oool0
0`000000oooo0?ooo`3m0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0GP3oool0
01@0oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
05h0oooo000D0?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`1N0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`40oooo0P00000f0?ooo`030000
003oool0oooo05h0oooo000D0?ooo`800000o`3oool40?ooo`800000<`3oool00`000000oooo0?oo
o`1O0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`1O0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`1O0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`L0
oooo0P00000_0?ooo`030000003oool0oooo05l0oooo000D0?ooo`030000003oool0oooo0?l0oooo
2@3oool010000000oooo0?ooo`3oool8000002<0oooo00<000000?ooo`3oool0G`3oool001@0oooo
00<000000?ooo`3oool0o`3oool:0?ooo`<00000203oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo05l0oooo000D0?ooo`030000003oool0oooo0?l0oooo5P3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo05l0oooo000D0?ooo`800000o`3ooolH0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0G`3oool001@0oooo00<000000?ooo`3oool0o`3ooolH0?oo
o`040000003oool0oooo0?ooo`<000006@3oool00`000000oooo0?ooo`1O0?ooo`00503oool00`00
0000oooo0?ooo`3o0?oooaT0oooo0`0000030?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0G`3oool001@0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`8000005P3oool00`000000
oooo0?ooo`1O0?ooo`00503oool00`000000oooo0?ooo`3o0?ooob80oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`1O0?ooo`00503oool00`000000oooo0?ooo`3o0?ooob<0oooo0P00
000C0?ooo`030000003oool0oooo05l0oooo000D0?ooo`030000003oool0oooo0?l0oooo9@3oool2
00000140oooo00<000000?ooo`3oool0G`3oool001@0oooo0P00003o0?ooobP0oooo0P00000?0?oo
o`030000003oool0oooo05l0oooo000D0?ooo`030000003oool0oooo0?l0oooo:@3oool;000000@0
oooo00<000000?ooo`3oool0G`3oool001@0oooo00<000000?ooo`3oool0o`3ooold0?ooo`050000
003oool0oooo0?ooo`000000H@3oool001@0oooo00<000000?ooo`3oool0o`3ooole0?ooo`040000
003oool0oooo00000640oooo000D0?ooo`030000003oool0oooo0?l0oooo=P3oool00`000000oooo
0000001Q0?ooo`001@3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo0?l0oooo=P3o
ool00`000000oooo0000001Q0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`800000H@3oool000L0oooo00@0
00000?ooo`3oool000000P0007l00`000000001o0000O`040000O`<00000o`0007lh0000O`030000
000007l0001o0100001oC`3oool000D0oooo0P0000030?ooo`040000003oool0oooo00000?l0oooo
X`3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oooj40oooo
00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooonS0?ooo`00
1@3oool2000000@0oooo0P00003o0?oooj@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo00040?oo
o`8000000P3oool3000000<0oooo1@0000030?ooo`8000000P3oool3000000@0oooo0`00003o0?oo
ohd0oooo00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`00003o0?oooh`0oooo00030?ooo`040000003oool0000000000080oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080
oooo0`0000060?ooo`030000003oool0oooo0?l0ooooRP3oool000<0oooo00<000000?ooo`3oool0
0`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000<0oooo0P00003o0?ooohd0oooo00030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?ooohd0oooo
00040?ooo`8000000P3oool5000000040?ooo`0000000000000000D0oooo0P0000020?ooo`@00000
103oool300000?l0ooooS03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 .55149 L
.79762 .55947 L
.8125 .57258 L
.82738 .57002 L
.84226 .57018 L
.85714 .58421 L
.87202 .58127 L
.8869 .59136 L
.90179 .60053 L
.91667 .60061 L
.93155 .60053 L
Mfstroke
.93155 .60053 m
.94626 .61803 L
s
.94678 .61803 m
.96131 .60969 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool01@000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`00503oool00`000000oooo0?ooo`3o0?oood80oooo00<000000?ooo`3oool0403oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`3o0?oo
od80oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool06`3oool3000001H0oooo000D0?ooo`030000003oool0oooo0?l0oooo@P3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`00503oool00`000000oooo0?ooo`3o0?oood80oooo00<000000?ooo`3o
ool0E@3oool001@0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo?@3oool00`000000oooo
0?ooo`1E0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo?03o
ool00`000000oooo0?ooo`1E0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo?03oool00`000000oooo0?ooo`1E0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo>`3oool00`000000oooo0?ooo`1E0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo>`3oool00`000000oooo0?ooo`1E0?ooo`00
503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo>P3oool00`000000oooo
0?ooo`1E0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo>P3o
ool00`000000oooo0?ooo`1E0?ooo`00503oool2000000L0oooo00<000000?ooo`3oool0o`3oooli
0?ooo`030000003oool0oooo05D0oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3oooli0?ooo`030000003oool0oooo05D0oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo05D0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo05D0oooo
000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003o
ool0oooo05D0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolg
0?ooo`030000003oool0oooo05D0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0o`3ooolg0?ooo`030000003oool0oooo05D0oooo000D0?ooo`8000002@3oool00`000000
oooo0?ooo`3o0?ooocH0oooo00<000000?ooo`3oool0EP3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool0EP3oool001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool0EP3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooocD0oooo00<00000
0?ooo`3oool0EP3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
oc@0oooo00<000000?ooo`3oool0EP3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?oooc@0oooo00<000000?ooo`3oool0EP3oool001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3o0?oooc@0oooo00<000000?ooo`3oool0EP3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo0?l0oooo<`3oool00`000000oooo0?ooo`1F0?ooo`00503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo<`3oool00`000000oooo0?ooo`1F
0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo<`3oool00`00
0000oooo0?ooo`1F0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
oooo<P3oool00`000000oooo0?ooo`1F0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0?l0oooo<P3oool00`000000oooo0?ooo`1F0?ooo`002P3oool3000000L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oooc40oooo00<000000?ooo`3oool0EP3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0?l0oooo<03oool00`000000oooo0?ooo`1F0?ooo`002`3oool20000O`030000000007l0001o
00@0001o0`00000?0000O`030000000007l0001o01<0001o00<000000000O`0007l0o`0007lI0000
O`030000000007l0001o00L0001oC`3oool000X0oooo0`0000070?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0000003o0?oooaX0oooo00<000000?ooo`3o
ool0EP3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`040000
003oool0oooo0?ooo`<000003@3oool00`000000oooo0000003o0?oooaX0oooo00<000000?ooo`3o
ool0EP3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`<00000
0`3oool2000000X0oooo00D000000?ooo`3oool0oooo0000003o0?oooaT0oooo00<000000?ooo`3o
ool0EP3oool000X0oooo100000060?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooolF0?ooo`030000003oool0oooo05H0oooo
000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?l0oooo5P3oool00`000000oooo0?ooo`1F0?ooo`00503oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?oooaD0oooo00<000000?ooo`3oool0EP3oool001@0oooo0P00000N0?oo
o`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo5@3oool00`00
0000oooo0?ooo`1F0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool0o`3ooolD0?ooo`030000003oool0oooo05H0oooo000D0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0203oool200000?l0oooo503oool00`000000oooo
0?ooo`1F0?ooo`00503oool00`000000oooo0?ooo`0]0?ooo`800000o`3ooolB0?ooo`030000003o
ool0oooo05H0oooo000D0?ooo`030000003oool0oooo02l0oooo0P00003o0?oooa00oooo00<00000
0?ooo`3oool0EP3oool001@0oooo00<000000?ooo`3oool0<@3oool200000?l0oooo3P3oool00`00
0000oooo0?ooo`1F0?ooo`00503oool00`000000oooo0?ooo`0c0?ooo`800000o`3oool<0?ooo`03
0000003oool0oooo05H0oooo000D0?ooo`800000=P3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
00<000000?ooo`3oool0EP3oool001@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo00<000000?ooo`3oool0EP3oool001@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool0EP3oool001@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool0EP3oool001@0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3o
ool0EP3oool001@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?ooo`H0oooo
00<000000?ooo`3oool0EP3oool001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`3o0?ooo`D0oooo00<000000?ooo`3oool0EP3oool001@0oooo0P00000k0?ooo`030000003oool0
oooo0?l0oooo103oool00`000000oooo0?ooo`1F0?ooo`00503oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo0?l0oooo103oool00`000000oooo0?ooo`1F0?ooo`00503oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo0`3oool00`000000oooo0?ooo`1F0?ooo`00
503oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000oooo
0?ooo`1F0?ooo`00503oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0?l0oooo0P3o
ool00`000000oooo0?ooo`1F0?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo0?l0oooo0@3oool00`000000oooo0?ooo`1F0?ooo`00503oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`1F0?ooo`00503oool2000003l0
oooo0P00003o0?ooo`030000003oool0oooo05L0oooo000D0?ooo`030000003oool0oooo0400oooo
0P00003m0?ooo`030000003oool0oooo05L0oooo000D0?ooo`030000003oool0oooo0480oooo0P00
003k0?ooo`030000003oool0oooo05L0oooo000D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0n03oool00`000000oooo0?ooo`1G0?ooo`00503oool00`000000oooo0?ooo`150?oo
o`800000n03oool00`000000oooo0?ooo`1G0?ooo`00103oool4000000<0oooo0P0000070?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0m@3oool00`000000oooo0?ooo`1G0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool0E`3oool000H0oooo
00D000000?ooo`3oool0oooo000000020000O`030000000007l0001o00@0001o0`0000190000O`03
0000000007l0001o0?<0001o00<000000000O`0007l0200007m?0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
0000l`3oool00`000000oooo0?ooo`1G0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000l@3oool00`000000
oooo0?ooo`1G0?ooo`00103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`3oool0E`3oool000H0oooo
00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`3]0?ooo`030000003oool0oooo05L0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0k@3oool00`000000oooo0?ooo`1G0?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool0E`3oool001@0oooo0P00001B0?oo
o`030000003oool0oooo0>/0oooo00<000000?ooo`3oool0E`3oool001@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`3Z0?ooo`030000003oool0oooo05L0oooo000D0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0jP3oool00`000000oooo0?ooo`1G0?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000iP3oool00`000000oooo0?ooo`1G0?ooo`00503oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool0E`3oool0
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo
05L0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0h`3oool00`000000
oooo0?ooo`1G0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0hP3oool00`000000oooo
0?ooo`1G0?ooo`00503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0>80oooo00<0
00000?ooo`3oool0E`3oool001@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`3Q
0?ooo`030000003oool0oooo05L0oooo000D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0h@3oool00`000000oooo0?ooo`1G0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo0>00oooo00<000000?ooo`3oool0E`3oool001@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo05L0oooo000D0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`1G0?ooo`00503oool2
000005h0oooo0P00003P0?ooo`030000003oool0oooo05L0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00003N0?ooo`030000003oool0oooo05L0oooo000D0?ooo`030000003oool0oooo0640
oooo0P00003L0?ooo`030000003oool0oooo05L0oooo000D0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`1G0?ooo`00503oool00`000000oooo0?oo
o`1T0?ooo`800000f@3oool00`000000oooo0?ooo`1G0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0E`3oool001@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo05L0oooo000D0?ooo`80
0000J@3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo05L0oooo000D0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`1G0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0E`3o
ool001@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0
oooo05L0oooo000D0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0dP3oool00`00
0000oooo0?ooo`1G0?ooo`00103oool400000080oooo0`0000070?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`1G0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`3A0?ooo`030000003oool0oooo05L0oooo00060?ooo`030000003oool0oooo0080oooo0P00
07l00`000000001o0000O`040000O`<00000K00007l00`000000001o0000O`3?0000O`0300000000
07l0001o00T0001oC`3oool000H0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`350?ooo`030000003o
ool0oooo05P0oooo00060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`1^0?ooo`800000103oool2000000030?ooo`000000oooo0<D0oooo00<000000?ooo`3oool0F03o
ool000@0oooo0`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool0
10000000oooo0000000000030?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0F03o
ool000H0oooo00@000000?ooo`3oool0oooo100000060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0;40oooo00<0
00000?ooo`3oool0F03oool001@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0F03oool001@0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0=0?ooo`800000/`3oool00`000000oooo0?ooo`1H0?oo
o`00503oool2000007X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000002b0?ooo`03
0000003oool0oooo05P0oooo000D0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000002b0?ooo`030000003oool0oooo05P0oooo000D0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000002b0?ooo`030000003o
ool0oooo05P0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00002b0?ooo`030000003oool0oooo05P0oooo000D0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000;40oooo00<0
00000?ooo`3oool0F03oool001@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000/@3oool00`000000oooo0?ooo`1H0?ooo`00503oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2_0?ooo`030000003oool0oooo05P0oooo000D0?ooo`800000O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0[`3oool00`00
0000oooo0?ooo`1H0?ooo`00503oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo05P0
oooo000D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0X@3oool00`000000oooo
0?ooo`1H0?ooo`00503oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000XP3oool00`000000oooo0?oo
o`1H0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool000000:80oooo00<00000
0?ooo`3oool0F03oool001@0oooo00<000000?ooo`3oool0P@3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000:40oooo00<00000
0?ooo`3oool0F03oool001@0oooo00<000000?ooo`3oool0P`3oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00002Q0?ooo`030000003oool0oooo05P0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000002P0?ooo`030000003oool0oooo05P0oooo000D0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
09h0oooo00<000000?ooo`3oool0F03oool001@0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0W@3oool00`000000
oooo0?ooo`1H0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo05P0oooo
000D0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0F03oool001@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0W03oool00`000000oooo0?ooo`1H0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool0F03oool001@0oooo0P00002B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0F03oool001@0oooo00<000000?ooo`3oool0
TP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000002C0?ooo`030000003oool0oooo05P0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
0000T`3oool00`000000oooo0?ooo`1H0?ooo`00503oool00`000000oooo0?ooo`2C0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000002C0?ooo`03
0000003oool0oooo05P0oooo000D0?ooo`030000003oool0oooo09@0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000002B0?ooo`030000003oool0oooo05P0
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000002B0?ooo`03
0000003oool0oooo05P0oooo00040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000002B0?ooo`030000003oool0oooo05P0oooo00050?ooo`030000003oool0oooo0080
oooo00@000000000O`0007l000001P0007l300000:80001o00D000000000O`0007l0001o00000005
0000O`030000000007l0001o08l0001o00<000000000O`0007l02@0007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo05P0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`1H0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0F03oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`1H0?ooo`00503oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`1H0?ooo`00503oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`1I0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo05T0oooo000D0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo05T0
oooo000D0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
000000230?ooo`030000003oool0oooo05T0oooo000D0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0103oool00`000000oooo000000230?ooo`030000003oool0oooo05T0oooo000D
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool000000880oooo00<000000?ooo`3oool0F@3oool001@0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`1I0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo05T0oooo000D0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo05T0oooo000D0?ooo`800000/`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1I0?ooo`00
503oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0000001d0?ooo`030000003oool0oooo05T0oooo000D0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000001d0?ooo`030000003o
ool0oooo05T0oooo000D0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000007<0oooo00<000000?ooo`3oool0F@3oool001@0oooo00<00000
0?ooo`3oool0`03oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`1I0?ooo`00503oool00`000000oooo0?ooo`300?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1I0?ooo`00503oool0
0`000000oooo0?ooo`310?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1I0?ooo`00503oool200000<<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`1^0?ooo`030000003oool0oooo05T0oooo000D0?ooo`030000003oool0oooo0<d0
oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1I0?ooo`00503oool00`000000oooo
0?ooo`3=0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0F@3oool001@0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo05T0oooo000D
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1I
0?ooo`00503oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0F@3oool001@0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo05T0oooo000D0?ooo`800000d@3oool00`000000oooo0?ooo`1Z0?ooo`030000
003oool0oooo05T0oooo000D0?ooo`030000003oool0oooo0=00oooo00@000000?ooo`3oool0oooo
2@00001P0?ooo`030000003oool0oooo05T0oooo000D0?ooo`030000003oool0oooo0=40oooo0`00
00090?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0F@3oool001@0oooo00<00000
0?ooo`3oool0gP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0F@3oool001@0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`0<0?oo
o`<00000C03oool00`000000oooo0?ooo`1I0?ooo`00103oool400000080oooo0`0000070?ooo`03
0000003oool0oooo0=l0oooo00<000000?ooo`3oool02P3oool2000000<0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`1I0?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`070?ooo`800000
1@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo05T0oooo00050?ooo`030000003o
ool0oooo00<0oooo0P0007l00`000000001o0000O`040000O`<00000h@0007l3000000@0001o0P00
00080000O`030000000007l0001o04P0001o00<000000000O`0007l02P0007m?0?ooo`001P3oool0
10000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0i03oool4000000X0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`1I0?ooo`001`3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`1I0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0l`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo05T0oooo0005
0?ooo`8000000`3oool4000000H0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo05T0oooo000D0?ooo`030000003oool0oooo0?@0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`1I0?ooo`00503oool00`000000oooo0?ooo`3d0?ooo`03
0000003oool0oooo0080oooo0P0000120?ooo`030000003oool0oooo05T0oooo000D0?ooo`800000
mP3oool010000000oooo0000000000020?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0F@3oool001@0oooo00<000000?ooo`3oool0m@3oool2000000D0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`1I0?ooo`00503oool00`000000oooo0?ooo`3m0?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool0F@3oool001@0oooo00<000000?ooo`3oool0o@3oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo05T0oooo000D0?ooo`030000003oool0oooo
0?h0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1I0?ooo`00503oool00`000000
oooo0?ooo`3o0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0FP3oool001@0oooo
00<000000?ooo`3oool0o`3oool10?ooo`800000>P3oool00`000000oooo0?ooo`1J0?ooo`00503o
ool200000?l0oooo103oool2000003P0oooo00<000000?ooo`3oool0FP3oool001@0oooo00<00000
0?ooo`3oool0o`3oool50?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0FP3oool0
01@0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0FP3oool001@0oooo00<000000?ooo`3oool0o`3oool70?ooo`800000=03oool00`000000
oooo0?ooo`1J0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`T0oooo00@000000?ooo`3oool0
oooo2000000X0?ooo`030000003oool0oooo05X0oooo000D0?ooo`030000003oool0oooo0?l0oooo
2P3oool3000000P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1J0?ooo`00503o
ool00`000000oooo0?ooo`3o0?oooaH0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`1J0?ooo`00503oool200000?l0oooo603oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo05X0oooo000D0?ooo`030000003oool0oooo0?l0oooo603oool010000000oooo0?ooo`3oool3
000001h0oooo00<000000?ooo`3oool0FP3oool001@0oooo00<000000?ooo`3oool0o`3ooolI0?oo
o`<000000`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05X0oooo000D0?ooo`03
0000003oool0oooo0?l0oooo803oool2000001/0oooo00<000000?ooo`3oool0FP3oool001@0oooo
00<000000?ooo`3oool0o`3ooolR0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
FP3oool001@0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`800000603oool00`000000oooo0?oo
o`1J0?ooo`00503oool00`000000oooo0?ooo`3o0?ooobD0oooo0P00000F0?ooo`030000003oool0
oooo05X0oooo000D0?ooo`800000o`3ooolX0?ooo`800000503oool00`000000oooo0?ooo`1J0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooobT0oooo2`0000090?ooo`030000003oool0oooo05X0
oooo000D0?ooo`030000003oool0oooo0?l0oooo=03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo05X0oooo000D0?ooo`030000003oool0oooo0?l0oooo=@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo05X0oooo000D0?ooo`030000003oool0oooo0?l0oooo=P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo05X0oooo00050?ooo`800000103oool20000
00L0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`030000003oool0oooo0080oooo0P00001M0?oo
o`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0o`3ooolg0?ooo`040000003oool00000000005l0oooo00070?ooo`040000003oool0
oooo00000080001o00<000000000O`0007l0100007l300000?l0001o>00007l00`000000001o0000
O`0@0000Odl0oooo00050?ooo`8000000`3oool010000000oooo0?ooo`00003o0?oooj<0oooo0007
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`00103oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0ooooX`3oool000D0oooo0P00
00040?ooo`800000o`3ooonT0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00103oool200000080
oooo0`0000030?ooo`D000000`3oool200000080oooo0`0000040?ooo`<00000o`3ooon=0?ooo`00
0`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool00000o`3ooon<0?ooo`000`3oool010000000oooo0000000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`<00000
1P3oool00`000000oooo0?ooo`3o0?ooohX0oooo00030?ooo`030000003oool0oooo00<0oooo0`00
00030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000030?ooo`800000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooon=0?ooo`00103oool2
00000080oooo1@000000103oool000000000000000050?ooo`8000000P3oool4000000@0oooo0`00
003o0?oooh`0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 432 266.991 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0 0.0206011 [
[.03869 -0.0125 -8 -9.8125 ]
[.03869 -0.0125 8 0 ]
[.20238 -0.0125 -11 -9.8125 ]
[.20238 -0.0125 11 0 ]
[.38095 -0.0125 -14 -9.8125 ]
[.38095 -0.0125 14 0 ]
[.55952 -0.0125 -14 -9.8125 ]
[.55952 -0.0125 14 0 ]
[.7381 -0.0125 -14 -9.8125 ]
[.7381 -0.0125 14 0 ]
[.91667 -0.0125 -14 -9.8125 ]
[.91667 -0.0125 14 0 ]
[1.025 0 0 -5.0625 ]
[1.025 0 70 5.0625 ]
[.01131 .10301 -6 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.03869 0 m
.03869 .00625 L
s
gsave
.03869 -0.0125 -69 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20238 0 m
.20238 .00625 L
s
gsave
.20238 -0.0125 -72 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
81.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1536) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 0 m
.55952 .00625 L
s
gsave
.55952 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2304) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3072) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -75 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3840) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
1.025 0 -61 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 11.562 moveto
(Size) show
129.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(10)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(15)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(20)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(25)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GFLOPS) show
99.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03869 .02019 m
.05357 .04843 L
.06845 .09395 L
.08333 .11053 L
.09821 .10886 L
.1131 .11798 L
.12798 .12935 L
.14286 .10372 L
.15774 .12692 L
.17262 .13409 L
.1875 .14128 L
.20238 .16148 L
.21726 .18333 L
.23214 .19126 L
.24702 .20381 L
.2619 .21244 L
.27679 .23459 L
.29167 .23469 L
.30655 .26786 L
.32143 .27125 L
.33631 .28439 L
.35119 .30765 L
.36607 .31919 L
.38095 .31064 L
.39583 .33619 L
.41071 .36002 L
.4256 .36856 L
.44048 .32055 L
.45536 .38386 L
.47024 .40542 L
.48512 .35593 L
.5 .38154 L
.51488 .43171 L
.52976 .38643 L
.54464 .43045 L
.55952 .45754 L
.5744 .43267 L
.58929 .45629 L
.60417 .47666 L
.61905 .45558 L
.63393 .47615 L
.64881 .50184 L
.66369 .49856 L
.67857 .4995 L
.69345 .5157 L
.70833 .5204 L
.72321 .51434 L
.7381 .50502 L
.75298 .53838 L
.76786 .53461 L
Mistroke
.78274 .55149 L
.79762 .55947 L
.8125 .57258 L
.82738 .57002 L
.84226 .57018 L
.85714 .58421 L
.87202 .58127 L
.8869 .59136 L
.90179 .60053 L
.91667 .60061 L
.93155 .60053 L
Mfstroke
.93155 .60053 m
.94626 .61803 L
s
.94678 .61803 m
.96131 .60969 L
.97619 .58128 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{432, 266.938},
  AnimationDisplayTime->0.043329,
  AnimationCycleOffset->-63,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000002/0oooo100000020?ooo`<00000103oool2000000@0oooo0P00000X0?ooo`@000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000:03oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P00001R0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`1O0?ooo`00503oool01@000000oooo0?ooo`000000oooo00D00000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@00000:P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo00000640
oooo000D0?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo0?oo
o`<00000103oool2000002d0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool3
000002X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool200000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001Q0?ooo`00503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
001Q0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000:`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0P00000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo
0?ooo`00001Q0?ooo`005@3oool3000000@0oooo00<000000?ooo`3oool0:@3oool4000000<0oooo
0`0000030?ooo`800000;@3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000040?ooo`<0
0000:03oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0W0?ooo`80
0000103oool2000000<0oooo100000030?ooo`800000:@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P00001R0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooom/
0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo0080oooo0P000002
0?ooo`@000000P3oool7000000030?ooo`000000000000P0oooo0`0000030?ooo`D0000000<0oooo
0000000000000P0000030?ooo`<00000103oool000/0ooooo`00001G000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000090?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02@0oooo00D000000?ooo`000000oooo
000000030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<000001@3oool001@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0903oool01@000000oooo0000003oool0000000D0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0
000000X0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo000D0?ooo`030000003oool0oooo0?l0ooooE@3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo00000002
00000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`00503oool00`000000oooo0?ooo`3o0?oo
oeD0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo01/0oooo0`00000F
0?ooo`00503oool00`000000oooo0?ooo`3o0?ooof<0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo000D0?ooo`030000003oool0oooo0?l0
ooooVP3oool001@0oooo0P0000030?ooo`030000003oool0oooo0?l0ooooU@3oool001@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooi@0oooo000D0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0o`3ooonD0?ooo`00503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0ooooT`3oool001@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3o0?oooi<0oooo000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
o`3ooonB0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooTP3o
ool001@0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooT@3oool001@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3o0?oooi40oooo000D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3ooon@0?ooo`00503oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0?l0ooooT03oool001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`3o0?oooi00oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooon?
0?ooo`00503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooS`3oool001@0
oooo0P0000090?ooo`030000003oool0oooo0?l0ooooS`3oool001@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3o0?ooohh0oooo000D0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0o`3ooon>0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0?l0ooooSP3oool001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
ohd0oooo000D0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`00
503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooS@3oool001@0oooo0P00
000<0?ooo`030000003oool0oooo0?l0ooooS03oool001@0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`3o0?oooh`0oooo000D0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0o`3ooon<0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
ooooR`3oool001@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?oooh/0oooo
000:0?ooo`<000001`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooRP3o
ool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0?l0ooooR@3oool000/0oooo0P0007l00`000000001o0000O`040000O`<000003`0007l00`00
0000001o0000O`0C0000O`030000000007l0001o0?l0001o8`0007m?0?ooo`002P3oool3000000L0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool000000?l0
ooooL`3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`040000
003oool0oooo0?ooo`<000003@3oool00`000000oooo0000003o0?ooog<0oooo000:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool3000000<0oooo0P00000:0?ooo`050000
003oool0oooo0?ooo`000000o`3ooomb0?ooo`002P3oool4000000H0oooo00<000000?ooo`3oool0
6@3oool2000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooofl0oooo
000D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?l0ooooK`3oool001@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooom^
0?ooo`00503oool2000001h0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0o`3ooom^0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool0o`3ooom]0?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00P0oooo0P00003o0?ooofd0oooo000D0?ooo`030000003oool0oooo02d0oooo0P00
003o0?ooof/0oooo000D0?ooo`030000003oool0oooo02l0oooo0P00003o0?ooofT0oooo000D0?oo
o`030000003oool0oooo0340oooo0P00003o0?ooofL0oooo000D0?ooo`030000003oool0oooo03<0
oooo0P00003o0?ooofD0oooo000D0?ooo`800000=P3oool00`000000oooo0?ooo`3o0?ooof80oooo
000D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`00503oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0?l0ooooH@3oool001@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`3o0?ooof00oooo000D0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0o`3ooomO0?ooo`00503oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0?l0ooooG`3oool001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`3o0?oooeh0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`3o0?oooed0oooo000D0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0o`3ooomM0?ooo`00503oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooG03oool001@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`3o0?oooe/0oooo000D0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0o`3ooomK0?ooo`00503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo0?l0ooooFP3oool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?oo
oeX0oooo000D0?ooo`800000?`3oool200000?l0ooooFP3oool001@0oooo00<000000?ooo`3oool0
@03oool200000?l0ooooF03oool001@0oooo00<000000?ooo`3oool0@P3oool200000?l0ooooEP3o
ool001@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oooe<0oooo000D0?oo
o`030000003oool0oooo04D0oooo0P00003o0?oooe<0oooo00040?ooo`@000000`3oool2000000L0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?oooe00oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0o`3ooom?0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
001o00<000000000O`0007l0100007l3000004T0001o00<000000000O`0007l0oP0007m?0?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1:0?ooo`800000o`3ooom>0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`800000o`3ooom<0?ooo`00
103oool3000000<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo0?l0ooooB@3oool000H0oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3o0?ooodP0oooo000D0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0o`3ooom80?ooo`00503oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo0?l0ooooA`3oool001@0oooo0P00001B0?ooo`030000003oool0oooo
0?l0ooooAP3oool001@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooodD0
oooo000D0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3ooom50?ooo`00503o
ool00`000000oooo0?ooo`1C0?ooo`H00000o`3ooom10?ooo`00503oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo0?l0oooo?`3oool001@0oooo00<000000?ooo`3oool0F@3oool00`00
0000oooo0?ooo`3o0?oooch0oooo000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0o`3oooln0?ooo`00503oool2000005/0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00503o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0oooo?@3oool001@0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`3o0?oooc`0oooo000D0?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool0o`3oooll0?ooo`00503oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo0?l0oooo>`3oool001@0oooo00<000000?ooo`3oool0G03oool00`000000oooo
0?ooo`3o0?oooc/0oooo000D0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3o
oolj0?ooo`00503oool2000005h0oooo0P00003o0?oooc/0oooo000D0?ooo`030000003oool0oooo
05l0oooo0P00003o0?ooocT0oooo000D0?ooo`030000003oool0oooo0640oooo0P00003o0?ooocL0
oooo000D0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0o`3ooold0?ooo`00503o
ool00`000000oooo0?ooo`1T0?ooo`800000o`3ooold0?ooo`00503oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo0?l0oooo<@3oool001@0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`3o0?oooc00oooo000D0?ooo`800000J@3oool00`000000oooo0?ooo`3o0?ooobl0
oooo000D0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0o`3oool_0?ooo`00503o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0?l0oooo;P3oool001@0oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0?ooo`3o0?ooobd0oooo000D0?ooo`030000003oool0oooo
06X0oooo00<000000?ooo`3oool0o`3oool]0?ooo`00103oool400000080oooo0`0000070?ooo`03
0000003oool0oooo06/0oooo00<000000?ooo`3oool0o`3oool/0?ooo`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`3o0?ooob`0oooo00060?ooo`030000003oool0oooo0080oooo0P0007l00`000000001o0000
O`040000O`<00000K00007l00`000000001o0000O`3K0000Odl0oooo00060?ooo`040000003oool0
oooo0?ooo`<000001`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0o`3ooolQ0?ooo`001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool0KP3oool2000000@0oooo0P0000000`3oool000000?ooo`3o0?ooob40oooo0004
0?ooo`<000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0700oooo00@00000
0?ooo`00000000000`3oool00`000000oooo0?ooo`3o0?ooob00oooo00060?ooo`040000003oool0
oooo0?ooo`@000001P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000D0?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000D0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool03@3oool200000?l0oooo3`3oool001@0
oooo0P00001j0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000o`3oool>0?ooo`00
503oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
o`3oool>0?ooo`00503oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`000000o`3oool>0?ooo`00503oool00`000000oooo0?ooo`1k0?ooo`030000003oool0
oooo00X0oooo00@000000?ooo`3oool00000o`3oool>0?ooo`00503oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000003o0?ooo`d0oooo000D
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3o
ool000000?l0oooo3@3oool001@0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool;0?ooo`00503oool20000
07l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0?l0oooo2`3oool001@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0?`0oooo000D0?ooo`030000003oool0oooo07l0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P00
003m0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool000000?d0oooo000D0?oo
o`030000003oool0oooo0840oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`00003l0?ooo`00503oool00`000000oooo0?ooo`230?oo
o`<00000203oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo00000?`0oooo000D0?oo
o`800000QP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000003k0?ooo`00503oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3i0?ooo`00503oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`3h0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3h0?ooo`00503oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3g0?ooo`00503oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`3g0?ooo`00503oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0>d0oooo000D0?ooo`800000TP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3]0?ooo`00
503oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000
oooo0?ooo`050?ooo`030000003oool000000>h0oooo000D0?ooo`030000003oool0oooo0980oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
0000kP3oool001@0oooo00<000000?ooo`3oool0T`3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`000000kP3oool001@0oooo00<000000?ooo`3oool0
U03oool2000000/0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000>d0
oooo00040?ooo`@000000`3oool2000000L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000003]0?ooo`00
103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0XP3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000k@3oool000D0
oooo00<000000?ooo`3oool00P3oool010000000001o0000O`0000060000O`<00000XP0007l01@00
0000001o0000O`0007l0000000D0001o00<000000000O`0007l0V`0007m?0?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2R
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`3Z0?ooo`001`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0X`3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0>X0oooo00040?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2S0?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool0j@3oool000D0oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
j@3oool001@0oooo00<000000?ooo`3oool0X`3oool00`000000oooo000000070?ooo`030000003o
ool0oooo0>T0oooo000D0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3X0?ooo`00503oool200000:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3X0?ooo`00503oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0gP3oool001@0oooo00<000000?ooo`3oool0[`3oool00`000000oooo
0?ooo`050?ooo`030000003oool000000=l0oooo000D0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0103oool00`000000oooo0000003O0?ooo`00503oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000003N0?ooo`00503oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3K0?ooo`00503oool00`000000oooo0?ooo`2a0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`3K0?ooo`00503oool00`000000oooo0?ooo`2b0?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool0fP3oool001@0oooo0P00002c0?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3?0?ooo`00
503oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0000003@0?ooo`00503oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`000000d03oool001@0oooo00<000000?ooo`3oool0_`3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000c`3oool001@0oooo00<00000
0?ooo`3oool0`03oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0c03o
ool001@0oooo00<000000?ooo`3oool0`03oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo0</0oooo000D0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`0000001`3oool0
0`000000oooo0?ooo`3;0?ooo`00503oool200000<<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3:0?ooo`00503oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo0<T0
oooo000D0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0b@3oool001@0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`380?ooo`00503oool00`000000oooo0?ooo`3>
0?ooo`030000003oool0oooo0<P0oooo000D0?ooo`030000003oool0oooo0<l0oooo00<000000?oo
o`3oool0a`3oool001@0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`370?ooo`00
503oool200000=40oooo00<000000?ooo`3oool0aP3oool001@0oooo00<000000?ooo`3oool0d03o
ool010000000oooo0?ooo`3oool900000;`0oooo000D0?ooo`030000003oool0oooo0=40oooo0`00
00090?ooo`030000003oool0oooo0;T0oooo000D0?ooo`030000003oool0oooo0=h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`2V0?ooo`00503oool00`000000oooo0?ooo`3O0?oo
o`030000003oool0oooo00`0oooo0`00002X0?ooo`00103oool400000080oooo0`0000070?ooo`03
0000003oool0oooo0=l0oooo00<000000?ooo`3oool02P3oool2000000<0oooo00<000000?ooo`3o
ool0Y@3oool000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0>00oooo00<000000?ooo`3oool01`3oool2000000D0oooo00<000000?ooo`3oool0
Y@3oool000D0oooo00<000000?ooo`3oool00`3oool20000O`030000000007l0001o00@0001o0`00
003Q0000O`<00000100007l2000000P0001o00<000000000O`0007l0E@0007m?0?ooo`001P3oool0
10000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0i03oool4000000X0oooo00<0
00000?ooo`3oool0Y03oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`3c0?ooo`030000003oool0oooo0:<0oooo00040?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo0:<0oooo0005
0?ooo`8000000`3oool4000000H0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`2S
0?ooo`00503oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo0:80oooo000D0?ooo`03
0000003oool0oooo0?@0oooo00<000000?ooo`3oool00P3oool2000009h0oooo000D0?ooo`800000
mP3oool010000000oooo0000000000020?ooo`030000003oool0oooo09/0oooo000D0?ooo`030000
003oool0oooo0?D0oooo0P0000050?ooo`030000003oool0oooo09X0oooo000D0?ooo`030000003o
ool0oooo0?d0oooo00<000000?ooo`3oool0V@3oool001@0oooo00<000000?ooo`3oool0o@3oool0
0`000000oooo0?ooo`2I0?ooo`00503oool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo
09P0oooo000D0?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3oool0U`3oool001@0oooo
00<000000?ooo`3oool0o`3oool10?ooo`800000U`3oool001@0oooo0P00003o0?ooo`@0oooo0P00
002E0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool0TP3oool0
01@0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo0940oooo000D0?ooo`03
0000003oool0oooo0?l0oooo1`3oool200000940oooo000D0?ooo`030000003oool0oooo0?l0oooo
2@3oool010000000oooo0?ooo`3oool8000008D0oooo000D0?ooo`030000003oool0oooo0?l0oooo
2P3oool3000000P0oooo00<000000?ooo`3oool0PP3oool001@0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`030000003oool0oooo0840oooo000D0?ooo`800000o`3ooolH0?ooo`030000003oool0
oooo0800oooo000D0?ooo`030000003oool0oooo0?l0oooo603oool010000000oooo0?ooo`3oool3
000002<0oooo00<000000?ooo`3oool0E@3oool001@0oooo00<000000?ooo`3oool0o`3ooolI0?oo
o`<000000`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo05D0oooo000D0?ooo`03
0000003oool0oooo0?l0oooo803oool2000001l0oooo00<000000?ooo`3oool0EP3oool001@0oooo
00<000000?ooo`3oool0o`3ooolR0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
EP3oool001@0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`8000006`3oool00`000000oooo0?oo
o`1G0?ooo`00503oool00`000000oooo0?ooo`3o0?ooobD0oooo0P00000I0?ooo`030000003oool0
oooo05L0oooo000D0?ooo`800000o`3ooolX0?ooo`8000005P3oool00`000000oooo0?ooo`1H0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooobT0oooo2`00000;0?ooo`030000003oool0oooo05P0
oooo000D0?ooo`030000003oool0oooo0?l0oooo=03oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo05T0oooo000D0?ooo`030000003oool0oooo0?l0oooo=@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo05T0oooo000D0?ooo`030000003oool0oooo0?l0oooo=P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo05X0oooo00050?ooo`800000103oool20000
00L0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`030000003oool0oooo0080oooo0P00001M0?oo
o`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0o`3ooolg0?ooo`040000003oool00000000005l0oooo00070?ooo`040000003oool0
oooo00000080001o00<000000000O`0007l0100007l300000?l0001o>00007l00`000000001o0000
O`0@0000Odl0oooo00050?ooo`8000000`3oool010000000oooo0?ooo`00003o0?oooj<0oooo0007
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`00103oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0ooooX`3oool000D0oooo0P00
00040?ooo`800000o`3ooonT0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00103oool200000080
oooo0`0000030?ooo`D000000`3oool200000080oooo0`0000040?ooo`<00000o`3ooon=0?ooo`00
0`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool00000o`3ooon<0?ooo`000`3oool010000000oooo0000000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`<00000
1P3oool00`000000oooo0?ooo`3o0?ooohX0oooo00030?ooo`030000003oool0oooo00<0oooo0`00
00030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000030?ooo`800000o`3ooon=0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooon=0?ooo`00103oool2
00000080oooo1@000000103oool000000000000000050?ooo`8000000P3oool4000000@0oooo0`00
003o0?oooh`0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.938, 0}} -> {-3.94637, -3.64741, \
0.197303, 0.14252}}]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 937}},
ScreenStyleEnvironment->"Working",
WindowSize->{956, 834},
WindowMargins->{{Automatic, 165}, {Automatic, 19}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 507, 15, 95, "Text"],
Cell[2264, 68, 166, 2, 104, "Input"],
Cell[2433, 72, 65, 1, 35, "Input"],
Cell[2501, 75, 65, 2, 35, "Input"],
Cell[2569, 79, 109, 2, 38, "Text"],

Cell[CellGroupData[{
Cell[2703, 85, 400, 10, 196, "Input"],

Cell[CellGroupData[{
Cell[3128, 99, 32020, 892, 275, 14157, 665, "GraphicsData", "PostScript", \
"Graphics"],
Cell[35151, 993, 32395, 895, 275, 14162, 665, "GraphicsData", "PostScript", \
"Graphics"],
Cell[67549, 1890, 33101, 904, 275, 14167, 665, "GraphicsData", "PostScript", \
"Graphics"],
Cell[100653, 2796, 33556, 910, 275, 14172, 665, "GraphicsData", "PostScript", \
"Graphics"],
Cell[134212, 3708, 33642, 911, 275, 14177, 665, "GraphicsData", "PostScript", \
"Graphics"],
Cell[167857, 4621, 33756, 912, 275, 14182, 665, "GraphicsData", "PostScript", \
"Graphics"],
Cell[201616, 5535, 33927, 914, 275, 14187, 665, "GraphicsData", "PostScript", \
"Graphics"],
Cell[235546, 6451, 33968, 914, 275, 14192, 665, "GraphicsData", "PostScript", \
"Graphics"],
Cell[269517, 7367, 34200, 917, 275, 14197, 665, "GraphicsData", "PostScript", \
"Graphics"],
Cell[303720, 8286, 34448, 920, 275, 14202, 665, "GraphicsData", "PostScript", \
"Graphics"],
Cell[338171, 9208, 34486, 921, 275, 14207, 665, "GraphicsData", "PostScript", \
"Graphics"],
Cell[372660, 10131, 34782, 924, 275, 14212, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[407445, 11057, 35192, 929, 275, 14217, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[442640, 11988, 35432, 932, 275, 14222, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[478075, 12922, 35619, 934, 275, 14227, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[513697, 13858, 35786, 936, 275, 14232, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[549486, 14796, 36034, 939, 275, 14237, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[585523, 15737, 36189, 941, 275, 14242, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[621715, 16680, 36538, 945, 275, 14247, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[658256, 17627, 36847, 949, 275, 14252, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[695106, 18578, 36998, 951, 275, 14257, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[732107, 19531, 37299, 955, 275, 14262, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[769409, 20488, 37579, 958, 275, 14267, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[806991, 21448, 37665, 959, 275, 14272, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[844659, 22409, 37954, 963, 275, 14277, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[882616, 23374, 38396, 968, 275, 14282, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[921015, 24344, 38701, 972, 275, 14287, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[959719, 25318, 38706, 972, 275, 14292, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[998428, 26292, 39314, 979, 275, 14297, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1037745, 27273, 39347, 979, 275, 14302, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1077095, 28254, 39150, 977, 275, 14307, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1116248, 29233, 39386, 980, 275, 14312, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1155637, 30215, 39946, 987, 275, 14317, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1195586, 31204, 40173, 989, 275, 14322, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1235762, 32195, 40551, 994, 275, 14327, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1276316, 33191, 41050, 1000, 275, 14332, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1317369, 34193, 41197, 1002, 275, 14337, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1358569, 35197, 41429, 1005, 275, 14342, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1400001, 36204, 41721, 1008, 275, 14347, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1441725, 37214, 41791, 1009, 275, 14352, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1483519, 38225, 41999, 1012, 275, 14357, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1525521, 39239, 42323, 1015, 275, 14362, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1567847, 40256, 42511, 1018, 275, 14367, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1610361, 41276, 42515, 1018, 275, 14371, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1652879, 42296, 42677, 1020, 275, 14375, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1695559, 43318, 42835, 1022, 275, 14379, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1738397, 44342, 42759, 1021, 275, 14384, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1781159, 45365, 42788, 1021, 275, 14389, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1823950, 46388, 43101, 1025, 275, 14394, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1867054, 47415, 43324, 1027, 275, 14399, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1910381, 48444, 43520, 1030, 275, 14404, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1953904, 49476, 43824, 1033, 275, 14409, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1997731, 50511, 44076, 1036, 275, 14414, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2041810, 51549, 44162, 1037, 275, 14419, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2085975, 52588, 44167, 1037, 275, 14424, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2130145, 53627, 44339, 1040, 275, 14429, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2174487, 54669, 44420, 1040, 275, 14434, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2218910, 55711, 44575, 1042, 275, 14439, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2263488, 56755, 44726, 1044, 275, 14444, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2308217, 57801, 44824, 1045, 275, 14449, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2353044, 58848, 44845, 1045, 275, 14454, 665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2397892, 59895, 45117, 1052, 275, 14495, 669, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2443012, 60949, 45272, 1054, 275, 14500, 669, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2488287, 62005, 40345, 993, 275, 14505, 669, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

